@@ -6,15 +6,16 @@ AUTHORS:
 - Travis Scrimshaw (2013-09-06): Initial version
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2013 Travis Scrimshaw <tscrim at ucdavis.edu>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
+from six import iteritems
 
 from sage.misc.cachefunc import cached_method
 from sage.misc.latex import latex
@@ -31,8 +32,6 @@ from sage.rings.polynomial.polynomial_ring import PolynomialRing_general
 from sage.rings.polynomial.multi_polynomial_ring_base import MPolynomialRing_base
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 
-import six
-
 
 def repr_from_monomials(monomials, term_repr, use_latex=False):
     r"""
@@ -120,7 +119,7 @@ def repr_from_monomials(monomials, term_repr, use_latex=False):
             return '0'
 
     ret = ''
-    for m,c in monomials:
+    for m, c in monomials:
         # Get the monomial portion
         term = term_repr(m)
 
@@ -157,6 +156,7 @@ def repr_from_monomials(monomials, term_repr, use_latex=False):
             ret = term
     return ret
 
+
 class DifferentialWeylAlgebraElement(AlgebraElement):
     """
     An element in a differential Weyl algebra.
@@ -285,7 +285,7 @@ class DifferentialWeylAlgebraElement(AlgebraElement):
             sage: dy - (3*x - z)*dx
             dy + z*dx - 3*x*dx
         """
-        return self.__class__(self.parent(), {m:-c for m,c in six.iteritems(self.__monomials)})
+        return self.__class__(self.parent(), {m:-c for m, c in iteritems(self.__monomials)})
 
     def _add_(self, other):
         """
@@ -303,7 +303,7 @@ class DifferentialWeylAlgebraElement(AlgebraElement):
 
         d = copy(self.__monomials)
         zero = self.parent().base_ring().zero()
-        for m,c in six.iteritems(other.__monomials):
+        for m, c in iteritems(other.__monomials):
             d[m] = d.get(m, zero) + c
             if d[m] == zero:
                 del d[m]
@@ -336,7 +336,7 @@ class DifferentialWeylAlgebraElement(AlgebraElement):
                 for i,p in enumerate(ml[1]):
                     for j in range(p):
                         next = []
-                        for m,c in cur: # Distribute and apply the derivative
+                        for m, c in cur:  # Distribute and apply the derivative
                             diff = list(m[1])
                             diff[i] += 1
                             next.append( ((m[0], tuple(diff)), c) )
@@ -347,7 +347,7 @@ class DifferentialWeylAlgebraElement(AlgebraElement):
                                 next.append( ((tuple(poly), m[1]), c) )
                         cur = next
 
-                for m,c in cur:
+                for m, c in cur:
                     # multiply the resulting term by the other term
                     m = (add_tuples(ml[0], m[0]), add_tuples(mr[1], m[1]))
                     d[m] = d.get(m, zero) + c
@@ -464,11 +464,11 @@ class DifferentialWeylAlgebraElement(AlgebraElement):
             sage: W.<x,y,z> = DifferentialWeylAlgebra(QQ)
             sage: dx,dy,dz = W.differentials()
             sage: elt = dy - (3*x - z)*dx + 1
-            sage: elt.support()
-            [((0, 0, 0), (0, 1, 0)),
-             ((1, 0, 0), (1, 0, 0)),
-             ((0, 0, 0), (0, 0, 0)),
-             ((0, 0, 1), (1, 0, 0))]
+            sage: sorted(elt.support())
+            [((0, 0, 0), (0, 0, 0)),
+            ((0, 0, 0), (0, 1, 0)),
+            ((0, 0, 1), (1, 0, 0)),
+            ((1, 0, 0), (1, 0, 0))]
         """
         return list(self.__monomials)
 
@@ -659,7 +659,7 @@ class DifferentialWeylAlgebra(Algebra, UniqueRepresentation):
             return self.element_class(self, {i: R(c) for i,c in x if R(c) != zero})
         x = self._poly_ring(x)
         return self.element_class(self, {(tuple(m), t): c
-                                         for m,c in six.iteritems(x.dict())})
+                                         for m, c in iteritems(x.dict())})
 
     def _coerce_map_from_(self, R):
         """
@@ -760,7 +760,7 @@ class DifferentialWeylAlgebra(Algebra, UniqueRepresentation):
             [1, x, y, dx, dy, x^2, x*y, x*dx, x*dy, y^2, y*dx, y*dy,
              dx^2, dx*dy, dy^2, x^3, x^2*y, x^2*dx, x^2*dy, x*y^2]
             sage: dx, dy = W.differentials()
-            sage: (dx*x).monomials()
+            sage: sorted((dx*x).monomials(), key=str)
             [1, x*dx]
             sage: B[(x*y).support()[0]]
             x*y
@@ -791,7 +791,7 @@ class DifferentialWeylAlgebra(Algebra, UniqueRepresentation):
             sage: W.algebra_generators()
             Finite family {'x': x, 'y': y, 'z': z, 'dx': dx, 'dy': dy, 'dz': dz}
         """
-        d = {x: self.gen(i) for i,x in enumerate(self.variable_names())}
+        d = {x: self.gen(i) for i, x in enumerate(self.variable_names())}
         return Family(self.variable_names(), lambda x: d[x])
 
     @cached_method
@@ -810,7 +810,7 @@ class DifferentialWeylAlgebra(Algebra, UniqueRepresentation):
             Finite family {'x': x, 'y': y, 'z': z}
         """
         N = self.variable_names()[:self._n]
-        d = {x: self.gen(i) for i,x in enumerate(N) }
+        d = {x: self.gen(i) for i, x in enumerate(N)}
         return Family(N, lambda x: d[x])
 
     @cached_method
@@ -829,7 +829,7 @@ class DifferentialWeylAlgebra(Algebra, UniqueRepresentation):
             Finite family {'dx': dx, 'dy': dy, 'dz': dz}
         """
         N = self.variable_names()[self._n:]
-        d = {x: self.gen(self._n+i) for i,x in enumerate(N) }
+        d = {x: self.gen(self._n+i) for i, x in enumerate(N)}
         return Family(N, lambda x: d[x])
 
     def gen(self, i):
@@ -866,7 +866,7 @@ class DifferentialWeylAlgebra(Algebra, UniqueRepresentation):
             sage: W.ngens()
             6
         """
-        return self._n*2
+        return self._n * 2
 
     @cached_method
     def one(self):
