@@ -3,7 +3,7 @@ Calculus functions
 """
 from __future__ import absolute_import
 from sage.matrix.all import matrix
-from sage.matrix.matrix import is_Matrix
+from sage.structure.element import is_Matrix
 from sage.structure.element import is_Vector
 from sage.symbolic.ring import is_SymbolicVariable
 from .functional import diff
