@@ -1,15 +1,15 @@
 r"""
 Finite Complex Reflection Groups
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2011-2015 Christian Stump <christian.stump at gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 from sage.misc.abstract_method import abstract_method
 from sage.misc.all import prod
@@ -17,6 +17,7 @@ from sage.misc.cachefunc import cached_method
 from sage.categories.category_with_axiom import CategoryWithAxiom
 from sage.categories.coxeter_groups import CoxeterGroups
 
+
 class FiniteComplexReflectionGroups(CategoryWithAxiom):
     r"""
     The category of finite complex reflection groups.
@@ -234,7 +235,7 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                               "the degrees should be larger than 2")
             tester.assertEqual(len(degrees), self.rank(),
                                "the number of degrees should coincide with the rank")
-            tester.assertEqual(sum(d-1 for d in degrees), self.number_of_reflections(),
+            tester.assertEqual(sum(d - 1 for d in degrees), self.number_of_reflections(),
                                "the sum of the degrees should be consistent with the number of reflections")
 
         def _test_codegrees(self, **options):
@@ -289,7 +290,7 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                               "the codegrees should be nonnegative")
             tester.assertEqual(len(codegrees), self.rank(),
                                "the number of codegrees should coincide with the rank")
-            tester.assertEqual(sum(d+1 for d in codegrees),
+            tester.assertEqual(sum(d + 1 for d in codegrees),
                                self.number_of_reflection_hyperplanes(),
                                "the sum of the codegrees should be consistent with the number of reflection hyperplanes")
 
@@ -323,7 +324,7 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                 15
             """
             from sage.rings.all import ZZ
-            return ZZ.sum(codeg+1 for codeg in self.codegrees())
+            return ZZ.sum(codeg + 1 for codeg in self.codegrees())
 
         @cached_method
         def number_of_reflections(self):
@@ -357,7 +358,7 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                 15
             """
             from sage.rings.all import ZZ
-            return ZZ.sum(deg-1 for deg in self.degrees())
+            return ZZ.sum(deg - 1 for deg in self.degrees())
 
         @cached_method
         def rank(self):
@@ -522,7 +523,7 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                 [E(4)    1]
             """
             from sage.matrix.all import Matrix
-            return Matrix( list(self.independent_roots()) ).inverse()
+            return Matrix(list(self.independent_roots())).inverse()
 
     class ElementMethods:
 
@@ -605,7 +606,7 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
             """
             return self.to_matrix().trace()
 
-        #@cached_in_parent_method
+        # @cached_in_parent_method
         def reflection_length(self, in_unitary_group=False):
             r"""
             Return the reflection length of ``self``.
@@ -724,17 +725,20 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                 else:
                     cs = list(c)
                 l = cs[0].reflection_length(in_unitary_group=True)
-                f = lambda pi: any(pi.reflection_length(in_unitary_group=True)
-                                   + (c*pi**-1).reflection_length(in_unitary_group=True) == l
-                                   for c in cs)
+
+                def f(pi):
+                    return any(pi.reflection_length(in_unitary_group=True)
+                               + (c * pi**-1).reflection_length(in_unitary_group=True) == l
+                               for c in cs)
                 # first computing the conjugacy classes only needed if the
                 #   interaction with gap3 is slow due to a bug
-                #self.conjugacy_classes()
+                # self.conjugacy_classes()
                 return filter(f, self)
 
             # TODO: have a cached and an uncached version
             @cached_method
-            def noncrossing_partition_lattice(self, c=None, L=None, in_unitary_group=False):
+            def noncrossing_partition_lattice(self, c=None, L=None,
+                                              in_unitary_group=False):
                 r"""
                 Return the interval `[1,c]` in the absolute order of
                 ``self`` as a finite lattice.
@@ -759,6 +763,10 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
 
                 EXAMPLES::
 
+                    sage: W = SymmetricGroup(4)
+                    sage: W.noncrossing_partition_lattice()
+                    Finite lattice containing 14 elements
+
                     sage: W = WeylGroup(['G', 2])
                     sage: W.noncrossing_partition_lattice()
                     Finite lattice containing 8 elements
@@ -785,7 +793,7 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
 
                 R = self.reflections()
                 if L is None:
-                    L = self.elements_below_coxeter_element(c=c)
+                    L = list(self.elements_below_coxeter_element(c=c))
                     try:
                         if c.is_coxeter_element():
                             smart_covers = in_unitary_group = True
@@ -797,13 +805,13 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                 if smart_covers:
                     for pi in L:
                         for t in R:
-                            tau = pi*t
+                            tau = pi * t
                             if tau in L and ref_lens[pi] + 1 == ref_lens[tau]:
-                                rels.append((pi,tau))
+                                rels.append((pi, tau))
                 else:
-                    rels = [(pi,tau) for pi in L for tau in L
-                            if ref_lens[pi] + ref_lens[pi.inverse()*tau] == ref_lens[tau]]
-                P = Poset((L,rels), cover_relations=smart_covers, facade=True)
+                    rels = [(pi, tau) for pi in L for tau in L
+                            if ref_lens[pi] + ref_lens[pi.inverse() * tau] == ref_lens[tau]]
+                P = Poset((L, rels), cover_relations=smart_covers, facade=True)
                 if P.is_lattice():
                     return LatticePoset(P)
                 else:
@@ -868,12 +876,12 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                 chain = next(iter)
                 while len(chain) <= m:
                     chain.append(c)
-                    for i in range(len(chain)-1, 0, -1):
-                        chain[i] = chain[i-1]**-1 * chain[i]
+                    for i in range(len(chain) - 1, 0, -1):
+                        chain[i] = chain[i - 1]**-1 * chain[i]
                     k = m + 1 - len(chain)
-                    for positions in Combinations(range(m+1),k):
+                    for positions in Combinations(range(m + 1), k):
                         ncm = []
-                        for l in range(m+1):
+                        for l in range(m + 1):
                             if l in positions:
                                 ncm.append(one)
                             else:
@@ -1255,4 +1263,3 @@ class FiniteComplexReflectionGroups(CategoryWithAxiom):
                     """
                     return self.fuss_catalan_number(1, positive=positive,
                                                     polynomial=polynomial)
-
