@@ -18,6 +18,7 @@ Here is some terminology used in this file:
 
 from sage.misc.abstract_method import abstract_method
 from sage.categories.category_with_axiom import CategoryWithAxiom
+from sage.plot.plot import graphics_array
 
 class FinitePosets(CategoryWithAxiom):
     r"""
@@ -466,15 +467,18 @@ class FinitePosets(CategoryWithAxiom):
 
         def birational_free_labelling(self, linear_extension=None,
                                       prefix='x', base_field=None,
-                                      reduced=False, addvars=None):
+                                      reduced=False, addvars=None,
+                                      labels=None,
+                                      min_label=None,
+                                      max_label=None):
             r"""
             Return the birational free labelling of ``self``.
 
             Let us hold back defining this, and introduce birational
             toggles and birational rowmotion first. These notions have
             been introduced in [EP2013]_ as generalizations of the notions
-            of toggles (:meth:`order_ideal_toggle`) and :meth:`rowmotion
-            <rowmotion>` on order ideals of a finite poset. They
+            of toggles (:meth:`~sage.categories.posets.Posets.ParentMethods.order_ideal_toggle`) 
+            and :meth:`rowmotion <rowmotion>` on order ideals of a finite poset. They
             have been studied further in [GR2013]_.
 
             Let `\mathbf{K}` be a field, and `P` be a finite poset. Let
@@ -595,6 +599,23 @@ class FinitePosets(CategoryWithAxiom):
               names of extra variables to be adjoined to the ground
               field (these don't have an effect on the labels)
 
+            - ``labels`` -- (default: ``'x'``) Either a function
+              that takes an element of the poset and returns a name
+              for the indeterminate corresponding to that element,
+              or a string containing a comma-separated list of
+              indeterminates that will be assigned to elements in
+              the order of ``linear_extension``. If the
+              list contains more indeterminates than needed, the
+              excess will be ignored. If it contains too few, then
+              the needed indeterminates will be constructed from
+              ``prefix``.
+
+            - ``min_label`` -- (default: ``'a'``) a string to be
+              used as the label for the element `0` of `\widehat{P}`
+
+            - ``max_label`` -- (default: ``'b'``) a string to be
+              used as the label for the element `1` of `\widehat{P}`
+
             OUTPUT:
 
             The birational free labelling of the poset ``self`` and the
@@ -649,6 +670,38 @@ class FinitePosets(CategoryWithAxiom):
                 sage: l[1][2]
                 x3
 
+            Illustrating labelling with a function::
+
+                sage: P = posets.ChainPoset(2).product(posets.ChainPoset(2))
+                sage: l = P.birational_free_labelling(labels=lambda e : 'x_' + str(e[0]) + str(e[1]))
+                sage: sorted(l[1].items())
+                [((0, 0), x_00), ((0, 1), x_01), ((1, 0), x_10), ((1, 1), x_11)]
+                sage: l[2]
+                a
+
+            The same, but with ``min_label`` and ``max_label`` provided::
+
+                sage: P = posets.ChainPoset(2).product(posets.ChainPoset(2))
+                sage: l = P.birational_free_labelling(labels=lambda e : 'x_' + str(e[0]) + str(e[1]), min_label="lambda", max_label="mu")
+                sage: sorted(l[1].items())
+                [((0, 0), x_00), ((0, 1), x_01), ((1, 0), x_10), ((1, 1), x_11)]
+                sage: l[2]
+                lambda
+                sage: l[3]
+                mu
+
+            Illustrating labelling with a comma separated list of labels::
+
+                sage: l = P.birational_free_labelling(labels='w,x,y,z')
+                sage: sorted(l[1].items())
+                [((0, 0), w), ((0, 1), x), ((1, 0), y), ((1, 1), z)]
+                sage: l = P.birational_free_labelling(labels='w,x,y,z,m')
+                sage: sorted(l[1].items())
+                [((0, 0), w), ((0, 1), x), ((1, 0), y), ((1, 1), z)]
+                sage: l = P.birational_free_labelling(labels='w')
+                sage: sorted(l[1].items())
+                [((0, 0), w), ((0, 1), x1), ((1, 0), x2), ((1, 1), x3)]
+
             Illustrating the warning about facade::
 
                 sage: P = Poset({1: [2, 3]}, facade=False)
@@ -779,6 +832,11 @@ class FinitePosets(CategoryWithAxiom):
                  {},
                  a,
                  b)
+                sage: P.birational_free_labelling(labels="x,y,z", min_label="spam", max_label="eggs")
+                (Fraction Field of Multivariate Polynomial Ring in spam, eggs over Rational Field,
+                 {},
+                 spam,
+                 eggs)
             """
             if base_field is None:
                 from sage.rings.rational_field import QQ
@@ -786,21 +844,29 @@ class FinitePosets(CategoryWithAxiom):
             if linear_extension is None:
                 linear_extension = self.linear_extension()
             n = self.cardinality()
-            varstring = ""
-            for i in range(1, n + 1):
-                varstring += prefix + str(i) + ','
-            if reduced:
-                varstring = varstring[:-1]
+            label_list = []
+            if labels:
+                if callable(labels):
+                    label_list = [labels(e) for e in linear_extension]
+                else:
+                    label_list = labels.split(',')
+                    if len(label_list) > n:
+                        label_list = label_list[:n]
+                    elif len(label_list) < n:
+                        label_list += [prefix + str(i) for i in range(1, n + 1 - len(label_list))]
             else:
-                varstring = 'a,' + varstring + 'b'
+                label_list = [prefix + str(i) for i in range(1, n + 1)]
+            if not reduced:
+                if min_label is None:
+                    min_label = 'a'
+                if max_label is None:
+                    max_label = 'b'
+                label_list = [min_label] + label_list + [max_label]
             if addvars:
-                varstring += ',' + addvars
-            if len(varstring) > 0 and varstring[0] == ',':
-                varstring = varstring[1:]
-            if len(varstring) > 0:
-                varnum = varstring.count(',') + 1
-            else:
-                varnum = 0
+                label_list += addvars.split(',')
+            varstring = ','.join(label_list)
+            varnum = len(label_list)
+
             from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
             PR = PolynomialRing(base_field, varstring, varnum)
             # Now, ``PR`` is the polynomial ring in `n + 2` indeterminates
@@ -1344,13 +1410,43 @@ class FinitePosets(CategoryWithAxiom):
             pan_orbits = self.panyushev_orbits(element_constructor = list)
             return [[element_constructor(self.order_ideal(oideal)) for oideal in orbit] for orbit in pan_orbits]
 
+        def rowmotion_orbits_plots(self):
+            r"""
+            Return plots of the rowmotion orbits of order ideals in ``self``.
+
+            The rowmotion orbit of an order ideal is its orbit under
+            rowmotion (see :meth:`rowmotion`).
+
+            EXAMPLES::
+
+                sage: P = Poset( {1: [2, 3], 2: [], 3: [], 4: [2]} )
+                sage: P.rowmotion_orbits_plots()
+                Graphics Array of size 2 x 5
+                sage: P = Poset({})
+                sage: P.rowmotion_orbits_plots()
+                Graphics Array of size 2 x 1
+
+            """
+            plot_of_orb_plots=[]
+            max_orbit_size = 0            
+            for orb in self.rowmotion_orbits():
+                orb_plots=[]
+                if len(orb) > max_orbit_size:
+                    max_orbit_size = len(orb)                
+                for oi in orb:
+                    oiplot = self.order_ideal_plot(oi)
+                    orb_plots.append(oiplot)
+                plot_of_orb_plots.append(orb_plots)    
+            return graphics_array(plot_of_orb_plots, ncols = max_orbit_size)
+
+
         def toggling_orbits(self, vs, element_constructor = set):
             r"""
             Return the orbits of order ideals in ``self`` under the
             operation of toggling the vertices ``vs[0], vs[1], ...``
             in this order.
 
-            See :meth:`order_ideal_toggle` for a definition of toggling.
+            See :meth:`~sage.categories.posets.Posets.ParentMethods.order_ideal_toggle` for a definition of toggling.
 
             .. WARNING::
 
@@ -1398,6 +1494,36 @@ class FinitePosets(CategoryWithAxiom):
                 orbits.append([element_constructor(_) for _ in orbit])
             return orbits
 
+        def toggling_orbits_plots(self, vs):
+            r"""
+            Return plots of the orbits of order ideals in ``self`` under the
+            operation of toggling the vertices ``vs[0], vs[1], ...``
+            in this order.
+
+            See :meth:`toggling_orbits` for more information.
+
+            EXAMPLES::
+
+                sage: P = Poset( {1: [2, 3], 2: [], 3: [], 4: [2]} )
+                sage: P.toggling_orbits_plots([1,2,3,4])
+                Graphics Array of size 2 x 5
+                sage: P = Poset({})
+                sage: P.toggling_orbits_plots([])
+                Graphics Array of size 2 x 1
+
+            """
+            plot_of_orb_plots=[]  
+            max_orbit_size = 0             
+            for orb in self.toggling_orbits(vs):
+                orb_plots=[]
+                if len(orb) > max_orbit_size:
+                    max_orbit_size = len(orb)                
+                for oi in orb:
+                    oiplot = self.order_ideal_plot(oi)
+                    orb_plots.append(oiplot)
+                plot_of_orb_plots.append(orb_plots)    
+            return graphics_array(plot_of_orb_plots, ncols = max_orbit_size)
+
         def panyushev_orbit_iter(self, antichain, element_constructor=set, stop=True, check=True):
             r"""
             Iterate over the Panyushev orbit of an antichain
@@ -1590,7 +1716,7 @@ class FinitePosets(CategoryWithAxiom):
             ``self`` under the operation of toggling the vertices
             ``vs[0], vs[1], ...`` in this order.
 
-            See :meth:`order_ideal_toggle` for a definition of toggling.
+            See :meth:`~sage.categories.posets.Posets.ParentMethods.order_ideal_toggle` for a definition of toggling.
 
             .. WARNING::
 
