@@ -15,7 +15,6 @@ The ``codes.encoders`` object may be used to access the encoders that Sage can b
 **Generic encoders**
 
 - :class:`linear_code.LinearCodeGeneratorMatrixEncoder <sage.coding.linear_code.LinearCodeGeneratorMatrixEncoder>`
-- :class:`linear_code.LinearCodeParityCheckEncoder <sage.coding.linear_code.LinearCodeParityCheckEncoder>`
 - :class:`linear_code.LinearCodeSystematicEncoder <sage.coding.linear_code.LinearCodeSystematicEncoder>`
 
 **Generalized Reed-Solomon code encoders**
@@ -51,7 +50,6 @@ _lazy_import('sage.coding.cyclic_code', ['CyclicCodePolynomialEncoder',
 _lazy_import('sage.coding.extended_code', 'ExtendedCodeExtendedMatrixEncoder')
 _lazy_import('sage.coding.grs', ['GRSEvaluationVectorEncoder', 'GRSEvaluationPolynomialEncoder'])
 _lazy_import('sage.coding.linear_code', ['LinearCodeGeneratorMatrixEncoder',
-                                         'LinearCodeParityCheckEncoder',
                                          'LinearCodeSystematicEncoder'])
 _lazy_import('sage.coding.punctured_code', 'PuncturedCodePuncturedMatrixEncoder')
 _lazy_import('sage.coding.reed_muller_code', ['ReedMullerVectorEncoder', 'ReedMullerPolynomialEncoder'])
