@@ -40,7 +40,7 @@ from sage.matrix.matrix_space import MatrixSpace
 from sage.rings.finite_rings.finite_field_constructor import FiniteField as GF
 from sage.interfaces.gap import gfq_gap_to_sage
 from .linear_code import LinearCode
-from sage.misc.package import is_package_installed, PackageNotFoundError
+from sage.features.gap import GapPackage
 
 
 def QuasiQuadraticResidueCode(p):
@@ -71,8 +71,7 @@ def QuasiQuadraticResidueCode(p):
 
     AUTHOR: David Joyner (11-2005)
     """
-    if not is_package_installed('gap_packages'):
-        raise PackageNotFoundError('gap_packages')
+    GapPackage("guava", spkg="gap_packages").require()
     F = GF(2)
     gap.load_package("guava")
     gap.eval("C:=QQRCode(" + str(p) + ")")
@@ -113,8 +112,7 @@ def RandomLinearCodeGuava(n, k, F):
     current_randstate().set_seed_gap()
 
     q = F.order()
-    if not is_package_installed('gap_packages'):
-        raise PackageNotFoundError('gap_packages')
+    GapPackage("guava", spkg="gap_packages").require()
     gap.load_package("guava")
     gap.eval("C:=RandomLinearCode("+str(n)+","+str(k)+", GF("+str(q)+"))")
     gap.eval("G:=GeneratorMat(C)")
