@@ -17,21 +17,20 @@ coordinate of `c`.
 # (at your option) any later version.
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
+from __future__ import absolute_import
 
-from linear_code import (AbstractLinearCode,
-                         LinearCodeParityCheckEncoder,
-                         LinearCodeSyndromeDecoder,
-                         LinearCodeNearestNeighborDecoder)
+from .linear_code import AbstractLinearCode
 from sage.misc.cachefunc import cached_method
 from sage.rings.integer import Integer
 from sage.rings.finite_rings.finite_field_constructor import GF
 from sage.categories.homset import Hom
-from relative_finite_field_extension import RelativeFiniteFieldExtension
+from .relative_finite_field_extension import RelativeFiniteFieldExtension
 from sage.matrix.constructor import matrix
 from sage.modules.free_module_element import vector
-from decoder import Decoder, DecodingError
+from .decoder import Decoder, DecodingError
 from copy import copy
 
+
 class SubfieldSubcode(AbstractLinearCode):
     r"""
     Representation of a subfield subcode.
