@@ -1300,7 +1300,7 @@ def _mutation_type_from_data( n, dig6, compute_if_necessary=True ):
 
     EXAMPLES::
 
-        sage: from sage.combinat.cluster_algebra_quiver.mutation_class import _digraph_to_dig6, _dg_canonical_form
+        sage: from sage.combinat.cluster_algebra_quiver.mutation_class import _digraph_to_dig6
         sage: from sage.combinat.cluster_algebra_quiver.mutation_type import _mutation_type_from_data
         sage: from sage.combinat.cluster_algebra_quiver.quiver import ClusterQuiver
         sage: dg = ClusterQuiver(['F',4]).canonical_label().digraph()
@@ -1473,8 +1473,8 @@ def _random_tests(mt, k, mut_class=None, nr_mut=5):
                 # while making sure that we do not mutate back
                 mut_tmp = mut
                 while mut == mut_tmp:
-                    mut = random.randint(0,dg.order()-1)
-                dg_new = _digraph_mutate( dg, mut, dg.order(), 0 )
+                    mut = random.randint(0, dg.order() - 1)
+                dg_new = _digraph_mutate(dg, mut)
                 M = _edge_list_to_matrix(dg.edges(), list(range(dg.order())), [])
                 mt_new = _connected_mutation_type( dg_new )
                 if not mt == mt_new:
