@@ -18,8 +18,10 @@ that is a map between two :class:`enumerated sets <EnumeratedSets>`::
 By default, this decorator is a no-op: it returns the decorated method
 as is::
 
-    sage: MyPermutation.reverse
+    sage: MyPermutation.reverse  # py2
     <unbound method MyPermutation.reverse>
+    sage: MyPermutation.reverse  # py3
+    <function MyPermutation.reverse at ...>
 
 See :func:`combinatorial_map_wrapper` for the various options this
 decorator can take.
@@ -45,15 +47,15 @@ thereof, for all the combinatorial maps that apply to it.
     ``sage.combinat.combinatorial_map.combinatorial_map``. This is
     good enough for those doctests, but remains fragile.
 
-    For real use cases it's probably best to just edit this source
+    For real use cases, it is probably best to just edit this source
     file statically (see below).
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2011 Christian Stump <christian.stump at gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 def combinatorial_map_trivial(f=None, order=None, name=None):
     r"""
@@ -93,10 +95,15 @@ def combinatorial_map_trivial(f=None, order=None, name=None):
         ....:         '''
         ....:         # ... code ...
 
-        sage: MyPermutation.reverse
+        sage: MyPermutation.reverse  # py2
         <unbound method MyPermutation.reverse>
-        sage: MyPermutation.descent_set
+        sage: MyPermutation.reverse  # py3
+        <function MyPermutation.reverse at ...>
+
+        sage: MyPermutation.descent_set  # py2
         <unbound method MyPermutation.descent_set>
+        sage: MyPermutation.descent_set  # py3
+        <function MyPermutation.descent_set at ...>
     """
     if f is None:
         return lambda f: f
@@ -175,8 +182,10 @@ def combinatorial_map_wrapper(f=None, order=None, name=None):
 
     The method ``major_index`` defined about is not a combinatorial map::
 
-        sage: MyPermutation.major_index
+        sage: MyPermutation.major_index  # py2
         <unbound method MyPermutation.major_index>
+        sage: MyPermutation.major_index  # py3
+        <function MyPermutation.major_index at ...>
 
     But one can define a function that turns ``major_index`` into a combinatorial map::
 
