@@ -48,13 +48,9 @@ AUTHORS:
 
 REFERENCES:
 
-.. [Kashiwara93] \M. Kashiwara.
-   The Crystal Base and Littelmann's Refined Demazure Character Formula.
-   Duke Math. J. **71** (3), pp. 839--858, 1993.
+- [Ka1993]_
 
-.. [NZ97] \T. Nakashima and A. Zelevinsky.
-   Polyhedral Realizations of Crystal Bases for Quantized Kac-Moody Algebras.
-   Adv. Math. **131**, pp. 253--278, 1997.
+- [NZ1997]_
 """
 
 #*****************************************************************************
@@ -198,7 +194,7 @@ class TCrystal(UniqueRepresentation, Parent):
     r"""
     The crystal `T_{\lambda}`.
 
-    Let `\lambda` be a weight. As defined in [Kashiwara93]_ the crystal
+    Let `\lambda` be a weight. As defined in [Ka1993]_ the crystal
     `T_{\lambda} = \{ t_{\lambda} \}` is a single element crystal with the
     crystal structure defined by
 
@@ -712,7 +708,7 @@ class ElementaryCrystal(UniqueRepresentation, Parent):
 
         B(\infty) \hookrightarrow B_i \otimes B(\infty),
 
-    satisfying certain properties (see [Kashiwara93]_).  The above embedding
+    satisfying certain properties (see [Ka1993]_).  The above embedding
     may be iterated to obtain a new embedding
 
     .. MATH::
@@ -721,7 +717,7 @@ class ElementaryCrystal(UniqueRepresentation, Parent):
         \otimes \cdots \otimes B_{i_2} \otimes B_{i_1} \otimes B(\infty),
 
     which is a foundational object in the study of *polyhedral realizations of
-    crystals* (see, for example, [NZ97]_).
+    crystals* (see, for example, [NZ1997]_).
     """
 
     @staticmethod
@@ -998,7 +994,7 @@ class ComponentCrystal(UniqueRepresentation, Parent):
     r"""
     The component crystal.
 
-    Defined in [Kashiwara93]_, the component crystal `C = \{c\}` is the single
+    Defined in [Ka1993]_, the component crystal `C = \{c\}` is the single
     element crystal whose crystal structure is defined by
 
     .. MATH::
