@@ -10,20 +10,13 @@ AUTHORS:
 - Travis Scrimshaw: Initial version
 
 Generalized Young walls are certain generalizations of Young tableaux
-introduced in [KS10]_ and designed to be a realization of the crystals
+introduced in [KS2010]_ and designed to be a realization of the crystals
 `\mathcal{B}(\infty)` and `\mathcal{B}(\lambda)` in type `A_n^{(1)}`.
 
 REFERENCES:
 
-.. [KS10] \J.-A. Kim and D.-U. Shin.
-   Generalized Young walls and crystal bases for quantum affine algebra
-   of type `A`.
-   Proc. Amer. Math. Soc. 138(11), pp. 3877--3889, 2010.
-
-.. [KLRS] \S.-J. Kang, K.-H. Lee, H. Ryu, and B. Salisbury.
-   A combinatorial description of the affine Gindikin-Karpelevich formula of
-   type `A_n^{(1)}`.
-   :arXiv:`1203.1640`.
+- [KLRS2016]_
+- [KS2010]_
 """
 
 #******************************************************************************
@@ -267,7 +260,7 @@ class GeneralizedYoungWall(CombinatorialElement):
         r"""
         Return the value of `\mathscr{N}` on ``self``.
 
-        In [KLRS]_, the statistic `\mathscr{N}` was defined on elements in
+        In [KLRS2016]_, the statistic `\mathscr{N}` was defined on elements in
         `\mathcal{Y}(\infty)` which counts how many parts are in the
         corresponding Kostant partition.  Specifically, the computation of
         `\mathscr{N}(Y)` is done using the following algorithm:
@@ -352,7 +345,7 @@ class GeneralizedYoungWall(CombinatorialElement):
     def e(self,i):
         r"""
         Return the application of the Kashiwara raising operator
-        `\widetilde{e}_i` on ``self``.
+        `e_i` on ``self``.
 
         This will remove the `i`-colored box corresponding to the
         rightmost `+` in ``self.signature(i)``.
@@ -386,7 +379,7 @@ class GeneralizedYoungWall(CombinatorialElement):
     def f(self,i):
         r"""
         Return the application of the Kashiwara lowering operator
-        `\widetilde{f}_i` on ``self``.
+        `f_i` on ``self``.
 
         This will add an `i`-colored colored box to the site corresponding
         to the leftmost plus in ``self.signature(i)``.
@@ -433,7 +426,7 @@ class GeneralizedYoungWall(CombinatorialElement):
         else:
             s += "\\begin{tikzpicture}[baseline=5,scale=.45] \n \\foreach \\x [count=\\s from 0] in \n"
             s += "{" + ','.join("{" + ','.join( str(i) for i in r ) + "}" for r in self.data ) + "} \n"
-            s += "{\\foreach \\y [count=\\t from 0] in \\x {  \\node[font=\\scriptsize] at (-\\t,\\s) {$\\y$}; \n \draw (-\\t+.5,\\s+.5) to (-\\t-.5,\\s+.5); \n \draw (-\\t+.5,\\s-.5) to (-\\t-.5,\\s-.5); \n \draw (-\\t-.5,\\s-.5) to (-\\t-.5,\\s+.5);  } \n \draw[-,thick] (.5,\\s+1) to (.5,-.5) to (-\\t-1,-.5); } \n \\end{tikzpicture} \n"
+            s += "{\\foreach \\y [count=\\t from 0] in \\x {  \\node[font=\\scriptsize] at (-\\t,\\s) {$\\y$}; \n \\draw (-\\t+.5,\\s+.5) to (-\\t-.5,\\s+.5); \n \\draw (-\\t+.5,\\s-.5) to (-\\t-.5,\\s-.5); \n \\draw (-\\t-.5,\\s-.5) to (-\\t-.5,\\s+.5);  } \n \\draw[-,thick] (.5,\\s+1) to (.5,-.5) to (-\\t-1,-.5); } \n \\end{tikzpicture} \n"
         return s
 
     def _latex_(self):
@@ -452,7 +445,7 @@ class GeneralizedYoungWall(CombinatorialElement):
         else:
             s += "\\begin{tikzpicture}[baseline=5,scale=.25] \\foreach \\x [count=\\s from 0] in \n"
             s += "{" + ','.join("{" + ','.join( str(i) for i in r ) + "}" for r in self.data ) + "} \n"
-            s += "{\\foreach \\y [count=\\t from 0] in \\x {  \\node[font=\\tiny] at (-\\t,\\s) {$\\y$}; \n \draw (-\\t+.5,\\s+.5) to (-\\t-.5,\\s+.5); \n \draw (-\\t+.5,\\s-.5) to (-\\t-.5,\\s-.5); \n \draw (-\\t-.5,\\s-.5) to (-\\t-.5,\\s+.5);  } \n \draw[-] (.5,\\s+1) to (.5,-.5) to (-\\t-1,-.5); } \n \\end{tikzpicture} \n"
+            s += "{\\foreach \\y [count=\\t from 0] in \\x {  \\node[font=\\tiny] at (-\\t,\\s) {$\\y$}; \n \\draw (-\\t+.5,\\s+.5) to (-\\t-.5,\\s+.5); \n \\draw (-\\t+.5,\\s-.5) to (-\\t-.5,\\s-.5); \n \\draw (-\\t-.5,\\s-.5) to (-\\t-.5,\\s+.5);  } \n \\draw[-] (.5,\\s+1) to (.5,-.5) to (-\\t-1,-.5); } \n \\end{tikzpicture} \n"
         return s
 
     def weight(self, root_lattice=False):
@@ -461,8 +454,8 @@ class GeneralizedYoungWall(CombinatorialElement):
 
         INPUT:
 
-        - `root_lattice` -- boolean determining whether weight should appear in
-          root lattice or not in extended affine weight lattice.
+        - ``root_lattice`` -- boolean determining whether weight should appear
+          in root lattice or not in extended affine weight lattice.
 
         EXAMPLES::
 
@@ -604,7 +597,7 @@ class GeneralizedYoungWall(CombinatorialElement):
         is in the highest weight crystal cut out by the given highest weight
         ``La``.
 
-        By Theorem 4.1 of [KS10]_, a generalized Young wall `Y` represents a
+        By Theorem 4.1 of [KS2010]_, a generalized Young wall `Y` represents a
         vertex in the highest weight crystal `Y(\lambda)`, with
         `\lambda = \Lambda_{i_1} + \Lambda_{i_2} + \cdots + \Lambda_{i_\ell}`
         a dominant integral weight of level `\ell > 0`, if it satisfies the
@@ -656,7 +649,7 @@ class GeneralizedYoungWall(CombinatorialElement):
 class InfinityCrystalOfGeneralizedYoungWalls(UniqueRepresentation, Parent):
     r"""
     The crystal `\mathcal{Y}(\infty)` of generalized Young walls of
-    type `A_n^{(1)}` as defined in [KS10]_.
+    type `A_n^{(1)}` as defined in [KS2010]_.
 
     A generalized Young wall is a collection of boxes stacked on a fixed board,
     such that color of the box at the site located in the `j`-th row from the
@@ -679,7 +672,7 @@ class InfinityCrystalOfGeneralizedYoungWalls(UniqueRepresentation, Parent):
 
     .. MATH::
 
-        \widetilde{e}_i,\ \widetilde{f}_i \colon \mathcal{Y}(\infty)
+        e_i,\ f_i \colon \mathcal{Y}(\infty)
         \longrightarrow \mathcal{Y}(\infty) \sqcup \{0\}, \qquad
         \varepsilon_i,\ \varphi_i \colon \mathcal{Y}(\infty)
         \longrightarrow \ZZ, \qquad
@@ -701,7 +694,7 @@ class InfinityCrystalOfGeneralizedYoungWalls(UniqueRepresentation, Parent):
 
     See :meth:`GeneralizedYoungWall.e()`, :meth:`GeneralizedYoungWall.f()`,
     and :meth:`GeneralizedYoungWall.signature()` for more about
-    `\widetilde{e}_i`, `\widetilde{f}_i`, and `i`-signatures.
+    `e_i`, `f_i`, and `i`-signatures.
 
 
     INPUT:
@@ -810,7 +803,7 @@ class CrystalOfGeneralizedYoungWallsElement(GeneralizedYoungWall):
 
     def e(self,i):
         r"""
-        Compute the action of `\widetilde{e}_i` restricted to the highest weight crystal.
+        Compute the action of `e_i` restricted to the highest weight crystal.
 
         EXAMPLES::
 
@@ -830,7 +823,7 @@ class CrystalOfGeneralizedYoungWallsElement(GeneralizedYoungWall):
 
     def f(self,i):
         r"""
-        Compute the action of `\widetilde{f}_i` restricted to the highest weight crystal.
+        Compute the action of `f_i` restricted to the highest weight crystal.
 
         EXAMPLES::
 
@@ -885,7 +878,7 @@ class CrystalOfGeneralizedYoungWalls(InfinityCrystalOfGeneralizedYoungWalls):
     The crystal `\mathcal{Y}(\lambda)` of generalized Young walls of the given
     type with highest weight `\lambda`.
 
-    These were characterized in Theorem 4.1 of [KS10]_.
+    These were characterized in Theorem 4.1 of [KS2010]_.
     See :meth:`GeneralizedYoungWall.in_highest_weight_crystal()`.
 
     INPUT:
