@@ -17,14 +17,9 @@ AUTHORS:
 # (at your option) any later version.
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
-
-from sage.structure.parent import Parent
-from sage.structure.unique_representation import UniqueRepresentation
-from sage.categories.highest_weight_crystals import HighestWeightCrystals
-from sage.categories.infinite_enumerated_sets import InfiniteEnumeratedSets
-from sage.combinat.root_system.cartan_type import CartanType
 from sage.combinat.crystals.pbw_crystal import PBWCrystalElement, PBWCrystal
 
+
 class MVPolytope(PBWCrystalElement):
     """
     A Mirković-Vilonen (MV) polytope.
@@ -74,8 +69,8 @@ class MVPolytope(PBWCrystalElement):
             sage: b = MV.module_generators[0].f_string([1,2,1,2])
             sage: latex(b)
             \begin{tikzpicture}
-            \draw (0, 0) -- (-1, 1) -- (-1, 1) -- (-2, 0) -- (-2, -2);
             \draw (0, 0) -- (0, -2) -- (-1, -3) -- (-1, -3) -- (-2, -2);
+            \draw (0, 0) -- (-1, 1) -- (-1, 1) -- (-2, 0) -- (-2, -2);
             \draw[fill=black] (0, 0) circle (0.1);
             \draw[fill=black] (-2, -2) circle (0.1);
             \end{tikzpicture}
@@ -116,7 +111,7 @@ class MVPolytope(PBWCrystalElement):
         ret = "\\begin{tikzpicture}\n"
 
         final = None
-        for red in w0.reduced_words():
+        for red in sorted(w0.reduced_words()):
             ret += "\\draw "
             cur = proj(P.zero())
             red = tuple(red)
@@ -165,7 +160,7 @@ class MVPolytope(PBWCrystalElement):
         al = P.simple_roots()
 
         vertices = set([P.zero()])
-        for red in w0.reduced_words():
+        for red in sorted(w0.reduced_words()):
             cur = P.zero()
             red = tuple(red)
             roots = [P.sum(c*al[a] for a,c in root)
@@ -407,24 +402,24 @@ class MVPolytopes(PBWCrystal):
             sage: b = MV.highest_weight_vector().f_string([1,2,1,2])
             sage: latex(b)
             \begin{tikzpicture}
-            \draw (0, 0) -- (-1, 1) -- (-1, 1) -- (-2, 0) -- (-2, -2);
             \draw (0, 0) -- (0, -2) -- (-1, -3) -- (-1, -3) -- (-2, -2);
+            \draw (0, 0) -- (-1, 1) -- (-1, 1) -- (-2, 0) -- (-2, -2);
             \draw[fill=black] (0, 0) circle (0.1);
             \draw[fill=black] (-2, -2) circle (0.1);
             \end{tikzpicture}
             sage: MV.set_latex_options(P=P, circle_size=float(0.2))
             sage: latex(b)
             \begin{tikzpicture}
-            \draw (0, 0) -- (-2, 1) -- (-2, 1) -- (-2, 0) -- (0, -2);
             \draw (0, 0) -- (2, -2) -- (2, -3) -- (2, -3) -- (0, -2);
+            \draw (0, 0) -- (-2, 1) -- (-2, 1) -- (-2, 0) -- (0, -2);
             \draw[fill=black] (0, 0) circle (0.2);
             \draw[fill=black] (0, -2) circle (0.2);
             \end{tikzpicture}
             sage: MV.set_latex_options(mark_endpoints=False)
             sage: latex(b)
             \begin{tikzpicture}
-            \draw (0, 0) -- (-2, 1) -- (-2, 1) -- (-2, 0) -- (0, -2);
             \draw (0, 0) -- (2, -2) -- (2, -3) -- (2, -3) -- (0, -2);
+            \draw (0, 0) -- (-2, 1) -- (-2, 1) -- (-2, 0) -- (0, -2);
             \end{tikzpicture}
             sage: MV.set_latex_options(P=MV.weight_lattice_realization(),
             ....:                      circle_size=0.2,
