@@ -860,9 +860,11 @@ def AffineGeometryDesign(n, d, F, point_coordinates=True, check=True):
     blocks = []
     l1 = int(q_binomial(n+1, d+1, q) - q_binomial(n, d+1, q))
     l2 = q**d
-    for m1 in islice(reduced_echelon_matrix_iterator(F,d+1,n+1,copy=False), l1):
+    for m1 in islice(reduced_echelon_matrix_iterator(F,d+1,n+1,copy=False),
+                     int(l1)):
         b = []
-        for m2 in islice(reduced_echelon_matrix_iterator(F,1,d+1,copy=False), l2):
+        for m2 in islice(reduced_echelon_matrix_iterator(F,1,d+1,copy=False),
+                         int(l2)):
             m = m2*m1
             m.echelonize()
             m.set_immutable()
