@@ -13,28 +13,15 @@ least)... it does !
 
 The constructions have been implemented while reading two papers simultaneously,
 for one of them sometimes provides the informations that the other one does
-not. The first one is Haim Hanani's original paper [Hanani60]_, and the other
+not. The first one is Haim Hanani's original paper [Han1960]_, and the other
 one is a paper from Horan and Hurlbert which goes through all constructions
-[HH12]_.
+[HH2012]_.
 
 It can be used through the ``designs`` object::
 
     sage: designs.steiner_quadruple_system(8)
     Incidence structure with 8 points and 14 blocks
 
-REFERENCES:
-
-.. [Hanani60] Haim Hanani,
-  On quadruple systems,
-  pages 145--157, vol. 12,
-  Canadian Journal of Mathematics,
-  1960
-  http://cms.math.ca/cjm/v12/cjm1960v12.0145-0157.pdf
-
-.. [HH12] Victoria Horan and Glenn Hurlbert,
-  *Overlap Cycles for Steiner Quadruple Systems*,
-  2012, :arxiv:`1204.3215`
-
 AUTHORS:
 
 - Nathann Cohen (May 2013, while listening to "*Le Blues Du Pauvre Delahaye*")
@@ -67,7 +54,7 @@ This function redistributes its work among 6 constructions :
 
 It also defines two specific Steiner Quadruple Systems that the constructions
 require, i.e. `SQS_{14}` and `SQS_{38}` as well as the systems of pairs
-`P_{\alpha}(m)` and `\overline P_{\alpha}(m)` (see [Hanani60]_).
+`P_{\alpha}(m)` and `\overline P_{\alpha}(m)` (see [Han1960]_).
 
 Functions
 ---------
@@ -511,7 +498,7 @@ def P(alpha, m):
     r"""
     Return the collection of pairs `P_{\alpha}(m)`
 
-    For more information on this system, see [Hanani60]_.
+    For more information on this system, see [Han1960]_.
 
     EXAMPLES::
 
@@ -573,7 +560,7 @@ def barP(eps, m):
     r"""
     Return the collection of pairs `\overline P_{\alpha}(m)`
 
-    For more information on this system, see [Hanani60]_.
+    For more information on this system, see [Han1960]_.
 
     EXAMPLES::
 
@@ -588,7 +575,7 @@ def barP_system(m):
     r"""
     Return the 1-factorization of `K_{2m}` `\overline P(m)`
 
-    For more information on this system, see [Hanani60]_.
+    For more information on this system, see [Han1960]_.
 
     EXAMPLES::
 
