@@ -26,7 +26,7 @@ The code was tested afterwards by Liz Beazley and Ed Richmond.
       R. Vakil, A geometric Littlewood-Richardson rule, :arXiv:`math/0302294`
       or K. Purbhoo, Puzzles, Tableaux and Mosaics, :arXiv:`0705.1184`.
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2013 Franco Saliola <saliola@gmail.com>,
 #                     2013 Allen Knutson,
 #                     2013 Avinash Dalal,
@@ -35,8 +35,8 @@ The code was tested afterwards by Liz Beazley and Ed Richmond.
 #                     2013 Ed Richmond
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from sage.plot.graphics import Graphics
 from sage.plot.polygon import polygon
 from sage.plot.line import line
@@ -979,8 +979,16 @@ class PuzzleFilling(object):
             sage: ps = KnutsonTaoPuzzleSolver("H")
             sage: puzzle = ps('0101','1001')[0]
             sage: puzzle
-            {(1, 2): 1/\1  10\/0, (1, 3): 0/\10  1\/1, (3, 3): 1/1\1, (4, 4): 10/0\1,
-            (1, 4): 1/\1  10\/0, (1, 1): 0/1\10, (2, 3): 1/\0  0\/1, (2, 2): 0/0\0, (3, 4): 0/\0  1\/10, (2, 4): 0/\0  0\/0}
+            {(1, 1): 0/1\10,
+             (1, 2): 1/\1  10\/0,
+             (1, 3): 0/\10  1\/1,
+             (1, 4): 1/\1  10\/0,
+             (2, 2): 0/0\0,
+             (2, 3): 1/\0  0\/1,
+             (2, 4): 0/\0  0\/0,
+             (3, 3): 1/1\1,
+             (3, 4): 0/\0  1\/10,
+             (4, 4): 10/0\1}
             sage: puzzle[(1,2)]  # indirect doctest
             1/\1  10\/0
         """
@@ -1126,7 +1134,7 @@ class PuzzleFilling(object):
             sage: pieces = [piece,piece]
             sage: P.add_pieces(pieces)
             sage: P
-            {(2, 4): 1/0\0, (1, 4): 1/0\0}
+            {(1, 4): 1/0\0, (2, 4): 1/0\0}
         """
         (i, j) = self.kink_coordinates()
         for piece in pieces:
@@ -1194,7 +1202,8 @@ class PuzzleFilling(object):
             sage: P.__repr__()
             '{}'
         """
-        return str(self._squares)
+        from pprint import pformat
+        return pformat(self._squares)
 
     def __iter__(self):
         r"""
@@ -1206,9 +1215,16 @@ class PuzzleFilling(object):
             sage: ps = KnutsonTaoPuzzleSolver("H")
             sage: puzzle = ps('0101','1001')[0]
             sage: puzzle
-            {(1, 2): 1/\1  10\/0, (1, 3): 0/\10  1\/1, (3, 3): 1/1\1, (4, 4): 10/0\1,
-            (1, 4): 1/\1  10\/0, (1, 1): 0/1\10, (2, 3): 1/\0  0\/1, (2, 2): 0/0\0,
-            (3, 4): 0/\0  1\/10, (2, 4): 0/\0  0\/0}
+            {(1, 1): 0/1\10,
+             (1, 2): 1/\1  10\/0,
+             (1, 3): 0/\10  1\/1,
+             (1, 4): 1/\1  10\/0,
+             (2, 2): 0/0\0,
+             (2, 3): 1/\0  0\/1,
+             (2, 4): 0/\0  0\/0,
+             (3, 3): 1/1\1,
+             (3, 4): 0/\0  1\/10,
+             (4, 4): 10/0\1}
             sage: [p for p in puzzle]
             [1/\1  10\/0,
             0/\10  1\/1,
@@ -1415,8 +1431,25 @@ class KnutsonTaoPuzzleSolver(UniqueRepresentation):
         2
         sage: solns.sort(key=str)
         sage: solns
-        [{(1, 2): 1/\0  0\/1, (1, 3): 0/\0  0\/0, (3, 3): 1/1\1, (4, 4): 10/0\1, (1, 4): 1/\0  0\/1, (1, 1): 0/0\0, (2, 3): 0/\10  1\/1, (2, 2): 1/1\1, (3, 4): 0/\0  1\/10, (2, 4): 1/\1  10\/0},
-        {(1, 2): 1/\1  10\/0, (1, 3): 0/\0  1\/10, (3, 3): 0/0\0, (4, 4): 1/1\1, (1, 4): 1/\0  0\/1, (1, 1): 0/1\10, (2, 3): 10/\1  0\/0, (2, 2): 0/0\0, (3, 4): 1/\0  0\/1, (2, 4): 1/\1  1\/1}]
+        [{(1, 1): 0/0\0,
+          (1, 2): 1/\0  0\/1,
+          (1, 3): 0/\0  0\/0,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 1/1\1,
+          (2, 3): 0/\10  1\/1,
+          (2, 4): 1/\1  10\/0,
+          (3, 3): 1/1\1,
+          (3, 4): 0/\0  1\/10,
+          (4, 4): 10/0\1}, {(1, 1): 0/1\10,
+          (1, 2): 1/\1  10\/0,
+          (1, 3): 0/\0  1\/10,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 0/0\0,
+          (2, 3): 10/\1  0\/0,
+          (2, 4): 1/\1  1\/1,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (4, 4): 1/1\1}]
 
     The pieces in a puzzle filling are indexed by pairs of non-negative
     integers `(i, j)` with `1 \leq i \leq j \leq n`, where `n` is the
@@ -1466,51 +1499,289 @@ class KnutsonTaoPuzzleSolver(UniqueRepresentation):
         sage: ps = KnutsonTaoPuzzleSolver("H")
         sage: solns = ps('0101', '0101')
         sage: sorted(solns, key=str)
-        [{(1, 2): 1/\0  0\/1, (1, 3): 0/\0  0\/0, (3, 3): 1/1\1, (4, 4): 10/0\1, (1, 4): 1/\0  0\/1, (1, 1): 0/0\0, (2, 3): 0/\10  1\/1, (2, 2): 1/1\1, (3, 4): 0/\0  1\/10, (2, 4): 1/\1  10\/0},
-        {(1, 2): 1/\1  10\/0, (1, 3): 0/\0  1\/10, (3, 3): 0/0\0, (4, 4): 1/1\1, (1, 4): 1/\0  0\/1, (1, 1): 0/1\10, (2, 3): 10/\1  0\/0, (2, 2): 0/0\0, (3, 4): 1/\0  0\/1, (2, 4): 1/\1  1\/1}]
+        [{(1, 1): 0/0\0,
+          (1, 2): 1/\0  0\/1,
+          (1, 3): 0/\0  0\/0,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 1/1\1,
+          (2, 3): 0/\10  1\/1,
+          (2, 4): 1/\1  10\/0,
+          (3, 3): 1/1\1,
+          (3, 4): 0/\0  1\/10,
+          (4, 4): 10/0\1}, {(1, 1): 0/1\10,
+          (1, 2): 1/\1  10\/0,
+          (1, 3): 0/\0  1\/10,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 0/0\0,
+          (2, 3): 10/\1  0\/0,
+          (2, 4): 1/\1  1\/1,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (4, 4): 1/1\1}]
 
     Equivariant puzzles::
 
         sage: ps = KnutsonTaoPuzzleSolver("HT")
         sage: solns = ps('0101', '0101')
         sage: sorted(solns, key=str)
-        [{(1, 2): 1/\0  0\/1, (1, 3): 0/\0  0\/0, (3, 3): 0/0\0, (4, 4): 1/1\1, (1, 4): 1/\0  0\/1, (1, 1): 0/0\0, (2, 3): 0/\1  1\/0, (2, 2): 1/1\1, (3, 4): 1/\0  0\/1, (2, 4): 1/\1  1\/1},
-        {(1, 2): 1/\0  0\/1, (1, 3): 0/\0  0\/0, (3, 3): 1/1\1, (4, 4): 10/0\1, (1, 4): 1/\0  0\/1, (1, 1): 0/0\0, (2, 3): 0/\10  1\/1, (2, 2): 1/1\1, (3, 4): 0/\0  1\/10, (2, 4): 1/\1  10\/0},
-        {(1, 2): 1/\1  10\/0, (1, 3): 0/\0  1\/10, (3, 3): 0/0\0, (4, 4): 1/1\1, (1, 4): 1/\0  0\/1, (1, 1): 0/1\10, (2, 3): 10/\1  0\/0, (2, 2): 0/0\0, (3, 4): 1/\0  0\/1, (2, 4): 1/\1  1\/1}]
+        [{(1, 1): 0/0\0,
+          (1, 2): 1/\0  0\/1,
+          (1, 3): 0/\0  0\/0,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 1/1\1,
+          (2, 3): 0/\1  1\/0,
+          (2, 4): 1/\1  1\/1,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (4, 4): 1/1\1}, {(1, 1): 0/0\0,
+          (1, 2): 1/\0  0\/1,
+          (1, 3): 0/\0  0\/0,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 1/1\1,
+          (2, 3): 0/\10  1\/1,
+          (2, 4): 1/\1  10\/0,
+          (3, 3): 1/1\1,
+          (3, 4): 0/\0  1\/10,
+          (4, 4): 10/0\1}, {(1, 1): 0/1\10,
+          (1, 2): 1/\1  10\/0,
+          (1, 3): 0/\0  1\/10,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 0/0\0,
+          (2, 3): 10/\1  0\/0,
+          (2, 4): 1/\1  1\/1,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (4, 4): 1/1\1}]
 
     K-Theory puzzles::
 
         sage: ps = KnutsonTaoPuzzleSolver("K")
         sage: solns = ps('0101', '0101')
         sage: sorted(solns, key=str)
-        [{(1, 2): 1/\0  0\/1, (1, 3): 0/\0  0\/0, (3, 3): 1/1\1, (4, 4): 10/0\1, (1, 4): 1/\0  0\/1, (1, 1): 0/0\0, (2, 3): 0/\10  1\/1, (2, 2): 1/1\1, (3, 4): 0/\0  1\/10, (2, 4): 1/\1  10\/0},
-        {(1, 2): 1/\1  10\/0, (1, 3): 0/\0  1\/10, (3, 3): 0/0\0, (4, 4): 1/1\1, (1, 4): 1/\0  0\/1, (1, 1): 0/1\10, (2, 3): 10/\1  0\/0, (2, 2): 0/0\0, (3, 4): 1/\0  0\/1, (2, 4): 1/\1  1\/1},
-        {(1, 2): 1/\1  10\/0, (1, 3): 0/\0  1\/K, (3, 3): 1/1\1, (4, 4): 10/0\1, (1, 4): 1/\0  0\/1, (1, 1): 0/1\10, (2, 3): K/\K  0\/1, (2, 2): 0/0\0, (3, 4): 0/\0  1\/10, (2, 4): 1/\1  K\/0}]
+        [{(1, 1): 0/0\0,
+          (1, 2): 1/\0  0\/1,
+          (1, 3): 0/\0  0\/0,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 1/1\1,
+          (2, 3): 0/\10  1\/1,
+          (2, 4): 1/\1  10\/0,
+          (3, 3): 1/1\1,
+          (3, 4): 0/\0  1\/10,
+          (4, 4): 10/0\1}, {(1, 1): 0/1\10,
+          (1, 2): 1/\1  10\/0,
+          (1, 3): 0/\0  1\/10,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 0/0\0,
+          (2, 3): 10/\1  0\/0,
+          (2, 4): 1/\1  1\/1,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (4, 4): 1/1\1}, {(1, 1): 0/1\10,
+          (1, 2): 1/\1  10\/0,
+          (1, 3): 0/\0  1\/K,
+          (1, 4): 1/\0  0\/1,
+          (2, 2): 0/0\0,
+          (2, 3): K/\K  0\/1,
+          (2, 4): 1/\1  K\/0,
+          (3, 3): 1/1\1,
+          (3, 4): 0/\0  1\/10,
+          (4, 4): 10/0\1}]
 
     Two-step puzzles::
 
         sage: ps = KnutsonTaoPuzzleSolver("H2step")
         sage: solns = ps('01201', '01021')
         sage: sorted(solns, key=str)
-        [{(1, 2): 1/\0  0\/1, (1, 3): 2/\0  0\/2, (3, 3): 1/1\1, (4, 5): 20/\2  1\/10, (4, 4): 1/1\1, (5, 5): 10/0\1, (1, 4): 0/\0  0\/0, (1, 1): 0/0\0, (1, 5): 1/\0  0\/1, (2, 3): 2/\2  21\/1, (2, 2): 1/2\21, (2, 5): 1/\1  10\/0, (3, 4): 21/\2  1\/1, (2, 4): 0/\10  2\/21, (3, 5): 0/\0  2\/20},
-        {(1, 2): 1/\1  10\/0, (1, 3): 2/\1  1\/2, (3, 3): 0/0\0, (4, 5): 2(10)/\2  0\/1, (4, 4): 0/0\0, (5, 5): 1/1\1, (1, 4): 0/\0  1\/10, (1, 1): 0/1\10, (1, 5): 1/\0  0\/1, (2, 3): 2/\2  20\/0, (2, 2): 0/2\20, (2, 5): 1/\1  1\/1, (3, 4): 20/\2  0\/0, (2, 4): 10/\1  2\/20, (3, 5): 1/\0  2\/2(10)},
-        {(1, 2): 1/\21  20\/0, (1, 3): 2/\2  21\/1, (3, 3): 1/1\1, (4, 5): 21/\2  1\/1, (4, 4): 10/0\1, (5, 5): 1/1\1, (1, 4): 0/\0  2\/20, (1, 1): 0/2\20, (1, 5): 1/\0  0\/1, (2, 3): 1/\0  0\/1, (2, 2): 0/0\0, (2, 5): 1/\1  2\/21, (3, 4): 0/\0  1\/10, (2, 4): 20/\2  0\/0, (3, 5): 21/\0  0\/21}]
+        [{(1, 1): 0/0\0,
+          (1, 2): 1/\0  0\/1,
+          (1, 3): 2/\0  0\/2,
+          (1, 4): 0/\0  0\/0,
+          (1, 5): 1/\0  0\/1,
+          (2, 2): 1/2\21,
+          (2, 3): 2/\2  21\/1,
+          (2, 4): 0/\10  2\/21,
+          (2, 5): 1/\1  10\/0,
+          (3, 3): 1/1\1,
+          (3, 4): 21/\2  1\/1,
+          (3, 5): 0/\0  2\/20,
+          (4, 4): 1/1\1,
+          (4, 5): 20/\2  1\/10,
+          (5, 5): 10/0\1}, {(1, 1): 0/1\10,
+          (1, 2): 1/\1  10\/0,
+          (1, 3): 2/\1  1\/2,
+          (1, 4): 0/\0  1\/10,
+          (1, 5): 1/\0  0\/1,
+          (2, 2): 0/2\20,
+          (2, 3): 2/\2  20\/0,
+          (2, 4): 10/\1  2\/20,
+          (2, 5): 1/\1  1\/1,
+          (3, 3): 0/0\0,
+          (3, 4): 20/\2  0\/0,
+          (3, 5): 1/\0  2\/2(10),
+          (4, 4): 0/0\0,
+          (4, 5): 2(10)/\2  0\/1,
+          (5, 5): 1/1\1}, {(1, 1): 0/2\20,
+          (1, 2): 1/\21  20\/0,
+          (1, 3): 2/\2  21\/1,
+          (1, 4): 0/\0  2\/20,
+          (1, 5): 1/\0  0\/1,
+          (2, 2): 0/0\0,
+          (2, 3): 1/\0  0\/1,
+          (2, 4): 20/\2  0\/0,
+          (2, 5): 1/\1  2\/21,
+          (3, 3): 1/1\1,
+          (3, 4): 0/\0  1\/10,
+          (3, 5): 21/\0  0\/21,
+          (4, 4): 10/0\1,
+          (4, 5): 21/\2  1\/1,
+          (5, 5): 1/1\1}]
 
     Two-step equivariant puzzles::
 
         sage: ps = KnutsonTaoPuzzleSolver("HT2step")
         sage: solns = ps('10212', '12012')
         sage: sorted(solns, key=str)
-        [{(1, 2): 0/\(21)0  1\/2, (1, 3): 2/\1  (21)0\/0, (3, 3): 0/0\0, (4, 5): 1/\1  2\/21, (4, 4): 2/2\2, (5, 5): 21/1\2, (1, 4): 1/\1  1\/1, (1, 1): 1/1\1, (1, 5): 2/\1  1\/2, (2, 3): 0/\2  2\/0, (2, 2): 2/2\2, (2, 5): 2/\2  21\/1, (3, 4): 2/\0  0\/2, (2, 4): 1/\21  2\/2, (3, 5): 1/\0  0\/1},
-        {(1, 2): 0/\(21)0  1\/2, (1, 3): 2/\1  (21)0\/0, (3, 3): 0/0\0, (4, 5): 2/\1  1\/2, (4, 4): 1/1\1, (5, 5): 2/2\2, (1, 4): 1/\1  1\/1, (1, 1): 1/1\1, (1, 5): 2/\1  1\/2, (2, 3): 0/\2  2\/0, (2, 2): 2/2\2, (2, 5): 2/\2  2\/2, (3, 4): 1/\0  0\/1, (2, 4): 1/\2  2\/1, (3, 5): 2/\0  0\/2},
-        {(1, 2): 0/\(21)0  1\/2, (1, 3): 2/\1  (21)0\/0, (3, 3): 2/2\2, (4, 5): 1/\1  2\/21, (4, 4): 20/0\2, (5, 5): 21/1\2, (1, 4): 1/\1  1\/1, (1, 1): 1/1\1, (1, 5): 2/\1  1\/2, (2, 3): 0/\20  2\/2, (2, 2): 2/2\2, (2, 5): 2/\2  21\/1, (3, 4): 0/\0  2\/20, (2, 4): 1/\21  20\/0, (3, 5): 1/\0  0\/1},
-        {(1, 2): 0/\1  1\/0, (1, 3): 2/\1  1\/2, (3, 3): 0/0\0, (4, 5): 1/\1  2\/21, (4, 4): 2/2\2, (5, 5): 21/1\2, (1, 4): 1/\1  1\/1, (1, 1): 1/1\1, (1, 5): 2/\1  1\/2, (2, 3): 2/\2  20\/0, (2, 2): 0/2\20, (2, 5): 2/\2  21\/1, (3, 4): 2/\0  0\/2, (2, 4): 1/\21  2\/2, (3, 5): 1/\0  0\/1},
-        {(1, 2): 0/\1  1\/0, (1, 3): 2/\1  1\/2, (3, 3): 0/0\0, (4, 5): 2/\1  1\/2, (4, 4): 1/1\1, (5, 5): 2/2\2, (1, 4): 1/\1  1\/1, (1, 1): 1/1\1, (1, 5): 2/\1  1\/2, (2, 3): 2/\2  20\/0, (2, 2): 0/2\20, (2, 5): 2/\2  2\/2, (3, 4): 1/\0  0\/1, (2, 4): 1/\2  2\/1, (3, 5): 2/\0  0\/2},
-        {(1, 2): 0/\10  1\/1, (1, 3): 2/\10  10\/2, (3, 3): 1/1\1, (4, 5): 10/\1  2\/20, (4, 4): 2/2\2, (5, 5): 20/0\2, (1, 4): 1/\1  10\/0, (1, 1): 1/1\1, (1, 5): 2/\1  1\/2, (2, 3): 2/\2  21\/1, (2, 2): 1/2\21, (2, 5): 2/\2  20\/0, (3, 4): 2/\1  1\/2, (2, 4): 0/\20  2\/2, (3, 5): 0/\0  1\/10},
-        {(1, 2): 0/\10  1\/1, (1, 3): 2/\10  10\/2, (3, 3): 1/1\1, (4, 5): 2/\1  1\/2, (4, 4): 10/0\1, (5, 5): 2/2\2, (1, 4): 1/\1  10\/0, (1, 1): 1/1\1, (1, 5): 2/\1  1\/2, (2, 3): 2/\2  21\/1, (2, 2): 1/2\21, (2, 5): 2/\2  2\/2, (3, 4): 0/\0  1\/10, (2, 4): 0/\2  2\/0, (3, 5): 2/\0  0\/2},
-        {(1, 2): 0/\20  21\/1, (1, 3): 2/\2  20\/0, (3, 3): 0/0\0, (4, 5): 2/\1  1\/2, (4, 4): 1/1\1, (5, 5): 2/2\2, (1, 4): 1/\1  2\/21, (1, 1): 1/2\21, (1, 5): 2/\1  1\/2, (2, 3): 0/\1  1\/0, (2, 2): 1/1\1, (2, 5): 2/\2  2\/2, (3, 4): 1/\0  0\/1, (2, 4): 21/\2  1\/1, (3, 5): 2/\0  0\/2},
-        {(1, 2): 0/\20  21\/1, (1, 3): 2/\2  20\/0, (3, 3): 1/1\1, (4, 5): 2/\1  1\/2, (4, 4): 10/0\1, (5, 5): 2/2\2, (1, 4): 1/\1  2\/21, (1, 1): 1/2\21, (1, 5): 2/\1  1\/2, (2, 3): 0/\10  1\/1, (2, 2): 1/1\1, (2, 5): 2/\2  2\/2, (3, 4): 0/\0  1\/10, (2, 4): 21/\2  10\/0, (3, 5): 2/\0  0\/2},
-        {(1, 2): 0/\21  21\/0, (1, 3): 2/\2  21\/1, (3, 3): 0/0\0, (4, 5): 2/\1  1\/2, (4, 4): 1/1\1, (5, 5): 2/2\2, (1, 4): 1/\1  2\/21, (1, 1): 1/2\21, (1, 5): 2/\1  1\/2, (2, 3): 1/\1  10\/0, (2, 2): 0/1\10, (2, 5): 2/\2  2\/2, (3, 4): 1/\0  0\/1, (2, 4): 21/\2  1\/1, (3, 5): 2/\0  0\/2}]
+        [{(1, 1): 1/1\1,
+          (1, 2): 0/\(21)0  1\/2,
+          (1, 3): 2/\1  (21)0\/0,
+          (1, 4): 1/\1  1\/1,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 2/2\2,
+          (2, 3): 0/\2  2\/0,
+          (2, 4): 1/\2  2\/1,
+          (2, 5): 2/\2  2\/2,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (3, 5): 2/\0  0\/2,
+          (4, 4): 1/1\1,
+          (4, 5): 2/\1  1\/2,
+          (5, 5): 2/2\2}, {(1, 1): 1/1\1,
+          (1, 2): 0/\(21)0  1\/2,
+          (1, 3): 2/\1  (21)0\/0,
+          (1, 4): 1/\1  1\/1,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 2/2\2,
+          (2, 3): 0/\2  2\/0,
+          (2, 4): 1/\21  2\/2,
+          (2, 5): 2/\2  21\/1,
+          (3, 3): 0/0\0,
+          (3, 4): 2/\0  0\/2,
+          (3, 5): 1/\0  0\/1,
+          (4, 4): 2/2\2,
+          (4, 5): 1/\1  2\/21,
+          (5, 5): 21/1\2}, {(1, 1): 1/1\1,
+          (1, 2): 0/\(21)0  1\/2,
+          (1, 3): 2/\1  (21)0\/0,
+          (1, 4): 1/\1  1\/1,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 2/2\2,
+          (2, 3): 0/\20  2\/2,
+          (2, 4): 1/\21  20\/0,
+          (2, 5): 2/\2  21\/1,
+          (3, 3): 2/2\2,
+          (3, 4): 0/\0  2\/20,
+          (3, 5): 1/\0  0\/1,
+          (4, 4): 20/0\2,
+          (4, 5): 1/\1  2\/21,
+          (5, 5): 21/1\2}, {(1, 1): 1/1\1,
+          (1, 2): 0/\1  1\/0,
+          (1, 3): 2/\1  1\/2,
+          (1, 4): 1/\1  1\/1,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 0/2\20,
+          (2, 3): 2/\2  20\/0,
+          (2, 4): 1/\2  2\/1,
+          (2, 5): 2/\2  2\/2,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (3, 5): 2/\0  0\/2,
+          (4, 4): 1/1\1,
+          (4, 5): 2/\1  1\/2,
+          (5, 5): 2/2\2}, {(1, 1): 1/1\1,
+          (1, 2): 0/\1  1\/0,
+          (1, 3): 2/\1  1\/2,
+          (1, 4): 1/\1  1\/1,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 0/2\20,
+          (2, 3): 2/\2  20\/0,
+          (2, 4): 1/\21  2\/2,
+          (2, 5): 2/\2  21\/1,
+          (3, 3): 0/0\0,
+          (3, 4): 2/\0  0\/2,
+          (3, 5): 1/\0  0\/1,
+          (4, 4): 2/2\2,
+          (4, 5): 1/\1  2\/21,
+          (5, 5): 21/1\2}, {(1, 1): 1/1\1,
+          (1, 2): 0/\10  1\/1,
+          (1, 3): 2/\10  10\/2,
+          (1, 4): 1/\1  10\/0,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 1/2\21,
+          (2, 3): 2/\2  21\/1,
+          (2, 4): 0/\2  2\/0,
+          (2, 5): 2/\2  2\/2,
+          (3, 3): 1/1\1,
+          (3, 4): 0/\0  1\/10,
+          (3, 5): 2/\0  0\/2,
+          (4, 4): 10/0\1,
+          (4, 5): 2/\1  1\/2,
+          (5, 5): 2/2\2}, {(1, 1): 1/1\1,
+          (1, 2): 0/\10  1\/1,
+          (1, 3): 2/\10  10\/2,
+          (1, 4): 1/\1  10\/0,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 1/2\21,
+          (2, 3): 2/\2  21\/1,
+          (2, 4): 0/\20  2\/2,
+          (2, 5): 2/\2  20\/0,
+          (3, 3): 1/1\1,
+          (3, 4): 2/\1  1\/2,
+          (3, 5): 0/\0  1\/10,
+          (4, 4): 2/2\2,
+          (4, 5): 10/\1  2\/20,
+          (5, 5): 20/0\2}, {(1, 1): 1/2\21,
+          (1, 2): 0/\20  21\/1,
+          (1, 3): 2/\2  20\/0,
+          (1, 4): 1/\1  2\/21,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 1/1\1,
+          (2, 3): 0/\1  1\/0,
+          (2, 4): 21/\2  1\/1,
+          (2, 5): 2/\2  2\/2,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (3, 5): 2/\0  0\/2,
+          (4, 4): 1/1\1,
+          (4, 5): 2/\1  1\/2,
+          (5, 5): 2/2\2}, {(1, 1): 1/2\21,
+          (1, 2): 0/\20  21\/1,
+          (1, 3): 2/\2  20\/0,
+          (1, 4): 1/\1  2\/21,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 1/1\1,
+          (2, 3): 0/\10  1\/1,
+          (2, 4): 21/\2  10\/0,
+          (2, 5): 2/\2  2\/2,
+          (3, 3): 1/1\1,
+          (3, 4): 0/\0  1\/10,
+          (3, 5): 2/\0  0\/2,
+          (4, 4): 10/0\1,
+          (4, 5): 2/\1  1\/2,
+          (5, 5): 2/2\2}, {(1, 1): 1/2\21,
+          (1, 2): 0/\21  21\/0,
+          (1, 3): 2/\2  21\/1,
+          (1, 4): 1/\1  2\/21,
+          (1, 5): 2/\1  1\/2,
+          (2, 2): 0/1\10,
+          (2, 3): 1/\1  10\/0,
+          (2, 4): 21/\2  1\/1,
+          (2, 5): 2/\2  2\/2,
+          (3, 3): 0/0\0,
+          (3, 4): 1/\0  0\/1,
+          (3, 5): 2/\0  0\/2,
+          (4, 4): 1/1\1,
+          (4, 5): 2/\1  1\/2,
+          (5, 5): 2/2\2}]
 
 
     Belkale-Kumar puzzles (the following example is Figure 2 of [KnutsonPurbhoo10]_)::
@@ -1522,7 +1793,21 @@ class KnutsonTaoPuzzleSolver(UniqueRepresentation):
         sage: solns[0].south_labels()
         ('3', '2', '1', '2', '1')
         sage: solns
-        [{(1, 2): 2/\3(2)  3(1)\/1, (1, 3): 1/\3(1)  3(2)\/2, (3, 3): 1/1\1, (4, 5): 1/\1  2\/2(1), (4, 4): 2/2\2, (5, 5): 2(1)/1\2, (1, 4): 3/\3  3(1)\/1, (1, 1): 1/3\3(1), (1, 5): 2/\2  3\/3(2), (2, 3): 2/\2  2(1)\/1, (2, 2): 1/2\2(1), (2, 5): 3(2)/\3  2(1)\/1, (3, 4): 2/\1  1\/2, (2, 4): 1/\2(1)  2\/2, (3, 5): 1/\1  1\/1}]
+        [{(1, 1): 1/3\3(1),
+          (1, 2): 2/\3(2)  3(1)\/1,
+          (1, 3): 1/\3(1)  3(2)\/2,
+          (1, 4): 3/\3  3(1)\/1,
+          (1, 5): 2/\2  3\/3(2),
+          (2, 2): 1/2\2(1),
+          (2, 3): 2/\2  2(1)\/1,
+          (2, 4): 1/\2(1)  2\/2,
+          (2, 5): 3(2)/\3  2(1)\/1,
+          (3, 3): 1/1\1,
+          (3, 4): 2/\1  1\/2,
+          (3, 5): 1/\1  1\/1,
+          (4, 4): 2/2\2,
+          (4, 5): 1/\1  2\/2(1),
+          (5, 5): 2(1)/1\2}]
     """
     def __init__(self, puzzle_pieces):
         r"""
@@ -1594,11 +1879,27 @@ class KnutsonTaoPuzzleSolver(UniqueRepresentation):
             sage: from sage.combinat.knutson_tao_puzzles import KnutsonTaoPuzzleSolver
             sage: ps = KnutsonTaoPuzzleSolver("H")
             sage: ps('0101','1001')
-            [{(1, 2): 1/\1  10\/0, (1, 3): 0/\10  1\/1, (3, 3): 1/1\1, (4, 4): 10/0\1, (1, 4): 1/\1  10\/0,
-            (1, 1): 0/1\10, (2, 3): 1/\0  0\/1, (2, 2): 0/0\0, (3, 4): 0/\0  1\/10, (2, 4): 0/\0  0\/0}]
+            [{(1, 1): 0/1\10,
+              (1, 2): 1/\1  10\/0,
+              (1, 3): 0/\10  1\/1,
+              (1, 4): 1/\1  10\/0,
+              (2, 2): 0/0\0,
+              (2, 3): 1/\0  0\/1,
+              (2, 4): 0/\0  0\/0,
+              (3, 3): 1/1\1,
+              (3, 4): 0/\0  1\/10,
+              (4, 4): 10/0\1}]
             sage: ps('0101','1001',algorithm='pieces')
-            [{(1, 2): 1/\1  10\/0, (1, 3): 0/\10  1\/1, (3, 3): 1/1\1, (4, 4): 10/0\1, (1, 4): 1/\1  10\/0,
-            (2, 4): 0/\0  0\/0, (2, 3): 1/\0  0\/1, (2, 2): 0/0\0, (3, 4): 0/\0  1\/10, (1, 1): 0/1\10}]
+            [{(1, 1): 0/1\10,
+              (1, 2): 1/\1  10\/0,
+              (1, 3): 0/\10  1\/1,
+              (1, 4): 1/\1  10\/0,
+              (2, 2): 0/0\0,
+              (2, 3): 1/\0  0\/1,
+              (2, 4): 0/\0  0\/0,
+              (3, 3): 1/1\1,
+              (3, 4): 0/\0  1\/10,
+              (4, 4): 10/0\1}]
         """
         lamda, mu = tuple(lamda), tuple(mu)
         if algorithm == 'pieces':
@@ -1752,7 +2053,7 @@ class KnutsonTaoPuzzleSolver(UniqueRepresentation):
             sage: list(ps._fill_puzzle_by_strips('0', '0'))
             [{(1, 1): 0/0\0}]
             sage: list(ps._fill_puzzle_by_strips('01', '01'))
-            [{(1, 2): 1/\0  0\/1, (1, 1): 0/0\0, (2, 2): 1/1\1}]
+            [{(1, 1): 0/0\0, (1, 2): 1/\0  0\/1, (2, 2): 1/1\1}]
         """
         queue = [PuzzleFilling(lamda, mu)]
         while queue:
