@@ -13,10 +13,10 @@ the set of :mod:`Dyck words<sage.combinat.dyck_word>` of size `n`.
 
 AUTHORS:
 
-    - Florent Hivert (2009-04)
-    - Christian Stump (2012-11) added pretty printing
+- Florent Hivert (2009-04)
+- Christian Stump (2012-11) added pretty printing
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2007 Florent Hivert <Florent.Hivert@univ-rouen.fr>,
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
@@ -28,19 +28,26 @@ AUTHORS:
 #
 #  The full text of the GPL is available at:
 #
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from __future__ import absolute_import
 
-from sage.rings.integer import Integer
-from .combinat import (CombinatorialClass, CombinatorialObject,
-                      InfiniteAbstractCombinatorialClass, catalan_number)
 from copy import copy
 
+from .combinat import catalan_number
+from sage.categories.infinite_enumerated_sets import InfiniteEnumeratedSets
+from sage.categories.monoids import Monoids
+from sage.rings.all import NN
+from sage.rings.integer import Integer
+from sage.structure.element import Element
+from sage.structure.parent import Parent
+from sage.structure.richcmp import richcmp
+from sage.structure.unique_representation import UniqueRepresentation
+
 
 def NonDecreasingParkingFunctions(n=None):
     r"""
-    Returns the combinatorial class of Non-Decreasing Parking Functions.
+    Return the set of Non-Decreasing Parking Functions.
 
     A *non-decreasing parking function* of size `n` is a non-decreasing
     function `f` from `\{1,\dots,n\}` to itself such that for all `i`,
@@ -54,7 +61,7 @@ def NonDecreasingParkingFunctions(n=None):
         [[1, 1, 1], [1, 1, 2], [1, 1, 3], [1, 2, 2], [1, 2, 3]]
 
     If no size is specified, then NonDecreasingParkingFunctions
-    returns the combinatorial class of all non-decreasing parking functions.
+    returns the set of all non-decreasing parking functions.
 
     ::
 
@@ -72,7 +79,7 @@ def NonDecreasingParkingFunctions(n=None):
         False
 
     If the size `n` is specified, then NonDecreasingParkingFunctions returns
-    combinatorial class of all non-decreasing parking functions of size `n`.
+    the set of all non-decreasing parking functions of size `n`.
 
     ::
 
@@ -112,11 +119,13 @@ def NonDecreasingParkingFunctions(n=None):
     else:
         return NonDecreasingParkingFunctions_n(n)
 
+
 def is_a(x, n=None):
     """
-    Check whether a list is a non-decreasing parking function. If a size
-    `n` is specified, checks if a list is a non-decreasing parking
-    function of size `n`.
+    Check whether a list is a non-decreasing parking function.
+
+    If a size `n` is specified, checks if a list is a non-decreasing
+    parking function of size `n`.
 
     TESTS::
 
@@ -128,11 +137,11 @@ def is_a(x, n=None):
         sage: is_a([1,1,3], 3)
         True
     """
-    if not isinstance(x, list):
+    if not isinstance(x, (list, tuple)):
         return False
     prev = 1
     for i, elt in enumerate(x):
-        if prev > elt or elt > i+1:
+        if prev > elt or elt > i + 1:
             return False
         prev = elt
     if n is not None and n != len(x):
@@ -140,16 +149,233 @@ def is_a(x, n=None):
     return True
 
 
-class NonDecreasingParkingFunctions_all(InfiniteAbstractCombinatorialClass):
+class NonDecreasingParkingFunction(Element):
+    r"""
+    A *non decreasing parking function* of size `n` is a non-decreasing
+    function `f` from `\{1,\dots,n\}` to itself such that for all `i`,
+    one has `f(i) \leq i`.
+
+    EXAMPLES::
+
+        sage: NonDecreasingParkingFunction([])
+        []
+        sage: NonDecreasingParkingFunction([1])
+        [1]
+        sage: NonDecreasingParkingFunction([2])
+        Traceback (most recent call last):
+        ...
+        ValueError: [2] is not a non-decreasing parking function
+        sage: NonDecreasingParkingFunction([1,2])
+        [1, 2]
+        sage: NonDecreasingParkingFunction([1,1,2])
+        [1, 1, 2]
+        sage: NonDecreasingParkingFunction([1,1,4])
+        Traceback (most recent call last):
+        ...
+        ValueError: [1, 1, 4] is not a non-decreasing parking function
+    """
+    def __init__(self, lst):
+        """
+        TESTS::
+
+            sage: NonDecreasingParkingFunction([1, 1, 2, 2, 5, 6])
+            [1, 1, 2, 2, 5, 6]
+        """
+        if not is_a(lst):
+            raise ValueError('%s is not a non-decreasing parking function' % lst)
+        parent = NonDecreasingParkingFunctions_n(len(lst))
+        Element.__init__(self, parent)
+        self._list = lst
+
+    def __getitem__(self, n):
+        """
+        Return the `n^{th}` item in the underlying list.
+
+        .. note::
+
+           Note that this is different than the image of ``n`` under
+           function.  It is "off by one".
+
+        EXAMPLES::
+
+            sage: p = NonDecreasingParkingFunction([1, 1, 2, 2, 5, 6])
+            sage: p[0]
+            1
+            sage: p[2]
+            2
+        """
+        return self._list[n]
+
+    def __call__(self, n):
+        """
+        Return the image of ``n`` under the parking function.
+
+        EXAMPLES::
+
+            sage: p = NonDecreasingParkingFunction([1, 1, 2, 2, 5, 6])
+            sage: p(3)
+            2
+            sage: p(6)
+            6
+        """
+        return self._list[n - 1]
+
+    def _mul_(self, lp):
+        """
+        The composition of non-decreasing parking functions.
+
+        EXAMPLES::
+
+            sage: p = NonDecreasingParkingFunction([1,1,3])
+            sage: q = NonDecreasingParkingFunction([1,2,2])
+            sage: p * q
+            [1, 1, 1]
+            sage: q * p
+            [1, 1, 2]
+        """
+        lp = lp._list
+        sp = self._list
+        lp = lp[:] + [i + 1 for i in range(len(lp), len(lp))]  # ?
+        sp = sp[:] + [i + 1 for i in range(len(sp), len(lp))]
+        return NonDecreasingParkingFunction([sp[i - 1] for i in lp])
+
+    def to_dyck_word(self):
+        """
+        Implement the bijection to :class:`Dyck
+        words<sage.combinat.dyck_word.DyckWords>`, which is defined as follows.
+        Take a non decreasing parking function, say [1,1,2,4,5,5], and draw
+        its graph::
+
+                     ___
+                    |  . 5
+                   _|  . 5
+               ___|  . . 4
+             _|  . . . . 2
+            |  . . . . . 1
+            |  . . . . . 1
+
+        The corresponding Dyck word [1,1,0,1,0,0,1,0,1,1,0,0] is then read off
+        from the sequence of horizontal and vertical steps. The converse
+        bijection is :meth:`.from_dyck_word`.
+
+        EXAMPLES::
+
+            sage: NonDecreasingParkingFunction([1,1,2,4,5,5]).to_dyck_word()
+            [1, 1, 0, 1, 0, 0, 1, 0, 1, 1, 0, 0]
+            sage: NonDecreasingParkingFunction([]).to_dyck_word()
+            []
+            sage: NonDecreasingParkingFunction([1,1,1]).to_dyck_word()
+            [1, 1, 1, 0, 0, 0]
+            sage: NonDecreasingParkingFunction([1,2,3]).to_dyck_word()
+            [1, 0, 1, 0, 1, 0]
+            sage: NonDecreasingParkingFunction([1,1,3,3,4,6,6]).to_dyck_word()
+            [1, 1, 0, 0, 1, 1, 0, 1, 0, 0, 1, 1, 0, 0]
+
+        TESTS::
+
+            sage: ndpf = NonDecreasingParkingFunctions(5)
+            sage: list(ndpf) == [pf.to_dyck_word().to_non_decreasing_parking_function() for pf in ndpf]
+            True
+        """
+        from sage.combinat.dyck_word import CompleteDyckWords_all
+        return CompleteDyckWords_all().from_non_decreasing_parking_function(self)
+
+    def __len__(self):
+        """
+        Return the length of ``self``.
+
+        EXAMPLES::
+
+            sage: ndpf = NonDecreasingParkingFunctions(5)
+            sage: len(ndpf.random_element())
+            5
+        """
+        return len(self._list)
+
+    def _repr_(self):
+        """
+        Return the string representation of ``self``.
+
+        EXAMPLES::
+
+            sage: NonDecreasingParkingFunction([1,1,1])
+            [1, 1, 1]
+        """
+        return str(self._list)
+
+    def _richcmp_(self, other, op):
+        """
+        Compare ``self`` with ``other``.
+
+        EXAMPLES::
+
+            sage: a = NonDecreasingParkingFunction([1,1,1])
+            sage: b = NonDecreasingParkingFunction([1,1,2])
+            sage: a == b, a < b, b <= a
+            (False, True, False)
+        """
+        return richcmp(self._list, other._list, op)
+
+    def __hash__(self):
+        """
+        Return the hash of ``self``.
+
+        EXAMPLES::
+
+            sage: a = NonDecreasingParkingFunction([1,1,1])
+            sage: b = NonDecreasingParkingFunction([1,1,2])
+            sage: hash(a) == hash(b)
+            False
+        """
+        return hash(tuple(self._list))
+
+    @classmethod
+    def from_dyck_word(cls, dw):
+        """
+        Bijection from :class:`Dyck
+        words<sage.combinat.dyck_word.DyckWords>`. It is the inverse of the
+        bijection :meth:`.to_dyck_word`. You can find there the mathematical
+        definition.
+
+        EXAMPLES::
+
+            sage: NonDecreasingParkingFunction.from_dyck_word([])
+            []
+            sage: NonDecreasingParkingFunction.from_dyck_word([1,0])
+            [1]
+            sage: NonDecreasingParkingFunction.from_dyck_word([1,1,0,0])
+            [1, 1]
+            sage: NonDecreasingParkingFunction.from_dyck_word([1,0,1,0])
+            [1, 2]
+            sage: NonDecreasingParkingFunction.from_dyck_word([1,0,1,1,0,1,0,0,1,0])
+            [1, 2, 2, 3, 5]
+
+        TESTS::
+
+          sage: ndpf = NonDecreasingParkingFunctions(5)
+          sage: list(ndpf) == [NonDecreasingParkingFunction.from_dyck_word(pf.to_dyck_word()) for pf in ndpf]
+          True
+        """
+        res = []
+        val = 1
+        for i in dw:
+            if i == 0:
+                val += 1
+            else:
+                res.append(val)
+        return cls(res)
+
+
+class NonDecreasingParkingFunctions_all(UniqueRepresentation, Parent):
     def __init__(self):
         """
         TESTS::
 
-            sage: DW = NonDecreasingParkingFunctions()
-            sage: DW == loads(dumps(DW))
+            sage: PF= NonDecreasingParkingFunctions()
+            sage: PF == loads(dumps(PF))
             True
         """
-        pass
+        Parent.__init__(self, category=InfiniteEnumeratedSets())
 
     def __repr__(self):
         """
@@ -179,23 +405,22 @@ class NonDecreasingParkingFunctions_all(InfiniteAbstractCombinatorialClass):
             return True
         return is_a(x)
 
-    def _infinite_cclass_slice(self, n):
+    def __iter__(self):
         """
-        Needed by InfiniteAbstractCombinatorialClass to buid __iter__.
+        An iterator
 
         TESTS::
 
-            sage: (NonDecreasingParkingFunctions()._infinite_cclass_slice(4)
-            ....:  == NonDecreasingParkingFunctions(4))
-            True
             sage: it = iter(NonDecreasingParkingFunctions()) # indirect doctest
             sage: [next(it) for i in range(8)]
             [[], [1], [1, 1], [1, 2], [1, 1, 1], [1, 1, 2], [1, 1, 3], [1, 2, 2]]
-         """
-        return NonDecreasingParkingFunctions_n(n)
+        """
+        for n in NN:
+            for pf in NonDecreasingParkingFunctions_n(n):
+                yield pf
 
 
-class NonDecreasingParkingFunctions_n(CombinatorialClass):
+class NonDecreasingParkingFunctions_n(UniqueRepresentation, Parent):
     r"""
     The combinatorial class of non-decreasing parking functions of
     size `n`.
@@ -234,11 +459,13 @@ class NonDecreasingParkingFunctions_n(CombinatorialClass):
             sage: PF = NonDecreasingParkingFunctions(3)
             sage: PF == loads(dumps(PF))
             True
+            sage: TestSuite(PF).run(skip='_test_elements')
         """
         n = Integer(n)
         if n < 0:
             raise ValueError('%s is not a non-negative integer' % n)
         self.n = n
+        Parent.__init__(self, category=Monoids().Enumerated().Finite())
 
     def __repr__(self):
         """
@@ -247,7 +474,7 @@ class NonDecreasingParkingFunctions_n(CombinatorialClass):
             sage: repr(NonDecreasingParkingFunctions(3))
             'Non-decreasing parking functions of size 3'
         """
-        return "Non-decreasing parking functions of size %s"%(self.n)
+        return "Non-decreasing parking functions of size %s" % self.n
 
     def __contains__(self, x):
         """
@@ -274,8 +501,10 @@ class NonDecreasingParkingFunctions_n(CombinatorialClass):
 
     def cardinality(self):
         """
-        Returns the number of non-decreasing parking functions of size
-        `n`. This number is the `n`-th :func:`Catalan
+        Return the number of non-decreasing parking functions of size
+        `n`.
+
+        This number is the `n`-th :func:`Catalan
         number<sage.combinat.combinat.catalan_number>`.
 
         EXAMPLES::
@@ -295,9 +524,42 @@ class NonDecreasingParkingFunctions_n(CombinatorialClass):
         """
         return catalan_number(self.n)
 
+    def random_element(self):
+        """
+        Return a random parking function of the given size.
+
+        EXAMPLES::
+
+            sage: ndpf = NonDecreasingParkingFunctions(5)
+            sage: x = ndpf.random_element(); x  # random
+            [1, 2, 2, 4, 5]
+            sage: x in ndpf
+            True
+        """
+        from sage.combinat.dyck_word import DyckWords
+        n = self.n
+        dw = DyckWords(n).random_element()
+        return NonDecreasingParkingFunction.from_dyck_word(dw)
+
+    def one(self):
+        """
+        Return the unit of this monoid.
+
+        This is the non-decreasing parking function [1, 2, ..., n].
+
+        EXAMPLES::
+
+            sage: ndpf = NonDecreasingParkingFunctions(5)
+            sage: x = ndpf.random_element(); x  # random
+            sage: e = ndpf.one()
+            sage: x == e*x == x*e
+            True
+        """
+        return NonDecreasingParkingFunction(list(range(1, self.n + 1)))
+
     def __iter__(self):
         """
-        Returns an iterator for non-decreasing parking functions of size `n`.
+        Return an iterator for non-decreasing parking functions of size `n`.
 
         .. warning::
 
@@ -338,12 +600,14 @@ class NonDecreasingParkingFunctions_n(CombinatorialClass):
                 sage: [e for e in PF]      # indirect doctest
                 [[1, 1], [1, 2]]
             """
-            if n==0:
-                yield [ ]; return
-            if n==1:
-                yield [1]; return
-            for res1 in iterator_rec(n-1):
-                for i in range(res1[-1], n+1):
+            if n == 0:
+                yield []
+                return
+            if n == 1:
+                yield [1]
+                return
+            for res1 in iterator_rec(n - 1):
+                for i in range(res1[-1], n + 1):
                     res = copy(res1)
                     res.append(i)
                     yield res
@@ -352,169 +616,4 @@ class NonDecreasingParkingFunctions_n(CombinatorialClass):
             yield NonDecreasingParkingFunction(res)
         return
 
-
-class NonDecreasingParkingFunction(CombinatorialObject):
-    r"""
-    A *non decreasing parking function* of size `n` is a non-decreasing
-    function `f` from `\{1,\dots,n\}` to itself such that for all `i`,
-    one has `f(i) \leq i`.
-
-    EXAMPLES::
-
-        sage: NonDecreasingParkingFunction([])
-        []
-        sage: NonDecreasingParkingFunction([1])
-        [1]
-        sage: NonDecreasingParkingFunction([2])
-        Traceback (most recent call last):
-        ...
-        ValueError: [2] is not a non-decreasing parking function
-        sage: NonDecreasingParkingFunction([1,2])
-        [1, 2]
-        sage: NonDecreasingParkingFunction([1,1,2])
-        [1, 1, 2]
-        sage: NonDecreasingParkingFunction([1,1,4])
-        Traceback (most recent call last):
-        ...
-        ValueError: [1, 1, 4] is not a non-decreasing parking function
-    """
-    def __init__(self, lst):
-        """
-        TESTS::
-
-            sage: NonDecreasingParkingFunction([1, 1, 2, 2, 5, 6])
-            [1, 1, 2, 2, 5, 6]
-        """
-        if not is_a(lst):
-            raise ValueError('%s is not a non-decreasing parking function' % lst)
-        CombinatorialObject.__init__(self, lst)
-
-    def __getitem__(self, n):
-        """
-        Returns the `n^{th}` item in the underlying list.
-
-        .. note::
-
-           Note that this is different than the image of ``n`` under
-           function.  It is "off by one".
-
-        EXAMPLES::
-
-            sage: p = NonDecreasingParkingFunction([1, 1, 2, 2, 5, 6])
-            sage: p[0]
-            1
-            sage: p[2]
-            2
-        """
-        return self._list[n]
-
-    def __call__(self, n):
-        """
-        Returns the image of ``n`` under the parking function.
-
-        EXAMPLES::
-
-            sage: p = NonDecreasingParkingFunction([1, 1, 2, 2, 5, 6])
-            sage: p(3)
-            2
-            sage: p(6)
-            6
-        """
-        return self._list[n-1]
-
-    def __mul__(self, lp):
-        """
-        The composition of non-decreasing parking functions.
-
-        EXAMPLES::
-
-            sage: p = NonDecreasingParkingFunction([1,1,3])
-            sage: q = NonDecreasingParkingFunction([1,2,2])
-            sage: p * q
-            [1, 1, 1]
-            sage: q * p
-            [1, 1, 2]
-        """
-        lp = lp._list
-        sp = self._list
-        lp = lp[:] + [i+1 for i in range(len(lp), len(lp))]
-        sp = sp[:] + [i+1 for i in range(len(sp), len(lp))]
-        return NonDecreasingParkingFunction([ sp[i-1] for i in lp ])
-
-    def to_dyck_word(self):
-        """
-        Implements the bijection to :class:`Dyck
-        words<sage.combinat.dyck_word.DyckWords>`, which is defined as follows.
-        Take a non decreasing parking function, say [1,1,2,4,5,5], and draw
-        its graph::
-
-                     ___
-                    |  . 5
-                   _|  . 5
-               ___|  . . 4
-             _|  . . . . 2
-            |  . . . . . 1
-            |  . . . . . 1
-
-        The corresponding Dyck word [1,1,0,1,0,0,1,0,1,1,0,0] is then read off
-        from the sequence of horizontal and vertical steps. The converse
-        bijection is :meth:`.from_dyck_word`.
-
-        EXAMPLES::
-
-            sage: NonDecreasingParkingFunction([1,1,2,4,5,5]).to_dyck_word()
-            [1, 1, 0, 1, 0, 0, 1, 0, 1, 1, 0, 0]
-            sage: NonDecreasingParkingFunction([]).to_dyck_word()
-            []
-            sage: NonDecreasingParkingFunction([1,1,1]).to_dyck_word()
-            [1, 1, 1, 0, 0, 0]
-            sage: NonDecreasingParkingFunction([1,2,3]).to_dyck_word()
-            [1, 0, 1, 0, 1, 0]
-            sage: NonDecreasingParkingFunction([1,1,3,3,4,6,6]).to_dyck_word()
-            [1, 1, 0, 0, 1, 1, 0, 1, 0, 0, 1, 1, 0, 0]
-
-        TESTS::
-
-            sage: ndpf=NonDecreasingParkingFunctions(5);
-            sage: list(ndpf) == [pf.to_dyck_word().to_non_decreasing_parking_function() for pf in ndpf]
-            True
-        """
-        from sage.combinat.dyck_word import CompleteDyckWords_all
-        return CompleteDyckWords_all().from_non_decreasing_parking_function(self)
-
-    @classmethod
-    def from_dyck_word(cls, dw):
-        """
-        Bijection from :class:`Dyck
-        words<sage.combinat.dyck_word.DyckWords>`. It is the inverse of the
-        bijection :meth:`.to_dyck_word`. You can find there the mathematical
-        definition.
-
-        EXAMPLES::
-
-            sage: NonDecreasingParkingFunction.from_dyck_word([])
-            []
-            sage: NonDecreasingParkingFunction.from_dyck_word([1,0])
-            [1]
-            sage: NonDecreasingParkingFunction.from_dyck_word([1,1,0,0])
-            [1, 1]
-            sage: NonDecreasingParkingFunction.from_dyck_word([1,0,1,0])
-            [1, 2]
-            sage: NonDecreasingParkingFunction.from_dyck_word([1,0,1,1,0,1,0,0,1,0])
-            [1, 2, 2, 3, 5]
-
-        TESTS::
-
-          sage: ndpf=NonDecreasingParkingFunctions(5);
-          sage: list(ndpf) == [NonDecreasingParkingFunction.from_dyck_word(pf.to_dyck_word()) for pf in ndpf]
-          True
-        """
-        res = []
-        val = 1
-        for i in dw:
-            if i == 0:
-                val+=1
-            else:
-                res.append(val)
-        return cls(res)
-
+    Element = NonDecreasingParkingFunction
