@@ -10,7 +10,8 @@ AUTHORS:
   lines, and tableaux of skew partition, composition, and
   skew/composition/partition/tableaux tuple shape.
 """
-from __future__ import print_function
+
+from __future__ import absolute_import, print_function
 
 from six.moves import range
 
