@@ -33,7 +33,6 @@ from sage.structure.unique_representation import UniqueRepresentation
 from sage.structure.parent import Parent
 from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
 from sage.graphs.digraph import DiGraph
-import sage.graphs.linearextensions
 from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
 from sage.graphs.dot2tex_utils import have_dot2tex
 from sage.structure.list_clone import ClonableArray
@@ -279,18 +278,18 @@ class LinearExtensionOfPoset(ClonableArray):
             1 [1, 2, 3, 4] [2, 1, 3, 4]
             2 [1, 2, 3, 4] [1, 2, 3, 4]
             3 [1, 2, 3, 4] [1, 2, 4, 3]
-            1 [1, 2, 4, 3] [2, 1, 4, 3]
-            2 [1, 2, 4, 3] [1, 4, 2, 3]
-            3 [1, 2, 4, 3] [1, 2, 3, 4]
-            1 [1, 4, 2, 3] [1, 4, 2, 3]
-            2 [1, 4, 2, 3] [1, 2, 4, 3]
-            3 [1, 4, 2, 3] [1, 4, 2, 3]
             1 [2, 1, 3, 4] [1, 2, 3, 4]
             2 [2, 1, 3, 4] [2, 1, 3, 4]
             3 [2, 1, 3, 4] [2, 1, 4, 3]
             1 [2, 1, 4, 3] [1, 2, 4, 3]
             2 [2, 1, 4, 3] [2, 1, 4, 3]
             3 [2, 1, 4, 3] [2, 1, 3, 4]
+            1 [1, 4, 2, 3] [1, 4, 2, 3]
+            2 [1, 4, 2, 3] [1, 2, 4, 3]
+            3 [1, 4, 2, 3] [1, 4, 2, 3]
+            1 [1, 2, 4, 3] [2, 1, 4, 3]
+            2 [1, 2, 4, 3] [1, 4, 2, 3]
+            3 [1, 2, 4, 3] [1, 2, 3, 4]
 
         TESTS::
 
@@ -430,7 +429,7 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
         sage: L.cardinality()
         5
         sage: L.list()
-        [[1, 2, 3, 4], [1, 2, 4, 3], [1, 4, 2, 3], [2, 1, 3, 4], [2, 1, 4, 3]]
+        [[1, 2, 3, 4], [2, 1, 3, 4], [2, 1, 4, 3], [1, 4, 2, 3], [1, 2, 4, 3]]
         sage: L.an_element()
         [1, 2, 3, 4]
         sage: L.poset()
@@ -465,8 +464,6 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
             True
             sage: L._poset is P
             True
-            sage: L._linear_extensions_of_hasse_diagram
-            Linear extensions of Hasse diagram of a poset containing 3 elements
             sage: TestSuite(L).run()
 
             sage: P = Poset((divisors(15), attrcall("divides")))
@@ -481,7 +478,6 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
             sage: TestSuite(L).run(skip="_test_an_element")
         """
         self._poset = poset
-        self._linear_extensions_of_hasse_diagram = sage.graphs.linearextensions.LinearExtensions(poset._hasse_diagram)
         self._is_facade = facade
         if facade:
             facade = (list,)
@@ -608,10 +604,11 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
             sage: P = Poset((elms, rels), linear_extension=True)
             sage: L = P.linear_extensions()
             sage: list(L)
-            [[1, 2, 3, 4], [1, 2, 4, 3], [1, 4, 2, 3], [2, 1, 3, 4], [2, 1, 4, 3]]
+            [[1, 2, 3, 4], [2, 1, 3, 4], [2, 1, 4, 3], [1, 4, 2, 3], [1, 2, 4, 3]]
         """
+        from sage.combinat.combinat_cython import linear_extension_iterator
         vertex_to_element = self._poset._vertex_to_element
-        for lin_ext in self._linear_extensions_of_hasse_diagram:
+        for lin_ext in linear_extension_iterator(self._poset._hasse_diagram):
             yield self._element_constructor_([vertex_to_element(_) for _ in lin_ext])
 
     def __contains__(self, obj):
@@ -723,18 +720,19 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
             sage: G = L.markov_chain_digraph(labeling = 'source'); G
             Looped multi-digraph on 5 vertices
         """
-        d = dict([x,dict([y,[]] for y in self)] for x in self)
+        L = sorted(self)
+        d = dict([x,dict([y,[]] for y in L)] for x in L)
         if action == 'promotion':
             R = list(range(self.poset().cardinality()))
         else:
             R = list(range(self.poset().cardinality() - 1))
         if labeling == 'source':
-            for x in self:
+            for x in L:
                 for i in R:
                     child = getattr(x, action)(i+1)
                     d[x][child]+=[self.poset().unwrap(x[i])]
         else:
-            for x in self:
+            for x in L:
                 for i in R:
                     child = getattr(x, action)(i+1)
                     d[x][child]+=[i+1]
@@ -795,7 +793,7 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
         """
         from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
         from sage.matrix.constructor import matrix
-        L = self.list()
+        L = sorted(self.list())
         n = self.poset().cardinality()
         R = PolynomialRing(QQ, 'x', n)
         x = [R.gen(i) for i in range(n)]
