@@ -80,8 +80,8 @@ class RiggedConfigurations(UniqueRepresentation, Parent):
 
     .. MATH::
 
-        \sum_{\overline{I} \times \mathbb{Z}_{>0}} i m_i^{(a)} \alpha_a
-        = \sum_{\overline{I} \times \mathbb{Z}_{>0}} i L_i^{(a)} \Lambda_a
+        \sum_{\overline{I} \times \ZZ_{>0}} i m_i^{(a)} \alpha_a
+        = \sum_{\overline{I} \times \ZZ_{>0}} i L_i^{(a)} \Lambda_a
         - \Lambda
 
     where `\alpha_a` is a simple root, `\Lambda_a` is a fundamental weight,
