@@ -1,13 +1,13 @@
 """
 Weyl Character Rings
 """
-#*****************************************************************************
+# ****************************************************************************
 #  Copyright (C) 2011 Daniel Bump <bump at match.stanford.edu>
 #                     Nicolas Thiery <nthiery at users.sf.net>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from __future__ import print_function
 
 import sage.combinat.root_system.branching_rules
@@ -17,7 +17,9 @@ from sage.combinat.root_system.cartan_type import CartanType
 from sage.combinat.root_system.root_system import RootSystem
 from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_attribute import lazy_attribute
+from sage.sets.recursively_enumerated_set import RecursivelyEnumeratedSet
 from sage.misc.functional import is_even
+from sage.misc.misc import inject_variable
 from sage.rings.all import ZZ
 
 
@@ -90,7 +92,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
     https://doc.sagemath.org/html/en/thematic_tutorials/lie.html
     """
     @staticmethod
-    def __classcall__(cls, ct, base_ring=ZZ, prefix=None, style="lattice"):
+    def __classcall__(cls, ct, base_ring=ZZ, prefix=None, style="lattice", k=None):
         """
         TESTS::
 
@@ -106,9 +108,9 @@ class WeylCharacterRing(CombinatorialFreeModule):
                 prefix = ct[0]+str(ct[1])
             else:
                 prefix = repr(ct)
-        return super(WeylCharacterRing, cls).__classcall__(cls, ct, base_ring=base_ring, prefix=prefix, style=style)
+        return super(WeylCharacterRing, cls).__classcall__(cls, ct, base_ring=base_ring, prefix=prefix, style=style, k=k)
 
-    def __init__(self, ct, base_ring=ZZ, prefix=None, style="lattice"):
+    def __init__(self, ct, base_ring=ZZ, prefix=None, style="lattice", k=None):
         """
         EXAMPLES::
 
@@ -128,12 +130,32 @@ class WeylCharacterRing(CombinatorialFreeModule):
                 prefix = repr(ct)
         self._prefix = prefix
         self._style = style
+        self._fusion_labels = None
+        self._k = k
+        if ct.is_irreducible():
+            self._opposition = ct.opposition_automorphism()
+            self._highest = self._space.highest_root()
+            self._hip = self._highest.inner_product(self._highest)
         if style == "coroots":
             self._word = self._space.weyl_group().long_element().reduced_word()
+
+        # Set the basis
+        if k is not None:
+            self._prefix += str(k)
+            fw = self._space.fundamental_weights()
+            def next_level(wt):
+                return [wt + la for la in fw if self.level(wt + la) <= k]
+            B = list(RecursivelyEnumeratedSet([self._space.zero()], next_level))
+            B = [self._space.from_vector_notation(wt, style=style) for wt in B]
+        else:
+            B = self._space
+
         # TODO: remove the Category.join once not needed anymore (bug in CombinatorialFreeModule)
-        # TODO: use GradedAlgebrasWithBasis
-        category = Category.join([AlgebrasWithBasis(base_ring), Algebras(base_ring).Subobjects()])
-        CombinatorialFreeModule.__init__(self, base_ring, self._space, category = category)
+        category = Category.join([AlgebrasWithBasis(base_ring),
+                                  Algebras(base_ring).Subobjects()])
+        if k is None:
+            category = category.Graded()
+        CombinatorialFreeModule.__init__(self, base_ring, B, category=category)
 
         # Register the embedding of self into ambient as a coercion
         self.lift.register_as_coercion()
@@ -143,7 +165,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
     @cached_method
     def ambient(self):
         """
-        Returns the weight ring of ``self``.
+        Return the weight ring of ``self``.
 
         EXAMPLES::
 
@@ -173,7 +195,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
             sage: A2.lift_on_basis(v)
             2*a2(1,1,1) + a2(1,2,0) + a2(1,0,2) + a2(2,1,0) + a2(2,0,1) + a2(0,1,2) + a2(0,2,1)
 
-        This is consistent with the analoguous calculation with symmetric
+        This is consistent with the analogous calculation with symmetric
         Schur functions::
 
             sage: s = SymmetricFunctions(QQ).s()
@@ -207,8 +229,8 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: A2=WeylCharacterRing("A2",style="coroots")
-            sage: h=sum(A2.fundamental_weights()); h
+            sage: A2 = WeylCharacterRing("A2",style="coroots")
+            sage: h = sum(A2.fundamental_weights()); h
             (2, 1, 0)
             sage: A2.demazure_character(h,word=[1,2])
             a2(0,0) + a2(-2,1) + a2(2,-1) + a2(1,1) + a2(-1,2)
@@ -335,7 +357,11 @@ class WeylCharacterRing(CombinatorialFreeModule):
             sage: WeylCharacterRing("A3")
             The Weyl Character Ring of Type A3 with Integer Ring coefficients
         """
-        return "The Weyl Character Ring of Type {} with {} coefficients".format(self._cartan_type._repr_(compact=True), self._base_ring)
+        if self._k is None:
+            return "The Weyl Character Ring of Type {} with {} coefficients".format(self._cartan_type._repr_(compact=True), self._base_ring)
+        else:
+            return "The Fusion Ring of Type {} and level {} with {} coefficients".format(self._cartan_type._repr_(compact=True), self._k, self._base_ring)
+
 
     def __call__(self, *args):
         """
@@ -414,6 +440,9 @@ class WeylCharacterRing(CombinatorialFreeModule):
         weight = self._space.from_vector_notation(weight, style = self._style)
         if not weight.is_dominant_weight():
             raise ValueError("{} is not a dominant element of the weight lattice".format(weight))
+        if self._k is not None:
+            if self.level(weight) > self._k:
+                raise ValueError("{} has level greater than {}".format(weight, self._k))
         return self.monomial(weight)
 
     def product_on_basis(self, a, b):
@@ -507,8 +536,39 @@ class WeylCharacterRing(CombinatorialFreeModule):
                     ret -= (1+c)*alpha[i]
                     done = False
                     break
+            if self._k is not None:
+                l = self.level(ret)
+                k = self._k
+                if l > k:
+                    if l == k+1:
+                        return [0, self._space.zero()]
+                    else:
+                        epsilon = -epsilon
+                        ret = self.affine_reflect(ret,k+1)
+                        done = False
         return [epsilon, ret]
 
+    def affine_reflect(self, wt, k=0):
+        r"""
+        INPUT:
+
+        - ``wt`` -- a weight
+        - ``k`` -- (optional) a positive integer
+
+        Returns the reflection of wt in the hyperplane
+        `\theta`. Optionally shifts by a multiple `k`of `\theta`.
+
+        EXAMPLES::
+
+            sage: B22 = FusionRing("B2",2)
+            sage: fw = B22.fundamental_weights(); fw
+            Finite family {1: (1, 0), 2: (1/2, 1/2)}
+            sage: [B22.affine_reflect(x,2) for x in fw]
+            [(2, 1), (3/2, 3/2)]
+        """
+        coef = ZZ(2*wt.inner_product(self._highest)/self._hip)
+        return wt+(k-coef)*self._highest
+
     def some_elements(self):
         """
         Return some elements of ``self``.
@@ -549,7 +609,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: A2=WeylCharacterRing("A2")
+            sage: A2 = WeylCharacterRing("A2")
             sage: v = A2.fundamental_weights()[1]; v
             (1, 0, 0)
             sage: A2._irr_weights(v)
@@ -578,7 +638,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: B2=WeylCharacterRing("B2", style="coroots")
+            sage: B2 = WeylCharacterRing("B2", style="coroots")
             sage: [B2._demazure_weights(v, word=[1,2]) for v in B2.fundamental_weights()]
             [{(1, 0): 1, (0, 1): 1}, {(-1/2, 1/2): 1, (1/2, -1/2): 1, (1/2, 1/2): 1}]
         """
@@ -603,7 +663,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: A2=WeylCharacterRing("A2",style="coroots")
+            sage: A2 = WeylCharacterRing("A2",style="coroots")
             sage: dd = {}; dd[(1,1)]=int(1)
             sage: A2._demazure_helper(dd,word=[1,2])
             {(0, 0, 0): 1, (-1, 1, 0): 1, (1, -1, 0): 1, (1, 0, -1): 1, (0, 1, -1): 1}
@@ -661,8 +721,8 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: B2=WeylCharacterRing("B2",style="coroots")
-            sage: chi=2*B2(1,0)
+            sage: B2 = WeylCharacterRing("B2",style="coroots")
+            sage: chi = 2*B2(1,0)
             sage: B2._weight_multiplicities(chi)
             {(0, 0): 2, (-1, 0): 2, (1, 0): 2, (0, -1): 2, (0, 1): 2}
         """
@@ -710,6 +770,40 @@ class WeylCharacterRing(CombinatorialFreeModule):
         """
         return self._prefix+self._wt_repr(hwv)
 
+    def level(self, wt):
+        """
+        Return the level of the weight, defined to be the value of
+        the weight on the coroot associated with the highest root.
+
+        EXAMPLES::
+
+            sage: R = FusionRing("F4",2); [R.level(x) for x in R.fundamental_weights()]
+            [2, 3, 2, 1]
+            sage: [CartanType("F4~").dual().a()[x] for x in [1..4]]
+            [2, 3, 2, 1]
+        """
+        return ZZ(2*wt.inner_product(self._highest)/self._hip)
+
+    def _dual_helper(self, wt):
+        """
+        If `w_0` is the long Weyl group element and `wt` is an
+        element of the weight lattice, this returns `-w_0(wt)`.
+
+        EXAMPLES::
+
+            sage: A3=WeylCharacterRing("A3")
+            sage: [A3._dual_helper(x) for x in A3.fundamental_weights()]
+            [(0, 0, 0, -1), (0, 0, -1, -1), (0, -1, -1, -1)]
+        """
+        if self.cartan_type()[0] == 'A': # handled separately for GL(n) compatibility
+            return self.space()([-x for x in reversed(wt.to_vector().list())])
+        ret = 0
+        alphacheck = self._space.simple_coroots()
+        fw = self._space.fundamental_weights()
+        for i in self._space.index_set():
+            ret += wt.inner_product(alphacheck[i])*fw[self._opposition[i]]
+        return ret
+
     def _wt_repr(self, wt):
         """
         Produce a representation of a vector in either coweight or
@@ -748,7 +842,11 @@ class WeylCharacterRing(CombinatorialFreeModule):
             sage: [G2._repr_term(x) for x in G2.fundamental_weights()]
             ['G2(1,0,-1)', 'G2(2,-1,-1)']
         """
-        return self.irr_repr(t)
+        if self._fusion_labels is not None:
+            t = tuple([t.inner_product(x) for x in self.simple_coroots()])
+            return self._fusion_labels[t]
+        else:
+            return self.irr_repr(t)
 
     def cartan_type(self):
         """
@@ -796,7 +894,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
     def highest_root(self):
         """
-        Return the highest_root.
+        Return the highest root.
 
         EXAMPLES::
 
@@ -945,22 +1043,22 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
     def adjoint_representation(self):
         """
-        Returns the adjoint representation as an element of the WeylCharacterRing".
+        Return the adjoint representation as an element of the WeylCharacterRing.
 
         EXAMPLES::
 
-            sage: G2=WeylCharacterRing("G2",style="coroots")
+            sage: G2 = WeylCharacterRing("G2",style="coroots")
             sage: G2.adjoint_representation()
             G2(0,1)
         """
         return self(self.highest_root())
 
     def maximal_subgroups(self):
-        """
+        r"""
         This method is only available if the Cartan type of
-        self is irreducible and of rank no greater than 8.
+        ``self`` is irreducible and of rank no greater than 8.
         This method produces a list of the maximal subgroups
-        of self, up to (possibly outer) automorphisms. Each line
+        of ``self``, up to (possibly outer) automorphisms. Each line
         in the output gives the Cartan type of a maximal subgroup
         followed by a command that creates the branching rule.
 
@@ -1022,11 +1120,13 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
     def maximal_subgroup(self, ct):
         """
+        Return a branching rule or a list of branching rules.
+
         INPUT:
 
-        - ``ct`` -- the Cartan type of a maximal subgroup of self.
+        - ``ct`` -- the Cartan type of a maximal subgroup of ``self``.
 
-        Returns a branching rule. In rare cases where there is
+        In rare cases where there is
         more than one maximal subgroup (up to outer automorphisms)
         with the given Cartan type, the function returns a list of
         branching rules.
@@ -1060,7 +1160,9 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
         def degree(self):
             """
-            The degree of ``self``, that is, the dimension of module.
+            Return the degree of ``self``.
+
+            This is the dimension of the associated module.
 
             EXAMPLES::
 
@@ -1069,12 +1171,13 @@ class WeylCharacterRing(CombinatorialFreeModule):
                 [7, 21, 8]
             """
             L = self.parent()._space
-            return sum(L.weyl_dimension(k)*c for k,c in self)
+            return sum(L.weyl_dimension(k) * c for k, c in self)
 
         def branch(self, S, rule="default"):
             """
-            Return the restriction of the character to the subalgebra. If no
-            rule is specified, we will try to specify one.
+            Return the restriction of the character to the subalgebra.
+
+            If no rule is specified, we will try to specify one.
 
             INPUT:
 
@@ -1082,8 +1185,8 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
             -  ``rule`` -- a branching rule
 
-            See :func:`branch_weyl_character` for more information
-            about branching rules.
+            See :func:`~sage.combinat.root_system.branching_rules.branch_weyl_character`
+            for more information about branching rules.
 
             EXAMPLES::
 
@@ -1096,9 +1199,50 @@ class WeylCharacterRing(CombinatorialFreeModule):
             """
             return sage.combinat.root_system.branching_rules.branch_weyl_character(self, self.parent(), S, rule=rule)
 
+        def dual(self):
+            """
+            The involution that replaces a representation with
+            its contragredient. (For Fusion rings, this is the
+            conjugation map.)
+
+            EXAMPLES::
+
+                sage: A3 = WeylCharacterRing("A3", style="coroots")
+                sage: A3(1,0,0)^2
+                A3(0,1,0) + A3(2,0,0)
+                sage: (A3(1,0,0)^2).dual()
+                A3(0,1,0) + A3(0,0,2)
+            """
+            if not self.parent().cartan_type().is_irreducible():
+                raise NotImplementedError("dual method is not implemented for reducible types")
+            d = self.monomial_coefficients()
+            WCR = self.parent()
+            return sum(d[k] * WCR._element_constructor_(self.parent()._dual_helper(k))
+                       for k in d)
+
+        def highest_weight(self):
+            r"""
+            Return the parametrizing dominant weight of an irreducible
+            character or simple element of a FusionRing.
+
+            This method is only available for basis elements.
+
+            EXAMPLES::
+
+                sage: G2 = WeylCharacterRing("G2", style="coroots")
+                sage: [x.highest_weight() for x in [G2(1,0),G2(0,1)]]
+                [(1, 0, -1), (2, -1, -1)]
+                sage: A21 = FusionRing("A2",1)
+                sage: [x.highest_weight() for x in A21.basis()]
+                [(0, 0, 0), (1/3, 1/3, -2/3), (2/3, -1/3, -1/3)]
+            """
+            if len(self.monomial_coefficients()) != 1:
+                raise ValueError("fusion weight is valid for basis elements only")
+            return self.leading_support()
+
         def __pow__(self, n):
             """
-            Return the nth power of self.
+            Return the n-th power of ``self``.
 
             We override the method in :mod:`sage.monoids.monoids` since
             using the Brauer-Klimyk algorithm, it is more efficient to
@@ -1164,8 +1308,8 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
             EXAMPLES::
 
-                sage: B3=WeylCharacterRing("B3",style="coroots")
-                sage: spin=B3(0,0,1)
+                sage: B3 = WeylCharacterRing("B3",style="coroots")
+                sage: spin = B3(0,0,1)
                 sage: spin.symmetric_power(6)
                 B3(0,0,0) + B3(0,0,2) + B3(0,0,4) + B3(0,0,6)
             """
@@ -1203,8 +1347,8 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
             EXAMPLES::
 
-                sage: B3=WeylCharacterRing("B3",style="coroots")
-                sage: spin=B3(0,0,1)
+                sage: B3 = WeylCharacterRing("B3",style="coroots")
+                sage: spin = B3(0,0,1)
                 sage: spin.exterior_power(6)
                 B3(1,0,0) + B3(0,1,0)
             """
@@ -1239,7 +1383,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
             EXAMPLES::
 
-                sage: A2=WeylCharacterRing("A2")
+                sage: A2 = WeylCharacterRing("A2")
                 sage: A2(1,1,0).adams_operation(3)
                 A2(2,2,2) - A2(3,2,1) + A2(3,3,0)
             """
@@ -1258,7 +1402,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
             EXAMPLES::
 
-                sage: A2=WeylCharacterRing("A2")
+                sage: A2 = WeylCharacterRing("A2")
                 sage: A2(1,1,0)._adams_operation_helper(3)
                 {(3, 3, 0): 1, (3, 0, 3): 1, (0, 3, 3): 1}
             """
@@ -1378,12 +1522,14 @@ class WeylCharacterRing(CombinatorialFreeModule):
 
         def weight_multiplicities(self):
             """
-            Produce the dictionary of weight multiplicities for the Weyl
-            character ``self``. The character does not have to be irreducible.
+            Return the dictionary of weight multiplicities for the Weyl
+            character ``self``.
+
+            The character does not have to be irreducible.
 
             EXAMPLES::
 
-                sage: B2=WeylCharacterRing("B2",style="coroots")
+                sage: B2 = WeylCharacterRing("B2",style="coroots")
                 sage: B2(0,1).weight_multiplicities()
                 {(-1/2, -1/2): 1, (-1/2, 1/2): 1, (1/2, -1/2): 1, (1/2, 1/2): 1}
             """
@@ -1404,7 +1550,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
             EXAMPLES::
 
                 sage: A2 = WeylCharacterRing("A2")
-                sage: [f1,f2]=A2.fundamental_weights()
+                sage: [f1,f2] = A2.fundamental_weights()
                 sage: r1 = A2(f1)*A2(f2); r1
                 A2(1,1,1) + A2(2,1,0)
                 sage: r2 = A2(f1)^3; r2
@@ -1412,7 +1558,8 @@ class WeylCharacterRing(CombinatorialFreeModule):
                 sage: r1.inner_product(r2)
                 3
             """
-            return sum(self.coefficient(x)*other.coefficient(x) for x in self.monomial_coefficients())
+            return sum(self.coefficient(x) * other.coefficient(x)
+                       for x in self.monomial_coefficients())
 
         def invariant_degree(self):
             """
@@ -1598,7 +1745,6 @@ class WeightRing(CombinatorialFreeModule):
         category = AlgebrasWithBasis(self._base_ring)
         CombinatorialFreeModule.__init__(self, self._base_ring, self._space, category = category)
 
-
     def _repr_(self):
         """
         EXAMPLES::
@@ -1674,8 +1820,8 @@ class WeightRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: A2=WeylCharacterRing("A2")
-            sage: a2=WeightRing(A2)
+            sage: A2 = WeylCharacterRing("A2")
+            sage: a2 = WeightRing(A2)
             sage: a2(1,0,0) * a2(0,1,0) # indirect doctest
             a2(1,1,0)
         """
@@ -1687,8 +1833,8 @@ class WeightRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: A3=WeylCharacterRing("A3")
-            sage: a3=WeightRing(A3)
+            sage: A3 = WeylCharacterRing("A3")
+            sage: a3 = WeightRing(A3)
             sage: a3.some_elements()
             [a3(1,0,0,0), a3(1,1,0,0), a3(1,1,1,0)]
         """
@@ -1700,7 +1846,7 @@ class WeightRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: A3=WeylCharacterRing("A3")
+            sage: A3 = WeylCharacterRing("A3")
             sage: WeightRing(A3).one_basis()
             (0, 0, 0, 0)
             sage: WeightRing(A3).one()
@@ -1714,24 +1860,25 @@ class WeightRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: A2=WeylCharacterRing("A2")
-            sage: a2=WeightRing(A2)
+            sage: A2 = WeylCharacterRing("A2")
+            sage: a2 = WeightRing(A2)
             sage: a2.parent()
             The Weyl Character Ring of Type A2 with Integer Ring coefficients
             sage: a2.parent() == A2
             True
-
         """
         return self._parent
 
     def weyl_character_ring(self):
         """
-        Return the parent Weyl Character Ring. A synonym for ``self.parent()``.
+        Return the parent Weyl Character Ring.
+
+        A synonym for ``self.parent()``.
 
         EXAMPLES::
 
-            sage: A2=WeylCharacterRing("A2")
-            sage: a2=WeightRing(A2)
+            sage: A2 = WeylCharacterRing("A2")
+            sage: a2 = WeightRing(A2)
             sage: a2.weyl_character_ring()
             The Weyl Character Ring of Type A2 with Integer Ring coefficients
         """
@@ -1798,7 +1945,9 @@ class WeightRing(CombinatorialFreeModule):
     def wt_repr(self, wt):
         r"""
         Return a string representing the irreducible character with
-        highest weight vector ``wt``. Uses coroot notation if the associated
+        highest weight vector ``wt``.
+
+        Uses coroot notation if the associated
         Weyl character ring is defined with ``style="coroots"``.
 
         EXAMPLES::
@@ -1818,8 +1967,8 @@ class WeightRing(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: G2=WeylCharacterRing("G2")
-            sage: g2=WeightRing(G2)
+            sage: G2 = WeylCharacterRing("G2")
+            sage: g2 = WeightRing(G2)
             sage: [g2(x) for x in g2.fundamental_weights()] # indirect doctest
             [g2(1,0,-1), g2(2,-1,-1)]
         """
@@ -1835,7 +1984,7 @@ class WeightRing(CombinatorialFreeModule):
 
             EXAMPLES::
 
-                sage: A2=WeylCharacterRing("A2")
+                sage: A2 = WeylCharacterRing("A2")
                 sage: a2 = WeightRing(A2)
                 sage: a2([0,1,0]).cartan_type()
                 ['A', 2]
@@ -1878,8 +2027,9 @@ class WeightRing(CombinatorialFreeModule):
 
         def scale(self, k):
             """
-            Multiplies a weight by `k`. The operation is extended by linearity
-            to the weight ring.
+            Multiply a weight by `k`.
+
+            The operation is extended by linearity to the weight ring.
 
             INPUT:
 
@@ -1896,12 +2046,14 @@ class WeightRing(CombinatorialFreeModule):
             d1 = self.monomial_coefficients()
             d2 = {}
             for mu in d1:
-                d2[k*mu]=d1[mu]
+                d2[k * mu] = d1[mu]
             return self.parent()._from_dict(d2)
 
         def shift(self, mu):
             r"""
-            Add `\mu` to any weight. Extended by linearity to the weight ring.
+            Add `\mu` to any weight.
+
+            Extended by linearity to the weight ring.
 
             INPUT:
 
@@ -1916,7 +2068,7 @@ class WeightRing(CombinatorialFreeModule):
             d1 = self.monomial_coefficients()
             d2 = {}
             for nu in d1:
-                d2[mu+nu]=d1[nu]
+                d2[mu + nu] = d1[nu]
             return self.parent()._from_dict(d2)
 
         def demazure(self, w, debug=False):
@@ -1942,12 +2094,12 @@ class WeightRing(CombinatorialFreeModule):
             EXAMPLES::
 
                 sage: B2 = WeylCharacterRing("B2",style="coroots")
-                sage: b2=WeightRing(B2)
+                sage: b2 = WeightRing(B2)
                 sage: b2(1,0).demazure([1])
                 b2(1,0) + b2(-1,2)
                 sage: b2(1,0).demazure([2])
                 b2(1,0)
-                sage: r=b2(1,0).demazure([1,2]); r
+                sage: r = b2(1,0).demazure([1,2]); r
                 b2(1,0) + b2(-1,2)
                 sage: r.demazure([1])
                 b2(1,0) + b2(-1,2)
@@ -1962,7 +2114,8 @@ class WeightRing(CombinatorialFreeModule):
             d = {}
             alphacheck = self.parent()._space.simple_coroots()
             for v in d1:
-                d[tuple(v.inner_product(alphacheck[j]) for j in self.parent().space().index_set())]=d1[v]
+                d[tuple(v.inner_product(alphacheck[j])
+                        for j in self.parent().space().index_set())] = d1[v]
             return self.parent()._from_dict(self.parent().parent()._demazure_helper(d, word, debug=debug))
 
         def demazure_lusztig(self, i, v):
@@ -2001,8 +2154,8 @@ class WeightRing(CombinatorialFreeModule):
 
                 sage: P.<v> = PolynomialRing(QQ)
                 sage: B2 = WeylCharacterRing("B2",style="coroots",base_ring=P); b2 = B2.ambient()
-                sage: def T1(f) : return f.demazure_lusztig(1,v)
-                sage: def T2(f) : return f.demazure_lusztig(2,v)
+                sage: def T1(f): return f.demazure_lusztig(1,v)
+                sage: def T2(f): return f.demazure_lusztig(2,v)
                 sage: T1(T2(T1(T2(b2(1,-1)))))
                 (v^2-v)*b2(0,-1) + v^2*b2(-1,1)
                 sage: [T1(T1(f))==(v-1)*T1(f)+v*f for f in [b2(0,0), b2(1,0), b2(2,3)]]
@@ -2028,12 +2181,149 @@ class WeightRing(CombinatorialFreeModule):
                 if len(i) == 0:
                     return self
                 elif len(i) == 1:
-                    return self.demazure_lusztig(i[0],v)
+                    return self.demazure_lusztig(i[0], v)
                 else:
-                    return self.demazure_lusztig(i[1:],v).demazure_lusztig(i[:1],v)
+                    return self.demazure_lusztig(i[1:], v).demazure_lusztig(i[:1],v)
             else:
                 try:
-                    return self.demazure_lusztig(i.reduced_word(),v)
+                    return self.demazure_lusztig(i.reduced_word(), v)
                 except Exception:
                     raise ValueError("unknown index {}".format(i))
 
+
+class FusionRing(WeylCharacterRing):
+    r"""
+    Return the Fusion Ring (Verlinde Algebra) of level ``k``.
+
+    INPUT:
+
+    - ``ct`` -- the Cartan type of a simple (finite-dimensional) Lie algebra
+    - ``k`` -- a nonnegative integer
+
+    This algebra has a basis indexed by the weights of level `\leq k`.
+    It is implemented as a variant of the :class:`WeylCharacterRing`.
+
+    EXAMPLES::
+
+        sage: A22 = FusionRing("A2",2)
+        sage: [f1, f2] = A22.fundamental_weights()
+        sage: M = [A22(x) for x in [0*f1, 2*f1, 2*f2, f1+f2, f2, f1]]
+        sage: [M[3] * x for x in M]
+        [A22(1,1),
+         A22(0,1),
+         A22(1,0),
+         A22(0,0) + A22(1,1),
+         A22(0,1) + A22(2,0),
+         A22(1,0) + A22(0,2)]
+
+    You may assign your own labels to the basis elements. In the next
+    example, we create the `SO(5)` fusion ring of level `2`, check the
+    weights of the basis elements, then assign new labels to them::
+
+        sage: B22 = FusionRing("B2", 2)
+        sage: sorted(B22.basis(), key=str)
+        [B22(0,0), B22(0,1), B22(0,2), B22(1,0), B22(1,1), B22(2,0)]
+        sage: sorted([x.highest_weight() for x in B22.basis()], key=str)
+        [(0, 0), (1, 0), (1, 1), (1/2, 1/2), (2, 0), (3/2, 1/2)]
+        sage: B22.fusion_labels(['1','X','Y1','Z','Xp','Y2'])
+        sage: list(B22.basis())
+        [1, X, Y1, Z, Xp, Y2]
+        sage: X*Y1
+        X + Xp
+        sage: Z*Z
+        1
+
+        sage: C22 = FusionRing("C2", 2)
+        sage: sorted(C22.basis(), key=str)
+        [C22(0,0), C22(0,1), C22(0,2), C22(1,0), C22(1,1), C22(2,0)]
+
+    REFERENCES:
+
+    - [DFMS1996]_ Chapter 16
+    - [Feingold2004]_
+    - [Fuchs1994]_
+    - [Walton1990]_
+    """
+    @staticmethod
+    def __classcall__(cls, ct, k, base_ring=ZZ, prefix=None, style="coroots"):
+        """
+        Normalize input to ensure a unique representation.
+
+        TESTS::
+
+            sage: F1 = FusionRing('B3', 2)
+            sage: F2 = FusionRing(CartanType('B3'), QQ(2), ZZ)
+            sage: F3 = FusionRing(CartanType('B3'), int(2), style="coroots")
+            sage: F1 is F2 and F2 is F3
+            True
+
+            sage: A23 = FusionRing('A2', 3)
+            sage: TestSuite(A23).run()
+
+            sage: B22 = FusionRing('B2', 2)
+            sage: TestSuite(B22).run()
+
+            sage: C31 = FusionRing('C3', 1)
+            sage: TestSuite(C31).run()
+
+            sage: D41 = FusionRing('D4', 1)
+            sage: TestSuite(D41).run()
+        """
+        return super(FusionRing, cls).__classcall__(cls, ct, base_ring=base_ring,
+                                                    prefix=prefix, style=style, k=k)
+
+    def some_elements(self):
+        """
+        Return some elements of ``self``.
+
+        EXAMPLES::
+
+            sage: D41 = FusionRing('D4', 1)
+            sage: D41.some_elements()
+            [D41(1,0,0,0), D41(0,0,1,0), D41(0,0,0,1)]
+        """
+        return [self.monomial(x) for x in self.fundamental_weights()
+                if self.level(x) <= self._k]
+
+    def fusion_labels(self, labels=None):
+        r"""
+        Set the labels of the basis.
+
+        INPUT:
+
+        - ``labels`` -- (default: ``None``) a list of strings
+
+        The length of the list ``labels`` must equal the
+        number of basis elements. These become the names of
+        the basis elements. If ``labels`` is ``None``, then
+        this resets the labels to the default.
+
+        EXAMPLES::
+
+            sage: A13 = FusionRing("A1", 3)
+            sage: A13.fusion_labels(['x0','x1','x2','x3'])
+            sage: fb = list(A13.basis()); fb
+            [x0, x1, x2, x3]
+            sage: Matrix([[x*y for y in A13.basis()] for x in A13.basis()])
+            [     x0      x1      x2      x3]
+            [     x1 x0 + x2 x1 + x3      x2]
+            [     x2 x1 + x3 x0 + x2      x1]
+            [     x3      x2      x1      x0]
+
+        We reset the labels to the default::
+
+            sage: A13.fusion_labels()
+            sage: fb
+            [A13(0), A13(1), A13(2), A13(3)]
+        """
+        if labels is None:
+            self._fusion_labels = None
+            return
+        d = {}
+        fb = list(self.basis())
+        for j, b in enumerate(fb):
+            wt = b.highest_weight()
+            t = tuple([wt.inner_product(x) for x in self.simple_coroots()])
+            d[t] = labels[j]
+            inject_variable(labels[j], b)
+        self._fusion_labels = d
