@@ -408,6 +408,60 @@ class RootedTree(AbstractClonableTree, NormalizedClonableList):
             t.append(other)
         return t
 
+    def single_graft(self, x, grafting_function, path_prefix=()):
+        r"""
+        Graft subtrees of `x` on ``self`` using the given function.
+
+        Let `x_1, x_2, \ldots, x_p` be the children of the root of
+        `x`. For each `i`, the subtree of `x` comprising all
+        descendants of `x_i` is joined by a new edge to
+        the vertex of ``self`` specified by the `i`-th path in the
+        grafting function (i.e., by the path
+        ``grafting_function[i]``).
+
+        The number of vertices of the result is the sum of the numbers
+        of vertices of ``self`` and `x` minus one, because the root of
+        `x` is not used.
+
+        This is used to define the product of the Grossman-Larson algebras.
+
+        INPUT:
+
+        - `x` -- a rooted tree
+
+        - ``grafting_function`` -- a list of paths in ``self``
+
+        - ``path_prefix`` -- optional tuple (default ``()``)
+
+        The ``path_prefix`` argument is only used for internal recursion.
+
+        EXAMPLES::
+
+            sage: LT = LabelledRootedTrees()
+            sage: y = LT([LT([],label='b')], label='a')
+            sage: x = LT([LT([],label='d')], label='c')
+            sage: y.single_graft(x,[(0,)])
+            a[b[d[]]]
+            sage: t = LT([LT([],label='b'),LT([],label='c')], label='a')
+            sage: s = LT([LT([],label='d'),LT([],label='e')], label='f')
+            sage: t.single_graft(s,[(0,),(1,)])
+            a[b[d[]], c[e[]]]
+        """
+        P = self.parent()
+        child_grafts = [suby.single_graft(x, grafting_function,
+                                          path_prefix + (i,))
+                        for i, suby in enumerate(self)]
+        try:
+            y1 = P(child_grafts, label=self.label())
+        except AttributeError:
+            y1 = P(child_grafts)
+
+        with y1.clone() as y2:
+            for k in range(len(x)):
+                if grafting_function[k] == path_prefix:
+                    y2.append(x[k])
+        return y2
+
 
 class RootedTrees(UniqueRepresentation, Parent):
     """
