@@ -231,7 +231,7 @@ class OrderedSetPartition(ClonableArray):
             sage: s = OS([[1, 3], [2, 4]])
             sage: s.check()
         """
-        assert self in self.parent()
+        assert self in self.parent(), "%s not in %s" % (self, self.parent())
 
     def _hash_(self):
         """
@@ -937,6 +937,14 @@ class OrderedSetPartitions(UniqueRepresentation, Parent):
             sage: OS = OrderedSetPartitions([1,2,3,4])
             sage: all(sp in OS for sp in OS)
             True
+            sage: [[1,2], [], [3,4]] in OS
+            False
+            sage: [Set([1,2]), Set([3,4])] in OS
+            True
+            sage: [set([1,2]), set([3,4])] in OS
+            Traceback (most recent call last):
+            ...
+            TypeError: X (=set([1, 2])) must be a Set
         """
         #x must be a list
         if not isinstance(x, (OrderedSetPartition, list, tuple)):
@@ -948,10 +956,10 @@ class OrderedSetPartitions(UniqueRepresentation, Parent):
             return False
 
         #Check to make sure each element of the list
-        #is a set
+        #is a nonempty set
         u = Set([])
         for s in x:
-            if not isinstance(s, (set, frozenset, Set_generic)):
+            if not s or not isinstance(s, (set, frozenset, Set_generic)):
                 return False
             u = u.union(s)
 
@@ -1297,11 +1305,15 @@ class OrderedSetPartitions_all(OrderedSetPartitions):
             sage: AOS = OrderedSetPartitions()
             sage: all(sp in AOS for sp in OS)
             True
-            sage: [[1,3],[4],[5,2]] in AOS
+            sage: AOS.__contains__([[1,3], [4], [5,2]])
             True
-            sage: [[1,4],[3]] in AOS
+            sage: AOS.__contains__([Set([1,3]), Set([4]), Set([5,2])])
+            True
+            sage: [Set([1,4]), Set([3])] in AOS
             False
-            sage: [[1,3],[4,2],[2,5]] in AOS
+            sage: [Set([1,3]), Set([4,2]), Set([2,5])] in AOS
+            False
+            sage: [Set([1,2]), Set()] in AOS
             False
         """
         if isinstance(x, OrderedSetPartition):
@@ -1314,10 +1326,10 @@ class OrderedSetPartitions_all(OrderedSetPartitions):
         if not isinstance(x, (list, tuple)):
             return False
 
-        # Check to make sure each element of the list is a set
-        if any(not isinstance(s, (set, frozenset, list, tuple, Set_generic))
-               for s in x):
+        # Check to make sure each element of the list is a nonempty set
+        if not all(s and isinstance(s, (set, frozenset, list, tuple, Set_generic)) for s in x):
             return False
+
         if not all(isinstance(s, (set, frozenset, Set_generic)) or len(s) == len(set(s)) for s in x):
             return False
         X = set(reduce(lambda A,B: A.union(B), x, set()))
