@@ -1459,7 +1459,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
         The subspace of the ring of symmetric functions spanned by
         `\{ s_{\lambda}[X/(1-t)] \}_{\lambda_1\le k} = \{ s_{\lambda}^{(k)}[X,t]\}_{\lambda_1 \le k}`
-        over the base ring `\mathbb{Q}[t]`. When `t=1`, this space is in fact a subalgebra of
+        over the base ring `\QQ[t]`. When `t=1`, this space is in fact a subalgebra of
         the ring of symmetric functions generated by the complete homogeneous symmetric functions
         `h_i` for `1\le i \le k`.
 
