@@ -29,7 +29,7 @@ class SymmetricFunctionAlgebra_witt(multiplicative.SymmetricFunctionAlgebra_mult
     denoted by `(x_{\lambda})` in [HazWitt1]_, section 9.63, and by
     `(q_{\lambda})` in [DoranIV1996]_. We will denote this basis by
     `(w_{\lambda})` (which is precisely how it is denoted in
-    [GriRei2014]_, Exercise 2.79(d)). It is a multiplicative basis
+    [GriRei18]_, Exercise 2.9.3(d)). It is a multiplicative basis
     (meaning that `w_{\emptyset} = 1` and that every partition
     `\lambda` satisfies
     `w_{\lambda} = w_{\lambda_1} w_{\lambda_2} w_{\lambda_3} \cdots`,
@@ -118,6 +118,8 @@ class SymmetricFunctionAlgebra_witt(multiplicative.SymmetricFunctionAlgebra_mult
        *Plethystic algebra*.
        :arXiv:`math/0407227v1`
 
+    .. [GriRei18]_
+
     EXAMPLES:
 
     Here are the first few Witt symmetric functions, in various bases::
@@ -494,7 +496,7 @@ class SymmetricFunctionAlgebra_witt(multiplicative.SymmetricFunctionAlgebra_mult
             sage: toy_inverse_transition_matrices[2]
             [ 1 -2]
             [ 0  1]
-            sage: toy_transition_matrices.keys()
+            sage: sorted(toy_transition_matrices)
             [0, 1, 2]
         """
         # Much of this code is adapted from dual.py
@@ -627,7 +629,7 @@ class SymmetricFunctionAlgebra_witt(multiplicative.SymmetricFunctionAlgebra_mult
             sage: w._h_inverse_transition_matrices[2]
             [ 1 -1]
             [ 0  1]
-            sage: w._h_transition_matrices.keys()
+            sage: sorted(w._h_transition_matrices)
             [0, 1, 2]
         """
         l = len(self._h_transition_matrices)
