@@ -1749,13 +1749,13 @@ class StandardSkewTableaux(SkewTableaux):
     ::
 
         sage: StandardSkewTableaux([[3, 2, 1], [1, 1]]).list()
-        [[[None, 1, 2], [None, 3], [4]],
+        [[[None, 2, 3], [None, 4], [1]],
+         [[None, 1, 2], [None, 3], [4]],
          [[None, 1, 2], [None, 4], [3]],
-         [[None, 1, 3], [None, 2], [4]],
-         [[None, 1, 4], [None, 2], [3]],
          [[None, 1, 3], [None, 4], [2]],
          [[None, 1, 4], [None, 3], [2]],
-         [[None, 2, 3], [None, 4], [1]],
+         [[None, 1, 4], [None, 2], [3]],
+         [[None, 1, 3], [None, 2], [4]],
          [[None, 2, 4], [None, 3], [1]]]
     """
     @staticmethod
@@ -1831,9 +1831,8 @@ class StandardSkewTableaux_all(StandardSkewTableaux):
             sage: [next(it) for x in range(10)]
             [[],
              [[1]],
-             [[1, 2]], [[1], [2]], [[None, 1], [2]], [[None, 2], [1]],
-             [[1, 2, 3]], [[1, 2], [3]], [[1, 3], [2]],
-             [[None, 1, 2], [3]]]
+             [[1, 2]], [[1], [2]], [[None, 2], [1]], [[None, 1], [2]],
+             [[1, 2, 3]], [[1, 2], [3]], [[1, 3], [2]], [[None, 2, 3], [1]]]
         """
         n = 0
         while True:
@@ -1892,21 +1891,24 @@ class StandardSkewTableaux_size(StandardSkewTableaux):
         EXAMPLES::
 
             sage: StandardSkewTableaux(2).list()
-            [[[1, 2]], [[1], [2]], [[None, 1], [2]], [[None, 2], [1]]]
+            [[[1, 2]], [[1], [2]], [[None, 2], [1]], [[None, 1], [2]]]
 
             sage: StandardSkewTableaux(3).list()
             [[[1, 2, 3]],
              [[1, 2], [3]], [[1, 3], [2]],
-             [[None, 1, 2], [3]], [[None, 1, 3], [2]],
-             [[None, 2, 3], [1]],
-             [[None, 1], [2, 3]], [[None, 2], [1, 3]],
-             [[None, None, 1], [2, 3]], [[None, None, 2], [1, 3]], [[None, None, 3], [1, 2]],
-             [[1], [2], [3]],
-             [[None, 1], [None, 2], [3]], [[None, 1], [None, 3], [2]], [[None, 2], [None, 3], [1]],
-             [[None, 1], [2], [3]], [[None, 2], [1], [3]], [[None, 3], [1], [2]],
-             [[None, None, 1], [None, 2], [3]], [[None, None, 1], [None, 3], [2]],
-             [[None, None, 2], [None, 1], [3]], [[None, None, 3], [None, 1], [2]],
-             [[None, None, 2], [None, 3], [1]], [[None, None, 3], [None, 2], [1]]]
+             [[None, 2, 3], [1]], [[None, 1, 2], [3]], [[None, 1, 3], [2]],
+             [[None, 2], [1, 3]], [[None, 1], [2, 3]],
+             [[None, None, 2], [1, 3]], [[None, None, 3], [1, 2]],
+             [[None, None, 1], [2, 3]],
+             [[1], [2], [3]], [[None, 2], [None, 3], [1]],
+             [[None, 1], [None, 2], [3]], [[None, 1], [None, 3], [2]],
+             [[None, 2], [1], [3]], [[None, 3], [1], [2]],
+             [[None, 1], [2], [3]], [[None, None, 3], [None, 2], [1]],
+             [[None, None, 2], [None, 3], [1]],
+             [[None, None, 1], [None, 3], [2]],
+             [[None, None, 1], [None, 2], [3]],
+             [[None, None, 2], [None, 1], [3]],
+             [[None, None, 3], [None, 1], [2]]]
         """
         for skp in SkewPartitions(self.n):
             for sst in StandardSkewTableaux_shape(skp):
@@ -1986,14 +1988,14 @@ class StandardSkewTableaux_shape(StandardSkewTableaux):
 
         EXAMPLES::
 
-            sage: [st for st in StandardSkewTableaux([[3, 2, 1], [1, 1]])]
-            [[[None, 1, 2], [None, 3], [4]],
+            sage: StandardSkewTableaux([[3, 2, 1], [1, 1]]).list()
+            [[[None, 2, 3], [None, 4], [1]],
+             [[None, 1, 2], [None, 3], [4]],
              [[None, 1, 2], [None, 4], [3]],
-             [[None, 1, 3], [None, 2], [4]],
-             [[None, 1, 4], [None, 2], [3]],
              [[None, 1, 3], [None, 4], [2]],
              [[None, 1, 4], [None, 3], [2]],
-             [[None, 2, 3], [None, 4], [1]],
+             [[None, 1, 4], [None, 2], [3]],
+             [[None, 1, 3], [None, 2], [4]],
              [[None, 2, 4], [None, 3], [1]]]
         """
         dag = self.skp.to_dag(format="tuple")
