@@ -137,18 +137,27 @@ def Subsets(s, k=None, submultiset=False):
         sage: S3 = Subsets(S2)
         sage: S3.cardinality()
         115792089237316195423570985008687907853269984665640564039457584007913129639936
-        sage: S3.unrank(14123091480)
+        sage: S3.unrank(14123091480) # py2
         {{{1, 3}, {1, 2, 3}, {2}, {1}},
          {{2}, {1, 2, 3}, {}, {1, 2}},
          {},
          {{2}, {1, 2, 3}, {}, {3}, {1, 2}},
          {{1, 2, 3}, {}, {1}}, {{2}, {2, 3}, {}, {1, 2}}}
+        sage: S3.unrank(14123091480) # py3
+        {{{2}, {1, 2, 3}, {1, 2}, {3}, {}},
+         {{1, 2, 3}, {2}, {1}, {1, 3}},
+         {{}, {2}, {2, 3}, {1, 2}},
+         {{}, {2}, {1, 2, 3}, {1, 2}},
+         {},
+         {{}, {1}, {1, 2, 3}}}
 
         sage: T = Subsets(S2, 10)
         sage: T.cardinality()
         278826214642518400
-        sage: T.unrank(1441231049)
+        sage: T.unrank(1441231049) # py2
         {{{3}, {1, 2}, {}, {2, 3}, {1}, {1, 3}, ..., {{2, 3}, {}}, {{}}}
+        sage: T.unrank(1441231049) # py3
+        {{{1, 2, 3}, {2}, {2, 3}}, {{3}, {1, 3}, ..., {3}, {1}, {}, {1, 3}}}
     """
     if k is not None:
         k = Integer(k)
@@ -190,11 +199,16 @@ class Subsets_s(Parent):
         Subsets of Subsets of Subsets of Finite Field of size 3
         sage: S.cardinality()
         115792089237316195423570985008687907853269984665640564039457584007913129639936
-        sage: S.unrank(3149254230)
+        sage: S.unrank(3149254230) # py2
         {{{1, 2}, {0, 1, 2}, {0, 2}, {0, 1}},
          {{1, 2}, {}, {0, 2}, {1}, {0, 1, 2}, {2}},
          {{1, 2}, {0}}, {{1, 2}, {0, 1}, {0, 1, 2}, {1}},
          {{0, 2}, {1}}}
+        sage: S.unrank(3149254230) # py3
+        {{{1}, {0, 2}}, {{0, 1, 2}, {0, 1}, {1}, {1, 2}},
+         {{2}, {1, 2}, {0, 1, 2}, {0, 2}, {1}, {}},
+         {{1, 2}, {0}},
+         {{0, 1, 2}, {0, 1}, {0, 2}, {1, 2}}}
     """
     # TODO: Set_object_enumerated does not inherit from Element... so we set
     # directly element_class as Set_object_enumerated
@@ -494,8 +508,8 @@ class Subsets_s(Parent):
 
         TESTS::
 
-            sage: Subsets(['a','b','c'])(['a','b'])  # indirect doctest
-            {'a', 'b'}
+            sage: sorted(Subsets(['a','b','c'])(['a','b']))  # indirect doctest
+            ['a', 'b']
         """
         if not isinstance(el, Element):
             return self._element_constructor_(el)
@@ -672,7 +686,7 @@ class Subsets_sk(Subsets_s):
 
     def first(self):
         """
-        Returns the first subset of s of size k.
+        Return the first subset of s of size k.
 
         EXAMPLES::
 
@@ -690,11 +704,12 @@ class Subsets_sk(Subsets_s):
         if self._k < 0 or self._k > self._s.cardinality():
             raise EmptySetError
         else:
-            return self.element_class(list(itertools.islice(self._s, self._k)))
+            return self.element_class(list(itertools.islice(self._s,
+                                                            int(self._k))))
 
     def last(self):
         """
-        Returns the last subset of s of size k.
+        Return the last subset of s of size k.
 
         EXAMPLES::
 
@@ -711,8 +726,8 @@ class Subsets_sk(Subsets_s):
         """
         if self._k > self._s.cardinality():
             raise EmptySetError
-        else:
-            return self.element_class([i for i in itertools.islice(reversed(self._s),self._k)])
+
+        return self.element_class([i for i in itertools.islice(reversed(self._s), int(self._k))])
 
     def _fast_iterator(self):
         r"""
@@ -1103,7 +1118,7 @@ class SubMultiset_s(Parent):
             sage: S(['d'])
             Traceback (most recent call last):
             ...
-            ValueError: ['d'] not in SubMultiset of ['a', 'c', 'b', 'b']
+            ValueError: ['d'] not in SubMultiset of [...]
         """
         e = self.element_class(X)
         if e not in self:
@@ -1263,7 +1278,7 @@ class SubMultiset_sk(SubMultiset_s):
         """
         from sage.combinat.integer_vector import IntegerVectors
         elts = list(self._d)
-        for iv in IntegerVectors(self._k, len(self._d), outer=self._d.values()):
+        for iv in IntegerVectors(self._k, len(self._d), outer=list(self._d.values())):
             yield sum([[elts[i]] * iv[i] for i in range(len(iv))], [])
 
 class SubsetsSorted(Subsets_s):
