@@ -20,6 +20,8 @@ from sage.rings.integer import Integer
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.structure.sage_object import SageObject
 
+from sage.misc.superseded import deprecated_function_alias
+
 class SBox(SageObject):
     r"""
     A substitution box or S-box is one of the basic components of
@@ -468,9 +470,10 @@ class SBox(SageObject):
         for i in range(2**self.input_size()):
             yield self(i)
 
-    def difference_distribution_matrix(self):
+    @cached_method
+    def difference_distribution_table(self):
         """
-        Return difference distribution matrix ``A`` for this S-box.
+        Return difference distribution table (DDT) ``A`` for this S-box.
 
         The rows of ``A`` encode the differences ``Delta I`` of the
         input and the columns encode the difference ``Delta O`` for
@@ -486,7 +489,7 @@ class SBox(SageObject):
 
             sage: from sage.crypto.sbox import SBox
             sage: S = SBox(7,6,0,4,2,5,1,3)
-            sage: S.difference_distribution_matrix()
+            sage: S.difference_distribution_table()
             [8 0 0 0 0 0 0 0]
             [0 2 2 0 2 0 0 2]
             [0 0 2 2 0 0 2 2]
@@ -512,6 +515,8 @@ class SBox(SageObject):
 
         return A
 
+    difference_distribution_matrix = deprecated_function_alias(25708, difference_distribution_table)
+
     def maximal_difference_probability_absolute(self):
         """
         Return the difference probability of the difference with the
@@ -532,7 +537,7 @@ class SBox(SageObject):
 
           This code is mainly called internally.
         """
-        A = self.difference_distribution_matrix().__copy__()
+        A = self.difference_distribution_table().__copy__()
         A[0,0] = 0
         return max(map(abs, A.list()))
 
@@ -552,9 +557,9 @@ class SBox(SageObject):
         return self.maximal_difference_probability_absolute()/(2.0**self.output_size())
 
     @cached_method
-    def linear_approximation_matrix(self, scale="absolute_bias"):
+    def linear_approximation_table(self, scale="absolute_bias"):
         r"""
-        Return linear approximation matrix (LAM) `A` for this S-box.
+        Return linear approximation table (LAT) `A` for this S-box.
 
         The entry `A[\alpha,\beta]` corresponds to the probability
         `Pr[\alpha\cdot x = \beta\cdot S(x)]`, where `S` is this S-box
@@ -573,7 +578,7 @@ class SBox(SageObject):
 
         INPUT:
 
-        - ``scale`` - string to choose the scaling for the LAM, one of
+        - ``scale`` - string to choose the scaling for the LAT, one of
             - "bias": elements are `e(\alpha, \beta)`
             - "correlation": elements are `c(\alpha, \beta)`
             - "absolute_bias": elements are `2^m\cdot e(\alpha, \beta)` (default)
@@ -583,7 +588,7 @@ class SBox(SageObject):
 
             sage: from sage.crypto.sbox import SBox
             sage: S = SBox(7,6,0,4,2,5,1,3)
-            sage: lat_abs_bias = S.linear_approximation_matrix()
+            sage: lat_abs_bias = S.linear_approximation_table()
             sage: lat_abs_bias
             [ 4  0  0  0  0  0  0  0]
             [ 0  0  0  0  2  2  2 -2]
@@ -594,16 +599,16 @@ class SBox(SageObject):
             [ 0 -2 -2  0  0 -2  2  0]
             [ 0 -2  2  0 -2  0  0 -2]
 
-            sage: lat_abs_bias/(1<<S.m) == S.linear_approximation_matrix(scale="bias")
+            sage: lat_abs_bias/(1<<S.m) == S.linear_approximation_table(scale="bias")
             True
 
-            sage: lat_abs_bias/(1<<(S.m-1)) == S.linear_approximation_matrix(scale="correlation")
+            sage: lat_abs_bias/(1<<(S.m-1)) == S.linear_approximation_table(scale="correlation")
             True
 
-            sage: lat_abs_bias*2 == S.linear_approximation_matrix(scale="fourier_coefficient")
+            sage: lat_abs_bias*2 == S.linear_approximation_table(scale="fourier_coefficient")
             True
 
-        According to this matrix the first bit of the input is equal
+        According to this table the first bit of the input is equal
         to the third bit of the output 6 out of 8 times::
 
             sage: for i in srange(8): print(S.to_bits(i)[0] == S.to_bits(S(i))[2])
@@ -642,6 +647,8 @@ class SBox(SageObject):
 
         return A
 
+    linear_approximation_matrix = deprecated_function_alias(25708, linear_approximation_table)
+
     def maximal_linear_bias_absolute(self):
         """
         Return maximal linear bias, i.e. how often the linear
@@ -655,7 +662,7 @@ class SBox(SageObject):
             sage: S.maximal_linear_bias_absolute()
             2
         """
-        A = self.linear_approximation_matrix().__copy__()
+        A = self.linear_approximation_table().__copy__()
         A[0,0] = 0
         return max(map(abs, A.list()))
 
@@ -725,7 +732,6 @@ class SBox(SageObject):
             gens = X + Y
 
         m = self.input_size()
-        n = self.output_size()
 
         solutions = []
         for i in range(1<<m):
@@ -833,7 +839,6 @@ class SBox(SageObject):
 
         m = self.input_size()
         n = self.output_size()
-        F = self._F
 
         if X is None and Y is None:
             P = self.ring()
@@ -1283,7 +1288,7 @@ class SBox(SageObject):
         m = self.input_size()
         n = self.output_size()
         ret = (1<<m) + (1<<n)
-        lat = self.linear_approximation_matrix()
+        lat = self.linear_approximation_table()
 
         for a in range(1, 1<<m):
             for b in range(1<<n):
@@ -1294,11 +1299,11 @@ class SBox(SageObject):
         return ret
 
     @cached_method
-    def autocorrelation_matrix(self):
+    def autocorrelation_table(self):
         r"""
-        Return autocorrelation matrix correspond to this S-Box.
+        Return the autocorrelation table corresponding to this S-Box.
 
-        for an `m \times n` S-Box `S`, its autocorrelation matrix entry at
+        for an `m \times n` S-Box `S`, its autocorrelation table entry at
         row `a \in \GF{2}^m` and column `b \in \GF{2}^n`
         (considering their integer representation) is defined as:
 
@@ -1306,14 +1311,14 @@ class SBox(SageObject):
 
             \sum_{x \in \GF{2}^m} (-1)^{b \cdot S(x) \oplus b \cdot S(x \oplus a)}
 
-        Equivalently, the columns `b` of autocorrelation matrix correspond to
+        Equivalently, the columns `b` of autocorrelation table correspond to
         the autocorrelation spectrum of component function `b \cdot S(x)`.
 
         EXAMPLES::
 
             sage: from sage.crypto.sbox import SBox
             sage: S = SBox(7,6,0,4,2,5,1,3)
-            sage: S.autocorrelation_matrix()
+            sage: S.autocorrelation_table()
             [ 8  8  8  8  8  8  8  8]
             [ 8  0  0  0  0  0  0 -8]
             [ 8  0 -8  0  0  0  0  0]
@@ -1326,24 +1331,26 @@ class SBox(SageObject):
         from sage.combinat.matrices.hadamard_matrix import hadamard_matrix
 
         n = self.output_size()
-        A = self.difference_distribution_matrix() * hadamard_matrix(1<<n)
+        A = self.difference_distribution_table() * hadamard_matrix(1<<n)
         A.set_immutable()
 
         return A
 
+    autocorrelation_matrix = deprecated_function_alias(25708, autocorrelation_table)
+
     @cached_method
-    def boomerang_connectivity_matrix(self):
+    def boomerang_connectivity_table(self):
         r"""
-        Return the boomerang connectivity matrix for this S-Box.
+        Return the boomerang connectivity table (BCT) for this S-Box.
 
         Boomerang connectivity matrix of an invertible `m \times m`
         S-Box `S` is an `2^m \times 2^m` matrix with entry at row
-        `\Delta_i \in \mathbb{F}_2^m` and column `\Delta_o \in \mathbb{F}_2^m`
+        `\Delta_i \in \GF{2}^m` and column `\Delta_o \in \GF{2}^m`
         equal to
 
         .. MATH::
 
-            |\{ x \in \mathbb{F}_2^m | S^{-1}( S(x) \oplus \Delta_o) \oplus
+            |\{ x \in \GF{2}^m | S^{-1}( S(x) \oplus \Delta_o) \oplus
                S^{-1}( S(x \oplus \Delta_i) \oplus \Delta_o) = \Delta_i\}|.
 
         For more results concerning boomerang connectivity matrix, see [CHPSS18]_ .
@@ -1353,7 +1360,7 @@ class SBox(SageObject):
         EXAMPLES::
 
             sage: from sage.crypto.sboxes import PRESENT
-            sage: PRESENT.boomerang_connectivity_matrix()
+            sage: PRESENT.boomerang_connectivity_table()
             [16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16]
             [16  0  4  4  0 16  4  4  4  4  0  0  4  4  0  0]
             [16  0  0  6  0  4  6  0  0  0  2  0  2  2  2  0]
@@ -1396,9 +1403,26 @@ class SBox(SageObject):
 
         A = Matrix(ZZ, nrows, ncols, A)
         A.set_immutable()
-
         return A
 
+    boomerang_connectivity_matrix = deprecated_function_alias(25708, boomerang_connectivity_table)
+
+    def boomerang_uniformity(self):
+        """
+        Return the boomerang uniformity
+
+        The boomerang uniformity is defined as the highest entry in the
+        boomerang connectivity table, ignoring the first row and column.
+
+        EXAMPLES::
+
+            sage: from sage.crypto.sboxes import AES
+            sage: AES.boomerang_uniformity()
+            6
+        """
+        bct = self.boomerang_connectivity_table()
+        return max(bct.delete_rows([0]).delete_columns([0]).list())
+
     def linear_structures(self):
         r"""
         Return a list of 3-valued tuple `(b, \alpha, c)` such that `\alpha` is
@@ -1430,7 +1454,7 @@ class SBox(SageObject):
         """
         n = self.output_size()
         m = self.input_size()
-        act = self.autocorrelation_matrix()
+        act = self.autocorrelation_table()
         ret = []
 
         for j in range(1, 1<<n):
@@ -1636,7 +1660,7 @@ class SBox(SageObject):
     def is_plateaued(self):
         r"""
         Return ``True`` if this S-Box is plateaued, i.e. for all nonzero
-        `b \in \mathbb{F}_2^n` the Boolean function `b \cdot S(x)`
+        `b \in \GF{2}^n` the Boolean function `b \cdot S(x)`
         is plateaued.
 
         EXAMPLES::
@@ -1672,7 +1696,7 @@ class SBox(SageObject):
             True
             sage: S.nonlinearity()
             6
-            sage: S.linear_approximation_matrix()
+            sage: S.linear_approximation_table()
             [ 8 -2  2 -2]
             [ 0 -2  2 -2]
             [ 0 -2  2 -2]
@@ -1712,6 +1736,7 @@ class SBox(SageObject):
         """
         return self == self.inverse()
 
+
 def feistel_construction(*args):
     r"""
     Return an S-Box constructed by Feistel structure using smaller S-Boxes in
