@@ -54,8 +54,8 @@ AUTHORS:
 - Steven Sivek (2005-12-22): first version
 
 - Steven Sivek (2006-02-07): updated to correctly handle the new
-  search form on the Sloane website, and it's now also smarter about
-  loading the local database in that it doesn't convert a sequence
+  search form on the Sloane website, and it is now also smarter about
+  loading the local database in that it does not convert a sequence
   from string form to a list of integers until absolutely necessary.
   This seems to cut the loading time roughly in half.
 
@@ -72,15 +72,15 @@ Classes and methods
 -------------------
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #
 #      Sage: Copyright (C) 2005-2006 William Stein <wstein@gmail.com>
 #                               and  Steven Sivek  <ssivek@mit.edu>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 import bz2
 import os
@@ -91,9 +91,8 @@ from six.moves.urllib.request import urlretrieve
 
 from sage.misc.all import verbose
 from sage.env import SAGE_SHARE
-import sage.rings.integer_ring
-ZZ = sage.rings.integer_ring.IntegerRing()
-from sage.misc.superseded import deprecation
+from sage.rings.integer_ring import ZZ
+
 
 class SloaneEncyclopediaClass:
     """
@@ -132,16 +131,14 @@ class SloaneEncyclopediaClass:
 
         INPUT:
 
-
-        -  ``N`` - int
-
+        -  ``N`` -- int
 
         OUTPUT: list
         """
         self.load()
-        if not N in self.__data__: # sequence N does not exist
+        if N not in self.__data__:  # sequence N does not exist
             return []
-        if self.__data__[N][1] is None: # list N has not been created yet
+        if self.__data__[N][1] is None:  # list N has not been created yet
             list = self.__data__[N][2].strip(',').split(',')
             self.__data__[N][1] = [ZZ(n) for n in list]
         return self.__data__[N][1]
@@ -153,7 +150,6 @@ class SloaneEncyclopediaClass:
         self.load()
         return len(self.__data__)
 
-
     def find(self, seq, maxresults=30):
         """
         Return a list of all sequences which have seq as a subsequence, up
@@ -162,11 +158,9 @@ class SloaneEncyclopediaClass:
 
         INPUT:
 
+        -  ``seq`` -- list
 
-        -  ``seq`` - list
-
-        -  ``maxresults`` - int
-
+        -  ``maxresults`` -- int
 
         OUTPUT: list of 2-tuples (i, v), where v is a sequence with seq as
         a subsequence.
@@ -174,7 +168,7 @@ class SloaneEncyclopediaClass:
         self.load()
 
         answer, nanswer = [], 0
-        pattern = re.sub(r'[\[\]]', ',', str(seq).replace(' ',''))
+        pattern = re.sub(r'[\[\]]', ',', str(seq).replace(' ', ''))
         for i in self.__data__:
             if self.__data__[i][2].find(pattern) != -1:
                 answer.append((i, self[i]))
@@ -184,7 +178,8 @@ class SloaneEncyclopediaClass:
 
         return answer
 
-    def install(self, oeis_url="http://oeis.org/stripped.gz", names_url="http://oeis.org/names.gz", overwrite=False):
+    def install(self, oeis_url="http://oeis.org/stripped.gz",
+                names_url="http://oeis.org/names.gz", overwrite=False):
         """
         Download and install the online encyclopedia, raising an IOError if
         either step fails.
@@ -202,21 +197,21 @@ class SloaneEncyclopediaClass:
           already installed and overwrite=True, download and install the latest
           version over the installed one.
         """
-        ### See if the encyclopedia already exists
+        # See if the encyclopedia already exists
         if not overwrite and os.path.exists(self.__file__):
             raise IOError("Sloane encyclopedia is already installed")
 
         tm = verbose("Downloading stripped version of Sloane encyclopedia")
         try:
-            fname, _ = urlretrieve(oeis_url);
+            fname, _ = urlretrieve(oeis_url)
         except IOError as msg:
-            raise IOError("%s\nError fetching the following website:\n    %s\nTry checking your internet connection."%(msg, oeis_url))
+            raise IOError("%s\nError fetching the following website:\n    %s\nTry checking your internet connection." % (msg, oeis_url))
 
-        if not names_url is None:
+        if names_url is not None:
             try:
-                nname, _ = urlretrieve(names_url);
+                nname, _ = urlretrieve(names_url)
             except IOError as msg:
-                raise IOError("%s\nError fetching the following website:\n    %s\nTry checking your internet connection."%(msg, names_url))
+                raise IOError("%s\nError fetching the following website:\n    %s\nTry checking your internet connection." % (msg, names_url))
         else:
             nname = None
         verbose("Finished downloading", tm)
@@ -224,7 +219,7 @@ class SloaneEncyclopediaClass:
         self.install_from_gz(fname, nname, overwrite)
         # Delete the temporary downloaded files
         os.remove(fname)
-        if not nname is None:
+        if nname is not None:
             os.remove(nname)
 
     def install_from_gz(self, stripped_file, names_file, overwrite=False):
@@ -247,11 +242,11 @@ class SloaneEncyclopediaClass:
 
         copy_gz_file(stripped_file, self.__file__)
 
-        if not names_file is None:
+        if names_file is not None:
             copy_gz_file(names_file, self.__file_names__)
         else:
             # Delete old copies of names.gz since their sequence numbers
-            # probably won't match the newly installed stripped.gz
+            # probably will not match the newly installed stripped.gz
             if os.path.exists(self.__file_names__):
                 os.remove(self.__file_names__)
 
@@ -259,7 +254,6 @@ class SloaneEncyclopediaClass:
         # automatically loaded next time the user tries to access it
         self.unload()
 
-
     def load(self):
         """
         Load the entire encyclopedia into memory from a file. This is done
@@ -275,7 +269,7 @@ class SloaneEncyclopediaClass:
         self.__data__ = {}
 
         tm = verbose("Loading Sloane encyclopedia from disk")
-        entry = re.compile(r'A(?P<num>\d{6}) ,(?P<body>.*),$');
+        entry = re.compile(r'A(?P<num>\d{6}) ,(?P<body>.*),$')
         for L in file_seq:
             if len(L) == 0:
                 continue
@@ -283,14 +277,15 @@ class SloaneEncyclopediaClass:
             if m:
                 seqnum = int(m.group('num'))
                 msg = m.group('body').strip()
-                self.__data__[seqnum] = [seqnum, None, ','+msg+',', None]
+                self.__data__[seqnum] = [seqnum, None, ',' + msg + ',', None]
         file_seq.close()
 
         try:
             file_names = bz2.BZ2File(self.__file_names__, 'r')
-            entry = re.compile(r'A(?P<num>\d{6}) (?P<body>.*)$');
+            entry = re.compile(r'A(?P<num>\d{6}) (?P<body>.*)$')
             for L in file_names:
-                if len(L) == 0: continue
+                if not L:
+                    continue
                 m = entry.search(L)
                 if m:
                     seqnum = int(m.group('num'))
@@ -298,10 +293,10 @@ class SloaneEncyclopediaClass:
             file_names.close()
             self.__loaded_names__ = True
         except KeyError:
-            ### Some sequence in the names file isn't in the database
+            # Some sequence in the names file is not in the database
             raise KeyError("Sloane OEIS sequence and name files do not match.  Try reinstalling, e.g. SloaneEncyclopedia.install(overwrite=True).")
-        except IOError as msg:
-            ### The names database is not installed
+        except IOError:
+            # The names database is not installed
             self.__loaded_names__ = False
 
         verbose("Finished loading", tm)
@@ -309,26 +304,27 @@ class SloaneEncyclopediaClass:
 
     def sequence_name(self, N):
         """
-        Return the name of sequence N in the encyclopedia. If sequence N
-        does not exist, return ''.  If the names database is not installed,
-        raise an IOError.
+        Return the name of sequence ``N`` in the encyclopedia.
+
+        If sequence ``N`` does not exist, return ``''``.  If the names
+        database is not installed, raise an ``IOError``.
 
         INPUT:
 
-        -  ``N`` - int
+        - ``N`` -- int
 
         OUTPUT: string
 
-        EXAMPLES:
+        EXAMPLES::
 
-        sage: SloaneEncyclopedia.sequence_name(1) # optional - sloane_database
-        'Number of groups of order n.'
+            sage: SloaneEncyclopedia.sequence_name(1) # optional - sloane_database
+            'Number of groups of order n.'
         """
         self.load()
         if not self.__loaded_names__:
             raise IOError("The Sloane OEIS names file is not installed.  Try reinstalling, e.g. SloaneEncyclopedia.install(overwrite=True).")
 
-        if not N in self.__data__: # sequence N does not exist
+        if N not in self.__data__:  # sequence N does not exist
             return ''
         return self.__data__[N][3]
 
@@ -342,19 +338,22 @@ class SloaneEncyclopediaClass:
         self.__loaded__ = False
         self.__loaded_names__ = False
 
+
 SloaneEncyclopedia = SloaneEncyclopediaClass()
 
+
 def copy_gz_file(gz_source, bz_destination):
     """
-    Decompress a gzipped file and install the bzipped verson.  This is
-    used by SloaneEncyclopedia.install_from_gz to install several
-    gzipped OEIS database files.
+    Decompress a gzipped file and install the bzipped version.
+
+    This is used by SloaneEncyclopedia.install_from_gz to install
+    several gzipped OEIS database files.
 
     INPUT:
 
-    - ``gz_source`` - string. The name of the gzipped file.
+    - ``gz_source`` -- string. The name of the gzipped file.
 
-    - ``bz_destination`` - string.  The name of the newly compressed file.
+    - ``bz_destination`` -- string.  The name of the newly compressed file.
     """
     import gzip
     from sage.misc.misc import sage_makedirs
@@ -365,7 +364,7 @@ def copy_gz_file(gz_source, bz_destination):
         db_text = gz_input.read()
         gz_input.close()
     except IOError as msg:
-        raise IOError("Error reading gzipped input file:\n%s"%msg)
+        raise IOError("Error reading gzipped input file:\n%s" % msg)
 
     # Write the bzipped output
     try:
@@ -374,53 +373,4 @@ def copy_gz_file(gz_source, bz_destination):
         bz2_output.write(db_text)
         bz2_output.close()
     except IOError as msg:
-        raise IOError("Error writing bzipped output file:\n%s"%msg)
-
-def parse_sequence(text=''):
-    r"""
-    This internal function was only used by the sloane_find function,
-    which is now deprecated.
-
-    TESTS::
-
-        sage: from sage.databases.sloane import parse_sequence
-        sage: parse_sequence()
-        doctest:...: DeprecationWarning: The function parse_sequence is not used anymore (2012-01-01).
-        See http://trac.sagemath.org/10358 for details.
-    """
-    deprecation(10358, "The function parse_sequence is not used anymore (2012-01-01).")
-
-def sloane_sequence(number=1, verbose=True):
-    r"""
-    This function is broken. It is replaced by the
-    :mod:`OEIS <sage.databases.oeis>` module.
-
-    Type ``oeis?`` for more information.
-
-    TESTS::
-
-        sage: sloane_sequence(123)
-        doctest:...: DeprecationWarning: The function sloane_sequence is deprecated. Use oeis() instead (2012-01-01).
-        See http://trac.sagemath.org/10358 for details.
-    """
-    deprecation(10358,
-            "The function sloane_sequence is deprecated. "
-            "Use oeis() instead (2012-01-01).")
-
-def sloane_find(list=[], nresults=30, verbose=True):
-    r"""
-    This function is broken. It is replaced by the
-    :mod:`OEIS <sage.databases.oeis>` module.
-
-    Type ``oeis?`` for more information.
-
-    TESTS::
-
-        sage: sloane_find([1,2,3])
-        doctest:...: DeprecationWarning: The function sloane_find is deprecated. Use oeis() instead (2012-01-01).
-        See http://trac.sagemath.org/10358 for details.
-    """
-    deprecation(10358,
-            "The function sloane_find is deprecated. "
-            "Use oeis() instead (2012-01-01).")
-
+        raise IOError("Error writing bzipped output file:\n%s" % msg)
