@@ -908,39 +908,40 @@ class SQLDatabase(SageObject):
         we specify its structure with a Python dictionary, each of whose keys
         is the name of a column::
 
-            sage: table_skeleton = {
-            ....: 'graph6':{'sql':'TEXT', 'index':True, 'primary_key':True},
-            ....: 'vertices':{'sql':'INTEGER'},
-            ....: 'edges':{'sql':'INTEGER'}
-            ....: }
+            sage: from collections import OrderedDict
+            sage: table_skeleton = OrderedDict([
+            ....: ('graph6',{'sql':'TEXT', 'index':True, 'primary_key':True}),
+            ....: ('vertices', {'sql':'INTEGER'}),
+            ....: ('edges', {'sql':'INTEGER'})
+            ....: ])
 
         Then we create the table::
 
             sage: D.create_table('simon', table_skeleton)
             sage: D.show('simon')
-            edges                graph6               vertices
+            graph6               vertices             edges
             ------------------------------------------------------------
 
         Now that we have the table, we will begin to populate the table with
         rows. First, add the graph on zero vertices.::
 
             sage: G = Graph()
-            sage: D.add_row('simon',(0, G.graph6_string(), 0))
+            sage: D.add_row('simon',(G.graph6_string(), 0, 0))
             sage: D.show('simon')
-            edges                graph6               vertices
+            graph6               vertices             edges
             ------------------------------------------------------------
-            0                    ?                    0
+            ?                    0                    0
 
         Next, add the graph on one vertex.::
 
             sage: G.add_vertex()
             0
-            sage: D.add_row('simon',(0, G.graph6_string(), 1))
+            sage: D.add_row('simon',(G.graph6_string(), 1, 0))
             sage: D.show('simon')
-            edges                graph6               vertices
+            graph6               vertices             edges
             ------------------------------------------------------------
-            0                    ?                    0
-            0                    @                    1
+            ?                    0                    0
+            @                    1                    0
 
         Say we want a database of graphs on four or less vertices::
 
@@ -948,32 +949,32 @@ class SQLDatabase(SageObject):
             sage: for i in range(2, 5):
             ....:     labels[i] = []
             ....:     for g in all_labeled_graphs(i):
-            ....:         g = g.canonical_label()
+            ....:         g = g.canonical_label(algorithm='sage')
             ....:         if g not in labels[i]:
             ....:             labels[i].append(g)
-            ....:             D.add_row('simon', (g.size(), g.graph6_string(), g.order()))
-            sage: D.show('simon') # random
-            edges                graph6               vertices
+            ....:             D.add_row('simon', (g.graph6_string(), g.order(), g.size()))
+            sage: D.show('simon')
+            graph6               vertices             edges
             ------------------------------------------------------------
-            0                    ?                    0
-            0                    @                    1
-            0                    A?                   2
-            1                    A_                   2
-            0                    B?                   3
-            1                    BG                   3
-            2                    BW                   3
-            3                    Bw                   3
-            0                    C?                   4
-            1                    C@                   4
-            2                    CB                   4
-            3                    CF                   4
-            3                    CJ                   4
-            2                    CK                   4
-            3                    CL                   4
-            4                    CN                   4
-            4                    C]                   4
-            5                    C^                   4
-            6                    C~                   4
+            ?                    0                    0
+            @                    1                    0
+            A?                   2                    0
+            A_                   2                    1
+            B?                   3                    0
+            BG                   3                    1
+            BW                   3                    2
+            Bw                   3                    3
+            C?                   4                    0
+            C@                   4                    1
+            CB                   4                    2
+            CF                   4                    3
+            CJ                   4                    3
+            CK                   4                    2
+            CL                   4                    3
+            CN                   4                    4
+            C]                   4                    4
+            C^                   4                    5
+            C~                   4                    6
 
         We can then query the database -- let's ask for all the graphs on four
         vertices with three edges. We do so by creating two queries and asking
@@ -1000,28 +1001,28 @@ class SQLDatabase(SageObject):
         instance. We can load the file as an immutable database::
 
             sage: E = SQLDatabase(replace_with_your_own_filepath + 'simon.db')
-            sage: E.show('simon') # random
-            edges                graph6               vertices
+            sage: E.show('simon')
+            graph6               vertices             edges
             ------------------------------------------------------------
-            0                    ?                    0
-            0                    @                    1
-            0                    A?                   2
-            1                    A_                   2
-            0                    B?                   3
-            1                    BG                   3
-            2                    BW                   3
-            3                    Bw                   3
-            0                    C?                   4
-            1                    C@                   4
-            2                    CB                   4
-            3                    CF                   4
-            3                    CJ                   4
-            2                    CK                   4
-            3                    CL                   4
-            4                    CN                   4
-            4                    C]                   4
-            5                    C^                   4
-            6                    C~                   4
+            ?                    0                    0
+            @                    1                    0
+            A?                   2                    0
+            A_                   2                    1
+            B?                   3                    0
+            BG                   3                    1
+            BW                   3                    2
+            Bw                   3                    3
+            C?                   4                    0
+            C@                   4                    1
+            CB                   4                    2
+            CF                   4                    3
+            CJ                   4                    3
+            CK                   4                    2
+            CL                   4                    3
+            CN                   4                    4
+            C]                   4                    4
+            C^                   4                    5
+            C~                   4                    6
             sage: E.drop_table('simon')
             Traceback (most recent call last):
             ...
@@ -1080,15 +1081,15 @@ class SQLDatabase(SageObject):
             sage: SD.create_table('simon', {'n':{'sql':'INTEGER', 'index':True}})
             sage: print(SD)
             table simon:
-                column n: index: True; unique: False; primary_key: False;
-                    sql: INTEGER;
+                column n: index: True; primary_key: False; sql: INTEGER;
+                    unique: False;
         """
         s = ''
         for table in self.__skeleton__:
             s += 'table ' + table + ':\n'
             for column in self.__skeleton__[table]:
                 s += '    column ' + column + ': '
-                for data in self.__skeleton__[table][column]:
+                for data in sorted(self.__skeleton__[table][column]):
                     s += data + ': ' \
                         + str(self.__skeleton__[table][column][data]) + '; '
                 s += '\n'
@@ -1101,28 +1102,33 @@ class SQLDatabase(SageObject):
 
         EXAMPLES::
 
+            sage: from collections import OrderedDict
             sage: DB = SQLDatabase()
-            sage: DB.create_table('lucy',{'id':{'sql':'INTEGER', 'primary_key':True, 'index':True}, 'a1':{'sql':'bool'}, 'b2':{'sql':'int', 'primary_key':False}})
+            sage: DB.create_table('lucy',OrderedDict([
+            ....: ('id', {'sql':'INTEGER', 'primary_key':True, 'index':True}),
+            ....: ('a1', {'sql':'bool'}),
+            ....: ('b2', {'sql':'int', 'primary_key':False})
+            ....: ]))
             sage: DB.add_rows('lucy', [(0,1,1),(1,1,4),(2,0,7),(3,1,384), (4,1,978932)],['id','a1','b2'])
             sage: d = copy(DB)
             sage: d == DB
             False
             sage: d.show('lucy')
-            a1                   id                   b2
+            id                   a1                   b2
             ------------------------------------------------------------
-            1                    0                    1
+            0                    1                    1
             1                    1                    4
-            0                    2                    7
-            1                    3                    384
-            1                    4                    978932
+            2                    0                    7
+            3                    1                    384
+            4                    1                    978932
             sage: DB.show('lucy')
-            a1                   id                   b2
+            id                   a1                   b2
             ------------------------------------------------------------
-            1                    0                    1
+            0                    1                    1
             1                    1                    4
-            0                    2                    7
-            1                    3                    384
-            1                    4                    978932
+            2                    0                    7
+            3                    1                    384
+            4                    1                    978932
         """
         # copy .db file
         new_loc = tmp_filename() + '.db'
@@ -1376,15 +1382,16 @@ class SQLDatabase(SageObject):
 
         EXAMPLES::
 
+            sage: from collections import OrderedDict
             sage: D = SQLDatabase()
-            sage: table_skeleton = {
-            ....: 'graph6':{'sql':'TEXT', 'index':True, 'primary_key':True},
-            ....: 'vertices':{'sql':'INTEGER'},
-            ....: 'edges':{'sql':'INTEGER'}
-            ....: }
+            sage: table_skeleton = OrderedDict([
+            ....: ('graph6', {'sql':'TEXT', 'index':True, 'primary_key':True}),
+            ....: ('vertices', {'sql':'INTEGER'}),
+            ....: ('edges', {'sql':'INTEGER'})
+            ....: ])
             sage: D.create_table('simon', table_skeleton)
             sage: D.show('simon')
-            edges                graph6               vertices
+            graph6               vertices             edges
             ------------------------------------------------------------
         """
         if self.__read_only__:
@@ -1452,33 +1459,34 @@ class SQLDatabase(SageObject):
 
         EXAMPLES::
 
+            sage: from collections import OrderedDict
             sage: MonicPolys = SQLDatabase()
-            sage: MonicPolys.create_table('simon', {'n':{'sql':'INTEGER', 'index':True}})
+            sage: MonicPolys.create_table('simon', OrderedDict([('n', {'sql':'INTEGER', 'index':True})]))
             sage: for n in range(20): MonicPolys.add_row('simon', (n,))
             sage: MonicPolys.add_column('simon', 'n_squared', {'sql':'INTEGER', 'index':False}, 0)
             sage: MonicPolys.show('simon')
-            n_squared            n
+            n                    n_squared
             ----------------------------------------
             0                    0
-            0                    1
-            0                    2
-            0                    3
-            0                    4
-            0                    5
-            0                    6
-            0                    7
-            0                    8
-            0                    9
-            0                    10
-            0                    11
-            0                    12
-            0                    13
-            0                    14
-            0                    15
-            0                    16
-            0                    17
-            0                    18
-            0                    19
+            1                    0
+            2                    0
+            3                    0
+            4                    0
+            5                    0
+            6                    0
+            7                    0
+            8                    0
+            9                    0
+            10                   0
+            11                   0
+            12                   0
+            13                   0
+            14                   0
+            15                   0
+            16                   0
+            17                   0
+            18                   0
+            19                   0
         """
         if self.__read_only__:
             raise RuntimeError('Cannot add columns to a read only database.')
@@ -2044,25 +2052,29 @@ class SQLDatabase(SageObject):
 
         EXAMPLES::
 
+            sage: from collections import OrderedDict
             sage: DB = SQLDatabase()
-            sage: DB.create_table('lucy',{'id':{'sql':'INTEGER', 'primary_key':True, 'index':True}, 'a1':{'sql':'bool'}, 'b2':{'sql':'int'}})
+            sage: DB.create_table('lucy', OrderedDict([
+            ....: ('id', {'sql':'INTEGER', 'primary_key':True, 'index':True}),
+            ....: ('a1', {'sql':'bool'}),
+            ....: ('b2', {'sql':'int'})]))
             sage: DB.add_rows('lucy', [(0,1,1),(1,1,4),(2,0,7),(3,1,384), (4,1,978932)],['id','a1','b2'])
             sage: DB.show('lucy')
-            a1                   id                   b2
+            id                   a1                   b2
             ------------------------------------------------------------
-            1                    0                    1
+            0                    1                    1
             1                    1                    4
-            0                    2                    7
-            1                    3                    384
-            1                    4                    978932
+            2                    0                    7
+            3                    1                    384
+            4                    1                    978932
             sage: Q = SQLQuery(DB, {'table_name':'lucy', 'display_cols':['id','a1','b2'], 'expression':['id','>=',3]})
             sage: DB.delete_rows(Q)
             sage: DB.show('lucy')
-            a1                   id                   b2
+            id                   a1                   b2
             ------------------------------------------------------------
-            1                    0                    1
+            0                    1                    1
             1                    1                    4
-            0                    2                    7
+            2                    0                    7
         """
         if self.__read_only__:
             raise RuntimeError('Cannot delete rows from a read only database.')
