@@ -8,7 +8,6 @@ __author__ = "Gustavo Niemeyer <gustavo@niemeyer.net>"
 __license__ = "PSF License"
 
 import datetime
-from sage.misc.decorators import rename_keyword
 
 __all__ = ["easter", "EASTER_JULIAN", "EASTER_ORTHODOX", "EASTER_WESTERN"]
 
@@ -16,7 +15,7 @@ EASTER_JULIAN   = 1
 EASTER_ORTHODOX = 2
 EASTER_WESTERN  = 3
 
-@rename_keyword(deprecation=6094, method="algorithm")
+
 def easter(year, algorithm=EASTER_WESTERN):
     """
     This function was ported from the work done by GM Arts,
@@ -49,7 +48,7 @@ def easter(year, algorithm=EASTER_WESTERN):
 
     and
 
-    http://www.tondering.dk/claus/calendar.html
+    https://www.tondering.dk/claus/calendar.html
 
     EXAMPLES::
 
@@ -112,4 +111,4 @@ def easter(year, algorithm=EASTER_WESTERN):
     p = i-j+e
     d = 1+(p+27+(p+6)//40)%31
     m = 3+(p+26)//30
-    return datetime.date(y,m,d)
+    return datetime.date(y, m, d)
