@@ -19,6 +19,7 @@ from .log import exp
 from .other import sqrt
 from sage.symbolic.constants import pi
 
+
 class Function_gamma(GinacFunction):
     def __init__(self):
         r"""
@@ -172,6 +173,7 @@ class Function_gamma(GinacFunction):
 
 gamma1 = Function_gamma()
 
+
 class Function_log_gamma(GinacFunction):
     def __init__(self):
         r"""
@@ -281,6 +283,7 @@ class Function_log_gamma(GinacFunction):
 
 log_gamma = Function_log_gamma()
 
+
 class Function_gamma_inc(BuiltinFunction):
     def __init__(self):
         r"""
@@ -371,9 +374,9 @@ class Function_gamma_inc(BuiltinFunction):
             return exp(-y)
         if x == 0:
             return -Ei(-y)
-        if x == Rational(1)/2: #only for x>0
+        if x == Rational((1, 2)):  # only for x>0
             from sage.functions.error import erf
-            return sqrt(pi)*(1-erf(sqrt(y)))
+            return sqrt(pi) * (1 - erf(sqrt(y)))
         return None
 
     def _evalf_(self, x, y, parent=None, algorithm='pari'):
@@ -446,6 +449,7 @@ class Function_gamma_inc(BuiltinFunction):
 # synonym.
 gamma_inc = Function_gamma_inc()
 
+
 class Function_gamma_inc_lower(BuiltinFunction):
     def __init__(self):
         r"""
@@ -598,6 +602,7 @@ class Function_gamma_inc_lower(BuiltinFunction):
 # synonym.
 gamma_inc_lower = Function_gamma_inc_lower()
 
+
 def gamma(a, *args, **kwds):
     r"""
     Gamma and upper incomplete gamma functions in one symbol.
@@ -671,23 +676,9 @@ def gamma(a, *args, **kwds):
     if not args:
         return gamma1(a, **kwds)
     if len(args) > 1:
-        raise TypeError("Symbolic function gamma takes at most 2 arguments (%s given)"%(len(args)+1))
-    return gamma_inc(a,args[0],**kwds)
+        raise TypeError("Symbolic function gamma takes at most 2 arguments (%s given)"% (len(args) + 1))
+    return gamma_inc(a, args[0], **kwds)
 
-def incomplete_gamma(*args, **kwds):
-    """
-        Deprecated name for :class:`Function_gamma_inc`.
-
-    TESTS::
-
-        sage: incomplete_gamma(1,1)
-        doctest:...: DeprecationWarning: Please use gamma_inc().
-        See http://trac.sagemath.org/16697 for details.
-        e^(-1)
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(16697, 'Please use gamma_inc().')
-    return gamma_inc(*args, **kwds)
 
 # We have to add the wrapper function manually to the symbol_table when we have
 # two functions with different number of arguments and the same name
@@ -863,15 +854,16 @@ def psi(x, *args, **kwds):
     if not args:
         return psi1(x, **kwds)
     if len(args) > 1:
-        raise TypeError("Symbolic function psi takes at most 2 arguments (%s given)"%(len(args)+1))
-    return psi2(x,args[0],**kwds)
+        raise TypeError("Symbolic function psi takes at most 2 arguments (%s given)" % (len(args) + 1))
+    return psi2(x, args[0], **kwds)
 
 # We have to add the wrapper function manually to the symbol_table when we have
 # two functions with different number of arguments and the same name
 symbol_table['functions']['psi'] = psi
 
 def _swap_psi(a, b): return psi(b, a)
-register_symbol(_swap_psi, {'giac':'Psi'})
+register_symbol(_swap_psi, {'giac': 'Psi'})
+
 
 class Function_beta(GinacFunction):
     def __init__(self):
