@@ -517,14 +517,32 @@ class Polyhedra_base(UniqueRepresentation, Parent):
             return self.element_class(self, Vrep, Hrep, **kwds)
         if nargs == 1 and is_Polyhedron(args[0]):
             polyhedron = args[0]
-            Hrep = [polyhedron.inequality_generator(), polyhedron.equation_generator()]
-            if self.base_ring() == RDF:
-                Hrep = [convert_base_ring_Hrep(_) for _ in Hrep]
-            return self.element_class(self, None, Hrep, **kwds)
+            return self._element_constructor_polyhedron(polyhedron, **kwds)
         if nargs == 1 and args[0] == 0:
             return self.zero()
         raise ValueError('Cannot convert to polyhedron object.')
 
+    def _element_constructor_polyhedron(self, polyhedron, **kwds):
+        """
+        The element (polyhedron) constructor for the case of 1 argument, a polyhedron.
+
+        This version of the method sets up the element using the H-representation only.
+        The element will have to recompute the V-representation.
+
+        EXAMPLES::
+
+            sage: from sage.geometry.polyhedron.parent import Polyhedra
+            sage: P = Polyhedra(QQ, 3)
+            sage: p = Polyhedron(vertices=[(0, 0, 0), (1, 0, 0), (0, 1, 0), (0, 0, 1)])
+            sage: p
+            A 3-dimensional polyhedron in ZZ^3 defined as the convex hull of 4 vertices
+            sage: P(p)
+            A 3-dimensional polyhedron in QQ^3 defined as the convex hull of 4 vertices
+        """
+        Vrep = None
+        Hrep = [polyhedron.inequality_generator(), polyhedron.equation_generator()]
+        return self._element_constructor_(Vrep, Hrep, **kwds)
+
     def base_extend(self, base_ring, backend=None):
         """
         Return the base extended parent.
@@ -541,11 +559,21 @@ class Polyhedra_base(UniqueRepresentation, Parent):
             Polyhedra in QQ^3
             sage: Polyhedra(ZZ,3).an_element().base_extend(QQ)
             A 3-dimensional polyhedron in QQ^3 defined as the convex hull of 4 vertices
+
+        TESTS:
+
+        Test that :trac:`22575` is fixed::
+
+            sage: P = Polyhedra(ZZ,3).base_extend(QQ, backend='field')
+            sage: P.backend()
+            'field'
+
         """
-        if self.base_ring().has_coerce_map_from(base_ring):
+        if (self.base_ring().has_coerce_map_from(base_ring)
+            and (backend is None or self.backend() == backend)):
             return self
         elif base_ring.has_coerce_map_from(self.base_ring()):
-            return Polyhedra(base_ring, self.ambient_dim())
+            return Polyhedra(base_ring, self.ambient_dim(), backend=backend)
 
     def _coerce_base_ring(self, other):
         r"""
@@ -911,3 +939,23 @@ class Polyhedra_polymake(Polyhedra_base):
 
 class Polyhedra_field(Polyhedra_base):
     Element = Polyhedron_field
+
+    def _element_constructor_polyhedron(self, polyhedron, **kwds):
+        """
+        The element (polyhedron) constructor for the case of 1 argument, a polyhedron.
+
+        This version of the method sets up the element using both representations.
+
+        EXAMPLES::
+
+            sage: from sage.geometry.polyhedron.parent import Polyhedra
+            sage: P = Polyhedra(AA, 3, backend='field')
+            sage: p = Polyhedron(vertices=[(0, 0, 0), (1, 0, 0), (0, 1, 0), (0, 0, 1)])
+            sage: P(p)
+            A 3-dimensional polyhedron in AA^3 defined as the convex hull of 4 vertices
+        """
+        Vrep = [polyhedron.vertex_generator(), polyhedron.ray_generator(),
+                polyhedron.line_generator()]
+        Hrep = [polyhedron.inequality_generator(), polyhedron.equation_generator()]
+        return self._element_constructor_(Vrep, Hrep,
+                                          Vrep_minimal=True, Hrep_minimal=True, **kwds)
