@@ -17,7 +17,7 @@ H(yperplane) and V(ertex) representation objects for polyhedra
 from sage.structure.sage_object import SageObject
 from sage.structure.element import is_Vector
 from sage.structure.richcmp import richcmp_method, richcmp
-from sage.rings.all import QQ, ZZ, RDF
+from sage.rings.all import ZZ
 from sage.modules.free_module_element import vector
 
 
@@ -299,7 +299,7 @@ class PolyhedronRepresentation(SageObject):
             sage: v.count(1)
             3
         """
-        return sum([1 for j in self if i==j])
+        return sum([1 for j in self if i == j])
 
 
 class Hrepresentation(PolyhedronRepresentation):
@@ -574,9 +574,9 @@ class Hrepresentation(PolyhedronRepresentation):
             ....:                eqns=[(1, -1, -1, 1)])
             sage: for h in P.Hrepresentation():
             ....:     print(h.repr_pretty())
-            x0 + x1 == x2 + 1
+            x0 + x1 - x2 == 1
             x0 >= 0
-            2*x0 + x1 + 1 >= 0
+            2*x0 + x1 >= -1
         """
         return repr_pretty(self.vector(), self.type(), **kwds)
 
@@ -594,9 +594,9 @@ class Hrepresentation(PolyhedronRepresentation):
             ....:                eqns=[(1, -1, -1, 1)])
             sage: for h in P.Hrepresentation():
             ....:     print(latex(h))
-            x_{0} + x_{1} = x_{2} + 1
+            x_{0} + x_{1} - x_{2} = 1
             x_{0} \geq 0
-            2 \, x_{0} + x_{1} + 1 \geq 0
+            2 \, x_{0} + x_{1} \geq -1
         """
         return self.repr_pretty(latex=True)
 
@@ -681,7 +681,7 @@ class Inequality(Hrepresentation):
         have_A = not self.A().is_zero()
         if have_A:
             s += repr(self.A()) + ' x '
-        if self.b()>=0:
+        if self.b() >= 0:
             if have_A:
                 s += '+'
         else:
@@ -920,6 +920,7 @@ class Vrepresentation(PolyhedronRepresentation):
             sage: TestSuite(pV).run(skip='_test_pickling')
         """
         assert polyhedron.parent() is self._polyhedron_parent
+        data = list(data)
         if len(data) != self._vector.degree():
             raise ValueError('V-representation data requires a list of length ambient_dim')
 
@@ -1407,7 +1408,8 @@ class Line(Vrepresentation):
         return Hobj.A() * self.vector()
 
 
-def repr_pretty(coefficients, type, prefix='x', indices=None, latex=False):
+def repr_pretty(coefficients, type, prefix='x', indices=None,
+                latex=False, style='>=', split=False):
     r"""
     Return a pretty representation of equation/inequality represented
     by the coefficients.
@@ -1425,9 +1427,16 @@ def repr_pretty(coefficients, type, prefix='x', indices=None, latex=False):
 
     - ``latex`` -- a boolean
 
+    - ``split`` -- a boolean; (Default: ``False``). If set to ``True``,
+                   the output is split into a 3-tuple containing the left-hand side,
+                   the relation, and the right-hand side of the object.
+
+    - ``style`` -- either ``"positive"`` (making all coefficients positive), or
+                   ``"<="`` or ``">="``.
+
     OUTPUT:
 
-    A string.
+    A string or 3-tuple of strings (depending on ``split``).
 
     EXAMPLES::
 
@@ -1436,9 +1445,9 @@ def repr_pretty(coefficients, type, prefix='x', indices=None, latex=False):
         sage: print(repr_pretty((0, 1, 0, 0), PolyhedronRepresentation.INEQUALITY))
         x0 >= 0
         sage: print(repr_pretty((1, 2, 1, 0), PolyhedronRepresentation.INEQUALITY))
-        2*x0 + x1 + 1 >= 0
+        2*x0 + x1 >= -1
         sage: print(repr_pretty((1, -1, -1, 1), PolyhedronRepresentation.EQUATION))
-        x2 + 1 == x0 + x1
+        -x0 - x1 + x2 == -1
     """
     from sage.misc.latex import latex as latex_function
     from sage.modules.free_module_element import vector
@@ -1448,15 +1457,34 @@ def repr_pretty(coefficients, type, prefix='x', indices=None, latex=False):
     if indices is None:
         indices = range(len(coeffs)-1)
     vars = vector([1] + list(SR(prefix + '{}'.format(i)) for i in indices))
-    positive_part = vector([max(c, 0) for c in coeffs])
-    negative_part = - (coeffs - positive_part)
-    assert coeffs == positive_part - negative_part
+    f = latex_function if latex else repr
     if type == PolyhedronRepresentation.EQUATION:
         rel = '=' if latex else '=='
     elif type == PolyhedronRepresentation.INEQUALITY:
-        rel = r'\geq' if latex else '>='
+        if style == '<=':
+            rel = r'\leq' if latex else '<='
+        else:
+            rel = r'\geq' if latex else '>='
     else:
         raise NotImplementedError(
             'no pretty printing available: wrong type {}'.format(type))
-    f = latex_function if latex else repr
-    return '{} {} {}'.format(f(positive_part*vars), rel, f(negative_part*vars))
+
+    if style == 'positive':
+        pos_part = vector([max(c, 0) for c in coeffs])
+        neg_part = pos_part - coeffs
+        assert coeffs == pos_part - neg_part
+        left_part = f(pos_part*vars)
+        right_part = f(neg_part*vars)
+    elif style == '>=':
+        left_part = f(coeffs[1:]*vars[1:])
+        right_part = f(-coeffs[0])
+    elif style == '<=':
+        left_part = f(-coeffs[1:]*vars[1:])
+        right_part = f(coeffs[0])
+    else:
+        raise NotImplementedError('no pretty printing available: wrong style {}'.format(style))
+
+    if not split:
+        return '{} {} {}'.format(left_part, rel, right_part)
+    else:
+        return (str(left_part), rel, str(right_part))
