@@ -12,7 +12,10 @@
 #include <boost/graph/bellman_ford_shortest_paths.hpp>
 #include <boost/graph/dijkstra_shortest_paths.hpp>
 #include <boost/graph/johnson_all_pairs_shortest.hpp>
+#include <boost/graph/biconnected_components.hpp>
+#include <boost/graph/properties.hpp>
 
+#include <map>
 #include <iostream>
 
 typedef int v_index;
@@ -39,7 +42,6 @@ typedef struct {
                                   // path from the starting vertex to v.
 } result_distances;
 
-
 template <class OutEdgeListS, // How neighbors are stored
           class VertexListS,  // How vertices are stored
           class DirectedS,    // The kind of graph (undirectedS, directedS, or bidirectionalS)
@@ -71,6 +73,13 @@ private:
     typedef typename std::vector<edge_descriptor> edge_container;
     typedef typename boost::property_map<adjacency_list, boost::vertex_index_t>::type vertex_to_int_map;
 
+    // This struct is used for biconnected_components function
+    struct order_edges {
+        bool operator()(const edge_descriptor& x, const edge_descriptor& y) const { return x.get_property() < y.get_property(); }
+    };
+    // This map is a parameter/output for biconnected_components function
+    typedef typename std::map<edge_descriptor, int, order_edges> edge_map;
+
 public:
     adjacency_list graph;
     std::vector<vertex_descriptor> vertices;
@@ -190,6 +199,24 @@ public:
         return to_return;
     }
 
+    // This function returns the biconnected components of the graph.
+    std::vector<std::vector<v_index>> blocks_and_cut_vertices() {
+        edge_map bicmp_map;
+        boost::associative_property_map<edge_map> bimap(bicmp_map);
+        std::size_t num_comps = biconnected_components(graph, bimap);
+
+        // We iterate over every edge and add the vertices of block i into to_return[i].
+        // to_return[i] could contain repetitions.
+        std::vector<std::vector<v_index>> to_return(num_comps, std::vector<v_index>(0));
+        typename boost::graph_traits<adjacency_list>::edge_iterator ei, ei_end;
+        for (boost::tie(ei, ei_end) = edges(graph); ei != ei_end; ++ei) {
+            to_return[bimap[*ei]].push_back(index[source(*ei, graph)]);
+            to_return[bimap[*ei]].push_back(index[target(*ei, graph)]);
+        }
+
+        return to_return;
+    }
+
     result_distances dijkstra_shortest_paths(v_index s) {
          v_index N = num_verts();
          result_distances to_return;
