@@ -59,8 +59,8 @@ Here is the list of options accepted by
 
 This module defines two dictionaries containing default options for the
 :meth:`~sage.graphs.generic_graph.GenericGraph.plot` and
-:meth:`~sage.graphs.generic_graph.GenericGraph.show` methods. These two dictionaries are
-``sage.graphs.graph_plot.DEFAULT_PLOT_OPTIONS`` and
+:meth:`~sage.graphs.generic_graph.GenericGraph.show` methods. These two
+dictionaries are ``sage.graphs.graph_plot.DEFAULT_PLOT_OPTIONS`` and
 ``sage.graphs.graph_plot.DEFAULT_SHOW_OPTIONS``, respectively.
 
 Obviously, these values are overruled when arguments are given explicitly.
@@ -88,7 +88,7 @@ previously::
       settings from ``DEFAULT_SHOW_OPTIONS`` only affects ``G.show()``.
 
     * In order to define a default value permanently, you can add a couple of
-      lines to `Sage's startup scripts <../../../repl/startup.html>`_. Example ::
+      lines to `Sage's startup scripts <../../../repl/startup.html>`_. Example::
 
        sage: import sage.graphs.graph_plot
        sage: sage.graphs.graph_plot.DEFAULT_SHOW_OPTIONS['figsize'] = [4,4]
@@ -100,11 +100,11 @@ previously::
     :widths: 30, 70
     :delim: |
 
-    :meth:`GraphPlot.set_pos` | Sets the position plotting parameters for this GraphPlot.
-    :meth:`GraphPlot.set_vertices` | Sets the vertex plotting parameters for this GraphPlot.
-    :meth:`GraphPlot.set_edges` | Sets the edge (or arrow) plotting parameters for the GraphPlot object.
-    :meth:`GraphPlot.show` | Shows the (Di)Graph associated with this GraphPlot object.
-    :meth:`GraphPlot.plot` | Returns a graphics object representing the (di)graph.
+    :meth:`GraphPlot.set_pos` | Set the position plotting parameters for this GraphPlot.
+    :meth:`GraphPlot.set_vertices` | Set the vertex plotting parameters for this GraphPlot.
+    :meth:`GraphPlot.set_edges` | Set the edge (or arrow) plotting parameters for the GraphPlot object.
+    :meth:`GraphPlot.show` | Show the (Di)Graph associated with this GraphPlot object.
+    :meth:`GraphPlot.plot` | Return a graphics object representing the (di)graph.
     :meth:`GraphPlot.layout_tree` | Compute a nice layout of a tree.
 """
 
@@ -214,34 +214,36 @@ DEFAULT_PLOT_OPTIONS = {
 class GraphPlot(SageObject):
     def __init__(self, graph, options):
         """
-        Returns a ``GraphPlot`` object, which stores all the parameters needed for
-        plotting (Di)Graphs.  A ``GraphPlot`` has a plot and show function, as well
-        as some functions to set parameters for vertices and edges.  This constructor
-        assumes default options are set.  Defaults are shown in the example below.
+        Return a ``GraphPlot`` object, which stores all the parameters needed
+        for plotting (Di)Graphs.
+
+        A ``GraphPlot`` has a plot and show function, as well as some functions
+        to set parameters for vertices and edges.  This constructor assumes
+        default options are set.  Defaults are shown in the example below.
 
         EXAMPLES::
 
             sage: from sage.graphs.graph_plot import GraphPlot
             sage: options = {
-            ....:   'vertex_size':200,
-            ....:   'vertex_labels':True,
-            ....:   'layout':None,
-            ....:   'edge_style':'solid',
-            ....:   'edge_color':'black',
-            ....:   'edge_colors':None,
-            ....:   'edge_labels':False,
-            ....:   'iterations':50,
-            ....:   'tree_orientation':'down',
-            ....:   'heights':None,
-            ....:   'graph_border':False,
-            ....:   'talk':False,
-            ....:   'color_by_label':False,
-            ....:   'partition':None,
-            ....:   'dist':.075,
-            ....:   'max_dist':1.5,
-            ....:   'loop_size':.075,
-            ....:   'edge_labels_background':'transparent'}
-            sage: g = Graph({0:[1,2], 2:[3], 4:[0,1]})
+            ....:   'vertex_size': 200,
+            ....:   'vertex_labels': True,
+            ....:   'layout': None,
+            ....:   'edge_style': 'solid',
+            ....:   'edge_color': 'black',
+            ....:   'edge_colors': None,
+            ....:   'edge_labels': False,
+            ....:   'iterations': 50,
+            ....:   'tree_orientation': 'down',
+            ....:   'heights': None,
+            ....:   'graph_border': False,
+            ....:   'talk': False,
+            ....:   'color_by_label': False,
+            ....:   'partition': None,
+            ....:   'dist': .075,
+            ....:   'max_dist': 1.5,
+            ....:   'loop_size': .075,
+            ....:   'edge_labels_background': 'transparent'}
+            sage: g = Graph({0:[1, 2], 2:[3], 4:[0, 1]})
             sage: GP = GraphPlot(g, options)
 
         """
@@ -250,23 +252,20 @@ class GraphPlot(SageObject):
             if k not in options:
                 options[k] = value
         self._plot_components = {}
-        self._nodelist = graph.vertices()
+        self._nodelist = list(graph)
         self._graph = graph
         self._options = options # contains both plot and show options
         self.set_pos()
         self._arcs = self._graph.has_multiple_edges(to_undirected=True)
         self._loops = self._graph.has_loops()
-        if self._graph.is_directed() and self._arcs:
-            self._arcdigraph = True
-        else:
-            self._arcdigraph = False
+        self._arcdigraph = self._graph.is_directed() and self._arcs
 
         self.set_vertices()
         self.set_edges()
 
     def _repr_(self):
         """
-        Returns a string representation of a ``GraphPlot`` object.
+        Return a string representation of a ``GraphPlot`` object.
 
         EXAMPLES:
 
@@ -280,7 +279,7 @@ class GraphPlot(SageObject):
 
     def set_pos(self):
         """
-        Sets the position plotting parameters for this GraphPlot.
+        Set the position plotting parameters for this GraphPlot.
 
         EXAMPLES:
 
@@ -290,8 +289,8 @@ class GraphPlot(SageObject):
             sage: g.graphplot(save_pos=True, layout='circular') # indirect doctest
             GraphPlot object for Graph on 5 vertices
 
-        The following illustrates the format of a position dictionary,
-        but due to numerical noise we do not check the values themselves::
+        The following illustrates the format of a position dictionary, but due
+        to numerical noise we do not check the values themselves::
 
             sage: g.get_pos()
             {0: (0.0, 1.0),
@@ -318,10 +317,10 @@ class GraphPlot(SageObject):
 
         TESTS:
 
-        Make sure that vertex locations are floats.  Not being floats
-        isn't a bug in itself but makes it too easy to accidentally
-        introduce a bug elsewhere, such as in :meth:`set_edges` (:trac:`10124`),
-        via silent truncating division of integers::
+        Make sure that vertex locations are floats.  Not being floats isn't a
+        bug in itself but makes it too easy to accidentally introduce a bug
+        elsewhere, such as in :meth:`set_edges` (:trac:`10124`), via silent
+        truncating division of integers::
 
             sage: g = graphs.FruchtGraph()
             sage: gp = g.graphplot()
@@ -339,15 +338,16 @@ class GraphPlot(SageObject):
         """
         self._pos = self._graph.layout(**self._options)
         # make sure the positions are floats (trac #10124)
-        self._pos = dict((k, (float(v[0]), float(v[1])))
-                         for k, v in iteritems(self._pos))
+        self._pos = {k: (float(v[0]), float(v[1]))
+                         for k, v in iteritems(self._pos)}
 
     def set_vertices(self, **vertex_options):
         """
-        Sets the vertex plotting parameters for this ``GraphPlot``.  This function
-        is called by the constructor but can also be called to make updates to
-        the vertex options of an existing ``GraphPlot`` object.  Note that the
-        changes are cumulative.
+        Set the vertex plotting parameters for this ``GraphPlot``.
+
+        This function is called by the constructor but can also be called to
+        make updates to the vertex options of an existing ``GraphPlot`` object.
+        Note that the changes are cumulative.
 
         EXAMPLES::
 
@@ -417,9 +417,7 @@ class GraphPlot(SageObject):
                 partition = self._options['partition']
                 l = len(partition)
                 R = rainbow(l)
-                vertex_colors = {}
-                for i in range(l):
-                    vertex_colors[R[i]] = partition[i]
+                vertex_colors = {R[i]: partition[i] for i in range(l)}
             elif not vertex_colors:
                 vertex_colors = vertex_color
         else:
@@ -429,10 +427,10 @@ class GraphPlot(SageObject):
             voptions['marker'] = self._options['vertex_shape']
 
         if self._graph.is_directed():
-            self._vertex_radius = sqrt(voptions['markersize']/pi)
-            self._arrowshorten = 2*self._vertex_radius
+            self._vertex_radius = sqrt(voptions['markersize'] / pi)
+            self._arrowshorten = 2 * self._vertex_radius
             if self._arcdigraph:
-                self._vertex_radius = sqrt(voptions['markersize']/(20500*pi))
+                self._vertex_radius = sqrt(voptions['markersize'] / (20500 * pi))
 
         voptions['zorder'] = 7
 
@@ -455,13 +453,13 @@ class GraphPlot(SageObject):
             colors = []
             for i in vertex_colors:
                 pos += [self._pos[j] for j in vertex_colors[i]]
-                colors += [i]*len(vertex_colors[i])
+                colors += [i] * len(vertex_colors[i])
 
             # If all the vertices have not been assigned a color
             if len(self._pos) != len(pos):
                 leftovers = [j for j in self._pos.values() if j not in pos]
                 pos += leftovers
-                colors += [vertex_color]*len(leftovers)
+                colors += [vertex_color] * len(leftovers)
 
             if self._arcdigraph:
                 self._plot_components['vertices'] = [circle(pos[i],
@@ -485,15 +483,16 @@ class GraphPlot(SageObject):
 
     def set_edges(self, **edge_options):
         """
-        Sets the edge (or arrow) plotting parameters for the ``GraphPlot`` object.
+        Set the edge (or arrow) plotting parameters for the ``GraphPlot``
+        object.
 
-        This function is called by the constructor but can also be called to make
-        updates to the vertex options of an existing ``GraphPlot`` object.  Note
-        that the changes are cumulative.
+        This function is called by the constructor but can also be called to
+        make updates to the vertex options of an existing ``GraphPlot`` object.
+        Note that the changes are cumulative.
 
         EXAMPLES::
 
-            sage: g = Graph({}, loops=True, multiedges=True, sparse=True)
+            sage: g = Graph(loops=True, multiedges=True, sparse=True)
             sage: g.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
             ....:  (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             sage: GP = g.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
@@ -504,7 +503,7 @@ class GraphPlot(SageObject):
 
         .. PLOT::
 
-            g = Graph({}, loops=True, multiedges=True, sparse=True)
+            g = Graph(loops=True, multiedges=True, sparse=True)
             g.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
                 (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             GP = g.graphplot(vertex_size=100, edge_labels=True,
@@ -520,7 +519,7 @@ class GraphPlot(SageObject):
 
         .. PLOT::
 
-            g = Graph({}, loops=True, multiedges=True, sparse=True)
+            g = Graph(loops=True, multiedges=True, sparse=True)
             g.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
                 (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             GP = g.graphplot(vertex_size=100, edge_labels=True,
@@ -531,7 +530,7 @@ class GraphPlot(SageObject):
 
         ::
 
-            sage: d = DiGraph({}, loops=True, multiedges=True, sparse=True)
+            sage: d = DiGraph(loops=True, multiedges=True, sparse=True)
             sage: d.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
             ....:   (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             sage: GP = d.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
@@ -542,7 +541,7 @@ class GraphPlot(SageObject):
 
         .. PLOT::
 
-            d = DiGraph({}, loops=True, multiedges=True, sparse=True)
+            d = DiGraph(loops=True, multiedges=True, sparse=True)
             d.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
                 (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             GP = d.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
@@ -558,7 +557,7 @@ class GraphPlot(SageObject):
 
         .. PLOT::
 
-            d = DiGraph({}, loops=True, multiedges=True, sparse=True)
+            d = DiGraph(loops=True, multiedges=True, sparse=True)
             d.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
                 (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             GP = d.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
@@ -578,33 +577,33 @@ class GraphPlot(SageObject):
             sage: test_graphs = graphs.FruchtGraph(), graphs.BullGraph()
             sage: tol = 0.001
             sage: for G in test_graphs:
-            ....:     E=G.edges()
+            ....:     E = G.edges()
             ....:     for e0, e1, elab in E:
             ....:         G.set_edge_label(e0, e1, '%d %d' % (e0, e1))
-            ....:     gp = G.graphplot(save_pos=True,edge_labels=True)
+            ....:     gp = G.graphplot(save_pos=True, edge_labels=True)
             ....:     vx = gp._plot_components['vertices'][0].xdata
             ....:     vy = gp._plot_components['vertices'][0].ydata
             ....:     for elab in gp._plot_components['edge_labels']:
             ....:         textobj = elab[0]
             ....:         x, y, s = textobj.x, textobj.y, textobj.string
             ....:         v0, v1 = map(int, s.split())
-            ....:         vn = vector(((x-(vx[v0]+vx[v1])/2.),y-(vy[v0]+vy[v1])/2.)).norm()
+            ....:         vn = vector(((x-(vx[v0]+vx[v1])/2.), y-(vy[v0]+vy[v1])/2.)).norm()
             ....:         assert vn < tol
 
         Ticket :trac:`24051` is fixed::
 
-            sage: G = Graph([(0,1), (0,1)], multiedges=True)
-            sage: G.plot(edge_colors={"red":[(1,0)]})
+            sage: G = Graph([(0, 1), (0, 1)], multiedges=True)
+            sage: G.plot(edge_colors={"red": [(1, 0)]})
             Graphics object consisting of 5 graphics primitives
         """
         for arg in edge_options:
             self._options[arg] = edge_options[arg]
         if 'edge_colors' in edge_options: self._options['color_by_label'] = False
-        if self._options['edge_labels_background']=="transparent":
-            self._options['edge_labels_background']="None"
+        if self._options['edge_labels_background'] == "transparent":
+            self._options['edge_labels_background'] = "None"
 
         # Handle base edge options: thickness, linestyle
-        eoptions={}
+        eoptions = {}
         if 'edge_style' in self._options:
             from sage.plot.misc import get_matplotlib_linestyle
             eoptions['linestyle'] = get_matplotlib_linestyle(
@@ -628,6 +627,8 @@ class GraphPlot(SageObject):
             else:
                 edges_to_draw[key] = [(label, color, head)]
 
+        v_to_int = {v: i for i,v in enumerate(self._graph)}
+
         if self._options['color_by_label'] or isinstance(self._options['edge_colors'], dict):
             if self._options['color_by_label']:
                 edge_colors = self._graph._color_by_label(format=self._options['color_by_label'])
@@ -636,50 +637,58 @@ class GraphPlot(SageObject):
             edges_drawn = []
             for color in edge_colors:
                 for edge in edge_colors[color]:
-                    key = tuple(sorted([edge[0],edge[1]]))
-                    if key == (edge[0],edge[1]): head = 1
-                    else: head = 0
-
+                    if v_to_int[edge[0]] < v_to_int[edge[1]]:
+                        key = (edge[0], edge[1])
+                        head = 1
+                    else:
+                        key = (edge[1], edge[0])
+                        head = 0
                     if len(edge) < 3:
-                        label = self._graph.edge_label(edge[0],edge[1])
+                        label = self._graph.edge_label(edge[0], edge[1])
                         if isinstance(label, list):
                             append_or_set(key, label[-1], color, head)
-                            edges_drawn.append((edge[0],edge[1],label[-1]))
-                            for i in range(len(label)-1):
+                            edges_drawn.append((edge[0], edge[1], label[-1]))
+                            for i in range(len(label) - 1):
                                 edges_to_draw[key].append((label[i], color, head))
-                                edges_drawn.append((edge[0],edge[1],label[i]))
+                                edges_drawn.append((edge[0], edge[1], label[i]))
                         else:
                             append_or_set(key, label, color, head)
-                            edges_drawn.append((edge[0],edge[1],label))
+                            edges_drawn.append((edge[0], edge[1], label))
                     else:
                         label = edge[2]
-                        labelList = self._graph.edge_label(edge[0],edge[1])
+                        labelList = self._graph.edge_label(edge[0], edge[1])
                         if isinstance(labelList, list):
-                            for i in range(len(labelList)):
-                                if labelList[i] == label:
+                            for l in labelList:
+                                if l == label:
                                     append_or_set(key, label, color, head)
-                                    edges_drawn.append((edge[0],edge[1],label))
+                                    edges_drawn.append((edge[0], edge[1], label))
                         else:
                             if labelList == label:
                                 append_or_set(key, label, color, head)
-                                edges_drawn.append((edge[0],edge[1],label))
+                                edges_drawn.append((edge[0], edge[1], label))
 
             # Add unspecified edges (default color black set in DEFAULT_PLOT_OPTIONS)
             for edge in self._graph.edge_iterator():
-                if (edge[0],edge[1],edge[2]) not in edges_drawn and \
+                if (edge[0], edge[1], edge[2]) not in edges_drawn and \
                     ( self._graph.is_directed() or
-                      (edge[1],edge[0],edge[2]) not in edges_drawn
+                      (edge[1], edge[0], edge[2]) not in edges_drawn
                     ):
-                    key = tuple(sorted([edge[0],edge[1]]))
-                    if key == (edge[0],edge[1]): head = 1
-                    else: head = 0
+                    if v_to_int[edge[0]] < v_to_int[edge[1]]:
+                        key = (edge[0], edge[1])
+                        head = 1
+                    else:
+                        key = (edge[1], edge[0])
+                        head = 0
                     append_or_set(key, edge[2], self._options['edge_color'], head)
 
         else:
-            for edge in self._graph.edges(sort=True):
-                key = tuple(sorted([edge[0],edge[1]]))
-                if key == (edge[0],edge[1]): head = 1
-                else: head = 0
+            for edge in self._graph.edge_iterator():
+                if v_to_int[edge[0]] < v_to_int[edge[1]]:
+                    key = (edge[0], edge[1])
+                    head = 1
+                else:
+                    key = (edge[1], edge[0])
+                    head = 0
                 append_or_set(key, edge[2], self._options['edge_color'], head)
 
         if edges_to_draw:
@@ -690,28 +699,29 @@ class GraphPlot(SageObject):
         # Check for multi-edges or loops
         if self._arcs or self._loops:
             tmp = edges_to_draw.copy()
-            dist = self._options['dist']*2.
+            dist = self._options['dist'] * 2.
             loop_size = self._options['loop_size']
             max_dist = self._options['max_dist']
             from sage.functions.all import sqrt
-            for (a,b) in tmp:
+            for a, b in tmp:
                 if a == b:
                     # Loops
                     distance = dist
-                    local_labels = edges_to_draw.pop((a,b))
-                    if len(local_labels)*dist > max_dist:
-                        distance = float(max_dist)/len(local_labels)
+                    local_labels = edges_to_draw.pop((a, b))
+                    len_local_labels = len(local_labels)
+                    if len_local_labels * dist > max_dist:
+                        distance = float(max_dist) / len_local_labels
                     curr_loop_size = loop_size
-                    for i in range(len(local_labels)):
+                    for i in range(len_local_labels):
                         self._plot_components['edges'].append(circle((self._pos[a][0],
                             self._pos[a][1]-curr_loop_size), curr_loop_size,
                             rgbcolor=local_labels[i][1], **eoptions))
                         if labels:
                             self._plot_components['edge_labels'].append(text(local_labels[i][0],
-                                (self._pos[a][0], self._pos[a][1]-2*curr_loop_size),
+                                (self._pos[a][0], self._pos[a][1] - 2 * curr_loop_size),
                                 background_color=self._options['edge_labels_background']))
-                        curr_loop_size += distance/4
-                elif len(edges_to_draw[(a,b)]) > 1:
+                        curr_loop_size += distance / 4
+                elif len(edges_to_draw[a,b]) > 1:
                     # Multi-edge
                     local_labels = edges_to_draw.pop((a,b))
 
@@ -720,107 +730,109 @@ class GraphPlot(SageObject):
                     p2 = self._pos[b]
                     M = ((p1[0]+p2[0])/2., (p1[1]+p2[1])/2.) # midpoint
                     if not p1[1] == p2[1]:
-                        S = float(p1[0]-p2[0])/(p2[1]-p1[1]) # perp slope
-                        y = lambda x : S*x-S*M[0]+M[1] # perp bisector line
+                        S = float(p1[0]-p2[0]) / (p2[1]-p1[1]) # perp slope
+                        y = lambda x: S*x-S*M[0]+M[1] # perp bisector line
 
                         # f,g are functions of distance d to determine x values
                         # on line y at d from point M
-                        f = lambda d : sqrt(d**2/(1.+S**2)) + M[0]
-                        g = lambda d : -sqrt(d**2/(1.+S**2)) + M[0]
+                        f = lambda d: sqrt(d**2/(1.+S**2)) + M[0]
+                        g = lambda d: -sqrt(d**2/(1.+S**2)) + M[0]
 
                         odd_x = f
                         even_x = g
                         if p1[0] == p2[0]:
-                            odd_y = lambda d : M[1]
+                            odd_y = lambda d: M[1]
                             even_y = odd_y
                         else:
-                            odd_y = lambda x : y(f(x))
-                            even_y = lambda x : y(g(x))
+                            odd_y = lambda x: y(f(x))
+                            even_y = lambda x: y(g(x))
                     else:
-                        odd_x = lambda d : M[0]
+                        odd_x = lambda d: M[0]
                         even_x = odd_x
-                        odd_y = lambda d : M[1] + d
-                        even_y = lambda d : M[1] - d
+                        odd_y = lambda d: M[1] + d
+                        even_y = lambda d: M[1] - d
 
                     # We now have the control points for each bezier curve
                     # in terms of distance parameter d.
                     # Also note that the label for each edge should be drawn at d/2.
                     # (This is because we're using the perp bisectors).
                     distance = dist
-                    if len(local_labels)*dist > max_dist:
-                        distance = float(max_dist)/len(local_labels)
-                    for i in range(len(local_labels)//2):
-                        k = (i+1.0)*distance
+                    len_local_labels = len(local_labels)
+                    if len_local_labels * dist > max_dist:
+                        distance = float(max_dist) / len_local_labels
+                    for i in range(len_local_labels // 2):
+                        k = (i + 1.0) * distance
                         if self._arcdigraph:
                             odd_start = self._polar_hack_for_multidigraph(p1,
-                                [odd_x(k),odd_y(k)], self._vertex_radius)[0]
-                            odd_end = self._polar_hack_for_multidigraph([odd_x(k),odd_y(k)],
+                                [odd_x(k), odd_y(k)], self._vertex_radius)[0]
+                            odd_end = self._polar_hack_for_multidigraph([odd_x(k), odd_y(k)],
                                 p2, self._vertex_radius)[1]
                             even_start = self._polar_hack_for_multidigraph(p1,
-                                [even_x(k),even_y(k)], self._vertex_radius)[0]
-                            even_end = self._polar_hack_for_multidigraph([even_x(k),even_y(k)],
+                                [even_x(k), even_y(k)], self._vertex_radius)[0]
+                            even_end = self._polar_hack_for_multidigraph([even_x(k), even_y(k)],
                                 p2, self._vertex_radius)[1]
                             self._plot_components['edges'].append(arrow(path=[[odd_start,
-                                [odd_x(k),odd_y(k)],odd_end]], head=local_labels[2*i][2],
+                                [odd_x(k), odd_y(k)], odd_end]], head=local_labels[2*i][2],
                                 zorder=1, rgbcolor=local_labels[2*i][1], **eoptions))
                             self._plot_components['edges'].append(arrow(path=[[even_start,
-                                [even_x(k),even_y(k)],even_end]], head=local_labels[2*i+1][2],
+                                [even_x(k), even_y(k)], even_end]], head=local_labels[2*i+1][2],
                                 zorder=1, rgbcolor=local_labels[2*i+1][1], **eoptions))
                         else:
                             self._plot_components['edges'].append(bezier_path([[p1,
-                                [odd_x(k),odd_y(k)],p2]],zorder=1,
+                                [odd_x(k), odd_y(k)], p2]], zorder=1,
                                 rgbcolor=local_labels[2*i][1], **eoptions))
                             self._plot_components['edges'].append(bezier_path([[p1,
-                                [even_x(k),even_y(k)],p2]],zorder=1,
+                                [even_x(k), even_y(k)], p2]], zorder=1,
                                 rgbcolor=local_labels[2*i+1][1], **eoptions))
                         if labels:
-                            j = k/2.0
+                            j = k / 2.0
                             self._plot_components['edge_labels'].append(text(local_labels[2*i][0],
-                                [odd_x(j),odd_y(j)], background_color=self._options['edge_labels_background']))
+                                [odd_x(j), odd_y(j)], background_color=self._options['edge_labels_background']))
                             self._plot_components['edge_labels'].append(text(local_labels[2*i+1][0],
-                                [even_x(j),even_y(j)],
+                                [even_x(j), even_y(j)],
                                 background_color=self._options['edge_labels_background']))
-                    if len(local_labels)%2 == 1:
-                        edges_to_draw[(a,b)] = [local_labels[-1]] # draw line for last odd
+                    if len_local_labels % 2:
+                        edges_to_draw[a,b] = [local_labels[-1]] # draw line for last odd
 
-        dir = self._graph.is_directed()
-        for (a,b) in edges_to_draw:
+        is_directed = self._graph.is_directed()
+        for a,b in edges_to_draw:
             if self._arcdigraph:
-                C,D = self._polar_hack_for_multidigraph(self._pos[a], self._pos[b], self._vertex_radius)
-                self._plot_components['edges'].append(arrow(C,D,
-                    rgbcolor=edges_to_draw[(a,b)][0][1], head=edges_to_draw[(a,b)][0][2],
+                C, D = self._polar_hack_for_multidigraph(self._pos[a], self._pos[b], self._vertex_radius)
+                self._plot_components['edges'].append(arrow(C, D,
+                    rgbcolor=edges_to_draw[a,b][0][1], head=edges_to_draw[a,b][0][2],
                     **eoptions))
                 if labels:
-                    self._plot_components['edge_labels'].append(text(str(edges_to_draw[(a,b)][0][0]),
+                    self._plot_components['edge_labels'].append(text(str(edges_to_draw[a,b][0][0]),
                         [(C[0]+D[0])/2., (C[1]+D[1])/2.],
                         background_color=self._options['edge_labels_background']))
-            elif dir:
-                self._plot_components['edges'].append(arrow(self._pos[a],self._pos[b],
-                    rgbcolor=edges_to_draw[(a,b)][0][1], arrowshorten=self._arrowshorten,
-                    head=edges_to_draw[(a,b)][0][2], **eoptions))
+            elif is_directed:
+                self._plot_components['edges'].append(arrow(self._pos[a], self._pos[b],
+                    rgbcolor=edges_to_draw[a,b][0][1], arrowshorten=self._arrowshorten,
+                    head=edges_to_draw[a,b][0][2], **eoptions))
             else:
-                self._plot_components['edges'].append(line([self._pos[a],self._pos[b]],
-                    rgbcolor=edges_to_draw[(a,b)][0][1], **eoptions))
+                self._plot_components['edges'].append(line([self._pos[a], self._pos[b]],
+                    rgbcolor=edges_to_draw[a,b][0][1], **eoptions))
             if labels and not self._arcdigraph:
-                self._plot_components['edge_labels'].append(text(str(edges_to_draw[(a,b)][0][0]),
-                    [(self._pos[a][0]+self._pos[b][0])/2.,
-                    (self._pos[a][1]+self._pos[b][1])/2.],
+                self._plot_components['edge_labels'].append(text(str(edges_to_draw[a,b][0][0]),
+                    [(self._pos[a][0] + self._pos[b][0])/2.,
+                    (self._pos[a][1] + self._pos[b][1])/2.],
                     background_color=self._options['edge_labels_background']))
 
     def _polar_hack_for_multidigraph(self, A, B, VR):
         """
-        Helper function to quickly compute the two points of intersection of a line
-        segment from A to B (xy tuples) and circles centered at A and B, both with
-        radius VR.  Returns a tuple of xy tuples representing the two points.
+        Helper function to quickly compute the two points of intersection of a
+        line segment from A to B (xy tuples) and circles centered at A and B,
+        both with radius VR.  Returns a tuple of xy tuples representing the two
+        points.
 
         EXAMPLES::
 
-            sage: d = DiGraph({}, loops=True, multiedges=True, sparse=True)
+            sage: d = DiGraph(loops=True, multiedges=True, sparse=True)
             sage: d.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
             ....:   (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             sage: GP = d.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
             ....:  edge_style='dashed')
-            sage: GP._polar_hack_for_multidigraph((0,1),(1,1),.1)
+            sage: GP._polar_hack_for_multidigraph((0, 1), (1, 1), .1)
             ([0.10..., 1.00...], [0.90..., 1.00...])
 
         TESTS:
@@ -830,27 +842,29 @@ class GraphPlot(SageObject):
             sage: GP = DiGraph().graphplot()
             sage: GP._polar_hack_for_multidigraph((0, 1), (2, 2), .1)
             ([0.08..., 1.04...], [1.91..., 1.95...])
-            sage: GP._polar_hack_for_multidigraph((int(0),int(1)),(int(2),int(2)),.1)
+            sage: GP._polar_hack_for_multidigraph((int(0), int(1)), (int(2), int(2)), .1)
             ([0.08..., 1.04...], [1.91..., 1.95...])
 
         """
-        D = [float(B[i]-A[i]) for i in range(2)]
-        R = sqrt(D[0]**2+D[1]**2)
-        theta = 3*pi/2
+        D = [float(B[i] - A[i]) for i in range(2)]
+        R = sqrt(D[0]**2 + D[1]**2)
+        theta = 3 * pi / 2
         if D[0] > 0:
-            theta = atan(D[1]/D[0])
+            theta = atan(D[1] / D[0])
             if D[1] < 0:
-                theta += 2*pi
+                theta += 2 * pi
         elif D[0] < 0:
-            theta = atan(D[1]/D[0]) + pi
+            theta = atan(D[1] / D[0]) + pi
         elif D[1] > 0:
-            theta = pi/2
-        return ([VR*cos(theta)+A[0], VR*sin(theta)+A[1]], [(R-VR)*cos(theta)+A[0],
-            (R-VR)*sin(theta)+A[1]])
+            theta = pi / 2
+        cos_theta = cos(theta)
+        sin_theta = sin(theta)
+        return ([VR * cos_theta + A[0], VR * sin_theta + A[1]],
+                [(R - VR) * cos_theta + A[0], (R - VR) * sin_theta + A[1]])
 
     def show(self, **kwds):
         """
-        Shows the (Di)Graph associated with this ``GraphPlot`` object.
+        Show the (Di)Graph associated with this ``GraphPlot`` object.
 
         INPUT:
 
@@ -887,7 +901,7 @@ class GraphPlot(SageObject):
 
     def plot(self, **kwds):
         """
-        Returns a graphics object representing the (di)graph.
+        Return a graphics object representing the (di)graph.
 
         INPUT:
 
@@ -1252,19 +1266,19 @@ class GraphPlot(SageObject):
             xmax = G.xmax()
             ymin = G.ymin()
             ymax = G.ymax()
-            dx = (xmax-xmin)/10.0
-            dy = (ymax-ymin)/10.0
-            border = (line([( xmin - dx, ymin - dy), ( xmin - dx, ymax + dy ),
-                ( xmax + dx, ymax + dy ), ( xmax + dx, ymin - dy ), ( xmin - dx, ymin - dy )],
-                thickness=1.3))
-            border.axes_range(xmin = (xmin - dx), xmax = (xmax + dx), ymin = (ymin - dy),
-                ymax = (ymax + dy))
+            dx = (xmax - xmin) / 10.0
+            dy = (ymax - ymin) / 10.0
+            border = (line([(xmin - dx, ymin - dy), (xmin - dx, ymax + dy),
+                            (xmax + dx, ymax + dy), (xmax + dx, ymin - dy),
+                            (xmin - dx, ymin - dy)], thickness=1.3))
+            border.axes_range(xmin=(xmin - dx), xmax=(xmax + dx),
+                              ymin=(ymin - dy), ymax=(ymax + dy))
             G += border
         G.set_aspect_ratio(1)
         G.axes(False)
         return G
 
-    def layout_tree(self,root,orientation):
+    def layout_tree(self, root, orientation):
         """
         Compute a nice layout of a tree.
 
@@ -1272,83 +1286,75 @@ class GraphPlot(SageObject):
 
         - ``root`` -- the root vertex.
 
-        - ``orientation`` -- Whether to place the root
-          at the top or at the bottom :
+        - ``orientation`` -- whether to place the root at the top or at the
+          bottom:
 
-            - ``orientation="down"`` -- children are placed below
-              their parent
-            - ``orientation="top"`` -- children are placed above
-              their parent
+          * ``orientation="down"`` -- children are placed below their parent
+          * ``orientation="top"`` -- children are placed above their parent
 
         EXAMPLES::
 
-            sage: T = graphs.RandomLobster(25,0.3,0.3)
-            sage: T.show(layout='tree',tree_orientation='up') # indirect doctest
-
             sage: from sage.graphs.graph_plot import GraphPlot
             sage: G = graphs.HoffmanSingletonGraph()
             sage: T = Graph()
             sage: T.add_edges(G.min_spanning_tree(starting_vertex=0))
-            sage: T.show(layout='tree',tree_root=0) # indirect doctest
+            sage: T.show(layout='tree', tree_root=0) # indirect doctest
 
         """
-
         T = self._graph
 
         if not self._graph.is_tree():
             raise RuntimeError("Cannot use tree layout on this graph: self.is_tree() returns False.")
 
-        children = {root:T.neighbors(root)}
+        children = {root: T.neighbors(root)}
 
         #always make a copy of the children because they get eaten
         stack = [[u for u in children[root]]]
         stick = [root]
-        parent = dict([(u,root) for u in children[root]])
+        parent = {u: root for u in children[root]}
         pos = {}
-        obstruction = [0.0]*T.num_verts()
+        obstruction = [0.0] * T.num_verts()
         if orientation == 'down':
             o = -1
         else:
             o = 1
 
-        def slide(v,dx):
+        def slide(v, dx):
             """
-
-            shift the vertex v and its descendants to the right by dx
+            Shift the vertex v and its descendants to the right by dx.
 
             Precondition: v and its descendents have already had their
             positions computed.
 
             """
-
             level = [v]
             while level:
                 nextlevel = []
                 for u in level:
-                    x,y = pos[u]
-                    x+= dx
-                    obstruction[y] = max(x+1, obstruction[y])
-                    pos[u] = x,y
+                    x, y = pos[u]
+                    x += dx
+                    obstruction[y] = max(x + 1, obstruction[y])
+                    pos[u] = x, y
                     nextlevel += children[u]
 
                 level = nextlevel
 
         while stack:
             C = stack[-1]
-            if len(C) == 0:
+            if not C:
                 p = stick.pop()
                 stack.pop()
                 cp = children[p]
-                y = o*len(stack)
-                if len(cp) == 0:
+                y = o * len(stack)
+                if not cp:
                     x = obstruction[y]
-                    pos[p] = x,y
+                    pos[p] = x, y
                 else:
-                    x = sum([pos[c][0] for c in cp])/(float(len(cp)))
+                    x = sum([pos[c][0] for c in cp]) / float(len(cp))
                     pos[p] = x,y
                     ox = obstruction[y]
                     if x < ox:
-                        slide(p,ox-x)
+                        slide(p, ox - x)
                         x = ox
                 obstruction[y] = x+1
                 continue
@@ -1361,8 +1367,7 @@ class GraphPlot(SageObject):
                 parent[c] = t
             children[t] = ct
 
-            stack.append([c for c in ct])
+            stack.append(ct)
             stick.append(t)
 
         return pos
-
