@@ -8,7 +8,16 @@ from .abelian_gps.all import *
 
 from .perm_gps.all import *
 
-from .generic import *
+from .generic import (discrete_log, discrete_log_rho, discrete_log_lambda,
+                      linear_relation, multiple, multiples)
+lazy_import('sage.groups.generic',
+            ['bsgs', 'discrete_log_generic', 'multiplication_names',
+             'addition_names', 'order_from_multiple', 'order_from_bounds',
+             'merge_points', 'structure_description'],
+            deprecation=(25785, "this is being removed from the global namespace"))
+
+# deprecation(24256)
+from sage.structure.element import generic_power as power
 
 lazy_import('sage.groups.class_function', 'ClassFunction')
 
