@@ -231,7 +231,6 @@ class FinitelyPresentedGroupElement(FreeGroupElement):
 
             sage: TestSuite(G).run()
             sage: TestSuite(H).run()
-
             sage: G.<a,b> = FreeGroup()
             sage: H = G / (G([1]), G([2, 2, 2]))
             sage: x = H([1, 2, -1, -2])
@@ -1096,6 +1095,7 @@ class FinitelyPresentedGroup(GroupMixinLibGAP, UniqueRepresentation,
             sage: C7 = G / [G.0**7]; C6 =  G / [G.0**6]
             sage: C14 = G / [G.0**14]; C3 =  G / [G.0**3]
             sage: C7.direct_product(C6).is_isomorphic(C14.direct_product(C3))
+            #I  Forcing finiteness test
             True
             sage: F = FreeGroup(2); D = F / [F([1,1,1,1,1]),F([2,2]),F([1,2])**2]
             sage: D.direct_product(D).as_permutation_group().is_isomorphic(
@@ -1189,6 +1189,7 @@ class FinitelyPresentedGroup(GroupMixinLibGAP, UniqueRepresentation,
             sage: alpha = (Q.gens(), [a,b])
             sage: S2 = C2.semidirect_product(Q, ([C2.0],[alpha]))
             sage: S1.is_isomorphic(S2)
+            #I  Forcing finiteness test
             True
 
         Dihedral groups can be constructed as semidirect products
@@ -1247,6 +1248,8 @@ class FinitelyPresentedGroup(GroupMixinLibGAP, UniqueRepresentation,
             sage: Se2 =  D.semidirect_product(C ,id2)
             sage: Dp1 = C.direct_product(D)
             sage: Dp1.is_isomorphic(Se1), Dp1.is_isomorphic(Se2)
+            #I  Forcing finiteness test
+            #I  Forcing finiteness test
             (True, True)
 
         Most checks for validity of input are left to GAP to handle::
@@ -1445,27 +1448,27 @@ class FinitelyPresentedGroup(GroupMixinLibGAP, UniqueRepresentation,
             sage: H = AlternatingGroup(3)
             sage: G.epimorphisms(H)
             [Generic morphism:
-            From: Finitely presented group < x0, x1, x2 | (x0*x1*x2)^2, x0^3 >
-            To:   Alternating group of order 3!/2 as a permutation group
-            Defn: x0 |--> ()
-                  x1 |--> (1,2,3)
-                  x2 |--> (1,3,2), Generic morphism:
-            From: Finitely presented group < x0, x1, x2 | (x0*x1*x2)^2, x0^3 >
-            To:   Alternating group of order 3!/2 as a permutation group
-            Defn: x0 |--> (1,2,3)
-                  x1 |--> ()
-                  x2 |--> (1,3,2), Generic morphism:
-            From: Finitely presented group < x0, x1, x2 | (x0*x1*x2)^2, x0^3 >
-            To:   Alternating group of order 3!/2 as a permutation group
-            Defn: x0 |--> (1,2,3)
-                  x1 |--> (1,2,3)
-                  x2 |--> (1,2,3), Generic morphism:
-            From: Finitely presented group < x0, x1, x2 | (x0*x1*x2)^2, x0^3 >
-            To:   Alternating group of order 3!/2 as a permutation group
-            Defn: x0 |--> (1,2,3)
-                  x1 |--> (1,3,2)
-                  x2 |--> ()]
-        
+               From: Finitely presented group < x0, x1, x2 | (x0*x1*x2)^2, x0^3 >
+               To:   Alternating group of order 3!/2 as a permutation group
+               Defn: x0 |--> ()
+                     x1 |--> (1,3,2)
+                     x2 |--> (1,2,3), Generic morphism:
+               From: Finitely presented group < x0, x1, x2 | (x0*x1*x2)^2, x0^3 >
+               To:   Alternating group of order 3!/2 as a permutation group
+               Defn: x0 |--> (1,3,2)
+                     x1 |--> ()
+                     x2 |--> (1,2,3), Generic morphism:
+               From: Finitely presented group < x0, x1, x2 | (x0*x1*x2)^2, x0^3 >
+               To:   Alternating group of order 3!/2 as a permutation group
+               Defn: x0 |--> (1,3,2)
+                     x1 |--> (1,2,3)
+                     x2 |--> (), Generic morphism:
+               From: Finitely presented group < x0, x1, x2 | (x0*x1*x2)^2, x0^3 >
+               To:   Alternating group of order 3!/2 as a permutation group
+               Defn: x0 |--> (1,2,3)
+                     x1 |--> (1,2,3)
+                     x2 |--> (1,2,3)]
+
         ALGORITHM:
         
         Uses libgap's GQuotients function.
