@@ -14,6 +14,8 @@ EXAMPLES::
 AUTHORS:
 
 - Simon Brandhorst (2018-02-08): initial version
+- Sebastian Oehms  (2018-11-15): have this functionality work for permutation groups (:trac:`26750`)
+  and implement :meth:`section` and :meth:`natural_map`
 """
 
 # ****************************************************************************
@@ -27,26 +29,26 @@ AUTHORS:
 # ****************************************************************************
 
 from sage.categories.homset import HomsetWithBase
-from sage.categories.groups import Groups
 from sage.categories.morphism import Morphism
 from sage.rings.integer_ring import ZZ
 from sage.groups.libgap_wrapper import ParentLibGAP
+from sage.libs.gap.element import GapElement
 from sage.misc.latex import latex
 
+
 class GroupMorphism_libgap(Morphism):
     r"""
-    Group morphism specified by the images of generators.
+    This wraps libGAP group homomorphisms.
 
-    This wraps GAP's ``GroupHomomorphismByImages`` function.
     Checking if the input defines a group homomorphism can be expensive
     if the group is large.
 
     INPUT:
 
     - ``homset`` -- the parent
-    - ``imgs`` -- a tuple of generators
-    - ``check`` -- (default: ``True``) check if the images define
-      a group homomorphism
+    - ``gap_hom`` -- a :class:`sage.libs.gap.element.GapElement` consisting of a group homomorphism
+    - ``check`` -- (default: ``True``) check if the ``gap_hom`` is a group
+      homomorphism; this can be expensive
 
     EXAMPLES::
 
@@ -74,6 +76,16 @@ class GroupMorphism_libgap(Morphism):
           From: Free Group on generators {a, b}
           To:   Finitely presented group < a, b | a, b^3 >
 
+    Homomorphisms can be defined between libGAP groups and permutation groups::
+
+        sage: S = Sp(4,3)
+        sage: P = PSp(4,3)
+        sage: pr = S.hom(P.gens())
+        sage: E = copy(S.one().matrix())
+        sage: E[3,0] = 2; e = S(E)
+        sage: pr(e)
+        (1,16,15)(3,22,18)(4,19,21)(6,34,24)(7,25,33)(9,40,27)(10,28,39)(12,37,30)(13,31,36)
+
     TESTS:
 
     Old tests inherited from MatrixGroupMorphisms::
@@ -235,39 +247,33 @@ class GroupMorphism_libgap(Morphism):
          over Finite Field of size 2
          to General Linear Group of degree 3 over Integer Ring in Category of groups
     """
-    def __init__(self, homset, imgs, check=True):
+    def __init__(self, homset, gap_hom, check=True):
         r"""
         Constructor method.
 
-        TESTS:
+        TESTS::
 
-        The following input does not define a valid group homomorphism::
-
-            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
-            sage: A = AbelianGroupGap([2])
-            sage: G = MatrixGroup([Matrix(ZZ, 2, [0,1,-1,0])])
-            sage: A.hom([G.gen(0)])
-            Traceback (most recent call last):
-            ...
-            ValueError: images do not define a group homomorphism
+            sage: G = GL(2, ZZ)
+            sage: H = GL(2, GF(2))
+            sage: P = Hom(G, H)
+            sage: gen1 = [g.gap() for g in G.gens()]
+            sage: gen2 = [H(g).gap() for g in G.gens()]
+            sage: phi = G.gap().GroupHomomorphismByImagesNC(H,gen1, gen2)
+            sage: phi = P.element_class(P,phi)
+            sage: phi(G.gen(0))
+            [0 1]
+            [1 0]
         """
-        from sage.libs.gap.libgap import libgap
-        Morphism.__init__(self, homset)
-        dom = homset.domain()
-        codom = homset.codomain()
-        gens = [x.gap() for x in dom.gens()]
-        imgs = [codom(x).gap() for x in imgs]
         if check:
-            if not len(gens) == len(imgs):
-                raise ValueError("provide an image for each generator")
-            self._phi = libgap.GroupHomomorphismByImages(dom.gap(), codom.gap(), gens, imgs)
-            # if it is not a group homomorphism, then
-            # self._phi is the gap boolean fail
-            if self._phi.is_bool():     # check we did not fail
-                raise ValueError("images do not define a group homomorphism")
-        else:
-            ByImagesNC = libgap.function_factory("GroupHomomorphismByImagesNC")
-            self._phi = ByImagesNC(dom.gap(), codom.gap(), gens, imgs)
+            if not gap_hom.IsGroupHomomorphism():
+                raise ValueError("not a group homomorphism")
+            if homset.domain().gap() != gap_hom.Source():
+                raise ValueError("domains do not agree")
+            if homset.codomain().gap() != gap_hom.Range():
+                raise ValueError("ranges do not agree")
+        Morphism.__init__(self, homset)
+        self._phi = gap_hom
+
 
     def __reduce__(self):
         r"""
@@ -342,6 +348,18 @@ class GroupMorphism_libgap(Morphism):
              generated by (f1*f2, f3*f4)
             sage: f.kernel().order()
             4
+            sage: S = Sp(6,3)
+            sage: P = PSp(6,3)
+            sage: pr = Hom(S, P).natural_map()
+            sage: pr.kernel()
+            Matrix group over Finite Field of size 3 with 1 generators (
+            [2 0 0 0 0 0]
+            [0 2 0 0 0 0]
+            [0 0 2 0 0 0]
+            [0 0 0 2 0 0]
+            [0 0 0 0 2 0]
+            [0 0 0 0 0 2]
+            )
         """
         dom = self.domain()
         return dom._subgroup_constructor(self.gap().Kernel())
@@ -377,14 +395,23 @@ class GroupMorphism_libgap(Morphism):
             a
             sage: x.parent()
             Finitely presented group < a, b | a, b^3 >
+            sage: G = GU(3,2)
+            sage: P = PGU(3,2)
+            sage: pr = Hom(G, P).natural_map()
+            sage: GS = G.subgroup([G.gen(0)])
+            sage: pr.pushforward(GS)
+            Subgroup of (The projective general unitary group of degree 3
+             over Finite Field of size 2) generated by
+             [(3,4,5)(10,18,14)(11,19,15)(12,20,16)(13,21,17)]
         """
         dom = self.domain()
         codom = self.codomain()
         phi = self.gap()
         if isinstance(J, dom.Element) and J in dom:
             return self._call_(dom(J))
-        if not isinstance(J, ParentLibGAP):
-            raise TypeError("J (={}) must be a libgap group".format(J))
+        from sage.groups.perm_gps.permgroup import PermutationGroup_generic
+        if not isinstance(J, (ParentLibGAP, PermutationGroup_generic)):
+            raise TypeError("J (={}) must be a libgap or permutation group".format(J))
         if dom.gap().IsSubgroup(J.gap()).sage():
             return codom._subgroup_constructor(phi.Image(J.gap()))
 
@@ -452,7 +479,8 @@ class GroupMorphism_libgap(Morphism):
         [1 0 0 0 0 0], [-1  0  0  0  0  0]
         )
         """
-        return self.codomain()( self.gap().Image(g.gap()) )
+        img_gap = self.gap().Image(g.gap())
+        return self.codomain()(img_gap)
 
     def lift(self, h):
         r"""
@@ -500,15 +528,55 @@ class GroupMorphism_libgap(Morphism):
             sage: S = B.subgroup([B.one()])
             sage: f.preimage(S) == f.kernel()
             True
+            sage: S = Sp(4,3)
+            sage: P = PSp(4,3)
+            sage: pr = Hom(S, P).natural_map()
+            sage: PS = P.subgroup([P.gen(0)])
+            sage: pr.preimage(PS)
+            Matrix group over Finite Field of size 3 with 2 generators (
+            [2 0 0 0]  [1 0 0 0]
+            [0 2 0 0]  [0 2 0 0]
+            [0 0 2 0]  [0 0 2 0]
+            [0 0 0 2], [0 0 0 1]
+            )
         """
         phi = self.gap()
-        if not isinstance(S, ParentLibGAP):
-            raise TypeError("%s must be a libGAP group of %s"%(S, self))
+        from sage.groups.perm_gps.permgroup import PermutationGroup_generic
+        if not isinstance(S, (ParentLibGAP, PermutationGroup_generic)):
+            raise TypeError("%s must be a libGAP or permutation group of %s"%(S, self))
         if not self.codomain().gap().IsSubgroup(S.gap()).sage():
             raise ValueError("%s must be a subgroup of %s"%(S, self))
         preimage = phi.PreImage(S.gap())
         return self.domain()._subgroup_constructor(preimage)
 
+
+    def section(self):
+        r"""
+        This method returns a section map of self by use of :meth:`lift`.
+        See :meth:`section` of :class:`sage.categories.map.Map`, as well.
+
+        OUTPUT:
+
+        an instance of :class:`sage.categories.morphism.SetMorphism`
+        mapping an element of the codomain of self to one of its preimages
+
+        EXAMPLES::
+
+            sage: G = GU(3,2)
+            sage: P = PGU(3,2)
+            sage: pr = Hom(G, P).natural_map()
+            sage: sect = pr.section()
+            sage: sect(P.an_element())
+            [a + 1     a     a]
+            [    1     1     0]
+            [    a     0     0]
+        """
+        from sage.categories.homset import Hom
+        from sage.categories.sets_cat import Sets
+        H = Hom(self.codomain(), self.domain(), category=Sets())
+        return H(lambda x: self.lift(x))
+
+
 class GroupHomset_libgap(HomsetWithBase):
     r"""
     Homsets of groups with a libgap backend.
@@ -547,14 +615,16 @@ class GroupHomset_libgap(HomsetWithBase):
             sage: TestSuite(H).run()
         """
         if check:
-            if not isinstance(G, ParentLibGAP):
-                raise TypeError("G (={}) must be a ParentLibGAP group".format(G))
-            if not isinstance(H, ParentLibGAP):
-                raise TypeError("H (={}) must be a ParentLibGAP group".format(H))
+            from sage.groups.perm_gps.permgroup import PermutationGroup_generic
+            if not isinstance(G, (ParentLibGAP, PermutationGroup_generic)):
+                raise TypeError("G (={}) must be a ParentLibGAP or a permutation group".format(G))
+            if not isinstance(H, (ParentLibGAP, PermutationGroup_generic)):
+                raise TypeError("H (={}) must be a ParentLibGAP or a permutation group".format(H))
         HomsetWithBase.__init__(self, G, H, category, check=check, base=ZZ)
 
     Element = GroupMorphism_libgap
 
+
     def _element_constructor_(self, x, check=True, **options):
         r"""
         Handle conversions and coercions.
@@ -570,11 +640,59 @@ class GroupHomset_libgap(HomsetWithBase):
             Traceback (most recent call last):
             ...
             TypeError: unable to convert 2 to an element of ...
+
+        A group homomorphism between a finitely presented group and a subgroup of a permutation group::
+
+            sage: PG = PGU(6,2)
+            sage: g, h = PG.gens()
+            sage: p1 = h^-3*(h^-1*g^-1)^2*h*g*h^2*g^-1*h^2*g*h^-5*g^-1
+            sage: p2 = g*(g*h)^2*g*h^-4*(g*h)^2*(h^2*g*h^-2*g)^2*h^-2*g*h^-2*g^-1*h^-1*g*h*g*h^-1*g
+            sage: p3 = h^-3*g^-1*h*g*h^4*g^-1*h^-1*g*h*(h^2*g^-1)^2*h^-4*g*h^2*g^-1*h^-7*g^-2*h^-2*g*h^-2*g^-1*h^-1*(g*h)^2*h^3
+            sage: p4 = h*(h^3*g)^2*h*g*h^-1*g*h^2*g^-1*h^-2*g*h^4*g^-1*h^3*g*h^-2*g*h^-1*g^-1*h^2*g*h*g^-1*h^-2*g*h*g^-1*h^2*g*h^2*g^-1
+            sage: p5 = h^2*g*h^2*g^-1*h*g*h^-1*g*h*g^-1*h^2*g*h^-2*g*h^2*g*h^-2*(h^-1*g)^2*h^4*(g*h^-1)^2*g^-1
+            sage: UPG = PG.subgroup([p1, p2, p3, p4, p5], canonicalize=False)
+            sage: B6 = BraidGroup(6)
+            sage: reprB6 = B6.hom(UPG.gens())
+            sage: b1, b2, b3, b4, b5 = B6.gens()
+            sage: reprB6(b1*b2*b3*b4*b5) == p1*p2*p3*p4*p5
+            True
+
+        TESTS:
+
+        The following input does not define a valid group homomorphism::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: A = AbelianGroupGap([2])
+            sage: G = MatrixGroup([Matrix(ZZ, 2, [0,1,-1,0])])
+            sage: A.hom([G.gen(0)])
+            Traceback (most recent call last):
+            ...
+            ValueError: images do not define a group homomorphism
         """
         if isinstance(x, (tuple, list)):
-            codomain = self.codomain()
-            im_gens = tuple([codomain(g) for g in x])
-            return self.element_class(self, im_gens, check=check, **options)
+            # there should be a better way
+            from sage.libs.gap.libgap import libgap
+            dom = self.domain()
+            codom = self.codomain()
+            gens = dom.gap().GeneratorsOfGroup()
+            imgs = [codom(g).gap() for g in x]
+            if check:
+                if not len(gens) == len(imgs):
+                    raise ValueError("provide an image for each generator")
+                phi = libgap.GroupHomomorphismByImages(dom.gap(), codom.gap(), gens, imgs)
+                # if it is not a group homomorphism, then
+                # self._phi is the gap boolean fail
+                if phi.is_bool():     # check we did not fail
+                    raise ValueError("images do not define a group homomorphism")
+            else:
+                ByImagesNC = libgap.function_factory("GroupHomomorphismByImagesNC")
+                phi = ByImagesNC(dom.gap(), codom.gap(), gens, imgs)
+            return self.element_class(self, phi, check=check, **options)
+        if isinstance(x, GapElement):
+            try:
+                return self.element_class(self, x, check=True, **options)
+            except ValueError:
+                pass
         return super(GroupHomset_libgap, self)._element_constructor_(x, check=check, **options)
 
     def _an_element_(self):
@@ -596,5 +714,39 @@ class GroupHomset_libgap(HomsetWithBase):
         """
         n = len(self.domain().gens())
         one = self.codomain().one()
-        return self.element_class(self, (one,) * n, check=False)
+        return self._element_constructor_((one,) * n, check=False)
 
+    def natural_map(self):
+        r"""
+        This method from :class:`HomsetWithBase` is overloaded here for cases in which
+        both groups have corresponding lists of generators.
+
+        OUTPUT:
+
+        an instance of the element class of self if there exists a group homomorphism
+        mapping the generators of the domain of self to the according generators of
+        the codomain. Else the method falls back to the default.
+
+        EXAMPLES::
+
+            sage: G = GL(3,2)
+            sage: P = PGL(3,2)
+            sage: nat = Hom(G, P).natural_map()
+            sage: type(nat)
+            <class 'sage.groups.libgap_morphism.GroupHomset_libgap_with_category.element_class'>
+            sage: g1, g2 = G.gens()
+            sage: nat(g1*g2)
+            (1,2,4,5,7,3,6)
+        """
+        if len(self.domain().gens()) == len(self.codomain().gens()):
+            dom_gap = self.domain().gap()
+            codom_gap = self.codomain().gap()
+            from sage.libs.gap.libgap import libgap
+            phi = libgap.GroupHomomorphismByImages(dom_gap,
+                                                   codom_gap,
+                                                   dom_gap.GeneratorsOfGroup(),
+                                                   codom_gap.GeneratorsOfGroup()
+                                                   )
+            if not phi.is_bool():     # phi is indeed a group homomorphism
+                return self.element_class(self, phi)
+        return super(GroupHomset_libgap, self).natural_map()
