@@ -58,38 +58,29 @@ AUTHORS:
 #
 #  The full text of the GPL is available at:
 #
-#                  http://www.gnu.org/licenses/
+#                  https://www.gnu.org/licenses/
 ##############################################################################
 from __future__ import print_function
 
-from sage.groups.group import Group
 from sage.rings.all import ZZ
 from sage.rings.all import QQbar
-from sage.rings.integer import is_Integer
-from sage.rings.ring import is_Ring
-from sage.rings.finite_rings.finite_field_constructor import is_FiniteField
 from sage.interfaces.gap import gap
 from sage.structure.element import is_Matrix
 from sage.matrix.matrix_space import MatrixSpace, is_MatrixSpace
 from sage.matrix.all import matrix
-from sage.misc.latex import latex
 from sage.structure.sequence import Sequence
 from sage.misc.cachefunc import cached_method
 from sage.modules.free_module_element import vector
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.power_series_ring import PowerSeriesRing
-from sage.arith.all import gcd
 from sage.rings.fraction_field import FractionField
 from sage.misc.functional import cyclotomic_polynomial
 from sage.rings.number_field.number_field import CyclotomicField
 from sage.combinat.integer_vector import IntegerVectors
 
 from sage.groups.matrix_gps.matrix_group import (
-    is_MatrixGroup, MatrixGroup_generic, MatrixGroup_gap )
-from sage.groups.matrix_gps.group_element import (
-    is_MatrixGroupElement, MatrixGroupElement_generic, MatrixGroupElement_gap)
-
-
+    MatrixGroup_generic, MatrixGroup_gap )
+from sage.groups.matrix_gps.group_element import is_MatrixGroupElement
 
 
 def normalize_square_matrices(matrices):
@@ -151,6 +142,7 @@ def normalize_square_matrices(matrices):
         raise ValueError('matrices must be square')
     return gens
 
+
 def QuaternionMatrixGroupGF3():
     r"""
     The quaternion group as a set of `2\times 2` matrices over `GF(3)`.
@@ -544,20 +536,18 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
         smallest one.
 
         EXAMPLES::
-        
+
             sage: MS = MatrixSpace(GF(2), 5, 5)
             sage: A = MS([[0,0,0,0,1],[0,0,0,1,0],[0,0,1,0,0],[0,1,0,0,0],[1,0,0,0,0]])
             sage: G = MatrixGroup([A])
             sage: G.as_permutation_group()
             Permutation Group with generators [(1,2)]
-            sage: MS = MatrixSpace( GF(7), 12, 12)
-            sage: GG = gap("ImfMatrixGroup( 12, 3 )")
-            sage: GG.GeneratorsOfGroup().Length()
-            3
-            sage: g1 = MS(eval(str(GG.GeneratorsOfGroup()[1]).replace("\n","")))
-            sage: g2 = MS(eval(str(GG.GeneratorsOfGroup()[2]).replace("\n","")))
-            sage: g3 = MS(eval(str(GG.GeneratorsOfGroup()[3]).replace("\n","")))
-            sage: G = MatrixGroup([g1, g2, g3])
+
+        A finite subgroup of  GL(12,Z) as a permutation group::
+
+            sage: imf=libgap.function_factory('ImfMatrixGroup')
+            sage: GG = imf( 12, 3 )
+            sage: G = MatrixGroup(GG.GeneratorsOfGroup())
             sage: G.cardinality()
             21499084800
             sage: set_random_seed(0); current_randstate().set_seed_gap()
@@ -588,13 +578,28 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
             sage: a.order(), b.order()
             (2, 1)
 
+        The above example in GL(12,Z), reduced modulo 7::
+
+            sage: MS = MatrixSpace( GF(7), 12, 12)
+            sage: G = MatrixGroup(map(MS, GG.GeneratorsOfGroup()))
+            sage: G.cardinality()
+            21499084800
+            sage: P = G.as_permutation_group()
+            sage: P.cardinality()
+            21499084800
+
+        Check that large degree is still working::
+
+            sage: Sp(6,3).as_permutation_group().cardinality()
+            9170703360
+
         Check that ``_permutation_group_morphism`` works (:trac:`25706`)::
 
             sage: MG = GU(3,2).as_matrix_group()
             sage: PG = MG.as_permutation_group()  # this constructs the morphism
             sage: mg = MG.an_element()
             sage: MG._permutation_group_morphism(mg)
-            (1,2,6,19,35,33)(3,9,26,14,31,23)(4,13,5)(7,22,17)(8,24,12)(10,16,32,27,20,28)(11,30,18)(15,25,36,34,29,21)
+            (1,2,6,19,35,33)(3,9,26,14,31,23)(4,13,5)(7,22,17)(8,24,12)(10,16,32,27,20,28)(11,30,18)(15,25,36,34,29,21) 
         """
         # Note that the output of IsomorphismPermGroup() depends on
         # memory locations and will change if you change the order of
@@ -602,25 +607,14 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
         from sage.groups.perm_gps.permgroup import PermutationGroup
         if not self.is_finite():
             raise NotImplementedError("Group must be finite.")
-        n = self.degree()
-        MS = MatrixSpace(self.base_ring(), n, n)
-        mats = [] # initializing list of mats by which the gens act on self
-        for g in self.gens():
-            p = MS(g.matrix())
-            m = p.rows()
-            mats.append(m)
-        mats_str = str(gap([[list(r) for r in m] for m in mats]))
-        gap.eval("iso:=IsomorphismPermGroup(Group("+mats_str+"))")
-        gap_permutation_map = gap("iso;")
+        iso=self._libgap_().IsomorphismPermGroup()
         if algorithm == "smaller":
-            gap.eval("small:= SmallerDegreePermutationRepresentation( Image( iso ) );")
-            C = gap("Image( small )")
-        else:
-            C = gap("Image( iso )")
-        PG = PermutationGroup(gap_group=C, canonicalize=False)
+            iso=iso.Image().SmallerDegreePermutationRepresentation()
+        PG = PermutationGroup(iso.Image().GeneratorsOfGroup().sage(), \
+                       canonicalize=False) # applying gap() - as PermutationGroup is not libGAP
 
         def permutation_group_map(element):
-            return PG(gap_permutation_map.ImageElm(element.gap()))
+            return PG(iso.ImageElm(element.gap()).sage()) 
 
         from sage.categories.homset import Hom
         self._permutation_group_morphism = Hom(self, PG)(permutation_group_map)
@@ -667,7 +661,6 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
         n = self.degree()
         MS = MatrixSpace(F,n,n)
         mats = [] # initializing list of mats by which the gens act on self
-        W = self.matrix_space().row_space()
         for g in gens:
             p = MS(g.matrix())
             m = p.rows()
@@ -712,8 +705,8 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
             sage: gens = [MS([[0,1],[-1,0]]),MS([[1,1],[2,3]])]
             sage: G = MatrixGroup(gens)
             sage: G.invariant_generators()
-            [x1^7*x2 - x1*x2^7, 
-             x1^12 - 2*x1^9*x2^3 - x1^6*x2^6 + 2*x1^3*x2^9 + x2^12, 
+            [x1^7*x2 - x1*x2^7,
+             x1^12 - 2*x1^9*x2^3 - x1^6*x2^6 + 2*x1^3*x2^9 + x2^12,
              x1^18 + 2*x1^15*x2^3 + 3*x1^12*x2^6 + 3*x1^6*x2^12 - 2*x1^3*x2^15 + x2^18]
 
             sage: q = 4; a = 2
@@ -775,7 +768,7 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
         else:
             VarStr = 'x'
         VarNames='('+','.join((VarStr+str(i+1) for i in range(n)))+')'
-        R=singular.ring(FieldStr,VarNames,'dp')
+        R=singular.ring(FieldStr,VarNames,'dp') # this does have a side-effect
         if hasattr(F,'polynomial') and F.gen()!=1: # we have to define minpoly
             singular.eval('minpoly = '+str(F.polynomial()).replace('x',str(F.gen())))
         A = [singular.matrix(n,n,str((x.matrix()).list())) for x in gens]
@@ -783,7 +776,7 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
         PR = PolynomialRing(F,n,[VarStr+str(i) for i in range(1,n+1)])
 
         if q == 0 or (q > 0 and self.cardinality()%q != 0):
-            from sage.all import Integer, Matrix
+            from sage.all import Matrix
             try:
                 elements = [ g.matrix() for g in self.list() ]
             except (TypeError,ValueError):
@@ -800,7 +793,6 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
                         for t in D[row].items():
                             singular.eval('%s[%d,%d]=%s[%d,%d]+(%s)*var(%d)'
                                           %(ReyName,i,row+1,ReyName,i,row+1, repr(t[1]),t[0]+1))
-                foobar = singular(ReyName)
                 IRName = 't'+singular._next_var_name()
                 singular.eval('matrix %s = invariant_algebra_reynolds(%s)'%(IRName,ReyName))
             else:
@@ -810,11 +802,11 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
                 singular.eval('matrix %s = invariant_algebra_reynolds(%s[1])'%(IRName,ReyName))
 
             OUT = [singular.eval(IRName+'[1,%d]'%(j))
-                   for j in range(1,1+singular('ncols('+IRName+')'))]
+                   for j in range(1, 1+int(singular('ncols('+IRName+')')))]
             return [PR(gen) for gen in OUT]
-        if self.cardinality()%q == 0:
-            PName = 't'+singular._next_var_name()
-            SName = 't'+singular._next_var_name()
+        if self.cardinality() % q == 0:
+            PName = 't' + singular._next_var_name()
+            SName = 't' + singular._next_var_name()
             singular.eval('matrix %s,%s=invariant_ring(%s)'%(PName,SName,Lgens))
             OUT = [
                 singular.eval(PName+'[1,%d]'%(j))
@@ -1070,10 +1062,10 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
             sage: chi = G.character(G.character_table()[1])
             sage: R.<x,y,z> = K[]
             sage: G.reynolds_operator(x*y^5, chi)
-            1/3*x*y^5 + (-2/3*izeta3^3 - izeta3^2 - 8/3*izeta3 - 4/3)*x^5*z + (2/3*izeta3^3 + izeta3^2 + 8/3*izeta3 + 1)*y*z^5
+            1/3*x*y^5 + (2/3*izeta3^3 + izeta3^2 + 8/3*izeta3 + 1)*x^5*z + (-2/3*izeta3^3 - izeta3^2 - 8/3*izeta3 - 4/3)*y*z^5
             sage: R.<x,y,z> = QQbar[]
             sage: G.reynolds_operator(x*y^5, chi)
-            1/3*x*y^5 + (-0.1666666666666667? + 0.2886751345948129?*I)*x^5*z + (-0.1666666666666667? - 0.2886751345948129?*I)*y*z^5
+             1/3*x*y^5 + (-0.1666666666666667? - 0.2886751345948129?*I)*x^5*z + (-0.1666666666666667? + 0.2886751345948129?*I)*y*z^5
 
         ::
 
@@ -1250,11 +1242,11 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
         EXAMPLES::
 
             sage: Gr = MatrixGroup(SymmetricGroup(2))
-            sage: Gr.invariants_of_degree(3)
-            [x0^3 + x1^3, x0^2*x1 + x0*x1^2]
+            sage: sorted(Gr.invariants_of_degree(3))
+            [x0^2*x1 + x0*x1^2, x0^3 + x1^3]
             sage: R.<x,y> = QQ[]
-            sage: Gr.invariants_of_degree(4, R=R)
-            [x^3*y + x*y^3, x^2*y^2, x^4 + y^4]
+            sage: sorted(Gr.invariants_of_degree(4, R=R))
+            [x^2*y^2, x^3*y + x*y^3, x^4 + y^4]
 
         ::
 
@@ -1262,9 +1254,9 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
             sage: Gr = MatrixGroup(DihedralGroup(3))
             sage: ct = Gr.character_table()
             sage: chi = Gr.character(ct[0])
-            sage: [f(*(g.matrix()*vector(R.gens()))) == chi(g)*f \
-                  for f in Gr.invariants_of_degree(3, R=R, chi=chi) for g in Gr]
-            [True, True, True, True, True, True]
+            sage: all(f(*(g.matrix()*vector(R.gens()))) == chi(g)*f
+            ....: for f in Gr.invariants_of_degree(3, R=R, chi=chi) for g in Gr)
+            True
 
         ::
 
@@ -1288,17 +1280,17 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
             sage: G =  MatrixGroup(CyclicPermutationGroup(3))
             sage: chi = G.character(G.character_table()[1])
             sage: R.<x,y,z> = K[]
-            sage: G.invariants_of_degree(2, R=R, chi=chi)
-            [x^2 + (2*izeta3^3 + 3*izeta3^2 + 8*izeta3 + 3)*y^2 + (-2*izeta3^3 - 3*izeta3^2 - 8*izeta3 - 4)*z^2,
-             x*y + (-2*izeta3^3 - 3*izeta3^2 - 8*izeta3 - 4)*x*z + (2*izeta3^3 + 3*izeta3^2 + 8*izeta3 + 3)*y*z]
+            sage: sorted(G.invariants_of_degree(2, R=R, chi=chi))
+            [x*y + (2*izeta3^3 + 3*izeta3^2 + 8*izeta3 + 3)*x*z + (-2*izeta3^3 - 3*izeta3^2 - 8*izeta3 - 4)*y*z,
+             x^2 + (-2*izeta3^3 - 3*izeta3^2 - 8*izeta3 - 4)*y^2 + (2*izeta3^3 + 3*izeta3^2 + 8*izeta3 + 3)*z^2]
 
         ::
 
             sage: S3 = MatrixGroup(SymmetricGroup(3))
             sage: chi = S3.character(S3.character_table()[0])
-            sage: S3.invariants_of_degree(5, chi=chi)
-            [x0^4*x1 - x0*x1^4 - x0^4*x2 + x1^4*x2 + x0*x2^4 - x1*x2^4,
-             x0^3*x1^2 - x0^2*x1^3 - x0^3*x2^2 + x1^3*x2^2 + x0^2*x2^3 - x1^2*x2^3]
+            sage: sorted(S3.invariants_of_degree(5, chi=chi))
+            [x0^3*x1^2 - x0^2*x1^3 - x0^3*x2^2 + x1^3*x2^2 + x0^2*x2^3 - x1^2*x2^3,
+            x0^4*x1 - x0*x1^4 - x0^4*x2 + x1^4*x2 + x0*x2^4 - x1*x2^4]
         """
         D = self.degree()
         deg = int(deg)
@@ -1316,7 +1308,7 @@ class FinitelyGeneratedMatrixGroup_gap(MatrixGroup_gap):
         for e in IntegerVectors(deg, D):
             F = self.reynolds_operator(R.monomial(*e), chi=chi)
             if not F.is_zero():
-                F = F/F.lc()
+                F = F / F.lc()
                 inv.add(F)
                 if len(inv) == ms[deg]:
                     break
