@@ -265,6 +265,7 @@ class GroupOfIsometries(FinitelyGeneratedMatrixGroup_gap):
             raise TypeError('matrix must be orthogonal '
                 'with respect to the invariant form')
 
+
 class GroupActionOnSubmodule(Action):
     r"""
     Matrix group action on a submodule from the right.
@@ -312,18 +313,17 @@ class GroupActionOnSubmodule(Action):
         import operator
         Action.__init__(self, MatrixGroup, submodule, is_left, operator.mul)
 
-    def _call_(self, a, g):
+    def _act_(self, g, a):
         r"""
         This defines the group action.
 
         INPUT:
 
-        - ``a`` -- an element of the invariant submodule
         - ``g`` -- an element of the acting group
 
-        OUTPUT:
+        - ``a`` -- an element of the invariant submodule
 
-        - an element of the invariant submodule
+        OUTPUT: an element of the invariant submodule
 
         EXAMPLES::
 
@@ -347,9 +347,11 @@ class GroupActionOnSubmodule(Action):
             [0 1]
         """
         if self.is_left():
-            return a.parent()(g.matrix()*a)
+            b = g.matrix() * a
         else:
-            return a.parent()(a*g.matrix())
+            b = a * g.matrix()
+        return a.parent()(b)
+
 
 class GroupActionOnQuotientModule(Action):
     r"""
@@ -395,15 +397,16 @@ class GroupActionOnQuotientModule(Action):
         import operator
         Action.__init__(self, MatrixGroup, quotient_module, is_left, operator.mul)
 
-    def _call_(self, a, g):
+    def _act_(self, g, a):
         r"""
         This defines the group action.
 
         INPUT:
 
-        - ``a`` -- an element of the invariant submodule
         - ``g`` -- an element of the acting group
 
+        - ``a`` -- an element of the invariant submodule
+
         OUTPUT:
 
         - an element of the invariant quotient module
@@ -427,6 +430,7 @@ class GroupActionOnQuotientModule(Action):
             Finitely generated module V/W over Integer Ring with invariants (6)
         """
         if self.is_left():
-            return a.parent()(g.matrix()*a.lift())
+            b = g.matrix() * a.lift()
         else:
-            return a.parent()(a.lift()*g.matrix())
+            b = a.lift() * g.matrix()
+        return a.parent()(b)
