@@ -63,6 +63,7 @@ from sage.misc.latex import latex
 from sage.groups.matrix_gps.named_group import (
     normalize_args_vectorspace, NamedMatrixGroup_generic, NamedMatrixGroup_gap )
 from sage.categories.groups import Groups
+from sage.groups.matrix_gps.finitely_generated import FinitelyGeneratedMatrixGroup_gap
 
 
 ###############################################################################
@@ -70,7 +71,7 @@ from sage.categories.groups import Groups
 ###############################################################################
 
 def GL(n, R, var='a'):
-    """
+    r"""
     Return the general linear group.
 
     The general linear group `GL( d, R )` consists of all `d \times d`
@@ -240,7 +241,6 @@ def SL(n, R, var='a'):
         cat = Groups()
     name = 'Special Linear Group of degree {0} over {1}'.format(degree, ring)
     ltx  = 'SL({0}, {1})'.format(degree, latex(ring))
-    from sage.libs.gap.libgap import libgap
     try:
         cmd  = 'SL({0}, {1})'.format(degree, ring._gap_init_())
         return LinearMatrixGroup_gap(degree, ring, True, name, ltx, cmd,
@@ -277,5 +277,17 @@ class LinearMatrixGroup_generic(NamedMatrixGroup_generic):
                 raise TypeError('matrix must non-zero determinant')
 
 
-class LinearMatrixGroup_gap(NamedMatrixGroup_gap, LinearMatrixGroup_generic):
+class LinearMatrixGroup_gap(NamedMatrixGroup_gap, LinearMatrixGroup_generic, FinitelyGeneratedMatrixGroup_gap):
+    r"""
+    The general or special linear group in GAP.
+
+    TESTS:
+
+    Check that :trac:`20867` is fixed::
+
+        sage: from sage.groups.matrix_gps.finitely_generated import FinitelyGeneratedMatrixGroup_gap
+        sage: G = GL(3,3)
+        sage: isinstance(G, FinitelyGeneratedMatrixGroup_gap)
+        True
+    """
     pass
