@@ -37,15 +37,15 @@ AUTHORS:
   for the construction of the Reynolds operator in Singular.
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2006 David Joyner and William Stein <wstein@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 from __future__ import absolute_import
 
@@ -525,7 +525,7 @@ class MatrixGroup_gap(GroupMixinLibGAP, MatrixGroup_generic, ParentLibGAP):
 
             sage: import itertools
             sage: W = WeylGroup(["A",3,1])
-            sage: list(itertools.islice(W, 4))
+            sage: list(itertools.islice(W, int(4)))
             [
             [1 0 0 0]  [-1  1  0  1]  [ 1  0  0  0]  [ 1  0  0  0]
             [0 1 0 0]  [ 0  1  0  0]  [ 1 -1  1  0]  [ 0  1  0  0]
@@ -535,8 +535,8 @@ class MatrixGroup_gap(GroupMixinLibGAP, MatrixGroup_generic, ParentLibGAP):
 
         and finite groups, too::
 
-            sage: G=GL(6,5)
-            sage: list(itertools.islice(G,4))
+            sage: G = GL(6,5)
+            sage: list(itertools.islice(G, int(4)))
             [
             [1 0 0 0 0 0]  [4 0 0 0 0 1]  [0 4 0 0 0 0]  [0 4 0 0 0 0]
             [0 1 0 0 0 0]  [4 0 0 0 0 0]  [0 0 4 0 0 0]  [0 0 4 0 0 0]
