@@ -111,9 +111,9 @@ class HomologyVectorSpaceWithBasis(CombinatorialFreeModule):
         sage: H = Klein_c.cohomology_ring(GF(2))
         sage: x,y = H.basis(1)
         sage: x.cup_product(x)
-        h^{2,0}
-        sage: x.cup_product(y)
         0
+        sage: x.cup_product(y)
+        h^{2,0}
         sage: y.cup_product(y)
         h^{2,0}
 
@@ -127,6 +127,10 @@ class HomologyVectorSpaceWithBasis(CombinatorialFreeModule):
         sage: v.cup_product(v)
         h^{2,0}
 
+    An isomorphism between the rings for the cubical model and the
+    `\Delta`-complex model can be obtained by sending `x` to `u+v`,
+    `y` to `v`. ::
+
         sage: X = simplicial_sets.RealProjectiveSpace(6)
         sage: H_X = X.cohomology_ring(GF(2))
         sage: a = H_X.basis()[1,0]
@@ -333,7 +337,7 @@ class HomologyVectorSpaceWithBasis(CombinatorialFreeModule):
 
     @cached_method
     def _to_cycle_on_basis(self, i):
-        """
+        r"""
         Return the (co)cycle representative of the basis element
         indexed by ``i``.
 
@@ -548,7 +552,7 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
             sage: T = cubical_complexes.Torus()
             sage: x,y = T.cohomology_ring(QQ).basis(1)
             sage: x.cup_product(y)
-            -h^{2,0}
+            h^{2,0}
             sage: x.cup_product(x)
             0
 
