@@ -1,3 +1,4 @@
+# -*- coding: UTF-8 -*-
 r"""
 Interface to GAP
 
@@ -187,6 +188,7 @@ from sage.misc.cachefunc import cached_method
 from sage.docs.instancedoc import instancedoc
 from sage.interfaces.tab_completion import ExtraTabCompletion
 from sage.structure.element import ModuleElement
+
 import re
 import os
 import io
@@ -194,12 +196,10 @@ import pexpect
 import time
 import platform
 import string
+import warnings
 
 WORKSPACE = gap_workspace_file()
 
-from sage.env import GAP_ROOT_DIR
-GAP_BINARY = os.path.join(GAP_ROOT_DIR, 'bin', 'gap.sh')
-
 first_try = True
 
 gap_cmd = "gap -r"
@@ -511,14 +511,14 @@ class Gap_generic(ExtraTabCompletion, Expect):
             sage: gap.load_package("chevie")
             Traceback (most recent call last):
             ...
-            RuntimeError: Error loading Gap package chevie. You may want to install the gap_packages and/or database_gap SPKGs.
+            RuntimeError: Error loading Gap package chevie. You may want to install gap_packages SPKG.
         """
         if verbose:
-            print("Loading GAP package %s" % pkg)
+            print("Loading GAP package {}" % pkg)
         x = self.eval('LoadPackage("%s")'%pkg)
         if x == 'fail':
             raise RuntimeError("Error loading Gap package "+str(pkg)+". "+
-                               "You may want to install the gap_packages and/or database_gap SPKGs.")
+                               "You may want to install gap_packages SPKG.")
 
     def eval(self, x, newlines=False, strip=True, split_lines=True, **kwds):
         r"""
@@ -610,8 +610,9 @@ class Gap_generic(ExtraTabCompletion, Expect):
                 current_outputs.append(E.before)
                 if x == 0:   # @p
                     if E.after != b'@p1.':
-                        print("Warning: possibly wrong version of GAP package interface\n")
-                        print("Crossing fingers and continuing\n")
+                        warnings.warn(
+                            "possibly wrong version of GAP package "
+                            "interface. Crossing fingers and continuing.")
                 elif x == 1: #@@
                     current_outputs.append(b'@')
                 elif x == 2: #special char
@@ -626,11 +627,11 @@ class Gap_generic(ExtraTabCompletion, Expect):
                 elif x == 4: # @e -- break loop
                     E.sendline("quit;")
                 elif x == 5: # @c completion, doesn't seem to happen when -p is in use
-                    print("I didn't think GAP could do this\n")
+                    warnings.warn("I didn't think GAP could do this")
                 elif x == 6: # @f GAP error message
                     current_outputs = error_outputs;
                 elif x == 7: # @h help text, but this stopped happening with new help
-                    print("I didn't think GAP could do this")
+                    warnings.warn("I didn't think GAP could do this")
                 elif x == 8: # @i awaiting normal input
                     break;
                 elif x == 9: # @m finished running a child
@@ -640,9 +641,9 @@ class Gap_generic(ExtraTabCompletion, Expect):
                 elif x==11: #@r echoing input
                     current_outputs = terminal_echo
                 elif x==12: #@sN shouldn't happen
-                    print("Warning: this should never happen")
+                    warnings.warn("this should never happen")
                 elif x==13: #@w GAP is trying to send a Window command
-                    print("Warning: this should never happen")
+                    warnings.warn("this should never happen")
                 elif x ==14: #@x seems to be safely ignorable
                     pass
                 elif x == 15:#@z GAP starting a subprocess
@@ -908,17 +909,16 @@ class Gap_generic(ExtraTabCompletion, Expect):
 
             sage: g = Gap()
             sage: g.function_call("ConjugacyClassesSubgroups", sage.interfaces.gap.GapElement(g, 'SymmetricGroup(2)', name = 'a_variable_with_a_very_very_very_long_name'))
-            [ ConjugacyClassSubgroups(SymmetricGroup( [ 1 .. 2 ] ),Group( [ () ] )),
-              ConjugacyClassSubgroups(SymmetricGroup( [ 1 .. 2 ] ),SymmetricGroup( [ 1 .. 2 ] )) ]
+            [ ConjugacyClassSubgroups(SymmetricGroup( [ 1 .. 2 ] ),Group( () )),
+              ConjugacyClassSubgroups(SymmetricGroup( [ 1 .. 2 ] ),Group( [ (1,2) ] )) ]
 
         When the command itself is so long that it warrants use of a temporary
         file to be communicated to GAP, this does not cause problems since
         the file will contain a single command::
 
             sage: g.function_call("ConjugacyClassesSubgroups", sage.interfaces.gap.GapElement(g, 'SymmetricGroup(2)', name = 'a_variable_with_a_name_so_very_very_very_long_that_even_by_itself_will_make_expect_use_a_file'))
-            [ ConjugacyClassSubgroups(SymmetricGroup( [ 1 .. 2 ] ),Group( [ () ] )),
-              ConjugacyClassSubgroups(SymmetricGroup( [ 1 .. 2 ] ),SymmetricGroup( [ 1 .. 2 ] )) ]
-
+            [ ConjugacyClassSubgroups(SymmetricGroup( [ 1 .. 2 ] ),Group( () )),
+              ConjugacyClassSubgroups(SymmetricGroup( [ 1 .. 2 ] ),Group( [ (1,2) ] )) ]
         """
         args, kwds = self._convert_args_kwds(args, kwds)
         self._check_valid_function_name(function)
@@ -1120,7 +1120,8 @@ class Gap(Gap_generic):
                  server=None,
                  server_tmpdir=None,
                  logfile=None,
-                 seed=None):
+                 seed=None,
+                 env={}):
         """
         EXAMPLES::
 
@@ -1129,13 +1130,20 @@ class Gap(Gap_generic):
         """
         self.__use_workspace_cache = use_workspace_cache
         cmd, self.__make_workspace = gap_command(use_workspace_cache, server is None)
-        cmd += " -b -p -T"
+        # -b: suppress banner
+        # -p: enable "package output mode"; this confusingly named option
+        #     causes GAP to output special control characters that are normally
+        #     intended for communication with a window manager (i.e. for xgap)
+        #     but that we also use to control GAP with pexepect
+        # -T: disable interactive break loop when encountering errors
+        # -E: disable readline support
+        cmd += " -b -p -T -E"
         if max_workspace_size is None:
             max_workspace_size = _get_gap_memory_pool_size_MB()
         cmd += ' -o ' + str(max_workspace_size)
         cmd += ' -s ' + str(max_workspace_size)
         cmd += ' -m 64m '   # attempt at a workaround for http://tracker.gap-system.org/issues/224
-        cmd += ' ' + os.path.join(SAGE_EXTCODE,'gap','sage.g')
+        cmd += ' ' + os.path.join(SAGE_EXTCODE, 'gap', 'sage.g')
         Expect.__init__(self,
                         name='gap',
                         prompt='gap> ',
@@ -1147,7 +1155,8 @@ class Gap(Gap_generic):
                         restart_on_ctrlc=True,
                         verbose_start=False,
                         logfile=logfile,
-                        eval_using_file_cutoff=100)
+                        eval_using_file_cutoff=100,
+                        env=env)
         self.__seq = 0
         self._seed = seed
 
@@ -1339,15 +1348,19 @@ class Gap(Gap_generic):
         """
         Print help on a given topic.
 
-        EXAMPLES::
+        EXAMPLES:
 
+        Note: In order to ensure consistent unicode handling from GAP we
+        start a GAP instance with a forced UTF-8 locale::
+
+            sage: gap = Gap(env={'LC_CTYPE': 'en_US.UTF-8'})
             sage: print(gap.help('SymmetricGroup', pager=False))
             <BLANKLINE>
-            50 Group Libraries
+              50.1-... SymmetricGroup
             <BLANKLINE>
-            When you start GAP, it already knows several groups. Currently GAP initially
-            knows the following groups:
+              ‣ SymmetricGroup( [filt, ]deg ) ─────────────────────────────────── function
             ...
+            <BLANKLINE>
         """
         tmp_to_use = self._local_tmpfile()
         if self.is_remote():
@@ -1364,6 +1377,7 @@ class Gap(Gap_generic):
             print(line)
         else:
             (sline,) = match.groups()
+            sline = int(sline) - 1
             if self.is_remote():
                 self._get_tmpfile()
             with io.open(self._local_tmpfile(), "r",
@@ -1371,9 +1385,20 @@ class Gap(Gap_generic):
                 help = fobj.read()
                 if pager:
                     from IPython.core.page import page
-                    page(help, start=int(sline) - 1)
+                    page(help, start=sline)
                 else:
-                    return help
+                    # Find the n-th line and return from there
+                    idx = -1
+                    while sline:
+                        try:
+                            idx = help.find('\n', idx + 1)
+                            sline -= 1
+                        except ValueError:
+                            # We ran out of lines early somehow; this shouldn't
+                            # happen though
+                            break
+
+                    return help[idx:]
 
     def set(self, var, value):
         """
@@ -1552,10 +1577,8 @@ def gap_reset_workspace(max_workspace_size=None, verbose=False):
     # Create new workspace with filename WORKSPACE
     g = Gap(use_workspace_cache=False, max_workspace_size=None)
     g.eval('SetUserPreference("HistoryMaxLines", 30)')
-    for pkg in ['GAPDoc', 'ctbllib', 'sonata', 'guava', 'factint', \
-                'gapdoc', 'grape', 'design', \
-                'toric', 'laguna', 'braid', 'polycyclic', 'nq']:
-        # NOTE: Do *not* autoload hap - it screws up PolynomialRing(Rationals,2)
+    from sage.tests.gap_packages import all_installed_packages
+    for pkg in all_installed_packages():
         try:
             g.load_package(pkg, verbose=verbose)
         except RuntimeError as msg:
@@ -1645,12 +1668,12 @@ class GapFunctionElement(FunctionElement):
         """
         EXAMPLES::
 
+            sage: gap = Gap(env={'LC_CTYPE': 'en_US.UTF-8'})
             sage: print(gap(4).SymmetricGroup.__doc__)
             <BLANKLINE>
-            50 Group Libraries
+              50.1-... SymmetricGroup
             <BLANKLINE>
-            When you start GAP, it already knows several groups. Currently GAP initially
-            knows the following groups:
+              ‣ SymmetricGroup( [filt, ]deg ) ─────────────────────────────────── function
             ...
         """
         M = self._obj.parent()
@@ -1660,16 +1683,16 @@ class GapFunctionElement(FunctionElement):
 
 @instancedoc
 class GapFunction(ExpectFunction):
-    def _instancedoc(self):
+    def _instancedoc_(self):
         """
         EXAMPLES::
 
+            sage: gap = Gap(env={'LC_CTYPE': 'en_US.UTF-8'})
             sage: print(gap.SymmetricGroup.__doc__)
             <BLANKLINE>
-            50 Group Libraries
+              50.1-... SymmetricGroup
             <BLANKLINE>
-            When you start GAP, it already knows several groups. Currently GAP initially
-            knows the following groups:
+              ‣ SymmetricGroup( [filt, ]deg ) ─────────────────────────────────── function
             ...
         """
         M = self._parent
