@@ -520,7 +520,8 @@ class Kash(Expect):
         try:
             Expect._start(self)
         except RuntimeError:
-            raise RuntimeError("You must install the optional Kash package to use Kash from Sage.")
+            from sage.misc.package import PackageNotFoundError
+            raise PackageNotFoundError("kash")
         # Turn off the annoying timer.
         self.eval('Time(false);')
 
