@@ -67,15 +67,16 @@ def kill_spawned_jobs(verbose=False):
     file = os.path.join(SAGE_TMP, 'spawned_processes')
     if not os.path.exists(file):
         return
-    for L in open(file).readlines():
-        i = L.find(' ')
-        pid = L[:i].strip()
-        try:
-            if verbose:
-                print("Killing spawned job %s" % pid)
-            os.killpg(int(pid), 9)
-        except OSError:
-            pass
+    with open(file) as f:
+        for L in f:
+            i = L.find(' ')
+            pid = L[:i].strip()
+            try:
+                if verbose:
+                    print("Killing spawned job %s" % pid)
+                os.killpg(int(pid), 9)
+            except OSError:
+                pass
 
 def is_running(pid):
     """
