@@ -20,12 +20,13 @@ from six.moves import cPickle
 
 import os
 import re
+import textwrap
 
 from .expect import Expect, ExpectElement, FunctionElement
 import sage.repl.preparse
 
 from sage.interfaces.tab_completion import ExtraTabCompletion
-from sage.structure.sage_object import dumps, load
+from sage.misc.persist import dumps, load
 from sage.docs.instancedoc import instancedoc
 
 
@@ -144,12 +145,23 @@ class Sage(ExtraTabCompletion, Expect):
             sage: sage0 == loads(dumps(sage0))
             True
         """
+
+        if init_code is None:
+            init_code = []
+        elif isinstance(init_code, string_types):
+            init_code = init_code.splitlines()
+        else:
+            try:
+                init_code = list(init_code)
+            except TypeError:
+                raise TypeError(
+                    'init_code should be a string or an iterable of lines '
+                    'of code')
+
         if python:
-            command = "python -u"
-            prompt = ">>>"
-            if init_code is None:
-                init_code = ['from sage.all import *',
-                             'from six.moves import cPickle']
+            command = 'python -u'
+            prompt = re.compile(b'>>> ')
+            init_code.append('from sage.all import *')
         else:
             command = ' '.join([
                 'sage-ipython',
@@ -161,9 +173,19 @@ class Sage(ExtraTabCompletion, Expect):
                 '--no-term-title',
                 '--simple-prompt',
             ])
-            prompt = re.compile('sage: ')
-            if init_code is None:
-                init_code = ['from six.moves import cPickle']
+            prompt = re.compile(b'sage: ')
+
+        init_code.append('from six.moves import cPickle')
+        init_code.append(textwrap.dedent("""
+            def _sage0_load_local(filename):
+                with open(filename, 'rb') as f:
+                    return cPickle.load(f)
+        """))
+        init_code.append(textwrap.dedent("""
+            def _sage0_load_remote(filename):
+                with open(filename, 'rb') as f:
+                    return loads(f.read())
+        """))
 
         Expect.__init__(self,
                         name='sage',
@@ -208,7 +230,7 @@ class Sage(ExtraTabCompletion, Expect):
             sage: 'gcd' in t
             True
         """
-        return eval(self.eval('print(repr(globals().keys()))'))
+        return eval(self.eval('print(repr(list(globals())))'))
 
     def __call__(self, x):
         """
@@ -236,12 +258,16 @@ class Sage(ExtraTabCompletion, Expect):
             return SageElement(self, x)
 
         if self.is_local():
-            open(self._local_tmpfile(), 'w').write(cPickle.dumps(x, 2))
-            return SageElement(self, 'cPickle.load(open("%s"))' % self._local_tmpfile())
+            with open(self._local_tmpfile(), 'wb') as fobj:
+                fobj.write(cPickle.dumps(x, 2))
+            code = '_sage0_load_local({!r})'.format(self._local_tmpfile())
+            return SageElement(self, code)
         else:
-            open(self._local_tmpfile(), 'w').write(dumps(x))   # my dumps is compressed by default
+            with open(self._local_tmpfile(), 'wb') as fobj:
+                fobj.write(dumps(x))   # my dumps is compressed by default
             self._send_tmpfile_to_server()
-            return SageElement(self, 'loads(open("%s").read())' % self._remote_tmpfile())
+            code = '_sage0_load_remote({!r})'.format(self._remote_tmpfile())
+            return SageElement(self, code)
 
     def __reduce__(self):
         """
@@ -295,6 +321,7 @@ class Sage(ExtraTabCompletion, Expect):
         """
         if self._preparse:
             line = self.preparse(line)
+        line = self._wrap_multiline(line)
         return Expect.eval(self, line, **kwds).strip()
 
     def set(self, var, value):
@@ -397,6 +424,35 @@ class Sage(ExtraTabCompletion, Expect):
         """
         return SageElement(self, x)
 
+    @staticmethod
+    def _wrap_multiline(s):
+        r"""
+        The Sage interface does not currently handle multi-line Python
+        statements well.
+
+        So given a multi-line Python statement, it is converted to an
+        equivalent ``eval()`` call.
+
+        EXAMPLES::
+
+            sage: import textwrap
+            sage: code = textwrap.dedent('''
+            ....:     def foo():
+            ....:         return 'foo'
+            ....: ''')
+            sage: print(sage0._wrap_multiline(code))
+            eval(compile("def foo():\n    return 'foo'", '<stdin>', 'single'))
+            sage: sage0.eval(code)
+            ''
+            sage: sage0.eval('foo()')
+            "'foo'"
+        """
+
+        if '\n' in s:
+            return "eval(compile({!r}, '<stdin>', 'single'))".format(s.strip())
+        else:
+            return s
+
 
 @instancedoc
 class SageElement(ExpectElement):
@@ -458,11 +514,11 @@ class SageElement(ExpectElement):
         """
         P = self.parent()
         if P.is_remote():
-            P.eval('save(%s, "%s")' % (self.name(), P._remote_tmpfile()))
+            P.eval('save({}, {!r})'.format(self.name(), P._remote_tmpfile()))
             P._get_tmpfile_from_server(self)
             return load(P._local_tmp_file())
         else:
-            P.eval('save(%s, "%s")' % (self.name(), P._local_tmpfile()))
+            P.eval('save({}, {!r})'.format(self.name(), P._local_tmpfile()))
             return load(P._local_tmpfile())
 
 
@@ -477,19 +533,23 @@ class SageFunction(FunctionElement):
             2
         """
         P = self._obj.parent()
+
+        # Important! Keep references to the argument values or else they may
+        # get cleared from the interpreter before we complete the function
+        # call.
         args = [P(x) for x in args]
-        args = ','.join([x.name() for x in args])
-        kwds = ",".join(["%s=%s" % (k, P(v).name())
-                         for k, v in iteritems(kwds)])
-        if args != "" and kwds != "":
-            callstr = '%s.%s(%s,%s)' % (self._obj._name, self._name, args, kwds)
-        elif kwds != "":
-            callstr = '%s.%s(%s)' % (self._obj._name, self._name, kwds)
-        elif args != "":
-            callstr = '%s.%s(%s)' % (self._obj._name, self._name, args)
+        kwds = [(k, P(v)) for k, v in iteritems(kwds)]
+
+        arg_str = ','.join(x.name() for x in args)
+        kwd_str = ','.join('%s=%s' % (k, v.name()) for k, v in kwds)
+
+        if arg_str and kwd_str:
+            args_str = '%s,%s' % (arg_str, kwd_str)
         else:
-            callstr = '%s.%s()' % (self._obj._name, self._name)
-        return SageElement(P, callstr)
+            args_str = arg_str + kwd_str  # At least one of these is empty
+
+        call_str = '%s.%s(%s)' % (self._obj._name, self._name, args_str)
+        return SageElement(P, call_str)
 
     def _repr_(self):
         """
@@ -530,7 +590,7 @@ def reduce_load_element(s):
     import base64
     s = base64.b32encode(s)
     sage0.eval('import base64')
-    return sage0('loads(base64.b32decode("%s"))' % s)
+    return sage0('loads(base64.b32decode({!r}))'.format(s))
 
 
 def sage0_console():
