@@ -37,10 +37,11 @@ Test that write errors to stderr are handled gracefully by GAP
     0
     sage: subprocess.call("echo syntax error | gp", **kwds)
     0
-    sage: subprocess.call("echo syntax error | ipython", **kwds) in (0,1)
+    sage: subprocess.call("echo syntax error | ipython", **kwds) in (0, 1, 120)
     True
     sage: subprocess.call("echo syntax error | Singular", **kwds)
     0
+    sage: f.close()
 """
 from __future__ import print_function
 from __future__ import absolute_import
