@@ -878,8 +878,6 @@ class AutomorphismFieldParal(FreeModuleAutomorphism, TensorFieldParal):
         self._vmodule = vector_field_module
         self._domain = vector_field_module._domain
         self._ambient_domain = vector_field_module._ambient_domain
-        self._extensions_graph = {self._domain: self}
-        self._restrictions_graph = {self._domain: self}
         # Initialization of derived quantities:
         TensorFieldParal._init_derived(self)
 
