@@ -49,7 +49,6 @@ from sage.manifolds.differentiable.curve import DifferentiableCurve
 from sage.manifolds.differentiable.integrated_curve import IntegratedCurve
 from sage.manifolds.differentiable.integrated_curve import IntegratedAutoparallelCurve
 from sage.manifolds.differentiable.integrated_curve import IntegratedGeodesic
-from sage.misc.cachefunc import cached_method
 
 class DifferentiableManifoldHomset(TopologicalManifoldHomset):
     r"""
@@ -783,7 +782,7 @@ class IntegratedCurveSet(DifferentiableCurveSet):
 
     def _element_constructor_(self, equations_rhs, velocities,
                  curve_parameter, initial_tangent_vector, chart=None,
-                 name=None, latex_name=None, verbose=False):
+                 name=None, latex_name=None, verbose=False, across_charts=False):
         r"""
         Construct an element of ``self``, i.e. an integrated curve
         `I \to M`, where `I` is a real interval and `M` some
@@ -815,7 +814,7 @@ class IntegratedCurveSet(DifferentiableCurveSet):
         # Standard construction
         return self.element_class(self, equations_rhs, velocities,
                 curve_parameter, initial_tangent_vector, chart=chart,
-                name=name, latex_name=latex_name, verbose=verbose)
+                name=name, latex_name=latex_name, verbose=verbose, across_charts=across_charts)
 
     def _an_element_(self):
         r"""
@@ -892,8 +891,6 @@ class IntegratedCurveSet(DifferentiableCurveSet):
         t = dom.canonical_coordinate()
         t_min = dom.lower_bound() # this is either an expression or a
         # finite value thanks to tests in '__init__'
-        t_max = dom.upper_bound() # this is either an expression or a
-        # finite value thanks to tests in '__init__'
 
         codom = self.codomain()
         dim = codom.dim()
@@ -1231,7 +1228,7 @@ class IntegratedAutoparallelCurveSet(IntegratedCurveSet):
 
     def _element_constructor_(self, affine_connection, curve_parameter,
                     initial_tangent_vector, chart=None, name=None,
-                    latex_name=None, verbose=False):
+                    latex_name=None, verbose=False, across_charts=False):
         r"""
         Construct an element of ``self``, i.e. an integrated
         autoparallel curve `I \to M`, where `I` is a real interval and
@@ -1265,7 +1262,7 @@ class IntegratedAutoparallelCurveSet(IntegratedCurveSet):
         # Standard construction
         return self.element_class(self, affine_connection,
                  curve_parameter, initial_tangent_vector, chart=chart,
-                 name=name,latex_name=latex_name, verbose=verbose)
+                 name=name,latex_name=latex_name, verbose=verbose, across_charts=across_charts)
 
     def _an_element_(self):
         r"""
@@ -1358,7 +1355,6 @@ class IntegratedAutoparallelCurveSet(IntegratedCurveSet):
         dim = codom.dim()
         i0 = codom.start_index()
         chart2 = codom.default_chart()
-        x = chart2[:][0]
         # In case the codomain coincides with the domain,
         # it is important to distinguish between the canonical
         # coordinate, and the curve parameter since, in such a
@@ -1686,7 +1682,7 @@ class IntegratedGeodesicSet(IntegratedAutoparallelCurveSet):
 
     def _element_constructor_(self, metric, curve_parameter,
                     initial_tangent_vector, chart=None, name=None,
-                    latex_name=None, verbose=False):
+                    latex_name=None, verbose=False, across_charts=False):
         r"""
         Construct an element of ``self``, i.e. an integrated geodesic
         `I \to M`, where `I` is a real interval and
@@ -1718,7 +1714,7 @@ class IntegratedGeodesicSet(IntegratedAutoparallelCurveSet):
         # Standard construction
         return self.element_class(self, metric, curve_parameter,
                  initial_tangent_vector, chart=chart, name=name,
-                 latex_name=latex_name, verbose=verbose)
+                 latex_name=latex_name, verbose=verbose, across_charts=across_charts)
 
     def _an_element_(self):
         r"""
