@@ -1277,7 +1277,7 @@ class PseudoRiemannianSubmanifold(PseudoRiemannianManifold,
             raise NotImplementedError("'mixed_projection' is"+
                                       " implemented only for hypersurfaces.")
         if isinstance(indices, (Integer, int)):
-            indices = range(indices)
+            indices = list(range(indices))
 
         if len(indices)>tensor.tensor_rank():
             raise ValueError("Too much contractions")
@@ -1299,8 +1299,8 @@ class PseudoRiemannianSubmanifold(PseudoRiemannianManifold,
                 multiprojector = multiprojector * self.normal().contract(g)
             else:
                 multiprojector = multiprojector * self.projector()
-        args = range(kp - tensor.tensor_type()[0], kp) + range(
-            tensor.tensor_type()[1]) + [tensor] + range(k)
+        args = list(range(kp - tensor.tensor_type()[0], kp)) + list(range(
+                tensor.tensor_type()[1])) + [tensor] + list(range(k))
         return multiprojector.contract(*args)
 
     @cached_method
