@@ -24,13 +24,13 @@ TESTS::
     [0 0]
 """
 
-#*****************************************************************************
+# ****************************************************************************
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from __future__ import print_function, absolute_import
 from six.moves import range
 from six import iteritems, integer_types
@@ -83,8 +83,7 @@ _Fields = Fields()
 
 def is_MatrixSpace(x):
     """
-    Returns True if self is an instance of MatrixSpace returns false if
-    self is not an instance of MatrixSpace
+    Return whether ``self`` is an instance of ``MatrixSpace``.
 
     EXAMPLES::
 
@@ -609,7 +608,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def cardinality(self):
         r"""
-        Return the number of elements in self.
+        Return the number of elements in ``self``.
 
         EXAMPLES::
 
@@ -651,36 +650,6 @@ class MatrixSpace(UniqueRepresentation, Parent):
         default = get_matrix_class(self.base_ring(), self.nrows(), self.ncols(), self.is_sparse(), None)
         return self.Element is default
 
-    def full_category_initialisation(self):
-        """
-        Make full use of the category framework.
-
-        .. NOTE::
-
-            It turns out that it causes a massive speed regression in
-            computations with elliptic curves, if a full initialisation
-            of the category framework of matrix spaces happens at
-            initialisation: The elliptic curves code treats matrix spaces
-            as containers, not as objects of a category. Therefore,
-            making full use of the category framework is now provided by
-            a separate method (see :trac:`11900`).
-
-        EXAMPLES::
-
-            sage: MS = MatrixSpace(QQ,8)
-            sage: TestSuite(MS).run()
-            sage: type(MS)
-            <class 'sage.matrix.matrix_space.MatrixSpace_with_category'>
-            sage: MS.full_category_initialisation()
-            doctest:...: DeprecationWarning: the full_category_initialization
-             method does nothing, as a matrix space now has its category
-             systematically fully initialized
-            See http://trac.sagemath.org/15801 for details.
-        """
-        deprecation(15801, "the full_category_initialization method does nothing,"
-                           " as a matrix space now has its category"
-                           " systematically fully initialized")
-
     @lazy_attribute
     def transposed(self):
         """
@@ -849,7 +818,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def change_ring(self, R):
         """
-        Return matrix space over R with otherwise same parameters as self.
+        Return matrix space over R with otherwise same parameters as ``self``.
 
         INPUT:
 
@@ -914,7 +883,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def _get_action_(self, S, op, self_on_left):
         r"""
-        Return the action of S on self
+        Return the action of S on ``self``.
 
         INPUT:
 
@@ -1136,7 +1105,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def _repr_(self):
         """
-        Returns the string representation of a MatrixSpace
+        Return the string representation of a MatrixSpace.
 
         EXAMPLES::
 
@@ -1181,7 +1150,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def _latex_(self):
         r"""
-        Returns the latex representation of a MatrixSpace
+        Return the latex representation of a MatrixSpace.
 
         EXAMPLES::
 
@@ -1226,7 +1195,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def __iter__(self):
         r"""
-        Returns a generator object which iterates through the elements of
+        Return a generator object which iterates through the elements of
         self. The order in which the elements are generated is based on a
         'weight' of a matrix which is the number of iterations on the base
         ring that are required to reach that matrix.
@@ -1529,7 +1498,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def dimension(self):
         r"""
-        Returns (m rows) \* (n cols) of self as Integer
+        Return (m rows) \* (n cols) of ``self`` as ``Integer``.
 
         EXAMPLES::
 
@@ -1542,7 +1511,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def dims(self):
         """
-        Returns (m row, n col) representation of self dimension
+        Return (m row, n col) representation of ``self`` dimension.
 
         EXAMPLES::
 
@@ -1556,7 +1525,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
     @cached_method
     def identity_matrix(self):
         """
-        Returns the identity matrix in ``self``.
+        Return the identity matrix in ``self``.
 
         ``self`` must be a space of square
         matrices. The returned matrix is immutable. Please use ``copy`` if
@@ -1607,7 +1576,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def is_dense(self):
         """
-        Returns True if matrices in self are dense and False otherwise.
+        Return whether matrices in ``self`` are dense.
 
         EXAMPLES::
 
@@ -1620,7 +1589,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def is_sparse(self):
         """
-        Returns True if matrices in self are sparse and False otherwise.
+        Return whether matrices in ``self`` are sparse.
 
         EXAMPLES::
 
@@ -1633,6 +1602,8 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def is_finite(self):
         """
+        Return whether this matrix space is finite.
+
         EXAMPLES::
 
             sage: MatrixSpace(GF(101), 10000).is_finite()
@@ -1646,7 +1617,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
         """
         Return the n-th generator of this matrix space.
 
-        This doesn't compute all basis matrices, so it is reasonably
+        This does not compute all basis matrices, so it is reasonably
         intelligent.
 
         EXAMPLES::
@@ -1671,7 +1642,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
     @cached_method
     def zero_matrix(self):
         """
-        Returns the zero matrix in ``self``.
+        Return the zero matrix in ``self``.
 
         ``self`` must be a space of square matrices. The returned matrix is
         immutable. Please use ``copy`` if you want a modified copy.
@@ -1706,8 +1677,9 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def ngens(self):
         """
-        Return the number of generators of this matrix space, which is the
-        number of entries in the matrices in this space.
+        Return the number of generators of this matrix space.
+
+        This is the number of entries in the matrices in this space.
 
         EXAMPLES::
 
@@ -1917,7 +1889,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def random_element(self, density=None, *args, **kwds):
         """
-        Returns a random element from this matrix space.
+        Return a random element from this matrix space.
 
         INPUT:
 
@@ -2114,7 +2086,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
     def _random_nonzero_element(self, *args, **kwds):
         """
-        Return a random non-zero matrix
+        Return a random non-zero matrix.
 
         This function repeatedly calls ``random_element`` until a non-zero
         matrix is obtained.
