@@ -53,7 +53,7 @@ from __future__ import absolute_import
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
+#                  https://www.gnu.org/licenses/
 #*****************************************************************************
 
 from .matroid import Matroid
@@ -81,8 +81,8 @@ class DualMatroid(Matroid):
         True
         sage: Md
         Dual of 'Vamos: Matroid of rank 4 on 8 elements with circuit-closures
-        {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'}, {'e', 'f', 'g', 'h'},
-             {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'}},
+        {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'}, {'a', 'b', 'g', 'h'},
+             {'c', 'd', 'e', 'f'}, {'e', 'f', 'g', 'h'}},
          4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}'
     """
 
@@ -98,11 +98,11 @@ class DualMatroid(Matroid):
             sage: Md.rank('abd') == M.corank('abd')
             True
             sage: Md
-            Dual of 'Vamos: Matroid of rank 4 on 8 elements with
-            circuit-closures
+            Dual of 'Vamos:
+            Matroid of rank 4 on 8 elements with circuit-closures
             {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'},
-                 {'e', 'f', 'g', 'h'}, {'a', 'b', 'g', 'h'},
-                 {'c', 'd', 'e', 'f'}},
+                 {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'},
+                 {'e', 'f', 'g', 'h'}},
              4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}'
         """
         if not isinstance(matroid, Matroid):
@@ -157,7 +157,8 @@ class DualMatroid(Matroid):
 
         INPUT:
 
-        - ``X`` -- An object with Python's ``frozenset`` interface containing a subset of ``self.groundset()``.
+        - ``X`` -- An object with Python's ``frozenset`` interface
+          containing a subset of ``self.groundset()``.
 
         OUTPUT:
 
@@ -345,14 +346,17 @@ class DualMatroid(Matroid):
             sage: M = matroids.named_matroids.Vamos().dual()
             sage: N = M._minor(contractions=set(['a']), deletions=set([]))
             sage: N._minor(contractions=set([]), deletions=set(['b', 'c']))
-            Dual of 'M / {'b', 'c'} \ {'a'}, where M is Vamos: Matroid of rank
-            4 on 8 elements with circuit-closures
-            {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'}, {'e', 'f', 'g',
-            'h'}, {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'}}, 4: {{'a', 'b',
-            'c', 'd', 'e', 'f', 'g', 'h'}}}'
+            Dual of 'M / {'b', 'c'} \ {'a'}, where M is Vamos:
+            Matroid of rank 4 on 8 elements with circuit-closures
+            {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'},
+                 {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'},
+                 {'e', 'f', 'g', 'h'}},
+             4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}'
         """
-        # Assumption: if self._matroid cannot make a dual, neither can its minor.
-        return DualMatroid(self._matroid._minor(contractions=deletions, deletions=contractions))
+        # Assumption: if self._matroid cannot make a dual, neither can
+        # its minor.
+        return DualMatroid(self._matroid._minor(contractions=deletions,
+                                                deletions=contractions))
 
     def dual(self):
         r"""
@@ -377,9 +381,9 @@ class DualMatroid(Matroid):
             3
             sage: N
             Pappus: Matroid of rank 3 on 9 elements with circuit-closures
-            {2: {{'a', 'b', 'c'}, {'a', 'f', 'h'}, {'c', 'e', 'g'},
-                 {'b', 'f', 'g'}, {'c', 'd', 'h'}, {'d', 'e', 'f'},
-                 {'a', 'e', 'i'}, {'b', 'd', 'i'}, {'g', 'h', 'i'}},
+            {2: {{'a', 'b', 'c'}, {'a', 'e', 'i'}, {'a', 'f', 'h'},
+                 {'b', 'd', 'i'}, {'b', 'f', 'g'}, {'c', 'd', 'h'},
+                 {'c', 'e', 'g'}, {'d', 'e', 'f'}, {'g', 'h', 'i'}},
              3: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i'}}}
         """
         return self._matroid
@@ -393,11 +397,11 @@ class DualMatroid(Matroid):
 
             sage: M = matroids.named_matroids.Vamos().dual()
             sage: print(M._repr_())
-            Dual of 'Vamos: Matroid of rank 4 on 8 elements with
-            circuit-closures
+            Dual of 'Vamos:
+            Matroid of rank 4 on 8 elements with circuit-closures
             {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'},
-                 {'e', 'f', 'g', 'h'}, {'a', 'b', 'g', 'h'},
-                 {'c', 'd', 'e', 'f'}},
+                 {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'},
+                 {'e', 'f', 'g', 'h'}},
              4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}'
         """
         return "Dual of '" + repr(self._matroid) + "'"
@@ -509,7 +513,8 @@ class DualMatroid(Matroid):
 
         """
         N = DualMatroid(self._matroid)
-        if getattr(self, '__custom_name') is not None:  # because of name wrangling, this is not caught by the default copy
+        if getattr(self, '__custom_name') is not None:
+            # because of name wrangling, this is not caught by the default copy
             N.rename(getattr(self, '__custom_name'))
         return N
 
@@ -532,7 +537,9 @@ class DualMatroid(Matroid):
         """
         from copy import deepcopy
         N = DualMatroid(deepcopy(self._matroid, memo))
-        if getattr(self, '__custom_name') is not None:  # because of name wrangling, this is not caught by the default deepcopy
+        if getattr(self, '__custom_name') is not None:
+            # because of name wrangling, this is not caught by the
+            # default deepcopy
             N.rename(deepcopy(getattr(self, '__custom_name'), memo))
         return N
 
@@ -554,13 +561,12 @@ class DualMatroid(Matroid):
             sage: M == loads(dumps(M))  # indirect doctest
             True
             sage: loads(dumps(M))
-            Dual of 'Vamos: Matroid of rank 4 on 8 elements with
-            circuit-closures
+            Dual of 'Vamos:
+            Matroid of rank 4 on 8 elements with circuit-closures
             {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'},
-                 {'e', 'f', 'g', 'h'}, {'a', 'b', 'g', 'h'},
-                 {'c', 'd', 'e', 'f'}},
+                 {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'},
+                 {'e', 'f', 'g', 'h'}},
              4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}'
-
         """
         import sage.matroids.unpickling
         data = (self._matroid, getattr(self, '__custom_name'))
