@@ -76,7 +76,7 @@ from __future__ import absolute_import
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 from .matroid import Matroid
-from .utilities import sanitize_contractions_deletions, setprint_s
+from .utilities import setprint_s
 
 
 class MinorMatroid(Matroid):
@@ -119,10 +119,10 @@ class MinorMatroid(Matroid):
         sage: N = MinorMatroid(matroid=M, contractions=set(['a']),
         ....:                  deletions=set())
         sage: N._minor(contractions=set(), deletions=set(['b', 'c']))
-        M / {'a'} \ {'b', 'c'}, where M is Vamos: Matroid of rank 4 on 8
-        elements with circuit-closures
-        {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'}, {'e', 'f', 'g', 'h'},
-             {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'}},
+        M / {'a'} \ {'b', 'c'}, where M is Vamos:
+        Matroid of rank 4 on 8 elements with circuit-closures
+        {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'}, {'a', 'b', 'g', 'h'},
+             {'c', 'd', 'e', 'f'}, {'e', 'f', 'g', 'h'}},
          4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}
     """
 
@@ -332,11 +332,11 @@ class MinorMatroid(Matroid):
             sage: M = MinorMatroid(matroids.named_matroids.Vamos(), contractions=set('c'), deletions={'b', 'f'})
             sage: N = M._minor(contractions=set(['a']), deletions=set([]))
             sage: N._minor(contractions=set([]), deletions=set(['d']))
-            M / {'a', 'c'} \ {'b', 'd', 'f'}, where M is Vamos: Matroid of
-            rank 4 on 8 elements with circuit-closures
+            M / {'a', 'c'} \ {'b', 'd', 'f'}, where M is Vamos:
+            Matroid of rank 4 on 8 elements with circuit-closures
             {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'},
-                 {'e', 'f', 'g', 'h'}, {'a', 'b', 'g', 'h'},
-                 {'c', 'd', 'e', 'f'}},
+                 {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'},
+                 {'e', 'f', 'g', 'h'}},
              4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}
         """
         return MinorMatroid(self._matroid, self._contractions.union(contractions), self._deletions.union(deletions))
@@ -351,11 +351,11 @@ class MinorMatroid(Matroid):
 
             sage: M = matroids.named_matroids.Vamos().dual()
             sage: print(M._repr_())
-            Dual of 'Vamos: Matroid of rank 4 on 8 elements with
-            circuit-closures
+            Dual of 'Vamos:
+            Matroid of rank 4 on 8 elements with circuit-closures
             {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'},
-                 {'e', 'f', 'g', 'h'}, {'a', 'b', 'g', 'h'},
-                 {'c', 'd', 'e', 'f'}},
+                 {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'},
+                 {'e', 'f', 'g', 'h'}},
              4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}'
         """
         s = "M"
@@ -476,9 +476,7 @@ class MinorMatroid(Matroid):
             True
             sage: M._matroid is N._matroid
             True
-
         """
-        from copy import copy
         N = MinorMatroid(self._matroid, self._contractions, self._deletions)
         if getattr(self, '__custom_name') is not None:  # because of name wrangling, this is not caught by the default copy
             N.rename(getattr(self, '__custom_name'))
@@ -520,11 +518,11 @@ class MinorMatroid(Matroid):
             sage: M == loads(dumps(M))  # indirect doctest
             True
             sage: loads(dumps(M))
-            M / {'a', 'b', 'c'} \ {'g'}, where M is Vamos: Matroid of rank 4
-            on 8 elements with circuit-closures
+            M / {'a', 'b', 'c'} \ {'g'}, where M is Vamos:
+            Matroid of rank 4 on 8 elements with circuit-closures
             {3: {{'a', 'b', 'c', 'd'}, {'a', 'b', 'e', 'f'},
-                 {'e', 'f', 'g', 'h'}, {'a', 'b', 'g', 'h'},
-                 {'c', 'd', 'e', 'f'}},
+                 {'a', 'b', 'g', 'h'}, {'c', 'd', 'e', 'f'},
+                 {'e', 'f', 'g', 'h'}},
              4: {{'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'}}}
         """
         import sage.matroids.unpickling
