@@ -13,7 +13,7 @@ AUTHORS:
 - Stefan van Zwam (2011-06-24): initial version
 
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2013 Rudi Pendavingh <rudi.pendavingh@gmail.com>
 #       Copyright (C) 2013 Stefan van Zwam <stefanvanzwam@gmail.com>
 #
@@ -21,19 +21,16 @@ AUTHORS:
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from __future__ import print_function
 from six import iteritems
 
 from sage.matrix.constructor import Matrix
-from sage.rings.all import ZZ, QQ, FiniteField, GF
+from sage.rings.all import ZZ, QQ, GF
 from sage.graphs.all import BipartiteGraph, Graph
-from pprint import pformat
 from sage.structure.all import SageObject
 from sage.graphs.spanning_tree import kruskal
-from sage.graphs.graph import Graph
-from sage.matrix.constructor import matrix
 from operator import itemgetter
 from sage.rings.number_field.number_field import NumberField
 
@@ -67,10 +64,12 @@ def setprint(X):
 
         sage: from sage.matroids.advanced import setprint
         sage: L = [{1, 2, 3}, {1, 2, 4}, {2, 3, 4}, {4, 1, 3}]
-        sage: print(L)
+        sage: print(L)  # py2
         [set([1, 2, 3]), set([1, 2, 4]), set([2, 3, 4]), set([1, 3, 4])]
-        sage: setprint(L)
+        sage: print(L)  # py3
         [{1, 2, 3}, {1, 2, 4}, {2, 3, 4}, {1, 3, 4}]
+        sage: setprint(L)
+        [{1, 2, 3}, {1, 2, 4}, {1, 3, 4}, {2, 3, 4}]
 
     Note that for iterables, the effect can be undesirable::
 
@@ -79,7 +78,7 @@ def setprint(X):
         sage: M.bases()
         Iterator over a system of subsets
         sage: setprint(M.bases())
-        [{'a', 'b', 'c'}, {'a', 'c', 'd'}, {'a', 'b', 'd'}]
+        [{'a', 'b', 'c'}, {'a', 'b', 'd'}, {'a', 'c', 'd'}]
 
     An exception was made for subclasses of SageObject::
 
@@ -113,7 +112,7 @@ def setprint_s(X, toplevel=False):
         sage: from sage.matroids.utilities import setprint_s
         sage: L = [{1, 2, 3}, {1, 2, 4}, {2, 3, 4}, {4, 1, 3}]
         sage: setprint_s(L)
-        '[{1, 2, 3}, {1, 2, 4}, {2, 3, 4}, {1, 3, 4}]'
+        '[{1, 2, 3}, {1, 2, 4}, {1, 3, 4}, {2, 3, 4}]'
 
     The ``toplevel`` argument only affects strings, to mimic ``print``'s
     behavior::
@@ -125,16 +124,17 @@ def setprint_s(X, toplevel=False):
         'abcd'
     """
     if isinstance(X, frozenset) or isinstance(X, set):
-        return '{' + ', '.join([setprint_s(x) for x in sorted(X)]) + '}'
+        return '{' + ', '.join(sorted(setprint_s(x) for x in X)) + '}'
     elif isinstance(X, dict):
-        return '{' + ', '.join([setprint_s(key) + ': ' + setprint_s(val) for key, val in sorted(iteritems(X))]) + '}'
+        return '{' + ', '.join(sorted(setprint_s(key) + ': ' + setprint_s(val)
+                                      for key, val in iteritems(X))) + '}'
     elif isinstance(X, str):
         if toplevel:
             return X
         else:
             return "'" + X + "'"
     elif hasattr(X, '__iter__') and not isinstance(X, SageObject):
-        return '[' + ', '.join([setprint_s(x) for x in sorted(X)]) + ']'
+        return '[' + ', '.join(sorted(setprint_s(x) for x in X)) + ']'
     else:
         return repr(X)
 
@@ -219,7 +219,7 @@ def sanitize_contractions_deletions(matroid, contractions, deletions):
         sage: setprint(sanitize_contractions_deletions(M, 'abc', 'defg'))
         [{'a', 'b', 'c'}, {'d', 'e', 'f', 'g'}]
         sage: setprint(sanitize_contractions_deletions(M, 'defg', 'abc'))
-        [{'d', 'e', 'g'}, {'a', 'b', 'c', 'f'}]
+        [{'a', 'b', 'c', 'f'}, {'d', 'e', 'g'}]
         sage: setprint(sanitize_contractions_deletions(M, [1, 2, 3], 'efg'))
         Traceback (most recent call last):
         ...
@@ -472,7 +472,7 @@ def spanning_stars(M):
 
     # T contain all edges in some spanning tree
     T = []
-    for (x,y) in H:
+    for x, y in H:
         if x < m:
             t = x
             x = y
@@ -482,7 +482,7 @@ def spanning_stars(M):
 
 # Partial fields and lifting
 
-def lift_cross_ratios(A, lift_map = None):
+def lift_cross_ratios(A, lift_map=None):
     r"""
     Return a matrix which arises from the given matrix by lifting cross ratios.
 
@@ -540,7 +540,7 @@ def lift_cross_ratios(A, lift_map = None):
         sage: Z
         [ 1  0  1  1  1]
         [ 1  1  0  0  z]
-        [ 0  z - 1  1  -z + 1  0]
+        [ 0  1 -z -1  0]
         sage: M = LinearMatroid(reduced_matrix = A)
         sage: sorted(M.cross_ratios())
         [3, 5]
@@ -567,7 +567,7 @@ def lift_cross_ratios(A, lift_map = None):
         T.update(G.subgraph(C).min_spanning_tree())
     # - fix a tree of the support graph G to units (= empty dict, product of 0 terms)
     F = {entry[2]: dict() for entry in T}
-    W = set(G.edges()) - set(T)
+    W = set(G.edge_iterator()) - set(T)
     H = G.subgraph(edges = T)
     while W:
         # - find an edge in W to process, closing a circuit in H which is induced in G
@@ -598,25 +598,25 @@ def lift_cross_ratios(A, lift_map = None):
         div = True
         for entry2 in entries:
             if div:
-                cr = cr/A[entry2]
+                cr /= A[entry2]
             else:
-                cr = cr* A[entry2]
+                cr *= A[entry2]
             div = not div
 
-        monomial = dict()
+        monomial = {}
         if len(path) % 4 == 0:
             if not cr == plus_one1:
                 monomial[cr] = 1
         else:
             cr = -cr
-            if not cr ==plus_one1:
+            if cr != plus_one1:
                 monomial[cr] = 1
             if  minus_one1 in monomial:
                 monomial[minus_one1] = monomial[minus_one1] + 1
             else:
                 monomial[minus_one1] = 1
 
-        if cr != plus_one1 and not cr in lift_map:
+        if cr != plus_one1 and cr not in lift_map:
             raise ValueError("Input matrix has a cross ratio "+str(cr)+", which is not in the lift_map")
         # - write the entry as a product of cross ratios of A
         div = True
@@ -709,11 +709,12 @@ def lift_map(target):
         R = GF(7)
         z = ZZ['z'].gen()
         S = NumberField(z*z-z+1, 'z')
-        return { R(1): S(1), R(3): S(z), R(3)**(-1): S(z)**5}
+        z = S(z)
+        return {R.one(): S.one(), R(3): z, R(3)**(-1): z**5}
 
     if target == "dyadic":
         R = GF(11)
-        return {R(1):QQ(1), R(-1):QQ(-1), R(2):QQ(2), R(6): QQ(1/2)}
+        return {R(1):QQ(1), R(-1):QQ(-1), R(2):QQ(2), R(6): QQ((1, 2))}
 
     if target == "gm":
         R = GF(19)
@@ -724,6 +725,7 @@ def lift_map(target):
 
     raise NotImplementedError(target)
 
+
 def split_vertex(G, u, v=None, edges=None):
     """
     Split a vertex in a graph.
@@ -758,7 +760,7 @@ def split_vertex(G, u, v=None, edges=None):
         v = G.add_vertex()
     elif v not in G:
         G.add_vertex(v)
-    elif G.degree(v) != 0:
+    elif G.degree(v):
         raise ValueError("v must be a new vertex or an isolated vertex")
     if edges is None:
         edges = []
