@@ -177,7 +177,7 @@ def load_submodules(module=None, exclude_pattern=None):
     if module is None:
         import sage
         module = sage
-        exclude_pattern = "^sage\.libs|^sage\.tests|tests$|^sage\.all_|all$|sage\.interacts$|^sage\.misc\.benchmark$"
+        exclude_pattern = r"^sage\.libs|^sage\.tests|tests$|^sage\.all_|all$|sage\.interacts$|^sage\.misc\.benchmark$"
 
     if exclude_pattern:
         import re
@@ -314,7 +314,7 @@ def find_object_modules(obj):
 
     # if the object is an instance, we try to guess where it is defined
     if sageinspect.isclassinstance(obj):
-        dec_pattern = re.compile("^(\w[\w0-9\_]*)\s*=", re.MULTILINE)
+        dec_pattern = re.compile(r"^(\w[\w0-9\_]*)\s*=", re.MULTILINE)
         module_to_obj2 = {}
         for module_name, obj_names in iteritems(module_to_obj):
             module_to_obj2[module_name] = []
