@@ -799,8 +799,10 @@ def xinterval(a, b):
 
     EXAMPLES::
 
-        sage: I = xinterval(2,5); I
+        sage: I = xinterval(2,5); I  # py2
         xrange(2, 6)
+        sage: I = xinterval(2,5); I  # py3
+        range(2, 6)
         sage: 5 in I
         True
         sage: 6 in I
