@@ -20,8 +20,6 @@ import warnings
 from sage.misc.latex import latex
 from sage.misc.sage_eval import sage_eval
 from sage.structure.sage_object import SageObject
-from sage.misc.superseded import deprecation
-from sage.misc.decorators import rename_keyword
 
 
 class HtmlFragment(str, SageObject):
