@@ -35,7 +35,7 @@ Check the fix from :trac:`8323`::
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
+#                  https://www.gnu.org/licenses/
 # ****************************************************************************
 from __future__ import print_function, absolute_import
 from six.moves import range
@@ -116,6 +116,7 @@ if hasattr(os, 'chmod'):
             print("Setting permissions of DOT_SAGE directory so only you "
                   "can read and write it.")
 
+
 def try_read(obj, splitlines=False):
     r"""
     Determine if a given object is a readable file-like object and if so
@@ -215,11 +216,11 @@ def try_read(obj, splitlines=False):
     return data
 
 
-
 #################################################
 # Next we create the Sage temporary directory.
 #################################################
 
+
 @lazy_string
 def SAGE_TMP():
     """
@@ -598,7 +599,7 @@ def set_verbose(level, files='all'):
 
     INPUT:
 
-    - ``level`` - an integer between 0 and 2, inclusive.
+    - ``level`` -- an integer between 0 and 2, inclusive.
 
     - ``files`` (default: 'all'): list of files to make verbose, or
        'all' to make ALL files verbose (the default).
@@ -617,6 +618,8 @@ def set_verbose(level, files='all'):
         [no output]
         sage: set_verbose(0)
     """
+    if level is None:
+        level = -1
     if isinstance(level, str):
         set_verbose_files([level])
     global LEVEL
@@ -674,19 +677,6 @@ def get_verbose():
     return LEVEL
 
 
-def cmp_props(left, right, props):
-    from sage.misc.superseded import deprecation
-    deprecation(23149, "cmp_props is deprecated")
-    for a in props:
-        lx = left.__getattribute__(a)()
-        rx = right.__getattribute__(a)()
-        if lx < rx:
-            return -1
-        elif lx > rx:
-            return 1
-    return 0
-
-
 def union(x, y=None):
     """
     Return the union of x and y, as a list. The resulting list need not
@@ -1251,7 +1241,7 @@ def some_tuples(elements, repeat, bound, max_samples=None):
     if max_samples is None:
         from itertools import islice, product
         P = elements if repeat is None else product(elements, repeat=repeat)
-        return islice(P, bound)
+        return islice(P, int(bound))
     else:
         if not (hasattr(elements, '__len__') and hasattr(elements, '__getitem__')):
             elements = list(elements)
@@ -1340,7 +1330,7 @@ def powerset(X):
     pairs = []
     for x in X:
         pairs.append((2**len(pairs), x))
-        for w in range(2**(len(pairs)-1), 2**(len(pairs))):
+        for w in range(2**(len(pairs) - 1), 2**(len(pairs))):
             yield [x for m, x in pairs if m & w]
 
 
@@ -1561,7 +1551,7 @@ class AttrCallObject(object):
             sage: series(sin(x), 4)
             1*x + (-1/6)*x^3 + Order(x^4)
         """
-        return getattr(x, self.name)(*(self.args+args), **self.kwds)
+        return getattr(x, self.name)(*(self.args + args), **self.kwds)
 
     def __repr__(self):
         """
@@ -1722,8 +1712,8 @@ def is_in_string(line, pos):
         # which is the case if the previous character isn't
         # a backslash, or it is but both previous characters
         # are backslashes.
-        if line[i-1:i] != '\\' or line[i-2:i] == '\\\\':
-            if line[i:i+3] in ['"""', "'''"]:
+        if line[i - 1: i] != '\\' or line[i - 2: i] == '\\\\':
+            if line[i: i + 3] in ['"""', "'''"]:
                 if not in_quote():
                     in_triple_quote = True
                 elif in_triple_quote:
