@@ -47,7 +47,7 @@ alternative is to use ClasscallMetaclass as metaclass::
 from __future__ import print_function, absolute_import
 from six import add_metaclass
 
-__all__ = [] # Don't document any parents
+__all__ = []  # Don't document any parents
 
 from sage.structure.parent import Parent
 from sage.structure.element_wrapper import ElementWrapper
@@ -55,6 +55,7 @@ from sage.structure.unique_representation import UniqueRepresentation
 from sage.misc.classcall_metaclass import ClasscallMetaclass
 from sage.misc.nested_class import NestedClassMetaclass
 
+
 class TestParent1(Parent):
     def __init__(self):
         """
@@ -86,6 +87,7 @@ class TestParent2(Parent):
     class Element(ElementWrapper):
         pass
 
+
 class TestParent3(UniqueRepresentation, Parent):
 
     def __init__(self):
@@ -112,7 +114,7 @@ class TestParent4(Parent):
             <sage.misc.nested_class_test.TestParent4_with_category object at ...>
         """
         from sage.categories.all import Sets
-        Parent.__init__(self, category = Sets())
+        Parent.__init__(self, category=Sets())
 
     def __eq__(self, other):
         """
@@ -134,6 +136,18 @@ class TestParent4(Parent):
         """
         return self.__class__ != other.__class__
 
+    def __hash__(self):
+        """
+        Return the hash of ``self``.
+
+        EXAMPLES::
+
+            sage: from sage.misc.nested_class_test import TestParent4
+            sage: hash(TestParent4()) == hash(TestParent4())
+            True
+        """
+        return hash(8960522744683456048)
+
     class Element(ElementWrapper):
         pass
 
@@ -145,6 +159,7 @@ class B(object):
     """
     pass
 
+
 class ABB(object):
     class B(object):
         """
@@ -153,11 +168,13 @@ class ABB(object):
         """
         pass
 
+
 class ABL(object):
     """
     There is no problem here.
     """
-    B=B
+    B = B
+
 
 class ALB(object):
     """
@@ -200,6 +217,7 @@ class ALBMeta(object):
         """
         pass
 
+
 CMeta = ALBMeta.CMeta
 
 
