@@ -113,16 +113,16 @@ defined Cython code, and with rather tricky argument lines::
 
 """
 from __future__ import print_function, absolute_import
+
+import six
+from six import iteritems, string_types, class_types
 from six.moves import range
-from six import iteritems, string_types, class_types, text_type
-from sage.misc.six import u
 
 import ast
 import inspect
 import functools
 import os
 import tokenize
-import types
 import re
 EMBEDDED_MODE = False
 from sage.env import SAGE_SRC
@@ -166,13 +166,15 @@ def isclassinstance(obj):
         sage: isclassinstance(myclass2)
         False
     """
-    return (not inspect.isclass(obj) and \
-            hasattr(obj, '__class__') and \
-            hasattr(obj.__class__, '__module__') and \
-            obj.__class__.__module__ not in ('__builtin__', 'exceptions'))
+
+    builtin_mods = set(['__builtin__', 'builtins', 'exceptions'])
+
+    return (not inspect.isclass(obj) and
+            hasattr(obj, '__class__') and
+            hasattr(obj.__class__, '__module__') and
+            obj.__class__.__module__ not in builtin_mods)
 
 
-import re
 # Parse strings of form "File: sage/rings/rational.pyx (starting at line 1080)"
 # "\ " protects a space in re.VERBOSE mode.
 __embedded_position_re = re.compile(r'''
@@ -206,18 +208,22 @@ def _extract_embedded_position(docstring):
     The following has been fixed in :trac:`13916`::
 
         sage: cython('''cpdef test_funct(x,y): return''')
-        sage: print(open(_extract_embedded_position(inspect.getdoc(test_funct))[1]).read())
+        sage: func_doc = inspect.getdoc(test_funct)
+        sage: with open(_extract_embedded_position(func_doc)[1]) as f:
+        ....:     print(f.read())
         cpdef test_funct(x,y): return
 
     Ensure that the embedded filename of the compiled function is correct.  In
     particular it should be relative to ``SPYX_TMP`` in order for certain
-    docmentation functions to work properly.  See :trac:`24097`::
+    documentation functions to work properly.  See :trac:`24097`::
 
         sage: from sage.env import DOT_SAGE
         sage: from sage.misc.sage_ostools import restore_cwd
         sage: with restore_cwd(DOT_SAGE):
         ....:     cython('''cpdef test_funct(x,y): return''')
-        sage: print(open(_extract_embedded_position(inspect.getdoc(test_funct))[1]).read())
+        sage: func_doc = inspect.getdoc(test_funct)
+        sage: with open(_extract_embedded_position(func_doc)[1]) as f:
+        ....:     print(f.read())
         cpdef test_funct(x,y): return
 
     AUTHORS:
@@ -280,8 +286,10 @@ def _extract_embedded_signature(docstring, name):
         ...
         sage: _extract_embedded_signature(MainClass.NestedClass.NestedSubClass.dummy.__doc__, 'dummy')[1]
         ArgSpec(args=['self', 'x', 'r'], varargs='args', keywords='kwds', defaults=((1, 2, 3.4),))
-        sage: _extract_embedded_signature(range.__call__.__doc__, '__call__')
+        sage: _extract_embedded_signature(range.__call__.__doc__, '__call__')  # py2
         ('x.__call__(...) <==> x(...)', None)
+        sage: _extract_embedded_signature(range.__call__.__doc__, '__call__')  # py3
+        ('Call self as a function.', None)
 
     """
     # If there is an embedded signature, it is in the first line
@@ -347,6 +355,7 @@ class BlockFinder:
             # block as well, except the pseudo-tokens COMMENT and NL.
             raise inspect.EndOfBlock
 
+
 def _getblock(lines):
     """
     Extract the block of code at the top of the given list of lines.
@@ -355,12 +364,21 @@ def _getblock(lines):
     it uses an instance of our custom :class:`BlockFinder`.
     """
     blockfinder = BlockFinder()
+    iter_lines = iter(lines)
+    if six.PY2:
+        tokenizer = tokenize.generate_tokens
+        readline = lambda: next(iter_lines)
+    else:
+        tokenizer = tokenize.tokenize
+        readline = lambda: next(iter_lines).encode('utf-8')
     try:
-        tokenize.tokenize(iter(lines).next, blockfinder.tokeneater)
+        for tok in tokenizer(readline):
+            blockfinder.tokeneater(*tok)
     except (inspect.EndOfBlock, IndentationError):
         pass
     return lines[:blockfinder.last]
 
+
 def _extract_source(lines, lineno):
     r"""
     Given a list of lines or a multiline string and a starting lineno,
@@ -407,8 +425,9 @@ class SageArgSpecVisitor(ast.NodeVisitor):
         sage: visitor = sms.SageArgSpecVisitor()
         sage: visitor.visit(ast.parse('[1,2,3]').body[0].value)
         [1, 2, 3]
-        sage: visitor.visit(ast.parse("{'a':('e',2,[None,({False:True},'pi')]), 37.0:'temp'}").body[0].value)
-        {37.0: 'temp', 'a': ('e', 2, [None, ({False: True}, 'pi')])}
+        sage: v = visitor.visit(ast.parse("{'a':('e',2,[None,({False:True},'pi')]), 37.0:'temp'}").body[0].value)
+        sage: sorted(v.items(), key=lambda x: str(x[0]))
+        [(37.0, 'temp'), ('a', ('e', 2, [None, ({False: True}, 'pi')]))]
         sage: v = ast.parse("jc = ['veni', 'vidi', 'vici']").body[0]; v
         <_ast.Assign object at ...>
         sage: [x for x in dir(v) if not x.startswith('__')]
@@ -435,20 +454,83 @@ class SageArgSpecVisitor(ast.NodeVisitor):
             sage: import ast, sage.misc.sageinspect as sms
             sage: visitor = sms.SageArgSpecVisitor()
             sage: vis = lambda x: visitor.visit_Name(ast.parse(x).body[0].value)
-            sage: [vis(n) for n in ['True', 'False', 'None', 'foo', 'bar']]
+            sage: [vis(n) for n in ['True', 'False', 'None', 'foo', 'bar']]  # py2
             [True, False, None, 'foo', 'bar']
-            sage: [type(vis(n)) for n in ['True', 'False', 'None', 'foo', 'bar']]
-            [<... 'bool'>, <... 'bool'>, <... 'NoneType'>, <... 'str'>, <... 'str'>]
+            sage: [type(vis(n)) for n in ['True', 'False', 'None', 'foo', 'bar']]  # py2
+            [<type 'bool'>, <type 'bool'>, <type 'NoneType'>, <type 'str'>, <type 'str'>]
+            sage: [vis(n) for n in ['foo', 'bar']]  # py3
+            ['foo', 'bar']
+            sage: [type(vis(n)) for n in ['foo', 'bar']]  # py3
+            [<type 'str'>, <type 'str'>]
         """
-        what = node.id
-        if what == 'None':
-            return None
-        elif what == 'True':
-            return True
-        elif what == 'False':
-            return False
+        if six.PY2:
+            what = node.id
+            if what == 'None':
+                return None
+            elif what == 'True':
+                return True
+            elif what == 'False':
+                return False
         return node.id
 
+    if six.PY3:
+        def visit_NameConstant(self, node):
+            """
+            Visit a Python AST :class:`ast.NameConstant` node.
+
+            This is an optimization added in Python 3.4 for the special cases
+            of True, False, and None.
+
+            INPUT:
+
+            - ``node`` - the node instance to visit
+
+            OUTPUT:
+
+            - None, True, False.
+
+            EXAMPLES::
+
+                sage: import ast, sage.misc.sageinspect as sms  # py3
+                sage: visitor = sms.SageArgSpecVisitor()  # py3
+                sage: vis = lambda x: visitor.visit_NameConstant(ast.parse(x).body[0].value)  # py3
+                sage: [vis(n) for n in ['True', 'False', 'None']]  # py3
+                [True, False, None]
+                sage: [type(vis(n)) for n in ['True', 'False', 'None']]  # py3
+                [<type 'bool'>, <type 'bool'>, <type 'NoneType'>]
+            """
+
+            return node.value
+
+        def visit_arg(self, node):
+            r"""
+            Visit a Python AST :class:`ast.arg` node.
+
+            This node type is only on Python 3, where function arguments are
+            more complex than just an identifier (e.g. they may also include
+            annotations).
+
+            For now we simply return the argument identifier as a string.
+
+            INPUT:
+
+            - ``node`` -- the node instance to visit
+
+            OUTPUT:
+
+            the argument name
+
+            EXAMPLES::
+
+                sage: import ast, sage.misc.sageinspect as sms  # py3
+                sage: s = "def f(a, b=2, c={'a': [4, 5.5, False]}, d=(None, True)):\n    return"  # py3
+                sage: visitor = sms.SageArgSpecVisitor()  # py3
+                sage: args = ast.parse(s).body[0].args.args  # py3
+                sage: [visitor.visit_arg(n) for n in args]  # py3
+                ['a', 'b', 'c', 'd']
+            """
+            return node.arg
+
     def visit_Num(self, node):
         """
         Visit a Python AST :class:`ast.Num` node.
@@ -466,8 +548,15 @@ class SageArgSpecVisitor(ast.NodeVisitor):
             sage: import ast, sage.misc.sageinspect as sms
             sage: visitor = sms.SageArgSpecVisitor()
             sage: vis = lambda x: visitor.visit_Num(ast.parse(x).body[0].value)
-            sage: [vis(n) for n in ['123', '0.0', str(-pi.n())]]
+            sage: [vis(n) for n in ['123', '0.0', str(-pi.n())]]  # py2
             [123, 0.0, -3.14159265358979]
+            sage: [vis(n) for n in ['123', '0.0']]  # py3
+            [123, 0.0]
+
+        .. NOTE::
+
+            On Python 3 negative numbers are parsed first, for some reason, as
+            a UnaryOp node.
         """
         return node.n
 
@@ -488,7 +577,7 @@ class SageArgSpecVisitor(ast.NodeVisitor):
             sage: import ast, sage.misc.sageinspect as sms
             sage: visitor = sms.SageArgSpecVisitor()
             sage: vis = lambda x: visitor.visit_Str(ast.parse(x).body[0].value)
-            sage: [vis(s) for s in ['"abstract"', "u'syntax'", '''r"tr\ee"''']]
+            sage: [vis(s) for s in ['"abstract"', "u'syntax'", r'''r"tr\ee"''']]
             ['abstract', u'syntax', 'tr\\ee']
         """
         return node.s
@@ -560,8 +649,9 @@ class SageArgSpecVisitor(ast.NodeVisitor):
             sage: import ast, sage.misc.sageinspect as sms
             sage: visitor = sms.SageArgSpecVisitor()
             sage: vis = lambda x: visitor.visit_Dict(ast.parse(x).body[0].value)
-            sage: [vis(d) for d in ['{}', "{1:one, 'two':2, other:bother}"]]
-            [{}, {1: 'one', 'other': 'bother', 'two': 2}]
+            sage: v = [vis(d) for d in ['{}', "{1:one, 'two':2, other:bother}"]]
+            sage: [sorted(d.items(), key=lambda x: str(x[0])) for d in v]
+            [[], [(1, 'one'), ('other', 'bother'), ('two', 2)]]
         """
         d = {}
         for k, v in zip(node.keys, node.values):
@@ -682,6 +772,8 @@ class SageArgSpecVisitor(ast.NodeVisitor):
             sage: vis = lambda x: visitor.visit(ast.parse(x).body[0].value)
             sage: [vis(d) for d in ['(3+(2*4))', '7|8', '5^3', '7/3', '7//3', '3<<4']] #indirect doctest # py2
             [11, 15, 6, 2, 2, 48]
+            sage: [vis(d) for d in ['(3+(2*4))', '7|8', '5^3', '7/3', '7//3', '3<<4']] #indirect doctest # py3
+            [11, 15, 6, 2.3333333333333335, 2, 48]
         """
         op = node.op.__class__.__name__
         if op == 'Add':
@@ -975,13 +1067,18 @@ def _sage_getargspec_from_ast(source):
 
     EXAMPLES::
 
+        sage: import warnings
+        sage: warnings.filterwarnings('ignore',
+        ....:                         r'inspect.getargspec\(\) is deprecated',
+        ....:                         DeprecationWarning)
         sage: import inspect, sage.misc.sageinspect as sms
         sage: from_ast = sms._sage_getargspec_from_ast
         sage: s = "def f(a, b=2, c={'a': [4, 5.5, False]}, d=(None, True)):\n    return"
         sage: from_ast(s)
         ArgSpec(args=['a', 'b', 'c', 'd'], varargs=None, keywords=None, defaults=(2, {'a': [4, 5.5, False]}, (None, True)))
         sage: context = {}
-        sage: exec compile(s, '<string>', 'single') in context
+        sage: exec compile(s, '<string>', 'single') in context  # py2
+        sage: exec(compile(s, '<string>', 'single'), context)  # py3
         sage: inspect.getargspec(context['f'])
         ArgSpec(args=['a', 'b', 'c', 'd'], varargs=None, keywords=None, defaults=(2, {'a': [4, 5.5, False]}, (None, True)))
         sage: from_ast(s) == inspect.getargspec(context['f'])
@@ -995,9 +1092,18 @@ def _sage_getargspec_from_ast(source):
     args = [visitor.visit(a) for a in ast_args.args]
     defaults = [visitor.visit(d) for d in ast_args.defaults]
 
-    return inspect.ArgSpec(args, ast_args.vararg, ast_args.kwarg,
+    if six.PY2:
+        vararg = ast_args.vararg
+        kwarg = ast_args.kwarg
+    else:
+        # vararg and kwarg may be None
+        vararg = getattr(ast_args.vararg, 'arg', None)
+        kwarg = getattr(ast_args.kwarg, 'arg', None)
+
+    return inspect.ArgSpec(args, vararg, kwarg,
                            tuple(defaults) if defaults else None)
 
+
 def _sage_getargspec_cython(source):
     r"""
     inspect.getargspec from source code.  That is, get the names and
@@ -1060,15 +1166,18 @@ def _sage_getargspec_cython(source):
 
     TESTS:
 
-    Some input that is malformed in Python but wellformed in Cython
-    is correctly parsed::
+    Some input that is malformed in Python 2 but well formed in Cython or
+    Python 3 is correctly parsed::
 
-        sage: def dummy_python(self,*args,x=1): pass
+        sage: def dummy_python(self, *args, x=1): pass  # py2
         Traceback (most recent call last):
         ...
         SyntaxError: invalid syntax
-        sage: cython("def dummy_cython(self,*args,x=1): pass")
-        sage: sgc("def dummy_cython(self,*args,x=1): pass")
+        sage: def dummy_python(self, *args, x=1): pass  # py3
+        sage: sgc("def dummy_python(self, *args, x=1): pass")  # py3
+        ArgSpec(args=['self', 'x'], varargs='args', keywords=None, defaults=(1,))
+        sage: cython("def dummy_cython(self, *args, x=1): pass")
+        sage: sgc("def dummy_cython(self, *args, x=1): pass")
         ArgSpec(args=['self', 'x'], varargs='args', keywords=None, defaults=(1,))
 
     In some examples above, a syntax error was raised when a type
@@ -1379,8 +1488,13 @@ def sage_getargspec(obj):
         sage: O = MyClass()
         sage: print(sage.misc.sageinspect.sage_getsource(O))
         def foo(x, a=')"', b={(2+1):'bar', not 1:3, 3<<4:5}): return
-        sage: sage.misc.sageinspect.sage_getargspec(O)
-        ArgSpec(args=['x', 'a', 'b'], varargs=None, keywords=None, defaults=(')"', {False: 3, 48: 5, 3: 'bar'}))
+        sage: spec = sage.misc.sageinspect.sage_getargspec(O)
+        sage: spec.args, spec.varargs, spec.keywords
+        (['x', 'a', 'b'], None, None)
+        sage: spec.defaults[0]
+        ')"'
+        sage: sorted(spec.defaults[1].items(), key=lambda x: str(x))
+        [(3, 'bar'), (48, 5), (False, 3)]
         sage: sage.misc.sageinspect.sage_getargspec(O.__call__)
         ArgSpec(args=['self', 'm', 'n'], varargs=None, keywords=None, defaults=None)
 
@@ -1432,7 +1546,7 @@ def sage_getargspec(obj):
     inspect module does)::
 
         sage: import inspect
-        sage: inspect.getargspec(range)
+        sage: inspect.getargspec(range)  # py2
         Traceback (most recent call last):
         ...
         TypeError: <built-in function range> is not a Python function
@@ -1662,11 +1776,8 @@ def _sage_getdoc_unformatted(obj):
 
     # Check if the __doc__ attribute was actually a string, and
     # not a 'getset_descriptor' or similar.
-    if isinstance(r, str):
+    if isinstance(r, string_types):
         return r
-    elif isinstance(r, text_type):
-        # On Python 2, we want str, not unicode
-        return r.encode('utf-8', 'ignore')
     else:
         # Not a string of any kind
         return ''
@@ -2004,9 +2115,9 @@ def sage_getsourcelines(obj):
 
         sage: from sage.misc.sageinspect import sage_getsourcelines
         sage: sage_getsourcelines(matrix)[1]
-        28
-        sage: sage_getsourcelines(matrix)[0][0][6:]
-        'MatrixFactory(object):\n'
+        22
+        sage: sage_getsourcelines(matrix)[0][0]
+        'def matrix(*args, **kwds):\n'
 
     Some classes customize this using a ``_sage_src_lines_`` method,
     which gives the source lines of a class instance, but not the class
@@ -2016,7 +2127,7 @@ def sage_getsourcelines(obj):
         sage: sage_getsourcelines(cachedfib)[0][0]
         'def fibonacci(n, algorithm="pari"):\n'
         sage: sage_getsourcelines(type(cachedfib))[0][0]
-         'cdef class CachedFunction(object):\n'
+        'cdef class CachedFunction(object):\n'
 
     TESTS::
 
@@ -2040,7 +2151,7 @@ def sage_getsourcelines(obj):
         sage: P.<x,y> = QQ[]
         sage: I = P*[x,y]
         sage: sage_getsourcelines(P)
-        (['cdef class MPolynomialRing_libsingular(MPolynomialRing_generic):\n',
+        (['cdef class MPolynomialRing_libsingular(MPolynomialRing_base):\n',
           '\n',
           '    def __cinit__(self):\n',
         ...)
@@ -2063,9 +2174,12 @@ def sage_getsourcelines(obj):
         sage: from sage.misc.sageinspect import sage_getsource
         sage: P = TestNestedParent()
         sage: E = P.element_class
-        sage: E.__bases__
+        sage: E.__bases__  # py2
         (<class sage.misc.nested_class_test.TestNestedParent.Element at ...>,
          <class 'sage.categories.sets_cat.Sets.element_class'>)
+        sage: E.__bases__  # py3
+        (<class 'sage.misc.nested_class_test.TestNestedParent.Element'>,
+         <class 'sage.categories.sets_cat.Sets.element_class'>)
         sage: print(sage_getsource(E))
             class Element:
                 "This is a dummy element class"
@@ -2134,11 +2248,10 @@ def sage_getsourcelines(obj):
 
     # First, we deal with nested classes. Their name contains a dot, and we
     # have a special function for that purpose.
-    if (not hasattr(obj, '__class__')) or (isinstance(obj, type) and type(obj) is not type):
-        # That happens for ParentMethods
-        # of categories
-        if '.' in obj.__name__ or '.' in getattr(obj,'__qualname__',''):
-            return _sage_getsourcelines_name_with_dot(obj)
+    # This is the case for ParentMethods of categories, for example.
+    if (inspect.isclass(obj) and
+            ('.' in obj.__name__ or '.' in getattr(obj, '__qualname__', ''))):
+        return _sage_getsourcelines_name_with_dot(obj)
 
     # Next, we try _sage_getdoc_unformatted()
     d = _sage_getdoc_unformatted(obj)
@@ -2172,13 +2285,15 @@ def sage_getsourcelines(obj):
 
     (orig, filename, lineno) = pos
     try:
-        source_lines = open(filename).readlines()
+        with open(filename) as f:
+            source_lines = f.readlines()
     except IOError:
         try:
             from sage.misc.misc import SPYX_TMP
             raw_name = filename.split('/')[-1]
             newname = os.path.join(SPYX_TMP, '_'.join(raw_name.split('_')[:-1]), raw_name)
-            source_lines = open(newname).readlines()
+            with open(newname) as f:
+                source_lines = f.readlines()
         except IOError:
             return None
 
