@@ -142,7 +142,7 @@ def warning(trac_number, message, warning_class=Warning, stacklevel=3):
         message += 'See http://trac.sagemath.org/'+ str(trac_number) + ' for details.'
     else:
         message += 'See https://trac.sagemath.org/'+ str(trac_number) + ' for details.'
-        
+
     # Stack level 3 to get the line number of the code which called
     # the deprecated function which called this function.
     warn(message, warning_class, stacklevel)
@@ -298,7 +298,7 @@ class __experimental_self_test(SageObject):
     already been issued by a previous doc-test in the @experimental code. Note
     that this behaviour can not be demonstrated within a single documentation
     string: Sphinx will itself supress multiple issued warnings.
-    
+
     TESTS::
 
         sage: from sage.misc.superseded import __experimental_self_test
@@ -312,16 +312,15 @@ class __experimental_self_test(SageObject):
 
 class DeprecatedFunctionAlias(object):
     """
-    A wrapper around methods or functions which automatically print
-    the correct deprecation message. See
-    :func:`deprecated_function_alias`.
+    A wrapper around methods or functions which automatically prints a
+    deprecation message. See :func:`deprecated_function_alias`.
 
     AUTHORS:
 
     - Florent Hivert (2009-11-23), with the help of Mike Hansen.
     - Luca De Feo (2011-07-11), printing the full module path when different from old path
     """
-    def __init__(self, trac_number, func, module, instance = None, unbound = None):
+    def __init__(self, trac_number, func, module, instance=None, unbound=None):
         r"""
         TESTS::
 
@@ -421,7 +420,8 @@ class DeprecatedFunctionAlias(object):
             other = self.func.__name__
 
         deprecation(self.trac_number,
-                    "%s is deprecated. Please use %s instead."%(self.__name__, other))
+                    "{} is deprecated. Please use {} instead.".format(
+                        self.__name__, other))
         if self.instance is None:
             return self.func(*args, **kwds)
         else:
@@ -458,12 +458,18 @@ class DeprecatedFunctionAlias(object):
             3
 
         """
-        return self if (inst is None) else DeprecatedFunctionAlias(self.trac_number, self.func, self.__module__, instance = inst, unbound = self)
+        if inst is None:
+            return self  # Unbound method lookup on class
+        else:
+            # Return a bound method wrapper
+            return DeprecatedFunctionAlias(self.trac_number, self.func,
+                                           self.__module__, instance=inst,
+                                           unbound=self)
 
 
 def deprecated_function_alias(trac_number, func):
     """
-    Create an aliased version of a function or a method which raise a
+    Create an aliased version of a function or a method which raises a
     deprecation warning message.
 
     If f is a function or a method, write
@@ -509,9 +515,12 @@ def deprecated_function_alias(trac_number, func):
      - Florent Hivert (2009-11-23), with the help of Mike Hansen.
      - Luca De Feo (2011-07-11), printing the full module path when different from old path
     """
-    _check_trac_number(trac_number)
-    frame1 = inspect.getouterframes(inspect.currentframe())[1][0]
-    module_name = inspect.getmodulename(frame1.f_code.co_filename)
+    module_name = None
+    frame0 = inspect.currentframe()
+    if frame0:
+        frame1 = frame0.f_back
+        if frame1:
+            module_name = inspect.getmodulename(frame1.f_code.co_filename)
     if module_name is None:
         module_name = '__main__'
     return DeprecatedFunctionAlias(trac_number, func, module_name)
