@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 Temporary file handling
 
@@ -21,9 +22,12 @@ AUTHORS:
 #*****************************************************************************
 from __future__ import print_function
 
+import io
 import os
 import tempfile
 import atexit
+import six
+
 
 def delete_tmpfiles():
     """
@@ -84,12 +88,13 @@ def tmp_dir(name="dir_", ext=""):
         sage: d   # random output
         '/home/username/.sage/temp/hostname/7961/dir_testing_XgRu4p.extension/'
         sage: os.chdir(d)
-        sage: _ = open('file_inside_d', 'w')
+        sage: f = open('file_inside_d', 'w')
 
     Temporary directories are unaccessible by other users::
 
         sage: os.stat(d).st_mode & 0o077
         0
+        sage: f.close()
     """
     from sage.misc.misc import SAGE_TMP
     tmp = tempfile.mkdtemp(prefix=name, suffix=ext, dir=str(SAGE_TMP))
@@ -133,12 +138,13 @@ def tmp_filename(name="tmp_", ext=""):
         sage: fn = tmp_filename('just_for_testing_', '.extension')
         sage: fn  # random
         '/home/username/.sage/temp/hostname/8044/just_for_testing_tVVHsn.extension'
-        sage: _ = open(fn, 'w')
+        sage: f = open(fn, 'w')
 
     Temporary files are unaccessible by other users::
 
         sage: os.stat(fn).st_mode & 0o077
         0
+        sage: f.close()
     """
     from sage.misc.misc import SAGE_TMP
     handle, tmp = tempfile.mkstemp(prefix=name, suffix=ext, dir=str(SAGE_TMP))
@@ -203,7 +209,7 @@ def graphics_filename(ext='.png'):
 #################################################################
 # write to a temporary file and move it in place
 #################################################################
-class atomic_write:
+class atomic_write(object):
     """
     Write to a given file using a temporary file and then rename it
     to the target file. This renaming should be atomic on modern
@@ -230,19 +236,30 @@ class atomic_write:
     - ``mode`` -- (default: ``0o666``) mode bits for the file. The
       temporary file is created with mode ``mode & ~umask`` and the
       resulting file will also have these permissions (unless the
-      mode bits of the file were changed manually).
+      mode bits of the file were changed manually). (Not to be confused with
+      the file opening mode.)
+
+    - ``binary`` -- (boolean, default: True on Python 2, False on Python 3) the
+      underlying file is opened in binary mode.  If False then it is opened in
+      text mode and an encoding with which to write the file may be supplied.
+
+    - ``**kwargs`` -- additional keyword arguments passed to the underlying
+      `io.open` call.
 
     EXAMPLES::
 
         sage: from sage.misc.temporary_file import atomic_write
         sage: target_file = tmp_filename()
-        sage: _ = open(target_file, "w").write("Old contents")
+        sage: with open(target_file, 'w') as f:
+        ....:     _ = f.write("Old contents")
         sage: with atomic_write(target_file) as f:
         ....:     _ = f.write("New contents")
         ....:     f.flush()
-        ....:     open(target_file, "r").read()
+        ....:     with open(target_file, 'r') as f2:
+        ....:         f2.read()
         'Old contents'
-        sage: open(target_file, "r").read()
+        sage: with open(target_file, 'r') as f:
+        ....:     f.read()
         'New contents'
 
     The name of the temporary file can be accessed using ``f.name``.
@@ -250,11 +267,14 @@ class atomic_write:
 
         sage: from sage.misc.temporary_file import atomic_write
         sage: target_file = tmp_filename()
-        sage: _ = open(target_file, "w").write("Old contents")
+        sage: with open(target_file, 'w') as f:
+        ....:     _ = f.write("Old contents")
         sage: with atomic_write(target_file) as f:
         ....:     f.close()
-        ....:     _ = open(f.name, "w").write("Newer contents")
-        sage: open(target_file, "r").read()
+        ....:     with open(f.name, 'w') as f2:
+        ....:         _ = f2.write("Newer contents")
+        sage: with open(target_file, 'r') as f:
+        ....:     f.read()
         'Newer contents'
 
     If an exception occurs while writing the file, the target file is
@@ -266,7 +286,8 @@ class atomic_write:
         Traceback (most recent call last):
         ...
         RuntimeError
-        sage: open(target_file, "r").read()
+        sage: with open(target_file, 'r') as f:
+        ....:     f.read()
         'Newer contents'
 
     Some examples of using the ``append`` option. Note that the file
@@ -278,12 +299,14 @@ class atomic_write:
         ....:     _ = f.write("Hello")
         sage: with atomic_write(target_file, append=True) as f:
         ....:     _ = f.write(" World")
-        sage: open(target_file, "r").read()
+        sage: with open(target_file, 'r') as f:
+        ....:     f.read()
         'Hello World'
         sage: with atomic_write(target_file, append=True) as f:
-        ....:     f.seek(0)
+        ....:     _ = f.seek(0)
         ....:     _ = f.write("HELLO")
-        sage: open(target_file, "r").read()
+        sage: with open(target_file, 'r') as f:
+        ....:     f.read()
         'HELLO World'
 
     If the target file is a symbolic link, the link is kept and the
@@ -293,7 +316,8 @@ class atomic_write:
         sage: os.symlink(target_file, link_to_target)
         sage: with atomic_write(link_to_target) as f:
         ....:     _ = f.write("Newest contents")
-        sage: open(target_file, "r").read()
+        sage: with open(target_file, 'r') as f:
+        ....:     f.read()
         'Newest contents'
 
     We check the permission bits of the new file. Note that the old
@@ -303,26 +327,54 @@ class atomic_write:
         sage: _ = os.umask(0o022)
         sage: with atomic_write(target_file) as f:
         ....:     pass
-        sage: oct(os.stat(target_file).st_mode & 0o777)
-        '644'
+        sage: '{:#o}'.format(os.stat(target_file).st_mode & 0o777)
+        '0o644'
         sage: _ = os.umask(0o077)
         sage: with atomic_write(target_file, mode=0o777) as f:
         ....:     pass
-        sage: oct(os.stat(target_file).st_mode & 0o777)
-        '700'
+        sage: '{:#o}'.format(os.stat(target_file).st_mode & 0o777)
+        '0o700'
 
     Test writing twice to the same target file. The outermost ``with``
     "wins"::
 
-        sage: _ = open(target_file, "w").write(">>> ")
+        sage: with open(target_file, 'w') as f:
+        ....:     _ = f.write('>>> ')
         sage: with atomic_write(target_file, append=True) as f, \
         ....:          atomic_write(target_file, append=True) as g:
         ....:     _ = f.write("AAA"); f.close()
         ....:     _ = g.write("BBB"); g.close()
-        sage: open(target_file, "r").read()
+        sage: with open(target_file, 'r') as f:
+        ....:     f.read()
         '>>> AAA'
+
+    Supplying an encoding means we're writing the file in "text mode" (in the
+    same sense as `io.open`) and so we must write unicode strings::
+
+        sage: target_file = tmp_filename()
+        sage: with atomic_write(target_file, binary=False,
+        ....:                   encoding='utf-8') as f:
+        ....:     _ = f.write(u'Hélas')
+        sage: import io
+        sage: with io.open(target_file, encoding='utf-8') as f:
+        ....:     print(f.read())
+        Hélas
+
+    Supplying an encoding in binary mode (or other arguments that don't
+    make sense to `io.open` in binary mode) is an error::
+
+        sage: writer = atomic_write(target_file, binary=True,
+        ....:                       encoding='utf-8')
+        sage: with writer as f:
+        ....:     _ = f.write(u'Hello')
+        Traceback (most recent call last):
+        ...
+        ValueError: binary mode doesn't take an encoding argument
+        sage: os.path.exists(writer.tempname)
+        False
     """
-    def __init__(self, target_filename, append=False, mode=0o666):
+    def __init__(self, target_filename, append=False, mode=0o666,
+                 binary=None, **kwargs):
         """
         TESTS::
 
@@ -342,6 +394,12 @@ class atomic_write:
         umask = os.umask(0); os.umask(umask)
         self.mode = mode & (~umask)
 
+        # 'binary' mode is the default on Python 2, whereas 'text' mode is the
+        # default on Python 3--this reflects consistent handling of the default
+        # str type on the two platforms
+        self.binary = six.PY2 if binary is None else binary
+        self.kwargs = kwargs
+
     def __enter__(self):
         """
         Create and return a temporary file in ``self.tmpdir`` (normally
@@ -360,16 +418,32 @@ class atomic_write:
             ....:     os.path.dirname(aw.target) == os.path.dirname(f.name)
             True
         """
-        self.tempfile = tempfile.NamedTemporaryFile(dir=self.tmpdir, delete=False)
-        self.tempname = self.tempfile.name
-        os.chmod(self.tempname, self.mode)
+
+        fd, name = tempfile.mkstemp(dir=self.tmpdir)
+        self.tempname = os.path.abspath(name)
+
+        rmode = 'r' + ('b' if self.binary else '')
+        wmode = 'w+' + ('b' if self.binary else '')
+
+        try:
+            self.tempfile = io.open(name, wmode, **self.kwargs)
+        except Exception:
+            # Some invalid arguments were passed to io.open
+            os.unlink(name)
+            raise
+        finally:
+            os.close(fd)
+
+        os.chmod(name, self.mode)
         if self.append:
             try:
-                r = open(self.target).read()
+                with io.open(self.target, rmode, **self.kwargs) as f:
+                    r = f.read()
             except IOError:
                 pass
             else:
                 self.tempfile.write(r)
+
         return self.tempfile
 
     def __exit__(self, exc_type, exc_val, exc_tb):
