@@ -9,8 +9,10 @@ from __future__ import print_function
 
 from sage.structure.sage_object import SageObject
 from sage.structure.unique_representation import UniqueRepresentation
+from sage.structure.richcmp import richcmp_method, rich_to_bool
 
 
+@richcmp_method
 class UnknownClass(UniqueRepresentation, SageObject):
     """
     TESTS::
@@ -58,7 +60,7 @@ class UnknownClass(UniqueRepresentation, SageObject):
 
     def __bool__(self):
         """
-        When evaluated in a boolean context ``Unknown()`` is evalutated into
+        When evaluated in a boolean context ``Unknown()`` is evaluated into
         ``False``.
 
         EXAMPLES::
@@ -94,8 +96,10 @@ class UnknownClass(UniqueRepresentation, SageObject):
             sage: Unknown and False    # should return False
             Unknown
         """
-        if other is False: return False
-        else:              return self
+        if other is False:
+            return False
+        else:
+            return self
 
     def __or__(self, other):
         """
@@ -119,8 +123,10 @@ class UnknownClass(UniqueRepresentation, SageObject):
             sage: Unknown or False    # should return Unknown
             False
         """
-        if other: return True
-        else:     return self
+        if other:
+            return True
+        else:
+            return self
 
     def __not__(self):
         """
@@ -142,7 +148,7 @@ class UnknownClass(UniqueRepresentation, SageObject):
         """
         return self
 
-    def __cmp__(self, other):
+    def __richcmp__(self, other, op):
         """
         Comparison of truth value.
 
@@ -160,13 +166,13 @@ class UnknownClass(UniqueRepresentation, SageObject):
             [False, False, True]
         """
         if other is self:
-            return 0
-        if isinstance(other, bool):
-            if other:
-                return -1
-            else:
-                return +1
+            return rich_to_bool(op, 0)
+        if not isinstance(other, bool):
+            return NotImplemented
+        if other:
+            return rich_to_bool(op, -1)
         else:
-            raise ValueError("Unable to compare {} with {}".format(self, other))
+            return rich_to_bool(op, +1)
+
 
 Unknown = UnknownClass()
