@@ -13,7 +13,7 @@ EXAMPLES::
     Infinity
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2005 William Stein <wstein@gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
@@ -25,171 +25,21 @@ EXAMPLES::
 #
 #  The full text of the GPL is available at:
 #
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from __future__ import print_function
 from six import integer_types
 
 from sage.rings.all import Rational, Integer, ZZ, QQ
-from sage.rings.infinity import is_Infinite, Infinity
+from sage.rings.infinity import Infinity, InfinityRing
 
-from sage.structure.parent_base import ParentWithBase
+from sage.structure.parent import Parent
+from sage.misc.fast_methods import Singleton
 from sage.structure.element import Element, is_InfinityElement
 from sage.structure.richcmp import richcmp
 
 from sage.modular.modsym.p1list import lift_to_sl2z_llong
 from sage.structure.element import is_Matrix
-from sage.misc.cachefunc import cached_method
-from sage.misc.superseded import deprecated_function_alias
-
-
-class Cusps_class(ParentWithBase):
-    """
-    The set of cusps.
-
-    EXAMPLES::
-
-        sage: C = Cusps; C
-        Set P^1(QQ) of all cusps
-        sage: loads(C.dumps()) == C
-        True
-    """
-    def __init__(self):
-        r"""
-        The set of cusps, i.e. `\mathbb{P}^1(\QQ)`.
-
-        EXAMPLES::
-
-            sage: C = sage.modular.cusps.Cusps_class() ; C
-            Set P^1(QQ) of all cusps
-            sage: Cusps == C
-            True
-        """
-        ParentWithBase.__init__(self, self)
-
-    def __eq__(self, right):
-        """
-        Return equality only if ``right`` is the set of cusps.
-
-        EXAMPLES::
-
-            sage: Cusps == Cusps
-            True
-            sage: Cusps == QQ
-            False
-        """
-        return isinstance(right, Cusps_class)
-
-    def __ne__(self, right):
-        """
-        Check that ``self`` is not equal to ``right``.
-
-        EXAMPLES::
-
-            sage: Cusps != Cusps
-            False
-            sage: Cusps != QQ
-            True
-        """
-        return not (self == right)
-
-    def _repr_(self):
-        """
-        String representation of the set of cusps.
-
-        EXAMPLES::
-
-            sage: Cusps
-            Set P^1(QQ) of all cusps
-            sage: Cusps._repr_()
-            'Set P^1(QQ) of all cusps'
-            sage: Cusps.rename('CUSPS'); Cusps
-            CUSPS
-            sage: Cusps.rename(); Cusps
-            Set P^1(QQ) of all cusps
-            sage: Cusps
-            Set P^1(QQ) of all cusps
-        """
-        return "Set P^1(QQ) of all cusps"
-
-    def _latex_(self):
-        """
-        Return latex representation of self.
-
-        EXAMPLES::
-
-            sage: latex(Cusps)
-            \mathbf{P}^1(\QQ)
-            sage: latex(Cusps) == Cusps._latex_()
-            True
-        """
-        return "\\mathbf{P}^1(\\QQ)"
-
-    def __call__(self, x):
-        """
-        Coerce x into the set of cusps.
-
-        EXAMPLES::
-
-            sage: a = Cusps(-4/5); a
-            -4/5
-            sage: Cusps(a) is a
-            False
-            sage: Cusps(1.5)
-            3/2
-            sage: Cusps(oo)
-            Infinity
-            sage: Cusps(I)
-            Traceback (most recent call last):
-            ...
-            TypeError: unable to convert I to a cusp
-        """
-        return Cusp(x, parent=self)
-
-    def _coerce_impl(self, x):
-        """
-        Canonical coercion of x into the set of cusps.
-
-        EXAMPLES::
-
-            sage: Cusps._coerce_(7/13)
-            7/13
-            sage: Cusps._coerce_(GF(7)(3))
-            Traceback (most recent call last):
-            ...
-            TypeError: no canonical coercion of element into self
-            sage: Cusps(GF(7)(3))
-            3
-            sage: Cusps._coerce_impl(GF(7)(3))
-            Traceback (most recent call last):
-            ...
-            TypeError: no canonical coercion of element into self
-        """
-        if is_Infinite(x):
-            return Cusp(x, parent=self)
-        else:
-            return self._coerce_try(x, QQ)
-
-    @cached_method
-    def zero(self):
-        """
-        Return the zero cusp.
-
-        .. NOTE::
-
-            The existence of this method is assumed by some
-            parts of Sage's coercion model.
-
-        EXAMPLES::
-
-            sage: Cusps.zero()
-            0
-        """
-        return Cusp(0, parent=self)
-
-    zero_element = deprecated_function_alias(17694, zero)
-
-Cusps = Cusps_class()
 
 
 class Cusp(Element):
@@ -526,7 +376,7 @@ class Cusp(Element):
             pass
 
         if not self.__b:
-            raise TypeError("cusp %s is not a rational number"%self)
+            raise TypeError("cusp %s is not a rational number" % self)
         self.__rational = self.__a / self.__b
         return self.__rational
 
@@ -553,7 +403,7 @@ class Cusp(Element):
             TypeError: cusp -3/7 is not an integer
         """
         if self.__b != 1:
-            raise TypeError("cusp %s is not an integer"%self)
+            raise TypeError("cusp %s is not an integer" % self)
         return self.__a
 
     def _repr_(self):
@@ -572,7 +422,7 @@ class Cusp(Element):
         if self.__b.is_zero():
             return "Infinity"
         if self.__b != 1:
-            return "%s/%s" % (self.__a,self.__b)
+            return "%s/%s" % (self.__a, self.__b)
         else:
             return str(self.__a)
 
@@ -592,7 +442,7 @@ class Cusp(Element):
         if self.__b.is_zero():
             return "\\infty"
         if self.__b != 1:
-            return "\\frac{%s}{%s}" % (self.__a,self.__b)
+            return "\\frac{%s}{%s}" % (self.__a, self.__b)
         else:
             return str(self.__a)
 
@@ -609,7 +459,7 @@ class Cusp(Element):
         """
         return Cusp(-self.__a, self.__b)
 
-    def is_gamma0_equiv(self, other, N, transformation = None):
+    def is_gamma0_equiv(self, other, N, transformation=None):
         r"""
         Return whether self and other are equivalent modulo the action of
         `\Gamma_0(N)` via linear fractional transformations.
@@ -663,7 +513,7 @@ class Cusp(Element):
         ALGORITHM: See Proposition 2.2.3 of Cremona's book 'Algorithms for
         Modular Elliptic Curves', or Prop 2.27 of Stein's Ph.D. thesis.
         """
-        if transformation not in [False,True,"matrix",None,"corner"]:
+        if transformation not in [False, True, "matrix", None, "corner"]:
             raise ValueError("Value %s of the optional argument transformation is not valid.")
 
         if not isinstance(other, Cusp):
@@ -680,14 +530,11 @@ class Cusp(Element):
         if transformation == "matrix":
             from sage.matrix.constructor import matrix
 
-        #if transformation :
-        #    transformation = "corner"
-
         if v1 == v2 and u1 == u2:
             if not transformation:
                 return True
             elif transformation == "matrix":
-                return True, matrix(ZZ,[[1,0],[0,1]])
+                return True, matrix(ZZ, [[1, 0], [0, 1]])
             else:
                 return True, one
 
@@ -698,23 +545,23 @@ class Cusp(Element):
             else:
                 return False, None
 
-        if (u1,v1) != (zero,one):
+        if (u1, v1) != (zero, one):
             if v1 in [zero, one]:
                 s1 = one
             else:
                 s1 = u1.inverse_mod(v1)
         else:
             s1 = 0
-        if (u2,v2) != (zero, one):
-            if v2 in [zero,one]:
+        if (u2, v2) != (zero, one):
+            if v2 in [zero, one]:
                 s2 = one
             else:
                 s2 = u2.inverse_mod(v2)
         else:
             s2 = zero
-        g = (v1*v2).gcd(N)
-        a = s1*v2 - s2*v1
-        if a%g != 0:
+        g = (v1 * v2).gcd(N)
+        a = s1 * v2 - s2 * v1
+        if a % g != 0:
             if not transformation:
                 return False
             else:
@@ -725,25 +572,25 @@ class Cusp(Element):
 
         # Now we know the cusps are equivalent.  Use the proof of Prop 2.2.3
         # of Cremona to find a matrix in Gamma_0(N) relating them.
-        if v1 == 0: # the first is oo
-            if v2 == 0: # both are oo
+        if v1 == 0:  # the first is oo
+            if v2 == 0:  # both are oo
                 if transformation == "matrix":
-                    return (True, matrix(ZZ,[[1,0],[0,1]]))
+                    return (True, matrix(ZZ, [[1, 0], [0, 1]]))
                 else:
                     return (True, one)
             else:
                 dum, s2, r2 = u2.xgcd(-v2)
                 assert dum.is_one()
-                if transformation ==  "matrix":
-                    return (True, matrix(ZZ, [[u2,r2],[v2,s2]]) )
+                if transformation == "matrix":
+                    return (True, matrix(ZZ, [[u2, r2], [v2, s2]]))
                 else:
                     return (True, u2)
 
-        elif v2 == 0: # the second is oo
+        elif v2 == 0:  # the second is oo
             dum, s1, r1 = u1.xgcd(-v1)
             assert dum.is_one()
             if transformation == "matrix":
-                return (True, matrix(ZZ, [[s1,-r1],[-v1,u1]]) )
+                return (True, matrix(ZZ, [[s1, -r1], [-v1, u1]]))
             else:
                 return (True, s1)
 
@@ -751,46 +598,46 @@ class Cusp(Element):
         assert dum.is_one()
         dum, s1, r1 = u1.xgcd(-v1)
         assert dum.is_one()
-        a = s1*v2 - s2*v1
-        assert (a%g).is_zero()
+        a = s1 * v2 - s2 * v1
+        assert (a % g).is_zero()
         # solve x*v1*v2 + a = 0 (mod N).
-        d,x0,y0 = (v1*v2).xgcd(N)          # x0*v1*v2 + y0*N = d = g.
+        d, x0, y0 = (v1 * v2).xgcd(N)          # x0*v1*v2 + y0*N = d = g.
         # so x0*v1*v2 - g = 0 (mod N)
-        x = -x0 * ZZ(a/g)
+        x = -x0 * ZZ(a / g)
         # now  x*v1*v2 + a = 0 (mod N)
 
         # the rest is all added in trac #10926
-        s1p = s1+x*v1
-        M = N//g
+        s1p = s1 + x * v1
+        M = N // g
 
         if transformation == "matrix":
-            C = s1p*v2 - s2*v1
-            if C % (M*v1*v2) == 0 :
-                k = - C//(M*v1*v2)
+            C = s1p * v2 - s2 * v1
+            if C % (M * v1 * v2) == 0:
+                k = - C // (M * v1 * v2)
             else:
-                k = - (C/(M*v1*v2)).round()
+                k = - (C / (M * v1 * v2)).round()
 
-            s1pp = s1p + k *M* v1
+            s1pp = s1p + k * M * v1
             # C += k*M*v1*v2  # is now the smallest in absolute value
-            C = s1pp*v2 - s2*v1
-            A = u2*s1pp - r2*v1
+            C = s1pp * v2 - s2 * v1
+            A = u2 * s1pp - r2 * v1
 
-            r1pp = r1 + (x+k*M)*u1
+            r1pp = r1 + (x + k * M) * u1
             B = r2 * u1 - r1pp * u2
             D = s2 * u1 - r1pp * v2
 
-            ga = matrix(ZZ, [[A,B],[C,D]])
+            ga = matrix(ZZ, [[A, B], [C, D]])
             assert ga.det() == 1
             assert C % N == 0
-            assert (A*u1 + B*v1)/(C*u1+D*v1) == u2/v2
+            assert (A * u1 + B * v1) / (C * u1 + D * v1) == u2 / v2
             return (True, ga)
 
         else:
             # mainly for backwards compatibility and
             # for how it is used in modular symbols
-            A = (u2*s1p - r2*v1)
+            A = (u2 * s1p - r2 * v1)
             if u2 != 0 and v1 != 0:
-                A = A % (u2*v1*M)
+                A = A % (u2 * v1 * M)
             return (True, A)
 
     def is_gamma1_equiv(self, other, N):
@@ -847,14 +694,14 @@ class Cusp(Element):
         u2 = other.__a
         v2 = other.__b
         g = v1.gcd(N)
-        if ((v2 - v1) % N == 0 and (u2 - u1) % g== 0):
+        if ((v2 - v1) % N == 0 and (u2 - u1) % g == 0):
             return True, 1
-        elif ((v2 + v1) % N == 0 and (u2 + u1) % g== 0):
+        elif ((v2 + v1) % N == 0 and (u2 + u1) % g == 0):
             return True, -1
         return False, 0
 
     def is_gamma_h_equiv(self, other, G):
-        """
+        r"""
         Return a pair (b, t), where b is True or False as self and other
         are equivalent under the action of G, and t is 1 or -1, as
         described below.
@@ -935,8 +782,8 @@ class Cusp(Element):
         g = v1.gcd(N)
 
         for h in H:
-            v_tmp = (h*v1) % N
-            u_tmp = (h*u2) % N
+            v_tmp = (h * v1) % N
+            u_tmp = (h * u2) % N
             if (v_tmp - v2) % N == 0 and (u_tmp - u1) % g == 0:
                 return True, 1
             if (v_tmp + v2) % N == 0 and (u_tmp + u1) % g == 0:
@@ -945,7 +792,7 @@ class Cusp(Element):
 
     def _acted_upon_(self, g, self_on_left):
         r"""
-        Implements the left action of `SL_2(\ZZ)` on self.
+        Implement the left action of `SL_2(\ZZ)` on self.
 
         EXAMPLES::
 
@@ -975,10 +822,10 @@ class Cusp(Element):
         """
         if not self_on_left:
             if (is_Matrix(g) and g.base_ring() is ZZ
-                    and g.ncols() == 2 and g.nrows() == 2):
+                    and g.ncols() == 2 == g.nrows()):
                 a, b, c, d = g.list()
-                return Cusp(a*self.__a + b*self.__b, c*self.__a + d*self.__b)
-
+                return Cusp(a * self.__a + b * self.__b,
+                            c * self.__a + d * self.__b)
 
     def apply(self, g):
         """
@@ -994,7 +841,8 @@ class Cusp(Element):
             sage: Cusp(0).apply([1,-3,0,1])
             -3
         """
-        return Cusp(g[0]*self.__a + g[1]*self.__b, g[2]*self.__a + g[3]*self.__b)
+        return Cusp(g[0] * self.__a + g[1] * self.__b,
+                    g[2] * self.__a + g[3] * self.__b)
 
     def galois_action(self, t, N):
         r"""
@@ -1008,17 +856,15 @@ class Cusp(Element):
         action of Galois for a congruence group `G` of level `N` is compatible
         with the action of the full congruence group `\Gamma(N)`.
 
-
         INPUT:
 
-           - `t` -- integer that is coprime to N
+        - `t` -- integer that is coprime to N
 
-           - `N` -- positive integer (level)
+        - `N` -- positive integer (level)
 
         OUTPUT:
 
-           - a cusp
-
+        - a cusp
 
         .. WARNING::
 
@@ -1078,8 +924,8 @@ class Cusp(Element):
         Here we check that the Galois action is indeed a permutation on the
         cusps of Gamma1(48) and check that :trac:`13253` is fixed. ::
 
-            sage: G=Gamma1(48)
-            sage: C=G.cusps()
+            sage: G = Gamma1(48)
+            sage: C = G.cusps()
             sage: for i in Integers(48).unit_gens():
             ....:   C_permuted = [G.reduce_cusp(c.galois_action(i,48)) for c in C]
             ....:   assert len(set(C_permuted))==len(C)
@@ -1094,17 +940,19 @@ class Cusp(Element):
 
         REFERENCES:
 
-            - Section 1.3 of Glenn Stevens, "Arithmetic on Modular Curves"
+        - Section 1.3 of Glenn Stevens, "Arithmetic on Modular Curves"
 
-            - There is a long comment about our algorithm in the source code for this function.
+        - There is a long comment about our algorithm in the source code for this function.
 
         AUTHORS:
 
-            - William Stein, 2009-04-18
+        - William Stein, 2009-04-18
 
         """
-        if self.is_infinity(): return self
-        if not isinstance(t, Integer): t = Integer(t)
+        if self.is_infinity():
+            return self
+        if not isinstance(t, Integer):
+            t = Integer(t)
 
         # Our algorithm for computing the Galois action works as
         # follows (see Section 1.3 of Glenn Stevens "Arithmetic on
@@ -1131,9 +979,112 @@ class Cusp(Element):
         a = self.__a
         b = self.__b * t.inverse_mod(N)
         if b.gcd(a) != 1:
-            _,_,a,b = lift_to_sl2z_llong(a,b,N)
-            a = Integer(a); b = Integer(b)
+            _, _, a, b = lift_to_sl2z_llong(a, b, N)
+            a = Integer(a)
+            b = Integer(b)
 
         # Now that we've computed the Galois action, we efficiently
         # construct the corresponding cusp as a Cusp object.
-        return Cusp(a,b,check=False)
+        return Cusp(a, b, check=False)
+
+
+class Cusps_class(Singleton, Parent):
+    """
+    The set of cusps.
+
+    EXAMPLES::
+
+        sage: C = Cusps; C
+        Set P^1(QQ) of all cusps
+        sage: loads(C.dumps()) == C
+        True
+    """
+    def __init__(self):
+        r"""
+        The set of cusps, i.e. `\mathbb{P}^1(\QQ)`.
+
+        EXAMPLES::
+
+            sage: C = sage.modular.cusps.Cusps_class() ; C
+            Set P^1(QQ) of all cusps
+            sage: Cusps == C
+            True
+        """
+        Parent.__init__(self, self)
+
+    Element = Cusp
+
+    def _repr_(self):
+        """
+        String representation of the set of cusps.
+
+        EXAMPLES::
+
+            sage: Cusps
+            Set P^1(QQ) of all cusps
+            sage: Cusps._repr_()
+            'Set P^1(QQ) of all cusps'
+            sage: Cusps.rename('CUSPS'); Cusps
+            CUSPS
+            sage: Cusps.rename(); Cusps
+            Set P^1(QQ) of all cusps
+            sage: Cusps
+            Set P^1(QQ) of all cusps
+        """
+        return "Set P^1(QQ) of all cusps"
+
+    def _latex_(self):
+        r"""
+        Return latex representation of self.
+
+        EXAMPLES::
+
+            sage: latex(Cusps)
+            \mathbf{P}^1(\QQ)
+            sage: latex(Cusps) == Cusps._latex_()
+            True
+        """
+        return r"\mathbf{P}^1(\QQ)"
+
+    def __call__(self, x):
+        """
+        Coerce x into the set of cusps.
+
+        EXAMPLES::
+
+            sage: a = Cusps(-4/5); a
+            -4/5
+            sage: Cusps(a) is a
+            False
+            sage: Cusps(1.5)
+            3/2
+            sage: Cusps(oo)
+            Infinity
+            sage: Cusps(I)
+            Traceback (most recent call last):
+            ...
+            TypeError: unable to convert I to a cusp
+
+        TESTS::
+
+            sage: Cusps.has_coerce_map_from(ZZ)
+            True
+            sage: Cusps.has_coerce_map_from(QQ)
+            True
+            sage: Cusps.has_coerce_map_from(GF(7))
+            False
+        """
+        return Cusp(x)
+
+    def _coerce_map_from_(self, R):
+        if QQ.has_coerce_map_from(R):
+            return True
+        if R is InfinityRing:
+            return True
+        return False
+
+    def _element_constructor_(self, x):
+        return Cusp(x)
+
+
+Cusps = Cusps_class()
