@@ -34,10 +34,10 @@ Different operations with cusps over a number field::
     7
     sage: alpha.ideal()
     Fractional ideal (7, a + 3)
-    sage: alpha.ABmatrix()
+    sage: M = alpha.ABmatrix(); M # random
     [a + 10, 2*a + 6, 7, a + 5]
-    sage: alpha.apply([0, 1, -1,0])
-    Cusp [7: -a - 10] of Number Field in a with defining polynomial x^2 + 5
+    sage: NFCusp(k, oo).apply(M)
+    Cusp [a + 10: 7] of Number Field in a with defining polynomial x^2 + 5
 
 Check Gamma0(N)-equivalence of cusps::
 
@@ -255,10 +255,14 @@ class NFCuspsSpace(UniqueRepresentation, Parent):
 
             sage: k.<a> = NumberField(x^2 + 5)
             sage: kCusps = NFCusps(k)
-            sage: c = kCusps(a,2)
+            sage: c = kCusps(a,2)  # py2
             Traceback (most recent call last):
             ...
             TypeError: __call__() takes exactly 2 arguments (3 given)
+            sage: c = kCusps(a,2)  # py3
+            Traceback (most recent call last):
+            ...
+            TypeError: __call__() takes 2 positional arguments but 3 were given
 
          ::
 
