@@ -54,7 +54,7 @@ TESTS::
     True
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2004, 2006 William Stein <wstein@gmail.com>
 #       Copyright (C) 2006 David Kohel <kohel@maths.usyd.edu.au>
 #       Copyright (C) 2006 Iftikhar Burhanuddin <burhanud@usc.edu>
@@ -63,8 +63,8 @@ TESTS::
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 
 import math
@@ -83,7 +83,7 @@ ZZy = rings.PolynomialRing(rings.ZZ, 'y')
 
 def Phi2_quad(J3, ssJ1, ssJ2):
     r"""
-    This function returns a certain quadratic polynomial over a finite
+    Return a certain quadratic polynomial over a finite
     field in indeterminate J3.
 
     The roots of the polynomial along with ssJ1 are the
@@ -136,16 +136,16 @@ def Phi2_quad(J3, ssJ1, ssJ2):
     ssJ1_pow2 = ssJ1**2
     ssJ2_pow2 = ssJ2**2
 
-    return J3.parent()([(-ssJ1 + 1488)*ssJ2_pow2+ (1488*ssJ1 +
-    40773375)*ssJ2 + ssJ1_pow2 - 162000*ssJ1 + 8748000000,
-    -ssJ2_pow2 + 1488*ssJ2 + (ssJ1 - 162000),
-    1])
-
+    return J3.parent()([(-ssJ1 + 1488) * ssJ2_pow2
+                        + (1488 * ssJ1 + 40773375) * ssJ2
+                        + ssJ1_pow2 - 162000 * ssJ1 + 8748000000,
+                        -ssJ2_pow2 + 1488 * ssJ2 + (ssJ1 - 162000),
+                        1])
 
 
 def Phi_polys(L, x, j):
     r"""
-    This function returns a certain polynomial of degree `L+1` in the
+    Return a certain polynomial of degree `L+1` in the
     indeterminate x over a finite field.
 
     The roots of the **modular** polynomial `\Phi(L, x, j)` are the
@@ -188,15 +188,15 @@ def Phi_polys(L, x, j):
     """
     r = 0
     for pol in pari.polmodular(L).Vec():
-        r = r*x + ZZy(pol)(j)
+        r = r * x + ZZy(pol)(j)
     return r
 
 
 def dimension_supersingular_module(prime, level=1):
     r"""
-    This function returns the dimension of the Supersingular module, which is
+    Return the dimension of the Supersingular module, which is
     equal to the dimension of the space of modular forms of weight `2`
-    and conductor equal to prime times level.
+    and conductor equal to ``prime`` times ``level``.
 
     INPUT:
 
@@ -205,7 +205,8 @@ def dimension_supersingular_module(prime, level=1):
     - ``level`` -- integer, positive
 
     OUTPUT:
-       dimension -- integer, nonnegative
+
+    - dimension -- integer, nonnegative
 
     EXAMPLES:
 
@@ -221,8 +222,9 @@ def dimension_supersingular_module(prime, level=1):
         sage: dimension_supersingular_module(83401)
         6950
 
-    NOTES:
-    The case of level > 1 has not been implemented yet.
+    .. NOTE::
+
+        The case of level > 1 has not been implemented yet.
 
     AUTHORS:
 
@@ -231,14 +233,14 @@ def dimension_supersingular_module(prime, level=1):
     - Iftikhar Burhanuddin - burhanud@usc.edu
     """
     if not(rings.Integer(prime).is_prime()):
-        raise ValueError("%s is not a prime"%prime)
+        raise ValueError("%s is not a prime" % prime)
 
     if level == 1:
         return Gamma0(prime).dimension_modular_forms(2)
 
-    #list of genus(X_0(level)) equal to zero
-    #elif (level in [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 12, 13, 16, 18, 25]):
-    #compute basis
+    # list of genus(X_0(level)) equal to zero
+    # elif (level in [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 12, 13, 16, 18, 25]):
+    # compute basis
 
     else:
         raise NotImplementedError
@@ -246,17 +248,19 @@ def dimension_supersingular_module(prime, level=1):
 
 def supersingular_D(prime):
     r"""
-    This function returns a fundamental discriminant `D` of an
-    imaginary quadratic field, where the given prime does not split
-    (see Silverman's Advanced Topics in the Arithmetic of Elliptic
-    Curves, page 184, exercise 2.30(d).)
+    Return a fundamental discriminant `D` of an
+    imaginary quadratic field, where the given prime does not split.
+
+    See Silverman's Advanced Topics in the Arithmetic of Elliptic
+    Curves, page 184, exercise 2.30(d).
 
     INPUT:
 
     - prime -- integer, prime
 
     OUTPUT:
-        D -- integer, negative
+
+    - D -- integer, negative
 
     EXAMPLES:
 
@@ -279,19 +283,20 @@ def supersingular_D(prime):
     - Iftikhar Burhanuddin - burhanud@usc.edu
     """
     if not(rings.Integer(prime).is_prime()):
-        raise ValueError("%s is not a prime"%prime)
+        raise ValueError("%s is not a prime" % prime)
 
-    #Making picking D more intelligent
+    # Making picking D more intelligent
     D = -1
     while True:
-        Dmod4 = rings.Mod(D,4)
-        if Dmod4 in (0,1) and (kronecker(D,prime) != 1):
+        Dmod4 = rings.Mod(D, 4)
+        if Dmod4 in (0, 1) and (kronecker(D, prime) != 1):
             return D
         D = D - 1
 
+
 def supersingular_j(FF):
     r"""
-    This function returns a supersingular j-invariant over the finite
+    Return a supersingular j-invariant over the finite
     field FF.
 
     INPUT:
@@ -299,8 +304,9 @@ def supersingular_j(FF):
     - ``FF``  -- finite field with p^2 elements, where p is a prime number
 
     OUTPUT:
-       finite field element -- a supersingular j-invariant
-       defined over the finite field FF
+
+    - finite field element -- a supersingular j-invariant
+      defined over the finite field FF
 
     EXAMPLES:
 
@@ -325,30 +331,30 @@ def supersingular_j(FF):
     - Iftikhar Burhanuddin -- burhanud@usc.edu
     """
     if not(FF.is_field()) or not(FF.is_finite()):
-        raise ValueError("%s is not a finite field"%FF)
+        raise ValueError("%s is not a finite field" % FF)
     prime = FF.characteristic()
     if not(rings.Integer(prime).is_prime()):
-        raise ValueError("%s is not a prime"%prime)
+        raise ValueError("%s is not a prime" % prime)
     if not(rings.Integer(FF.cardinality())) == rings.Integer(prime**2):
-        raise ValueError("%s is not a quadratic extension"%FF)
+        raise ValueError("%s is not a quadratic extension" % FF)
     if kronecker(-1, prime) != 1:
-        j_invss = 1728                 #(2^2 * 3)^3
+        j_invss = 1728                 # (2^2 * 3)^3
     elif kronecker(-2, prime) != 1:
-        j_invss = 8000                 #(2^2 * 5)^3
+        j_invss = 8000                 # (2^2 * 5)^3
     elif kronecker(-3, prime) != 1:
-        j_invss = 0                    #0^3
+        j_invss = 0                    # 0^3
     elif kronecker(-7, prime) != 1:
-        j_invss = 16581375             #(3 * 5 * 17)^3
+        j_invss = 16581375             # (3 * 5 * 17)^3
     elif kronecker(-11, prime) != 1:
-        j_invss = -32768               #-(2^5)^3
+        j_invss = -32768               # -(2^5)^3
     elif kronecker(-19, prime) != 1:
-        j_invss = -884736              #-(2^5 * 3)^3
+        j_invss = -884736              # -(2^5 * 3)^3
     elif kronecker(-43, prime) != 1:
-        j_invss = -884736000           #-(2^6 * 3 * 5)^3
+        j_invss = -884736000           # -(2^6 * 3 * 5)^3
     elif kronecker(-67, prime) != 1:
-        j_invss = -147197952000        #-(2^5 * 3 * 5 * 11)^3
+        j_invss = -147197952000        # -(2^5 * 3 * 5 * 11)^3
     elif kronecker(-163, prime) != 1:
-        j_invss = -262537412640768000  #-(2^6 * 3 * 5 * 23 * 29)^3
+        j_invss = -262537412640768000  # -(2^6 * 3 * 5 * 23 * 29)^3
     else:
         D = supersingular_D(prime)
         hc_poly = FF['x'](pari(D).polclass())
@@ -366,7 +372,7 @@ class SupersingularModule(hecke.HeckeModule_free_module):
 
     The characteristic must not divide the level.
 
-    NOTE: Currently, only level 1 is implemented.
+    .. NOTE:: Currently, only level 1 is implemented.
 
     EXAMPLES::
 
@@ -395,7 +401,6 @@ class SupersingularModule(hecke.HeckeModule_free_module):
             sage: SupersingularModule(3)
             Module of supersingular points on X_0(1)/F_3 over Integer Ring
         """
-
         if not prime.is_prime():
             raise ValueError("the argument prime must be a prime number")
         if prime.divides(level):
@@ -404,23 +409,22 @@ class SupersingularModule(hecke.HeckeModule_free_module):
             raise NotImplementedError("supersingular modules of level > 1 not yet implemented")
         self.__prime = prime
         from sage.rings.all import FiniteField
-        self.__finite_field = FiniteField(prime**2,'a')
+        self.__finite_field = FiniteField(prime**2, 'a')
         self.__level = level
         self.__hecke_matrices = {}
-        hecke.HeckeModule_free_module.__init__(
-            self, base_ring, prime*level, weight=2)
+        hecke.HeckeModule_free_module.__init__(self, base_ring,
+                                               prime * level, weight=2)
 
     def _repr_(self):
         """
-        String representation of self
+        String representation of self.
 
         EXAMPLES::
 
             sage: SupersingularModule(11)._repr_()
             'Module of supersingular points on X_0(1)/F_11 over Integer Ring'
         """
-
-        return "Module of supersingular points on X_0(%s)/F_%s over %s"%(
+        return "Module of supersingular points on X_0(%s)/F_%s over %s" % (
             self.__level, self.__prime, self.base_ring())
 
     def __richcmp__(self, other, op):
@@ -492,14 +496,15 @@ class SupersingularModule(hecke.HeckeModule_free_module):
     def dimension(self):
         r"""
         Return the dimension of the space of modular forms of weight 2
-        and level equal to the level associated to self.
+        and level equal to the level associated to ``self``.
 
         INPUT:
 
         - ``self`` -- SupersingularModule object
 
         OUTPUT:
-            integer -- dimension, nonnegative
+
+        - integer -- dimension, nonnegative
 
         EXAMPLES::
 
@@ -515,7 +520,8 @@ class SupersingularModule(hecke.HeckeModule_free_module):
             sage: S.dimension()
             6950
 
-        NOTES:
+        .. NOTE::
+
            The case of level > 1 has not yet been implemented.
 
         AUTHORS:
@@ -539,14 +545,15 @@ class SupersingularModule(hecke.HeckeModule_free_module):
 
     def level(self):
         r"""
-        This function returns the level associated to self.
+        This function returns the level associated to ``self``.
 
         INPUT:
 
         - ``self`` -- SupersingularModule object
 
         OUTPUT:
-            integer -- the level, positive
+
+        - integer -- the level, positive
 
         EXAMPLES::
 
@@ -564,8 +571,7 @@ class SupersingularModule(hecke.HeckeModule_free_module):
 
     def prime(self):
         r"""
-        This function returns the characteristic of the finite field
-        associated to self.
+        Return the characteristic of the finite field associated to ``self``.
 
         INPUT:
 
@@ -591,14 +597,15 @@ class SupersingularModule(hecke.HeckeModule_free_module):
 
     def weight(self):
         r"""
-        This function returns the weight associated to self.
+        Return the weight associated to ``self``.
 
         INPUT:
 
         - ``self`` -- SupersingularModule object
 
         OUTPUT:
-            integer -- weight, positive
+
+        - integer -- weight, positive
 
         EXAMPLES::
 
@@ -616,14 +623,16 @@ class SupersingularModule(hecke.HeckeModule_free_module):
 
     def supersingular_points(self):
         r"""
-        This function computes the supersingular j-invariants over the
-        finite field associated to self.
+        Compute the supersingular j-invariants over the
+        finite field associated to ``self``.
 
         INPUT:
 
         -  ``self`` -- SupersingularModule object
 
-        OUTPUT: list_j, dict_j -- list_j is the list of supersingular
+        OUTPUT:
+
+        - list_j, dict_j -- list_j is the list of supersingular
             j-invariants, dict_j is a dictionary with these
             j-invariants as keys and their indexes as values. The
             latter is used to speed up j-invariant look-up. The
@@ -639,12 +648,12 @@ class SupersingularModule(hecke.HeckeModule_free_module):
             ([6], {6: 0})
 
             sage: S = SupersingularModule(11)
-            sage: S.supersingular_points()
-            ([1, 0], {0: 1, 1: 0})
+            sage: S.supersingular_points()[0]
+            [1, 0]
 
             sage: S = SupersingularModule(37)
-            sage: S.supersingular_points()
-            ([8, 27*a + 23, 10*a + 20], {8: 0, 10*a + 20: 2, 27*a + 23: 1})
+            sage: S.supersingular_points()[0]
+            [8, 27*a + 23, 10*a + 20]
 
         AUTHORS:
 
@@ -665,27 +674,28 @@ class SupersingularModule(hecke.HeckeModule_free_module):
         dim = dimension_supersingular_module(prime, level)
 
         pos = int(0)
-        #using list to keep track of explored nodes using pos
+        # using list to keep track of explored nodes using pos
         ss_points = [jinv]
 
-        #using  to keep track of index of the previous node
+        # using  to keep track of index of the previous node
         ss_points_pre = [-1]
 
-        #using dictionary for fast j-invariant look-up
-        ss_points_dic = {jinv:pos}
+        # using dictionary for fast j-invariant look-up
+        ss_points_dic = {jinv: pos}
 
         T2_matrix = MatrixSpace(rings.Integers(), dim, sparse=True)(0)
 
         while pos < len(ss_points):
             if pos == 0:
-                neighbors = Phi_polys(2,X,ss_points[pos]).roots()
+                neighbors = Phi_polys(2, X, ss_points[pos]).roots()
             else:
                 j_prev = ss_points_pre[pos]
-                # TODO: These are quadratic polynomials -- maybe we should use the
-                # quadratic formula and fast square root finding (??)
+                # TODO: These are quadratic polynomials -- maybe we
+                # should use the quadratic formula and fast square
+                # root finding (??)
                 neighbors = Phi2_quad(X, ss_points[j_prev], ss_points[pos]).roots()
 
-            for (xj,ej) in neighbors:
+            for (xj, ej) in neighbors:
                 if xj not in ss_points_dic:
                     j = len(ss_points)
                     ss_points += [xj]
@@ -703,7 +713,6 @@ class SupersingularModule(hecke.HeckeModule_free_module):
         self.__hecke_matrices[2] = T2_matrix
         return (ss_points, ss_points_dic)
 
-
     def upper_bound_on_elliptic_factors(self, p=None, ellmax=2):
         r"""
         Return an upper bound (provably correct) on the number of
@@ -712,12 +721,12 @@ class SupersingularModule(hecke.HeckeModule_free_module):
 
         INPUT:
 
-        - ``p`` - (default: 997) prime to work modulo
+        - ``p`` -- (default: 997) prime to work modulo
 
         ALGORITHM: Currently we only use `T_2`.  Function will be
         extended to use more Hecke operators later.
 
-        The prime p is replaced by the smallest prime that doesn't
+        The prime p is replaced by the smallest prime that does not
         divide the level.
 
         EXAMPLES::
@@ -729,12 +738,12 @@ class SupersingularModule(hecke.HeckeModule_free_module):
         classes.)
         """
         # NOTE: The heuristic runtime is *very* roughly `p^2/(2\cdot 10^6)`.
-        #ellmax -- (default: 2) use Hecke operators T_ell with ell <= ellmax
+        # ellmax -- (default: 2) use Hecke operators T_ell with ell <= ellmax
         if p is None:
             p = 997
 
         while self.level() % p == 0:
-             p = next_prime(p)
+            p = next_prime(p)
 
         ell = 2
         t = self.hecke_matrix(ell).change_ring(rings.GF(p))
@@ -743,28 +752,28 @@ class SupersingularModule(hecke.HeckeModule_free_module):
         # turn this off when sparse rank is optimized.
         t = t.dense_matrix()
 
-        B = 2*math.sqrt(ell)
+        B = 2 * math.sqrt(ell)
         bnd = 0
         lower = -int(math.floor(B))
-        upper = int(math.floor(B))+1
+        upper = int(math.floor(B)) + 1
         for a in range(lower, upper):
-            tm = verbose("computing T_%s - %s"%(ell, a))
+            tm = verbose("computing T_%s - %s" % (ell, a))
             if a == lower:
                 c = a
             else:
                 c = 1
             for i in range(t.nrows()):
-                t[i,i] += c
-            tm = verbose("computing kernel",tm)
-            #dim = t.kernel().dimension()
+                t[i, i] += c
+            tm = verbose("computing kernel", tm)
+            # dim = t.kernel().dimension()
             dim = t.nrows() - t.rank()
             bnd += dim
-            verbose('got dimension = %s; new bound = %s'%(dim, bnd), tm)
+            verbose('got dimension = %s; new bound = %s' % (dim, bnd), tm)
         return bnd
 
-    def hecke_matrix(self,L):
+    def hecke_matrix(self, L):
         r"""
-        This function returns the `L^{\text{th}}` Hecke matrix.
+        Return the `L^{\text{th}}` Hecke matrix.
 
         INPUT:
 
@@ -773,7 +782,8 @@ class SupersingularModule(hecke.HeckeModule_free_module):
         - ``L`` -- integer, positive
 
         OUTPUT:
-            matrix -- sparse integer matrix
+
+        - matrix -- sparse integer matrix
 
         EXAMPLES:
 
@@ -822,7 +832,7 @@ class SupersingularModule(hecke.HeckeModule_free_module):
         Fp2 = self.__finite_field
         h = len(SS)
         R = self.base_ring()
-        T_L = MatrixSpace(R,h)(0)
+        T_L = MatrixSpace(R, h)(0)
         S, X = Fp2['x'].objgen()
 
         for i in range(len(SS)):
@@ -830,7 +840,7 @@ class SupersingularModule(hecke.HeckeModule_free_module):
             phi_L_in_x = Phi_polys(L, X, ss_i)
             rts = phi_L_in_x.roots()
             for r in rts:
-                T_L[i,int(II[r[0]])] = r[1]
+                T_L[i, int(II[r[0]])] = r[1]
 
         self.__hecke_matrices[L] = T_L
         return T_L
