@@ -5,15 +5,14 @@ AUTHORS:
 
 - Jan Poeschko (2012-07-02): initial version
 """
-
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2012 Jan Poeschko <jan@poeschko.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from __future__ import print_function
 
 from sage.geometry.polyhedron.constructor import Polyhedron
@@ -23,6 +22,7 @@ from sage.rings.rational_field import QQ
 
 from math import sqrt, floor, ceil
 
+
 def plane_inequality(v):
     """
     Return the inequality for points on the same side as the origin
@@ -42,6 +42,7 @@ def plane_inequality(v):
         c, v = -c, -v
     return [c] + list(v)
 
+
 def jacobi(M):
     r"""
     Compute the upper-triangular part of the Cholesky/Jacobi
@@ -69,6 +70,10 @@ def jacobi(M):
     certain Zariski-dense open subset of the set of all
     `n \times n`-matrices.
 
+    .. NOTE::
+
+        This should be a method of matrices.
+
     EXAMPLES::
 
         sage: from sage.modules.diamond_cutting import jacobi
@@ -103,10 +108,9 @@ def jacobi(M):
         sage: testall(M)
         True
     """
-    dim = M.dimensions()
-    if dim[0] != dim[1]:
+    if not M.is_square():
         raise ValueError("the matrix must be square")
-    dim = dim[0]
+    dim = M.nrows()
     q = [list(row) for row in M]
     for i in range(dim - 1):
         for j in range(i + 1, dim):
@@ -120,6 +124,7 @@ def jacobi(M):
             q[i][j] = 0
     return matrix(q)
 
+
 def diamond_cut(V, GM, C, verbose=False):
     r"""
     Perform diamond cutting on polyhedron ``V`` with basis matrix ``GM``
@@ -164,13 +169,14 @@ def diamond_cut(V, GM, C, verbose=False):
     L = [0] * dim
 
     # calculate the Gram matrix
-    q = matrix([[sum(GM[i][k] * GM[j][k] for k in range(dim)) for j in range(dim)] for i in range(dim)])
+    q = matrix([[sum(GM[i][k] * GM[j][k] for k in range(dim))
+                 for j in range(dim)] for i in range(dim)])
     if verbose:
-        print( "q:\n{}".format(q.n()) )
+        print("q:\n{}".format(q.n()))
     # apply Cholesky/Jacobi decomposition
     q = jacobi(q)
     if verbose:
-        print( "q:\n{}".format(q.n()) )
+        print("q:\n{}".format(q.n()))
 
     i = dim - 1
     T[i] = C
@@ -217,10 +223,8 @@ def diamond_cut(V, GM, C, verbose=False):
                 cut_count += 1
                 if verbose:
                     print("\n%d) Cut using normal vector %s" % (cut_count, hv))
-                hv = [QQ(round(elmt, 6)) for elmt in hv]
+                hv = [QQ(elmt.n(digits=6)) for elmt in hv]
                 inequalities.append(plane_inequality(hv))
-                #cut = Polyhedron(ieqs=[plane_inequality(hv)])
-                #V = V.intersection(cut)
 
     if verbose:
         print("Final cut")
@@ -232,6 +236,7 @@ def diamond_cut(V, GM, C, verbose=False):
 
     return V
 
+
 def calculate_voronoi_cell(basis, radius=None, verbose=False):
     """
     Calculate the Voronoi cell of the lattice defined by basis
@@ -255,7 +260,6 @@ def calculate_voronoi_cell(basis, radius=None, verbose=False):
         sage: V.volume()
         1
     """
-
     dim = basis.dimensions()
     artificial_length = None
     if dim[0] < dim[1]:
@@ -286,9 +290,9 @@ def calculate_voronoi_cell(basis, radius=None, verbose=False):
     if artificial_length is not None:
         # remove inequalities introduced by artificial basis points
         H = V.Hrepresentation()
-        H = [v for v in H if all(not V._is_zero(v.A() * w / 2 - v.b() and
-             not V._is_zero(v.A() * (-w) / 2 - v.b())) for w in additional_vectors)]
+        H = [v for v in H if all(not V._is_zero(v.A() * w / 2 - v.b()) and
+                                 not V._is_zero(v.A() * (-w) / 2 - v.b())
+                                 for w in additional_vectors)]
         V = Polyhedron(ieqs=H)
 
     return V
-
