@@ -65,7 +65,7 @@ from sage.rings.integer import Integer
 from sage.rings.all import ZZ
 
 from sage.structure.factory import UniqueFactory
-from sage.misc.decorators import rename_keyword
+
 
 class FreeAbelianMonoidFactory(UniqueFactory):
     """
@@ -111,7 +111,6 @@ class FreeAbelianMonoidFactory(UniqueFactory):
 FreeAbelianMonoid_factory = FreeAbelianMonoidFactory("sage.monoids.free_abelian_monoid.FreeAbelianMonoid_factory")
 
 
-@rename_keyword(deprecation=15289, n="index_set")
 def FreeAbelianMonoid(index_set=None, names=None, **kwds):
     r"""
     Return a free abelian monoid on `n` generators or with the generators
@@ -139,13 +138,15 @@ def FreeAbelianMonoid(index_set=None, names=None, **kwds):
         Free abelian monoid on 5 generators (a, b, c, d, e)
         sage: FreeAbelianMonoid(index_set=ZZ)
         Free abelian monoid indexed by Integer Ring
+        sage: FreeAbelianMonoid(names='x,y')
+        Free abelian monoid on 2 generators (x, y)
     """
     if isinstance(index_set, str): # Swap args (this works if names is None as well)
         names, index_set = index_set, names
 
     if index_set is None and names is not None:
         if isinstance(names, str):
-            index_set = names.count(',')
+            index_set = names.count(',') + 1
         else:
             index_set = len(names)
 
