@@ -76,7 +76,7 @@ example::
 
 Just like :mod:`sage.numerical.linear_functions`, (in)equalities
 become symbolic inequalities. See
-:mod:`~sage.numerical.linear_tensor_constraints` for detais.
+:mod:`~sage.numerical.linear_tensor_constraints` for details.
 
 .. NOTE::
 
