@@ -53,7 +53,7 @@ def normalize_input(a):
         return ((a,), {})
 
 
-class Parallel:
+class Parallel(object):
     r"""
     Create a ``parallel``-decorated function.
     This is the object created by :func:`parallel`.
@@ -63,7 +63,7 @@ class Parallel:
         EXAMPLES::
 
             sage: P = sage.parallel.decorate.Parallel(); P
-            <sage.parallel.decorate.Parallel instance at 0x...>
+            <sage.parallel.decorate.Parallel object at 0x...>
         """
         # The default p_iter is currently the 'fork' implementation.
         # This has changed.
@@ -432,7 +432,7 @@ def parallel(p_iter='fork', ncpus=None, **kwds):
 #   def f(...): ...
 ###################################################################
 
-class Fork:
+class Fork(object):
     """
     A ``fork`` decorator class.
     """
@@ -448,9 +448,9 @@ class Fork:
         EXAMPLES::
 
             sage: sage.parallel.decorate.Fork()
-            <sage.parallel.decorate.Fork instance at 0x...>
+            <sage.parallel.decorate.Fork object at 0x...>
             sage: sage.parallel.decorate.Fork(timeout=3)
-            <sage.parallel.decorate.Fork instance at 0x...>
+            <sage.parallel.decorate.Fork object at 0x...>
         """
         self.timeout = timeout
         self.verbose = verbose
