@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-from .graphics import show_default, Graphics
+from .graphics import Graphics
 from .plot import plot, graphics_array, list_plot, parametric_plot, polar_plot
 from .plot import plot_loglog, plot_semilogx, plot_semilogy
 from .plot import list_plot_loglog, list_plot_semilogx, list_plot_semilogy
