@@ -502,14 +502,9 @@ def line2d(points, **options):
     from sage.plot.all import Graphics
     from sage.plot.plot import xydata_from_point_list
     from sage.rings.all import CC, CDF
-    if points in CC or points in CDF:
-        pass
-    else:
-        try:
-            if not points:
-                return Graphics()
-        except ValueError: # numpy raises a ValueError if not empty
-            pass
+    points = list(points) # make sure points is a python list
+    if len(points) == 0:
+        return Graphics()
     xdata, ydata = xydata_from_point_list(points)
     g = Graphics()
     g._set_extra_kwds(Graphics._extract_kwds_for_show(options))
