@@ -40,13 +40,13 @@ EXAMPLES::
     sage: S.show()
 
 .. PLOT::
-    
+
     def f(x,y): return math.exp(x/5)*math.sin(y)
     P = plot3d(f,(-5,5),(-5,5), adaptive=True, color=['red','yellow'])
     from sage.plot.plot3d.plot3d import axes
     S = P + axes(6, color='black')
     sphinx_plot(S)
-    
+
 Here is an example using a colormap and a color function ``c``::
 
     sage: x, y = var('x y')
@@ -84,7 +84,7 @@ We plot "cape man"::
     sage: cape_man.show(aspect_ratio=[1,1,1])
 
 .. PLOT::
-    
+
     S = sphere(size=.5, color='yellow')
     from sage.plot.plot3d.shapes import Cone
     S += Cone(.5, .5, color='red').translate(0,0,.3)
@@ -96,14 +96,14 @@ We plot "cape man"::
     cape_man = P.scale(.2) + S.translate(1,0,0)
     cape_man.aspect_ratio([1,1,1])
     sphinx_plot(cape_man)
-    
+
 Or, we plot a very simple function indeed::
 
     sage: plot3d(pi, (-1,1), (-1,1))
     Graphics3d Object
 
 .. PLOT::
-    
+
     sphinx_plot(plot3d(pi, (-1,1), (-1,1)))
 
 Transparent with fractional opacity value::
@@ -142,14 +142,8 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 from __future__ import absolute_import
-import six
 import inspect
 
-if six.PY2:
-    getargspec = inspect.getargspec
-else:
-    getargspec = inspect.getfullargspec
-
 from six import iteritems
 
 from .tri_plot import TrianglePlot
@@ -162,6 +156,7 @@ from .texture import Texture
 from sage.ext.fast_eval import fast_float_arg
 
 from sage.functions.trig import cos, sin
+from sage.misc.sageinspect import sage_getargspec
 
 
 class _Coordinates(object):
@@ -193,8 +188,7 @@ class _Coordinates(object):
             sage: arb((x+z,y*z,z), z, (x,y))
             Arbitrary Coordinates coordinate transform (z in terms of x, y)
         """
-        import inspect
-        all_vars = getargspec(self.transform).args[1:]
+        all_vars = sage_getargspec(self.transform).args[1:]
         if set(all_vars) != set(indep_vars + [dep_var]):
             raise ValueError('variables were specified incorrectly for this coordinate system; incorrect variables were %s'%list(set(all_vars).symmetric_difference(set(indep_vars+[dep_var]))))
         self.dep_var = dep_var
@@ -266,43 +260,32 @@ class _Coordinates(object):
             (a + b, a - b, 2*a + b)
 
             sage: t1,t2,t3=T.to_cartesian(lambda a,b: 2*a+b)
-            sage: import inspect
-            sage: inspect.getargspec(t1) # py2
+            sage: from sage.misc.sageinspect import sage_getargspec
+            sage: sage_getargspec(t1)
             ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
-            sage: inspect.getfullargspec(t1) # py3
-            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None, kwonlyargs=[], kwonlydefaults=None, annotations={})
-            sage: inspect.getargspec(t2) # py2
+            sage: sage_getargspec(t2)
             ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
-            sage: inspect.getfullargspec(t2) # py3
-            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None, kwonlyargs=[], kwonlydefaults=None, annotations={})
-            sage: inspect.getargspec(t3) # py2
+            sage: sage_getargspec(t3)
             ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
-            sage: inspect.getfullargspec(t3) # py3
-            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None, kwonlyargs=[], kwonlydefaults=None, annotations={})
 
             sage: def g(a,b): return 2*a+b
             sage: t1,t2,t3=T.to_cartesian(g)
-            sage: inspect.getargspec(t1) # py2
+            sage: sage_getargspec(t1)
             ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
-            sage: inspect.getfullargspec(t1) # py3
-            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None, kwonlyargs=[], kwonlydefaults=None, annotations={})
             sage: t1,t2,t3=T.to_cartesian(2*a+b)
-            sage: inspect.getargspec(t1) # py2
+            sage: sage_getargspec(t1)
             ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
-            sage: inspect.getfullargspec(t1) # py3
-            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None, kwonlyargs=[], kwonlydefaults=None, annotations={})
 
         If we cannot guess the right parameter names, then the
         parameters are named `u` and `v`::
 
             sage: from sage.plot.plot3d.plot3d import _ArbitraryCoordinates
+            sage: from sage.misc.sageinspect import sage_getargspec
             sage: x, y, z = var('x y z')
             sage: T = _ArbitraryCoordinates((x + y, x - y, z), z,[x,y])
             sage: t1,t2,t3=T.to_cartesian(operator.add)
-            sage: inspect.getargspec(t1) # py2
+            sage: sage_getargspec(t1)
             ArgSpec(args=['u', 'v'], varargs=None, keywords=None, defaults=None)
-            sage: inspect.getfullargspec(t1) # py3
-            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None, kwonlyargs=[], kwonlydefaults=None, annotations={})
             sage: [h(1,2) for h in T.to_cartesian(operator.mul)]
             [3.0, -1.0, 2.0]
             sage: [h(u=1,v=2) for h in T.to_cartesian(operator.mul)]
@@ -350,8 +333,8 @@ class _Coordinates(object):
             if params is None:
                 if callable(func):
                     params = _find_arguments_for_callable(func)
-                    if params is None:
-                        params=['u','v']
+                    if not params:
+                        params = ['u', 'v']
                 else:
                     raise ValueError("function is not callable")
             def subs_func(t):
@@ -385,14 +368,12 @@ class _Coordinates(object):
           (self._name, self.dep_var, ', '.join(self.indep_vars))
 
 
-import inspect
-
 def _find_arguments_for_callable(func):
     """
     Find the names of arguments (that do not have default values) for
     a callable function, taking care of several special cases in Sage.
 
-    If the parameters cannot be found, then return None.
+    If the parameters cannot be found, then return ``[]``.
 
     EXAMPLES::
 
@@ -414,26 +395,22 @@ def _find_arguments_for_callable(func):
         sage: _find_arguments_for_callable(a+b)
         ['a', 'b']
         sage: _find_arguments_for_callable(operator.add)
+        []
     """
     if inspect.isfunction(func):
-        f_args = getargspec(func)
-        if f_args.defaults is None:
-            params = f_args.args
-        else:
-            params = f_args.args[:-len(f_args.defaults)]
+        pass
+    elif hasattr(func, 'arguments'):
+        # Might be a symbolic function with arguments
+        return [repr(s) for s in func.arguments()]
     else:
-        try:
-            f_args = getargspec(func.__call__)
-            if f_args.defaults is None:
-                params = f_args.args
-            else:
-                params = f_args.args[:-len(f_args.defaults)]
-        except TypeError:
-            # func.__call__ may be a built-in (or Cython) function
-            if hasattr(func, 'arguments'):
-                params = [repr(s) for s in func.arguments()]
-            else:
-                params=None
+        func = func.__call__
+
+    f_args = sage_getargspec(func)
+    if f_args.defaults is None:
+        params = f_args.args
+    else:
+        params = f_args.args[:-len(f_args.defaults)]
+
     return params
 
 
@@ -520,11 +497,11 @@ class Spherical(_Coordinates):
         Graphics3d Object
 
     .. PLOT::
-        
+
         r, phi, theta = var('r phi theta')
         T = Spherical('radius', ['azimuth', 'inclination'])
         sphinx_plot(plot3d(phi * theta, (theta, 0, pi), (phi, 0, 1), transformation=T))
-        
+
     We next graph the function where the inclination angle is constant::
 
         sage: S=Spherical('inclination', ['radius', 'azimuth'])
@@ -533,11 +510,11 @@ class Spherical(_Coordinates):
         Graphics3d Object
 
     .. PLOT::
-        
+
         S=Spherical('inclination', ['radius', 'azimuth'])
         r,theta=var('r,theta')
         sphinx_plot(plot3d(r-r+3, (r,0,3), (theta, 0, 2*pi), transformation=S))
-        
+
     See also :func:`spherical_plot3d` for more examples of plotting in spherical
     coordinates.
     """
@@ -589,11 +566,11 @@ class SphericalElevation(_Coordinates):
         Graphics3d Object
 
     .. PLOT::
-        
+
         T = SphericalElevation('radius', ['azimuth', 'elevation'])
         r, theta, phi = var('r theta phi')
         sphinx_plot(plot3d(phi * theta, (theta, 0, pi), (phi, 0, 1), transformation=T))
-        
+
     We next graph the function where the elevation angle is constant. This
     should be compared to the similar example for the ``Spherical`` coordinate
     system::
@@ -604,11 +581,11 @@ class SphericalElevation(_Coordinates):
         Graphics3d Object
 
     .. PLOT::
-        
+
         SE=SphericalElevation('elevation', ['radius', 'azimuth'])
         r,theta=var('r,theta')
         sphinx_plot(plot3d(3+r-r, (r,0,3), (theta, 0, 2*pi), transformation=SE))
-        
+
     Plot a sin curve wrapped around the equator::
 
         sage: P1=plot3d( (pi/12)*sin(8*theta), (r,0.99,1), (theta, 0, 2*pi), transformation=SE, plot_points=(10,200))
@@ -617,13 +594,13 @@ class SphericalElevation(_Coordinates):
         Graphics3d Object
 
     .. PLOT::
-        
+
         r,theta=var('r,theta')
         SE=SphericalElevation('elevation', ['radius', 'azimuth'])
         P1=plot3d( (pi/12)*sin(8*theta), (r,0.99,1), (theta, 0, 2*pi), transformation=SE, plot_points=(10,200))
         P2=sphere(center=(0,0,0), size=1, color='red', opacity=0.3)
         sphinx_plot(P1+P2)
-        
+
     Now we graph several constant elevation functions alongside several constant
     inclination functions. This example illustrates the difference between the
     ``Spherical`` coordinate system and the ``SphericalElevation`` coordinate
@@ -639,7 +616,7 @@ class SphericalElevation(_Coordinates):
         sage: show(sum(P1+P2), aspect_ratio=1)
 
     .. PLOT::
-        
+
         r, phi, theta = var('r phi theta')
         SE = SphericalElevation('elevation', ['radius', 'azimuth'])
         S = Spherical('inclination', ['radius', 'azimuth'])
@@ -650,7 +627,7 @@ class SphericalElevation(_Coordinates):
             P1 += plot3d( a, (r,0,3), (theta, 0, 2*pi), transformation=SE, opacity=0.85, color='blue')
             P2 += plot3d( a, (r,0,3), (theta, 0, 2*pi), transformation=S, opacity=0.85, color='red')
         sphinx_plot(P1+P2)
-        
+
     See also :func:`spherical_plot3d` for more examples of plotting in spherical
     coordinates.
     """
@@ -703,11 +680,11 @@ class Cylindrical(_Coordinates):
         Graphics3d Object
 
     .. PLOT::
-        
+
         T = Cylindrical('height', ['radius', 'azimuth'])
         r, theta, z = var('r theta z')
         sphinx_plot(plot3d(9-r**2, (r, 0, 3), (theta, 0, pi), transformation=T))
-        
+
     We next graph the function where the radius is constant::
 
         sage: S=Cylindrical('radius', ['azimuth', 'height'])
@@ -716,11 +693,11 @@ class Cylindrical(_Coordinates):
         Graphics3d Object
 
     .. PLOT::
-        
+
         S=Cylindrical('radius', ['azimuth', 'height'])
         theta,z=var('theta, z')
         sphinx_plot(plot3d(3+z-z, (theta,0,2*pi), (z, -2, 2), transformation=S))
-        
+
     See also :func:`cylindrical_plot3d` for more examples of plotting in cylindrical
     coordinates.
     """
@@ -852,7 +829,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         sphinx_plot(plot3d(lambda x, y: x**2 + y**2, (-2,2), (-2,2)))
 
     We plot the same 3d function but using adaptive refinement::
@@ -861,7 +838,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         sphinx_plot(plot3d(lambda x, y: x**2 + y**2, (-2,2), (-2,2), adaptive=True))
 
     Adaptive refinement but with more points::
@@ -870,7 +847,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         sphinx_plot(plot3d(lambda x, y: x**2 + y**2, (-2,2), (-2,2), adaptive=True, initial_depth=5))
 
     We plot some 3d symbolic functions::
@@ -881,7 +858,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         var('x y')
         sphinx_plot(plot3d(x**2 + y**2, (x,-2,2), (y,-2,2)))
 
@@ -891,7 +868,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         var('x y')
         sphinx_plot(plot3d(sin(x*y), (x, -pi, pi), (y, -pi, pi)))
 
@@ -903,7 +880,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         var('x y')
         sphinx_plot(plot3d(sin(x**2+y**2),(x,-5,5),(y,-5,5), plot_points=200))
 
@@ -913,7 +890,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         var('x y')
         sphinx_plot(plot3d(sin(x**2+y**2),(x,-5,5),(y,-5,5), plot_points=[10,100]))
 
@@ -925,7 +902,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         var('x y')
         sphinx_plot(plot3d(sin(x-y)*y*cos(x),(x,-3,3),(y,-3,3), mesh=True))
 
@@ -938,7 +915,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         x,y=var('x y')
         P = plot3d(x+y+sin(x*y), (x,-10,10),(y,-10,10), opacity=0.87, color='blue')
         Q = plot3d(x-2*y-cos(x*y),(x,-10,10),(y,-10,10),opacity=0.3,color='red')
@@ -953,7 +930,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         L = plot3d(lambda x,y: 0, (-5,5), (-5,5), color="lightblue", opacity=0.8)
         P = plot3d(lambda x,y: 4 - x**3 - y**2, (-2,2), (-2,2), color='green')
         Q = plot3d(lambda x,y: x**3 + y**2 - 4, (-2,2), (-2,2), color='orange')
@@ -966,7 +943,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         x, y = var('x y')
         sphinx_plot(plot3d(sin(pi*(x**2+y**2))/2,(x,-1,1),(y,-1,1)))
 
@@ -977,7 +954,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         x, y = var('x y')
         sphinx_plot(plot3d( 4*x*exp(-x**2-y**2), (x,-2,2), (y,-2,2)))
 
@@ -988,7 +965,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         sage: plot3d(cos(r),(r,0,17*pi/2),(phi,0,2*pi),transformation=trans,opacity=0.87).show(aspect_ratio=(1,1,2),frame=False)
 
     .. PLOT::
-        
+
         r, phi, z = var('r phi z')
         trans = (r*cos(phi),r*sin(phi),z)
         P = plot3d(cos(r),(r,0,17*pi/2),(phi,0,2*pi),transformation=trans,opacity=0.87)
@@ -1002,7 +979,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         r, theta, z = var('r theta z')
         cylindrical=(r*cos(theta),r*sin(theta),z)
         P = plot3d(z-z+3,(theta,0,pi/2),(z,0,pi/2),transformation=cylindrical)
@@ -1147,9 +1124,9 @@ def plot3d_adaptive(f, x_range, y_range, color="automatic",
         sage: from sage.plot.plot3d.plot3d import plot3d_adaptive
         sage: x,y=var('x,y'); plot3d_adaptive(sin(x*y), (x,-pi,pi), (y,-pi,pi), initial_depth=5)
         Graphics3d Object
-        
+
     .. PLOT::
-        
+
         from sage.plot.plot3d.plot3d import plot3d_adaptive
         x,y=var('x,y')
         sphinx_plot(plot3d_adaptive(sin(x*y), (x,-pi,pi), (y,-pi,pi), initial_depth=5))
@@ -1244,7 +1221,7 @@ def spherical_plot3d(f, urange, vrange, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         x,y=var('x,y')
         sphinx_plot(spherical_plot3d(x-x+2,(x,0,2*pi),(y,0,pi)))
 
@@ -1257,7 +1234,7 @@ def spherical_plot3d(f, urange, vrange, **kwds):
         sage: (rea + ima).show(aspect_ratio=1)  # long time (4s on sage.math, 2011)
 
     .. PLOT::
-        
+
         phi, theta = var('phi, theta')
         Y = spherical_harmonic(2, 1, theta, phi)
         rea = spherical_plot3d(abs(real(Y)), (phi,0,2*pi), (theta,0,pi), color='blue', opacity=0.6)
@@ -1270,7 +1247,7 @@ def spherical_plot3d(f, urange, vrange, **kwds):
         sage: spherical_plot3d(e^-y,(x,0,2*pi),(y,0,pi),opacity=0.5).show(frame=False)
 
     .. PLOT::
-        
+
         x,y=var('x,y')
         sphinx_plot(spherical_plot3d(e**-y,(x,0,2*pi),(y,0,pi),opacity=0.5))
 
@@ -1281,7 +1258,7 @@ def spherical_plot3d(f, urange, vrange, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         x,y=var('x,y')
         sphinx_plot(spherical_plot3d((2+cos(2*x))*(y+1),(x,0,2*pi),(y,0,pi),rgbcolor=(1,.1,.1)))
 
@@ -1294,7 +1271,7 @@ def spherical_plot3d(f, urange, vrange, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         x,y=var('x,y')
         sphinx_plot(spherical_plot3d(1+sin(5*x)/5,(x,0,2*pi),(y,0,pi),rgbcolor=(1,0.5,0),plot_points=(80,80),opacity=0.7))
 
@@ -1304,7 +1281,7 @@ def spherical_plot3d(f, urange, vrange, **kwds):
         sage: spherical_plot3d(1+2*cos(2*y),(x,0,3*pi/2),(y,0,pi)).show(aspect_ratio=(1,1,1))
 
     .. PLOT::
-        
+
         x,y=var('x,y')
         sphinx_plot(spherical_plot3d(1+2*cos(2*y),(x,0,3*pi/2),(y,0,pi)))
 
@@ -1323,7 +1300,7 @@ def cylindrical_plot3d(f, urange, vrange, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         r,u,v=var('r,u,v')
         f=u*v; urange=(u,0,pi); vrange=(v,0,pi)
         T = (r*cos(u), r*sin(u), v, [u,v])
@@ -1357,7 +1334,7 @@ def cylindrical_plot3d(f, urange, vrange, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         theta,z=var('theta,z')
         sphinx_plot(cylindrical_plot3d(z-z+2,(theta,0,3*pi/2),(z,-2,2)))
 
@@ -1369,7 +1346,7 @@ def cylindrical_plot3d(f, urange, vrange, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         theta,z=var('theta,z')
         sphinx_plot(cylindrical_plot3d(cosh(z),(theta,0,2*pi),(z,-2,2)))
 
@@ -1378,7 +1355,7 @@ def cylindrical_plot3d(f, urange, vrange, **kwds):
         sage: cylindrical_plot3d(e^(-z^2)*(cos(4*theta)+2)+1,(theta,0,2*pi),(z,-2,2),plot_points=[80,80]).show(aspect_ratio=(1,1,1))
 
     .. PLOT::
-        
+
         theta,z=var('theta,z')
         P = cylindrical_plot3d(e**(-z**2)*(cos(4*theta)+2)+1,(theta,0,2*pi),(z,-2,2),plot_points=[80,80])
         P.aspect_ratio([1,1,1])
@@ -1405,22 +1382,22 @@ def axes(scale=1, radius=None, **kwds):
         Graphics3d Object
 
     .. PLOT::
-        
+
         from sage.plot.plot3d.plot3d import axes
         S = axes(6, color='black')
         sphinx_plot(S)
-        
+
     ::
 
         sage: T = axes(2, .5); T
         Graphics3d Object
-        
+
     .. PLOT::
-        
+
         from sage.plot.plot3d.plot3d import axes
         T = axes(2, .5)
         sphinx_plot(T)
-        
+
     """
     if radius is None:
         radius = scale/100.0
