@@ -774,7 +774,12 @@ class Point(PrimitiveObject):
             cen = self.loc
         else:
             cen = transform.transform_point(self.loc)
-        return "Sphere center %s %s %s Rad %s %s" % (cen[0], cen[1], cen[2], self.size * TACHYON_PIXEL, self.texture.id)
+
+        radius = self.size * TACHYON_PIXEL
+        texture = self.texture.id
+        return ("Sphere center {center[0]!r} {center[1]!r} {center[2]!r} "
+                "Rad {radius!r} {texture}").format(center=cen, radius=radius,
+                                                   texture=texture)
 
     def obj_repr(self, render_params):
         """
@@ -913,7 +918,7 @@ class Line(PrimitiveObject):
 
             sage: L = line3d([(cos(i),sin(i),i^2) for i in srange(0,10,.01)],color='red')
             sage: L.tachyon_repr(L.default_render_params())[0]
-            'FCylinder base 1.0 0.0 0.0 apex 0.999950000417 0.00999983333417 0.0001 rad 0.005 texture...'
+            'FCylinder base 1.0 0.0 0.0 apex 0.9999500004166653 0.009999833334166664 0.0001 rad 0.005 texture...'
         """
         T = render_params.transform
         cmds = []
@@ -927,10 +932,12 @@ class Line(PrimitiveObject):
                 cmds.append(A.tachyon_repr(render_params))
                 render_params.pop_transform()
             else:
-                cmds.append("FCylinder base %s %s %s apex %s %s %s rad %s %s" % (px, py, pz,
-                                                                                 x, y, z,
-                                                                                 radius,
-                                                                                 self.texture.id))
+                cmd = ('FCylinder base {pos[0]!r} {pos[1]!r} {pos[2]!r} '
+                       'apex {apex[0]!r} {apex[1]!r} {apex[2]!r} '
+                       'rad {radius!r} {texture}').format(
+                               pos=(px, py, pz), apex=(x, y, z), radius=radius,
+                               texture=self.texture.id)
+                cmds.append(cmd)
             px, py, pz = x, y, z
         return cmds
 
