@@ -183,7 +183,6 @@ class Polygon(GraphicPrimitive_xydata):
 
         INPUT:
 
-
         -  ``z`` - optional 3D height above `xy`-plane, or a list of
            heights corresponding to the list of 2D polygon points.
 
@@ -235,7 +234,8 @@ class Polygon(GraphicPrimitive_xydata):
         else:
             zdata = [z]*len(self.xdata)
         if len(zdata) == len(self.xdata):
-            return IndexFaceSet([[(x, y, z) for x, y, z in zip(self.xdata, self.ydata, zdata)]], **options)
+            return IndexFaceSet([list(zip(self.xdata, self.ydata, zdata))],
+                                **options)
         else:
             raise ValueError('Incorrect number of heights given')
 
