@@ -38,16 +38,14 @@ class StreamlinePlot(GraphicPrimitive):
             sage: r.options()['plot_points']
             2
             sage: r.xpos_array
-            array([ 0.,  1.])
+            array([0., 1.])
             sage: r.yvec_array
-            masked_array(data =
-             [[1.0 1.0]
-             [0.5403023058681398 0.5403023058681398]],
-                         mask =
-             [[False False]
-             [False False]],
-                   fill_value = 1e+20)
-            <BLANKLINE>
+            masked_array(
+              data=[[1.0, 1.0],
+                    [0.5403023058681398, 0.5403023058681398]],
+              mask=[[False, False],
+                    [False, False]],
+              fill_value=1e+20)
 
         TESTS:
 
