@@ -29,13 +29,16 @@ from sage.rings.finite_rings.finite_field_constructor import FiniteField
 from sage.misc.misc import verbose
 import copy
 
-def Genus(A):
+def Genus(A, factored_determinant=None):
     r"""
     Given a nonsingular symmetric matrix `A`, return the genus of `A`.
 
     INPUT:
 
-    - ``A`` -- a symmetric matrix with coefficients in `\ZZ`
+    - ``A`` -- a symmetric matrix with integer coefficients
+
+    - ``factored_determinant`` -- (default: ``None``) a factorization object
+      the factored determinant of ``A``
 
     OUTPUT:
 
@@ -51,9 +54,31 @@ def Genus(A):
         [1 2]
         Signature:  (2, 0)
         Genus symbol at 2:    [1^2]_2
-    """
-    return GenusSymbol_global_ring(A)
 
+        sage: A = Matrix(ZZ, 2, 2, [2,1,1,2])
+        sage: Genus(A, A.det().factor())
+        Genus of
+        [2 1]
+        [1 2]
+        Signature:  (2, 0)
+        Genus symbol at 2:    1^-2
+        Genus symbol at 3:     1^-1 3^-1
+    """
+    if factored_determinant is None:
+        D = A.determinant()
+        D = 2*D
+        D = D.factor()
+    else:
+        D = factored_determinant * 2
+    sig_pair = signature_pair_of_matrix(A)
+    local_symbols = []
+    for f in D:
+        p = f[0]
+        val = f[1]
+        symbol = p_adic_symbol(A, p, val = val)
+        G = Genus_Symbol_p_adic_ring(p, symbol)
+        local_symbols.append(G)
+    return GenusSymbol_global_ring(sig_pair, local_symbols, representative=A)
 
 def LocalGenusSymbol(A, p):
     r"""
@@ -105,7 +130,6 @@ def is_GlobalGenus(G):
     EXAMPLES::
 
         sage: from sage.quadratic_forms.genera.genus import is_GlobalGenus
-
         sage: A = Matrix(ZZ, 2, 2, [1,1,1,2])
         sage: G = Genus(A)
         sage: is_GlobalGenus(G)
@@ -1622,15 +1646,22 @@ class GenusSymbol_global_ring(object):
 
     INPUT:
 
-    - ``A`` -- a symmetric matrix with integer coefficients
-    - ``max_elem_divisors`` -- the input precision for the valuation of a
-      maximal p-elementary divisor. (OPTIONAL)
+    - ``signature_pair`` -- a tuple of two non-negative integers
+
+    - ``local_symbols`` -- a list of :class:`Genus_Symbol_p_adic_ring`` instances
+      sorted by their primes
+
+    - ``representative`` -- (default: ``None``) integer symmetric matrix;
+      the gram matrix of a representative of this genus
+
+    - ``check`` -- (default: ``True``) a boolean; checks the input
 
     EXAMPLES::
 
-        sage: from sage.quadratic_forms.genera.genus import GenusSymbol_global_ring
-        sage: A = DiagonalQuadraticForm(ZZ, [1,2,3,4]).Hessian_matrix()
-        sage: G = GenusSymbol_global_ring(A); G
+        sage: from sage.quadratic_forms.genera.genus import GenusSymbol_global_ring, LocalGenusSymbol
+        sage: A = matrix.diagonal(ZZ, [2,4,6,8])
+        sage: local_symbols = [LocalGenusSymbol(A, p) for p in (2*A.det()).prime_divisors()]
+        sage: G = GenusSymbol_global_ring((4,0),local_symbols, representative=A);G
         Genus of
         [2 0 0 0]
         [0 4 0 0]
@@ -1639,36 +1670,45 @@ class GenusSymbol_global_ring(object):
         Signature:  (4, 0)
         Genus symbol at 2:    [2^-2 4^1 8^1]_6
         Genus symbol at 3:     1^3 3^-1
+
+    .. SEEALSO::
+
+        :func:`Genus` to create a :class:`GenusSymbol_global_ring` from the gram matrix directly.
     """
 
-    def __init__(self, A, max_elem_divisors=None):
+    def __init__(self, signature_pair, local_symbols, representative=None, check=True):
         r"""
-        Initialize a global genus symbol from a non-degenerate
-        integral gram matrix (and possibly information about its
-        largest elementary divisors).
-
+        Initialize a global genus symbol.
 
         EXAMPLES::
 
-            sage: from sage.quadratic_forms.genera.genus import GenusSymbol_global_ring
+            sage: from sage.quadratic_forms.genera.genus import Genus
 
             sage: A = DiagonalQuadraticForm(ZZ, [1,2,3,4]).Hessian_matrix()
-            sage: G = GenusSymbol_global_ring(A)
+            sage: G = Genus(A)
             sage: G == loads(dumps(G))
             True
         """
-        D = A.determinant()
-        D = 2*D
-        prms = [ p[0] for p in D.factor() ]
-        self._representative = A
-        self._signature = signature_pair_of_matrix(A)
-        self._local_symbols = []
-        for p in prms:
-            if max_elem_divisors is None:
-                val = D.valuation(p)
-            symbol = p_adic_symbol(A, p, val = val)
-            G = Genus_Symbol_p_adic_ring(p, symbol)
-            self._local_symbols.append(G)
+        if check:
+            if not all(isinstance(sym, Genus_Symbol_p_adic_ring) for sym in local_symbols):
+                raise TypeError("local symbols must be a list of local genus symbols")
+            n = signature_pair[0] + signature_pair[1]
+            if not all(sym.dimension()==n for sym in local_symbols):
+                raise TypeError("all local symbols must be of the same dimension")
+            if representative is not None:
+                if not representative.is_symmetric():
+                    raise ValueError("the representative must be a symmetric matrix")
+            # check the symbols are sorted increasing by their prime
+            if any(local_symbols[i].prime() >= local_symbols[i+1].prime()
+                   for i in range(len(local_symbols)-1)):
+                raise ValueError("the local symbols must be sorted by their primes")
+            if local_symbols[0].prime() != 2:
+                raise ValueError("the first symbol must be 2-adic")
+
+
+        self._representative = representative
+        self._signature = signature_pair
+        self._local_symbols = local_symbols
 
 
     def __repr__(self):
@@ -1681,9 +1721,9 @@ class GenusSymbol_global_ring(object):
 
         EXAMPLES::
 
-            sage: from sage.quadratic_forms.genera.genus import GenusSymbol_global_ring
+            sage: from sage.quadratic_forms.genera.genus import Genus
             sage: A = DiagonalQuadraticForm(ZZ, [1,2,3,4]).Hessian_matrix()
-            sage: GS = GenusSymbol_global_ring(A)
+            sage: GS = Genus(A)
             sage: GS
             Genus of
             [2 0 0 0]
@@ -1695,7 +1735,7 @@ class GenusSymbol_global_ring(object):
             Genus symbol at 3:     1^3 3^-1
 
             sage: A2 = Matrix(ZZ,2,2,[2,-1,-1,2])
-            sage: GenusSymbol_global_ring(A2)
+            sage: Genus(A2)
             Genus of
             [ 2 -1]
             [-1  2]
@@ -1753,12 +1793,12 @@ class GenusSymbol_global_ring(object):
 
         EXAMPLES::
 
-            sage: from sage.quadratic_forms.genera.genus import GenusSymbol_global_ring
+            sage: from sage.quadratic_forms.genera.genus import Genus
 
             sage: A1 = DiagonalQuadraticForm(ZZ, [1,2,3,4]).Hessian_matrix()
-            sage: GS1 = GenusSymbol_global_ring(A1)
+            sage: GS1 = Genus(A1)
             sage: A2 = DiagonalQuadraticForm(ZZ, [1,2,3,5]).Hessian_matrix()
-            sage: GS2 = GenusSymbol_global_ring(A2)
+            sage: GS2 = Genus(A2)
 
             sage: GS1 == GS2
             False
@@ -1809,12 +1849,12 @@ class GenusSymbol_global_ring(object):
 
         EXAMPLES::
 
-            sage: from sage.quadratic_forms.genera.genus import GenusSymbol_global_ring
+            sage: from sage.quadratic_forms.genera.genus import Genus
 
             sage: A1 = DiagonalQuadraticForm(ZZ, [1,2,3,4]).Hessian_matrix()
-            sage: GS1 = GenusSymbol_global_ring(A1)
+            sage: GS1 = Genus(A1)
             sage: A2 = DiagonalQuadraticForm(ZZ, [1,2,3,5]).Hessian_matrix()
-            sage: GS2 = GenusSymbol_global_ring(A2)
+            sage: GS2 = Genus(A2)
 
             sage: GS1 != GS2
             True
