@@ -74,9 +74,10 @@ Check that Cython source code appears in tracebacks::
 
     sage: from sage.repl.interpreter import get_test_shell
     sage: shell = get_test_shell()
-    sage: shell.run_cell('1/0')
-    ---------------------------------------------------------------------------
-    ZeroDivisionError                         Traceback (most recent call last)
+    sage: print("dummy line"); shell.run_cell('1/0') # see #25320 for the reason of the `...` and the dummy line in this test
+    dummy line
+    ...
+    ZeroDivisionError...Traceback (most recent call last)
     <ipython-input-...> in <module>()
     ----> 1 Integer(1)/Integer(0)
     <BLANKLINE>
@@ -355,11 +356,8 @@ class SageTestShell(SageShellOverride, TerminalInteractiveShell):
 
             sage: from sage.repl.interpreter import get_test_shell
             sage: shell = get_test_shell()
-            sage: rc = shell.run_cell('1/0')
-            ---------------------------------------------------------------------------
-            ZeroDivisionError                         Traceback (most recent call last)
-            ...
-            ZeroDivisionError: rational division by zero
+            sage: rc = shell.run_cell('2^50')
+            1125899906842624
             sage: rc is None
             True
             sage: shell.quit()
