@@ -16,8 +16,8 @@ EXAMPLES::
     sage: from sage.repl.rich_output.buffer import OutputBuffer
     sage: buf = OutputBuffer('this is the buffer content');  buf
     buffer containing 26 bytes
-    sage: buf.get()
-    'this is the buffer content'
+    sage: buf.get().decode('ascii')
+    u'this is the buffer content'
     sage: type(buf.get()) is bytes
     True
 """
@@ -32,6 +32,7 @@ EXAMPLES::
 
 
 import os
+import six
 from sage.structure.sage_object import SageObject
 
 
@@ -58,7 +59,7 @@ class OutputBuffer(SageObject):
             sage: buf2 = OutputBuffer(buf);  buf2
             buffer containing 26 bytes
 
-            sage: buf.get()
+            sage: buf.get_str()
             'this is the buffer content'
             sage: buf.filename(ext='.txt')
             '/....txt'
@@ -99,13 +100,13 @@ class OutputBuffer(SageObject):
             sage: from sage.repl.rich_output.buffer import OutputBuffer
             sage: name = sage.misc.temporary_file.tmp_filename()
             sage: with open(name, 'wb') as f:
-            ....:    _ = f.write('file content')
+            ....:    _ = f.write(b'file content')
             sage: buf = OutputBuffer.from_file(name);  buf
             buffer containing 12 bytes
 
             sage: buf.filename() == name
             True
-            sage: buf.get()
+            sage: buf.get_str()
             'file content'
         """
         buf = cls.__new__(cls)
@@ -128,7 +129,7 @@ class OutputBuffer(SageObject):
             sage: from sage.repl.rich_output.buffer import OutputBuffer
             sage: tmp = sage.misc.temporary_file.tmp_filename()
             sage: with open(tmp, 'wb') as f:
-            ....:    _ = f.write('file content')
+            ....:    _ = f.write(b'file content')
             sage: OutputBuffer._chmod_readonly(tmp)
             sage: import os, stat
             sage: stat.S_IMODE(os.stat(tmp).st_mode) & (stat.S_IWUSR | stat.S_IWGRP | stat.S_IWOTH)
@@ -173,8 +174,8 @@ class OutputBuffer(SageObject):
         EXAMPLES::
 
             sage: from sage.repl.rich_output.buffer import OutputBuffer
-            sage: c = OutputBuffer('test1234').get(); c
-            'test1234'
+            sage: c = OutputBuffer('test1234').get(); c.decode('ascii')
+            u'test1234'
             sage: type(c) is bytes
             True
             sage: c = OutputBuffer(u'été').get()
@@ -198,13 +199,45 @@ class OutputBuffer(SageObject):
         EXAMPLES::
 
             sage: from sage.repl.rich_output.buffer import OutputBuffer
-            sage: OutputBuffer('test1234').get()
-            'test1234'
+            sage: OutputBuffer('test1234').get().decode('ascii')
+            u'test1234'
             sage: OutputBuffer('test1234').get_unicode()
             u'test1234'
         """
         return self.get().decode('utf-8')
 
+    def get_str(self):
+        """
+        Return the buffer content as a ``str`` object for the current Python
+        version.
+
+        That is, returns a Python 2-style encoding-agnostic ``str`` on Python
+        2, and returns a unicode ``str`` on Python 3 with the buffer content
+        decoded from UTF-8.  In other words, this is equivalent to
+        ``OutputBuffer.get`` on Python 2 and ``OutputBuffer.get_unicode`` on
+        Python 3.  This is useful in some cases for cross-compatible code.
+
+        OUTPUT:
+
+        A ``str`` object.
+
+        EXAMPLES::
+
+            sage: from sage.repl.rich_output.buffer import OutputBuffer
+            sage: c = OutputBuffer('test1234').get_str(); c
+            'test1234'
+            sage: type(c) is str
+            True
+            sage: c = OutputBuffer(u'été').get_str()
+            sage: type(c) is str
+            True
+        """
+
+        if six.PY2:
+            return self.get()
+        else:
+            return self.get_unicode()
+
     def filename(self, ext=None):
         """
         Return the filename.
