@@ -69,6 +69,13 @@ Run test suite for valuations that do not correspond to a classical place::
     sage: w = K.valuation(v)
     sage: TestSuite(w).run() # long time
 
+Run test suite for a non-classical valuation that does not correspond to an
+affinoid contained in the unit disk::
+
+    sage: w = K.valuation((w, K.hom(K.gen()/2), K.hom(2*K.gen()))); w
+    2-adic valuation (in Rational function field in x over Rational Field after x |--> 1/2*x)
+    sage: TestSuite(w).run() # long time
+
 Run test suite for some other classical places over large ground fields::
 
     sage: K.<t> = FunctionField(GF(3))
@@ -135,7 +142,7 @@ developed for number fields in [Mac1936I]_ and [Mac1936II]_.
 
 """
 #*****************************************************************************
-#       Copyright (C) 2016-2017 Julian Rüth <julian.rueth@fsfe.org>
+#       Copyright (C) 2016-2018 Julian Rüth <julian.rueth@fsfe.org>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
@@ -144,6 +151,7 @@ developed for number fields in [Mac1936I]_ and [Mac1936II]_.
 #*****************************************************************************
 from sage.structure.factory import UniqueFactory
 from sage.rings.all import QQ
+from sage.misc.cachefunc import cached_method
 
 from sage.rings.valuation.valuation import DiscreteValuation, DiscretePseudoValuation, InfiniteDiscretePseudoValuation, NegativeInfiniteDiscretePseudoValuation
 from sage.rings.valuation.trivial_valuation import TrivialValuation
@@ -361,13 +369,8 @@ class FunctionFieldValuationFactory(UniqueFactory):
             raise ValueError("from_valuation_domain must map from %r to %r but %r maps from %r to %r"%(valuation.domain(), domain, from_valuation_domain, from_valuation_domain.domain(), from_valuation_domain.codomain()))
 
         if domain is domain.base():
-            # over rational function fields, we only support the map x |--> 1/x with another rational function field
             if valuation.domain() is not valuation.domain().base() or valuation.domain().constant_base_field() != domain.constant_base_field():
                 raise NotImplementedError("maps must be isomorphisms with a rational function field over the same base field, not with %r"%(valuation.domain(),))
-            if to_valuation_domain != domain.hom([~valuation.domain().gen()]):
-                raise NotImplementedError("to_valuation_domain must be the map %r not %r"%(domain.hom([~valuation.domain().gen()]), to_valuation_domain))
-            if from_valuation_domain != valuation.domain().hom([~domain.gen()]):
-                raise NotImplementedError("from_valuation_domain must be the map %r not %r"%(valuation.domain().hom([domain.gen()]), from_valuation_domain))
             if domain != valuation.domain():
                 # make it harder to create different representations of the same valuation
                 # (nothing bad happens if we did, but >= and <= are only implemented when this is the case.)
@@ -407,10 +410,12 @@ class FunctionFieldValuationFactory(UniqueFactory):
 
         if isinstance(valuation, tuple) and len(valuation) == 3:
             valuation, to_valuation_domain, from_valuation_domain = valuation
-            if domain is domain.base() and valuation.domain() is valuation.domain().base() and to_valuation_domain == domain.hom([~valuation.domain().gen()]) and from_valuation_domain == valuation.domain().hom([~domain.gen()]):
-                # valuation on the rational function field after x |--> 1/x
+            if domain is domain.base() and valuation.domain() is valuation.domain().base():
                 if valuation == valuation.domain().valuation(valuation.domain().gen()):
-                    # the classical valuation at the place 1/x
+                    if to_valuation_domain != domain.hom([~valuation.domain().gen()]) or from_valuation_domain != valuation.domain().hom([~domain.gen()]):
+                        raise ValueError("the only allowed automorphism for classical valuations is the automorphism x |--> 1/x")
+                    # valuation on the rational function field after x |--> 1/x,
+                    # i.e., the classical valuation at infinity
                     return parent.__make_element_class__(InfiniteRationalFunctionFieldValuation)(parent)
 
                 from sage.structure.dynamic_class import dynamic_class
@@ -570,7 +575,7 @@ class DiscreteFunctionFieldValuation_base(DiscreteValuation):
                     from functools import reduce
                     A = [base_valuation.extensions(L) for base_valuation in self.extensions(L.base())]
                     return reduce(add, A, [])
-                elif L.constant_field() is not K.constant_field() and K.constant_field().is_subring(L):
+                elif L.constant_base_field() is not K.constant_base_field() and K.constant_base_field().is_subring(L):
                     # subclasses should override this method and handle this case, so we never get here
                     raise NotImplementedError("Can not compute the extensions of %r from %r to %r since the base ring changes."%(self, self.domain(), L))
         raise NotImplementedError("extension of %r from %r to %r not implemented"%(self, K, L))
@@ -589,6 +594,33 @@ class RationalFunctionFieldValuation_base(FunctionFieldValuation_base):
         True
 
     """
+    @cached_method
+    def element_with_valuation(self, s):
+        r"""
+        Return an element with valuation ``s``.
+
+        EXAMPLES::
+
+            sage: K.<a> = NumberField(x^3+6)
+            sage: v = K.valuation(2)
+            sage: R.<x> = K[]
+            sage: w = GaussValuation(R, v).augmentation(x, 1/123)
+            sage: K.<x> = FunctionField(K)
+            sage: w = w.extension(K)
+            sage: w.element_with_valuation(122/123)
+            2/x
+            sage: w.element_with_valuation(1)
+            2
+
+        """
+        constant_valuation = self.restriction(self.domain().constant_base_field())
+        if constant_valuation.is_trivial():
+            return super(RationalFunctionFieldValuation_base, self).element_with_valuation(s)
+
+        a, b = self.value_group()._element_with_valuation(constant_valuation.value_group(), s)
+        ret = self.uniformizer()**a * constant_valuation.element_with_valuation(constant_valuation.value_group().gen()*b)
+
+        return self.simplify(ret, error=s)
 
 
 class ClassicalFunctionFieldValuation_base(DiscreteFunctionFieldValuation_base):
@@ -619,7 +651,7 @@ class ClassicalFunctionFieldValuation_base(DiscreteFunctionFieldValuation_base):
         """
         tester = self._tester(**options)
 
-        tester.assertTrue(self.domain().constant_field().is_subring(self.residue_field()))
+        tester.assertTrue(self.domain().constant_base_field().is_subring(self.residue_field()))
 
     def _ge_(self, other):
         r"""
@@ -643,7 +675,7 @@ class ClassicalFunctionFieldValuation_base(DiscreteFunctionFieldValuation_base):
         super(ClassicalFunctionFieldValuation_base, self)._ge_(other)
 
 
-class InducedFunctionFieldValuation_base(FunctionFieldValuation_base):
+class InducedRationalFunctionFieldValuation_base(FunctionFieldValuation_base):
     r"""
     Base class for function field valuation induced by a valuation on the
     underlying polynomial ring.
@@ -660,8 +692,8 @@ class InducedFunctionFieldValuation_base(FunctionFieldValuation_base):
 
             sage: K.<x> = FunctionField(QQ)
             sage: v = K.valuation(x) # indirect doctest
-            sage: from sage.rings.function_field.function_field_valuation import InducedFunctionFieldValuation_base
-            sage: isinstance(v, InducedFunctionFieldValuation_base)
+            sage: from sage.rings.function_field.function_field_valuation import InducedRationalFunctionFieldValuation_base
+            sage: isinstance(v, InducedRationalFunctionFieldValuation_base)
             True
             
         """
@@ -772,7 +804,7 @@ class InducedFunctionFieldValuation_base(FunctionFieldValuation_base):
         from sage.rings.valuation.augmented_valuation import AugmentedValuation_base
         from sage.rings.valuation.gauss_valuation import GaussValuation
         if isinstance(self._base_valuation, AugmentedValuation_base):
-            if self._base_valuation._base_valuation == GaussValuation(self.domain()._ring, TrivialValuation(self.domain().constant_field())):
+            if self._base_valuation._base_valuation == GaussValuation(self.domain()._ring, TrivialValuation(self.domain().constant_base_field())):
                 if self._base_valuation._mu == 1:
                     return "(%r)-adic valuation"%(self._base_valuation.phi())
         vK = self._base_valuation.restriction(self._base_valuation.domain().base_ring())
@@ -802,8 +834,8 @@ class InducedFunctionFieldValuation_base(FunctionFieldValuation_base):
         if L in FunctionFields() \
             and K.is_subring(L) \
             and L.base() is L \
-            and L.constant_field() is not K.constant_field() \
-            and K.constant_field().is_subring(L.constant_field()):
+            and L.constant_base_field() is not K.constant_base_field() \
+            and K.constant_base_field().is_subring(L.constant_base_field()):
             # The above condition checks whether L is an extension of K that
             # comes from an extension of the field of constants
             # Condition "L.base() is L" is important so we do not call this
@@ -813,7 +845,7 @@ class InducedFunctionFieldValuation_base(FunctionFieldValuation_base):
             W = self._base_valuation.extensions(L._ring)
             return [L.valuation(w) for w in W]
 
-        return super(InducedFunctionFieldValuation_base, self).extensions(L)
+        return super(InducedRationalFunctionFieldValuation_base, self).extensions(L)
 
     def _call_(self, f):
         r"""
@@ -839,23 +871,117 @@ class InducedFunctionFieldValuation_base(FunctionFieldValuation_base):
             sage: K.valuation(x).residue_ring()
             Rational Field
 
-            sage: K.<x> = FunctionField(QQ)
-            sage: v = valuations.GaussValuation(QQ['x'], QQ.valuation(2))
-            sage: w = K.valuation(v)
-            sage: w.residue_ring()
-            Fraction Field of Univariate Polynomial Ring in x over Finite Field of size 2 (using ...)
-
-            sage: R.<x> = QQ[]
-            sage: vv = v.augmentation(x, 1)
-            sage: w = K.valuation(vv)
-            sage: w.residue_ring()
-            Fraction Field of Univariate Polynomial Ring in x over Finite Field of size 2 (using ...)
-            
         """
         return self._base_valuation.residue_ring().fraction_field()
 
+    def restriction(self, ring):
+        r"""
+        Return the restriction of this valuation to ``ring``.
 
-class FiniteRationalFunctionFieldValuation(InducedFunctionFieldValuation_base, ClassicalFunctionFieldValuation_base, RationalFunctionFieldValuation_base):
+        EXAMPLES::
+
+            sage: K.<x> = FunctionField(QQ)
+            sage: K.valuation(x).restriction(QQ)
+            Trivial valuation on Rational Field
+
+        """
+        if ring.is_subring(self._base_valuation.domain()):
+            return self._base_valuation.restriction(ring)
+        return super(InducedRationalFunctionFieldValuation_base, self).restriction(ring)
+
+    def simplify(self, f, error=None, force=False):
+        r"""
+        Return a simplified version of ``f``.
+
+        Produce an element which differs from ``f`` by an element of
+        valuation strictly greater than the valuation of ``f`` (or strictly
+        greater than ``error`` if set.)
+        
+        If ``force`` is not set, then expensive simplifications may be avoided.
+
+        EXAMPLES::
+
+            sage: K.<x> = FunctionField(QQ)
+            sage: v = K.valuation(2)
+            sage: f = (x + 1)/(x - 1)
+
+        As the coefficients of this fraction are small, we do not simplify as
+        this could be very costly in some cases::
+
+            sage: v.simplify(f)
+            (x + 1)/(x - 1)
+
+        However, simplification can be forced::
+
+            sage: v.simplify(f, force=True)
+            3
+
+        """
+        f = self.domain().coerce(f)
+
+        if error is None:
+            # if the caller was sure that we should simplify, then we should try to do the best simplification possible
+            error = self(f) if force else self.upper_bound(f)
+
+        from sage.all import infinity
+        if error is infinity:
+            return f
+
+        numerator = f.numerator()
+        denominator = f.denominator()
+
+        v_numerator = self._base_valuation(numerator)
+        v_denominator = self._base_valuation(denominator)
+
+        if v_numerator - v_denominator > error:
+            return self.domain().zero()
+
+        if error == -infinity:
+            # This case is not implemented yet, so we just return f which is always safe.
+            return f
+
+        numerator = self.domain()(self._base_valuation.simplify(numerator, error=error+v_denominator, force=force))
+        denominator = self.domain()(self._base_valuation.simplify(denominator, error=max(v_denominator, error - v_numerator + 2*v_denominator), force=force))
+
+        ret = numerator/denominator
+        assert self(ret - f) > error
+        return ret
+
+    def _relative_size(self, f):
+        r"""
+        Return an estimate on the coefficient size of ``f``.
+
+        The number returned is an estimate on the factor between the number of
+        bits used by ``f`` and the minimal number of bits used by an element
+        congruent to ``f``.
+
+        This can be used by :meth:`simplify` to decide whether simplification
+        of coefficients is going to lead to a significant shrinking of the
+        coefficients of ``f``.
+
+        EXAMPLES:: 
+
+            sage: K.<x> = FunctionField(QQ)
+            sage: v = K.valuation(0)
+            sage: f = (x + 1024)/(x - 1024)
+
+        Here we report a small size, as the numerator and the denominator
+        independently can not be simplified much::
+
+            sage: v._relative_size(f)
+            1
+
+        However, a forced simplification, finds that we could have saved many
+        more bits::
+
+            sage: v.simplify(f, force=True)
+            -1
+
+        """
+        return max(self._base_valuation._relative_size(f.numerator()), self._base_valuation._relative_size(f.denominator()))
+
+
+class FiniteRationalFunctionFieldValuation(InducedRationalFunctionFieldValuation_base, ClassicalFunctionFieldValuation_base, RationalFunctionFieldValuation_base):
     r"""
     Valuation of a finite place of a function field.
 
@@ -894,12 +1020,12 @@ class FiniteRationalFunctionFieldValuation(InducedFunctionFieldValuation_base, C
             True
     
         """
-        InducedFunctionFieldValuation_base.__init__(self, parent, base_valuation)
+        InducedRationalFunctionFieldValuation_base.__init__(self, parent, base_valuation)
         ClassicalFunctionFieldValuation_base.__init__(self, parent)
         RationalFunctionFieldValuation_base.__init__(self, parent)
 
 
-class NonClassicalRationalFunctionFieldValuation(InducedFunctionFieldValuation_base, RationalFunctionFieldValuation_base):
+class NonClassicalRationalFunctionFieldValuation(InducedRationalFunctionFieldValuation_base, RationalFunctionFieldValuation_base):
     r"""
     Valuation induced by a valuation on the underlying polynomial ring which is
     non-classical.
@@ -929,9 +1055,50 @@ class NonClassicalRationalFunctionFieldValuation(InducedFunctionFieldValuation_b
             True
 
         """
-        InducedFunctionFieldValuation_base.__init__(self, parent, base_valuation)
+        InducedRationalFunctionFieldValuation_base.__init__(self, parent, base_valuation)
         RationalFunctionFieldValuation_base.__init__(self, parent)
 
+    def residue_ring(self):
+        r"""
+        Return the residue field of this valuation.
+
+        EXAMPLES::
+
+            sage: K.<x> = FunctionField(QQ)
+            sage: v = valuations.GaussValuation(QQ['x'], QQ.valuation(2))
+            sage: w = K.valuation(v)
+            sage: w.residue_ring()
+            Rational function field in x over Finite Field of size 2
+
+            sage: R.<x> = QQ[]
+            sage: vv = v.augmentation(x, 1)
+            sage: w = K.valuation(vv)
+            sage: w.residue_ring()
+            Rational function field in x over Finite Field of size 2
+
+            sage: R.<y> = K[]
+            sage: L.<y> = K.extension(y^2 + 2*x)
+            sage: w.extension(L).residue_ring()
+            Function field in u2 defined by u2^2 + x
+
+        TESTS:
+
+        This still works for pseudo-valuations::
+
+            sage: R.<x> = QQ[]
+            sage: v = valuations.GaussValuation(R, QQ.valuation(2))
+            sage: vv = v.augmentation(x, infinity)
+            sage: K.<x> = FunctionField(QQ)
+            sage: w = K.valuation(vv)
+            sage: w.residue_ring()
+            Finite Field of size 2
+
+        """
+        if not self.is_discrete_valuation():
+            # A pseudo valuation attaining negative infinity does typically not have a function field as its residue ring
+            return super(NonClassicalRationalFunctionFieldValuation, self).residue_ring()
+        return self._base_valuation.residue_ring().fraction_field().function_field()
+
 
 class FunctionFieldFromLimitValuation(FiniteExtensionFromLimitValuation, DiscreteFunctionFieldValuation_base):
     r"""
@@ -1122,10 +1289,54 @@ class FunctionFieldMappedValuation_base(FunctionFieldValuation_base, MappedValua
         return self._base_valuation.is_discrete_valuation()
 
 
-class RationalFunctionFieldMappedValuation(FunctionFieldMappedValuation_base, RationalFunctionFieldValuation_base):
+class FunctionFieldMappedValuationRelative_base(FunctionFieldMappedValuation_base):
+    r"""
+    A valuation on a function field which relies on a ``base_valuation`` on an
+    isomorphic function field and which is such that the map from and to the
+    other function field is the identity on the constant field.
+
+    EXAMPLES::
+    
+        sage: K.<x> = FunctionField(GF(2))
+        sage: v = K.valuation(1/x); v
+        Valuation at the infinite place
+
+    """
+    def __init__(self, parent, base_valuation, to_base_valuation_domain, from_base_valuation_domain):
+        r"""
+        TESTS::
+    
+            sage: K.<x> = FunctionField(GF(2))
+            sage: v = K.valuation(1/x)
+            sage: from sage.rings.function_field.function_field_valuation import FunctionFieldMappedValuationRelative_base
+            sage: isinstance(v, FunctionFieldMappedValuationRelative_base)
+            True
+    
+        """
+        FunctionFieldMappedValuation_base.__init__(self, parent, base_valuation, to_base_valuation_domain, from_base_valuation_domain)
+        if self.domain().constant_base_field() is not base_valuation.domain().constant_base_field():
+            raise ValueError("constant fields must be identical but they differ for %r and %r"%(self.domain(), base_valuation.domain()))
+
+    def restriction(self, ring):
+        r"""
+        Return the restriction of this valuation to ``ring``.
+
+        EXAMPLES::
+
+            sage: K.<x> = FunctionField(GF(2))
+            sage: K.valuation(1/x).restriction(GF(2))
+            Trivial valuation on Finite Field of size 2
+
+        """
+        if ring.is_subring(self.domain().constant_base_field()):
+            return self._base_valuation.restriction(ring)
+        return super(FunctionFieldMappedValuation_base, self).restriction(ring)
+
+
+class RationalFunctionFieldMappedValuation(FunctionFieldMappedValuationRelative_base, RationalFunctionFieldValuation_base):
     r"""
     Valuation on a rational function field that is implemented after a map to
-    an isomorphic (rational) function field.
+    an isomorphic rational function field.
 
     EXAMPLES::
 
@@ -1151,11 +1362,11 @@ class RationalFunctionFieldMappedValuation(FunctionFieldMappedValuation_base, Ra
             True
 
         """
-        FunctionFieldMappedValuation_base.__init__(self, parent, base_valuation, to_base_valuation_doain, from_base_valuation_domain)
+        FunctionFieldMappedValuationRelative_base.__init__(self, parent, base_valuation, to_base_valuation_doain, from_base_valuation_domain)
         RationalFunctionFieldValuation_base.__init__(self, parent)
 
 
-class InfiniteRationalFunctionFieldValuation(FunctionFieldMappedValuation_base, RationalFunctionFieldValuation_base, ClassicalFunctionFieldValuation_base):
+class InfiniteRationalFunctionFieldValuation(FunctionFieldMappedValuationRelative_base, RationalFunctionFieldValuation_base, ClassicalFunctionFieldValuation_base):
     r"""
     Valuation of the infinite place of a function field.
 
@@ -1177,7 +1388,7 @@ class InfiniteRationalFunctionFieldValuation(FunctionFieldMappedValuation_base,
 
         """
         x = parent.domain().gen()
-        FunctionFieldMappedValuation_base.__init__(self, parent, FunctionFieldValuation(parent.domain(), x), parent.domain().hom([1/x]), parent.domain().hom([1/x]))
+        FunctionFieldMappedValuationRelative_base.__init__(self, parent, FunctionFieldValuation(parent.domain(), x), parent.domain().hom([1/x]), parent.domain().hom([1/x]))
         RationalFunctionFieldValuation_base.__init__(self, parent)
         ClassicalFunctionFieldValuation_base.__init__(self, parent)
 
@@ -1195,7 +1406,7 @@ class InfiniteRationalFunctionFieldValuation(FunctionFieldMappedValuation_base,
         return "Valuation at the infinite place"
 
 
-class FunctionFieldExtensionMappedValuation(FunctionFieldMappedValuation_base):
+class FunctionFieldExtensionMappedValuation(FunctionFieldMappedValuationRelative_base):
     r"""
     A valuation on a finite extensions of function fields `L=K[y]/(G)` where `K` is
     another function field which redirects to another ``base_valuation`` on an
