@@ -78,18 +78,19 @@ AUTHORS:
 
 """
 from __future__ import absolute_import
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2010 William Stein <wstein@gmail.com>
 #       Copyright (C) 2011 Maarten Derickx <m.derickx.student@gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 import operator
 import itertools
+from functools import reduce
 
 from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_import import lazy_import
@@ -109,6 +110,7 @@ from sage.rings.ideal import Ideal_generic
 
 lazy_import('sage.matrix.constructor', 'matrix')
 
+
 class FunctionFieldIdeal(Element):
     """
     Fractional ideals of function fields.
@@ -159,11 +161,13 @@ class FunctionFieldIdeal(Element):
 
     def gens_reduced(self):
         r"""
-        Return reduced generators. This just returns the generators for now.
+        Return reduced generators.
 
-        This method is provided so that ideals in funtion fields have the method
-        :meth:`gens_reduced()`, just like ideals of number fields. Sage linear algebra
-        machinery sometimes requires this.
+        This just returns the generators for now.
+
+        This method is provided so that ideals in function fields have
+        the method :meth:`gens_reduced()`, just like ideals of number
+        fields. Sage linear algebra machinery sometimes requires this.
 
         EXAMPLES::
 
@@ -172,7 +176,6 @@ class FunctionFieldIdeal(Element):
             sage: I = O.ideal(x,x^2,x^2+x)
             sage: I.gens_reduced()
             (x,)
-
         """
         return self.gens()
 
@@ -205,6 +208,7 @@ class FunctionFieldIdeal(Element):
         """
         return self.ring()
 
+
 class FunctionFieldIdeal_rational(FunctionFieldIdeal):
     """
     Fractional ideals of the maximal order of a rational function field.
@@ -260,7 +264,7 @@ class FunctionFieldIdeal_rational(FunctionFieldIdeal):
             sage: I = O.ideal(x,1/(x+1)); I
             Ideal (1/(x + 1)) of Maximal order of Rational function field in x over Rational Field
         """
-        return "Ideal (%s) of %s"%(self._gen, self._ring)
+        return "Ideal (%s) of %s" % (self._gen, self._ring)
 
     def __contains__(self, element):
         """
@@ -514,6 +518,7 @@ class FunctionFieldIdeal_rational(FunctionFieldIdeal):
              factors.append( (self.ring().ideal(f), m) )
         return factors
 
+
 class FunctionFieldIdeal_module(FunctionFieldIdeal, Ideal_generic):
     """
     A fractional ideal specified by a finitely generated module over
@@ -663,7 +668,7 @@ class FunctionFieldIdeal_module(FunctionFieldIdeal, Ideal_generic):
             sage: O.ideal(x^2 + 1)
             Ideal (x^2 + 1, (x^2 + 1)*y) of Order in Function field in y defined by y^2 - x^3 - 1
         """
-        return "Ideal (%s) of %s"%(', '.join([repr(g) for g in self.gens()]), self.ring())
+        return "Ideal (%s) of %s" % (', '.join([repr(g) for g in self.gens()]), self.ring())
 
     def gens(self):
         """
@@ -818,6 +823,7 @@ class FunctionFieldIdeal_module(FunctionFieldIdeal, Ideal_generic):
             inv = inv.intersection(R.ideal(~g))
         return inv
 
+
 class FunctionFieldIdeal_global(FunctionFieldIdeal):
     """
     Fractional ideals of canonical function fields
@@ -866,10 +872,10 @@ class FunctionFieldIdeal_global(FunctionFieldIdeal):
         self._prime_below = None
         self._beta = None
 
-        # beta in matrix form for fast multiplicaton
+        # beta in matrix form for fast multiplication
         self._beta_matrix = None
 
-        # (p, q) with irreducibl polynomial p and q an element of O in vector
+        # (p, q) with irreducible polynomial p and q an element of O in vector
         # form, together generating the prime ideal. This data is obtained by
         # Kummer's theorem when this prime ideal is constructed. This is used
         # for fast multiplication with other ideal.
@@ -1065,7 +1071,7 @@ class FunctionFieldIdeal_global(FunctionFieldIdeal):
             return "Zero ideal of %s" % (self._ring,)
 
         s = ', '.join([repr(g) for g in self.gens_two()])
-        return "Ideal (%s) of %s"%(s, self._ring)
+        return "Ideal (%s) of %s" % (s, self._ring)
 
     def _add_(self, other):
         """
@@ -1779,12 +1785,14 @@ class FunctionFieldIdeal_global(FunctionFieldIdeal):
         """
         return self._prime_below
 
+
 class FunctionFieldIdealInfinite(FunctionFieldIdeal):
     """
     Base class of ideals of maximal infinite orders
     """
     pass
 
+
 class FunctionFieldIdealInfinite_rational(FunctionFieldIdealInfinite):
     """
     Fractional ideal of the maximal order of rational function field.
@@ -1860,7 +1868,7 @@ class FunctionFieldIdealInfinite_rational(FunctionFieldIdealInfinite):
             Ideal (1/x) of Maximal infinite order of Rational function field
             in x over Finite Field of size 2
         """
-        return "Ideal (%s) of %s"%(self._gen, self._ring)
+        return "Ideal (%s) of %s" % (self._gen, self._ring)
 
     def _add_(self, other):
         """
@@ -2042,6 +2050,7 @@ class FunctionFieldIdealInfinite_rational(FunctionFieldIdealInfinite):
         else:
             return f.denominator().degree() - f.numerator().degree()
 
+
 class FunctionFieldIdealInfinite_module(FunctionFieldIdealInfinite, Ideal_generic):
     """
     A fractional ideal specified by a finitely generated module over
@@ -2203,7 +2212,7 @@ class FunctionFieldIdealInfinite_module(FunctionFieldIdealInfinite, Ideal_generi
             sage: P*[a^2,a*b+c,c^3] # indirect doctest
             Ideal (a^2, a*b + c, c^3) of Multivariate Polynomial Ring in a, b, c over Rational Field
         """
-        return "Ideal %s of %s"%(self._repr_short(), self.ring())
+        return "Ideal %s of %s" % (self._repr_short(), self.ring())
 
     def module(self):
         """
@@ -2234,6 +2243,7 @@ class FunctionFieldIdealInfinite_module(FunctionFieldIdealInfinite, Ideal_generi
         """
         return self._module
 
+
 class FunctionFieldIdealInfinite_global(FunctionFieldIdealInfinite):
     """
     Ideals of the infinite maximal order.
@@ -2720,6 +2730,7 @@ class FunctionFieldIdealInfinite_global(FunctionFieldIdealInfinite):
 
         return self._ideal.valuation(self.ring()._to_iF(ideal))
 
+
 class IdealMonoid(UniqueRepresentation, Parent):
     r"""
     The monoid of ideals in orders of function fields.
@@ -2764,7 +2775,7 @@ class IdealMonoid(UniqueRepresentation, Parent):
             sage: M = O.ideal_monoid(); M._repr_()
             'Monoid of ideals of Maximal order of Rational function field in x over Finite Field of size 2'
         """
-        return "Monoid of ideals of %s"%self.__R
+        return "Monoid of ideals of %s" % self.__R
 
     def ring(self):
         """
