@@ -44,10 +44,7 @@ from six.moves import range
 
 from sage.groups.abelian_gps.values import AbelianGroupWithValues_class, AbelianGroupWithValuesElement
 from sage.groups.abelian_gps.abelian_group_element import AbelianGroupElement
-from sage.structure.sequence import Sequence
 from sage.structure.element import MonoidElement
-from sage.groups.old import Group
-from sage.arith.all import LCM
 from sage.rings.all import ZZ
 
 
