@@ -65,7 +65,7 @@ class NumberFieldHomset(RingHomset_generic):
             return self._coerce_impl(im_gens)
         try:
             return NumberFieldHomomorphism_im_gens(self, im_gens, check=check)
-        except (NotImplementedError, ValueError) as err:
+        except (NotImplementedError, ValueError):
             try:
                 return self._coerce_impl(im_gens)
             except TypeError:
@@ -301,8 +301,10 @@ class NumberFieldHomomorphism_im_gens(RingHomomorphism_im_gens):
             raise TypeError("Can only invert isomorphisms")
         V, V_into_K, _ = K.vector_space()
         _, _, L_into_W = L.vector_space()
-        linear_inverse = ~V.hom([(L_into_W*self*V_into_K)(_) for _ in V.basis()])
-        return L.hom([(V_into_K*linear_inverse*L_into_W)(_) for _ in [L.gen()]])
+        linear_inverse = ~V.hom([(L_into_W * self * V_into_K)(b)
+                                 for b in V.basis()])
+        return L.hom([(V_into_K * linear_inverse * L_into_W)(b)
+                      for b in [L.gen()]])
 
     def preimage(self, y):
         r"""
@@ -729,7 +731,7 @@ class CyclotomicFieldHomset(NumberFieldHomset):
             return self._coerce_impl(im_gens)
         try:
             return CyclotomicFieldHomomorphism_im_gens(self, im_gens, check=check)
-        except (NotImplementedError, ValueError) as err:
+        except (NotImplementedError, ValueError):
             try:
                 return self._coerce_impl(im_gens)
             except TypeError:
