@@ -144,7 +144,6 @@ def integral_elements_in_box(K, C):
         [-1/2*a + 2, 1/4*a^2 + 1/2*a, 0, 1, 2, 3, 4,...-1/4*a^2 - 1/2*a + 5, 1/2*a + 3, -1/4*a^2 + 5]
     """
     d = K.degree()
-    Z_F = K.maximal_order()
     Foo = K.real_embeddings()
     B = K.reduced_basis()
 
@@ -195,20 +194,17 @@ def integral_elements_in_box(K, C):
 
     from sage.geometry.lattice_polytope import LatticePolytope
     P = LatticePolytope(M)
-    S = []
 
     try:
         pts = P.points()
     except ValueError:
         return []
 
+    S = []
     for p in pts:
-        theta = sum([ p.list()[i]*B[i] for i in range(d)])
-        inbounds = True
-        for i in range(d):
-            inbounds = inbounds and Foo[i](theta) >= C[i][0] and Foo[i](theta) <= C[i][1]
-
-        if inbounds:
+        theta = sum(a * b for a, b in zip(p.list(), B))
+        if all((C[i][0] <= Foo[i](theta) <= C[i][1])
+               for i in range(d)):
             S.append(theta)
 
     return S
@@ -261,7 +257,7 @@ class tr_data_rel:
         self.m = m
         d = F.degree()
         self.d = d
-        self.n = m*d
+        self.n = n = m*d
         self.B = B
         self.gamma = hermite_constant(self.n-self.d)
 
@@ -288,7 +284,7 @@ class tr_data_rel:
                 for j in range(len(anm1s)):
                     anm1s[j] = [ anm1s[j] + [i] for i in range(m)]
                 anm1s = sum(anm1s, [])
-            anm1s = [sum([Z_Fbasis[i]*a[i] for i in range(self.d)]) for a in anm1s]
+            anm1s = [sum([Z_Fbasis[i] * aa[i] for i in range(self.d)]) for aa in anm1s]
             # Minimize trace in class.
             import numpy
             for i in range(len(anm1s)):
@@ -322,7 +318,7 @@ class tr_data_rel:
             self.k = k
             a = [0]*(k+1) + a
             self.amaxvals = [[]]*m
-            for i in range(0,n+1):
+            for i in range(n+1):
                 self.a[i] = a[i]
 
             # Bounds come from an application of Lagrange multipliers in degrees 2,3.
@@ -373,11 +369,9 @@ class tr_data_rel:
 
         the successor polynomial as a coefficient list.
         """
-
         import numpy
 
         m = self.m
-        n = self.n
         k = self.k
         d = self.d
 
@@ -855,9 +849,9 @@ def enumerate_totallyreal_fields_rel(F, m, B, a = [], verbose=0,
                 S[(d, ng)] = Fx([-1,6,-5,1])
 
     # Convert S to a sorted list of triples [d, fabs, f], taking care
-    # to use cmp() and not the comparison operators on PARI polynomials.
+    # not to use the comparison operators on PARI polynomials.
     S = [[s[0], s[1], t] for s, t in S.items()]
-    S.sort(key=lambda x: (x[0], [QQ(x) for x in x[1].polrecip().Vec()]))
+    S.sort(key=lambda x: (x[0], [QQ(cf) for cf in x[1].polrecip().Vec()]))
 
     # Now check for isomorphic fields
     weed_fields(S)
@@ -969,13 +963,12 @@ def enumerate_totallyreal_fields_all(n, B, verbose=0, return_seqs=False,
                     S += [[t[0],pari(t[1]).Polrev()] for t in T[1]]
                 else:
                     S += [[t[0],t[1]] for t in T]
-                j = i+1
                 for E in enumerate_totallyreal_fields_prim(n/d, int(math.floor((1.*B)**(1./d)/(1.*Sds[i][0])**(n*1./d**2)))):
                     for EF in F.composite_fields(NumberField(ZZx(E[1]), 'u')):
                         if EF.degree() == n and EF.disc() <= B:
                             S.append([EF.disc(), pari(EF.absolute_polynomial())])
     S += enumerate_totallyreal_fields_prim(n, B, verbose=verbose)
-    S.sort(key=lambda x: (x[0], [QQ(x) for x in x[1].polrecip().Vec()]))
+    S.sort(key=lambda x: (x[0], [QQ(cf) for cf in x[1].polrecip().Vec()]))
     weed_fields(S)
 
     # Output.
