@@ -30,6 +30,7 @@ TESTS::
 #                  http://www.gnu.org/licenses/
 # ****************************************************************************
 
+from __future__ import division
 from collections import defaultdict
 
 from sage.misc.misc import walltime
@@ -376,7 +377,7 @@ class pRational:
             val = self._valuation + other._valuation
         return self.__class__(self.p, self.x * other.x, self.exponent + other.exponent, valuation=val)
 
-    def __div__(self, other):
+    def __truediv__(self, other):
         r"""
         Return the quotient of ``self`` by ``other``.
 
@@ -396,6 +397,8 @@ class pRational:
             val = self._valuation - other._valuation
         return self.__class__(self.p, self.x / other.x, self.exponent - other.exponent, valuation=val)
 
+    __div__ = __truediv__
+
     def _quo_rem(self, other):
         """
         Quotient with remainder.
@@ -1485,7 +1488,7 @@ class DifferentialPrecisionGeneric(SageObject):
           a dictionary
 
         Here are the meanings of the keywords above:
-        - ``add``: time spent in adding new colunmns to the precision matrix
+        - ``add``: time spent in adding new columns to the precision matrix
           (corresponding to the creation of new elements)
         - ``mark``: time spent in marking elements for deletion
         - ``del``: time spent in deleting columns of the precision matrix
