@@ -218,7 +218,7 @@ class LocalGeneric(CommutativeRing):
         EXAMPLES::
 
             sage: latex(Zq(27,names='a')) #indirect doctest
-            \ZZ_{3^{3}}
+            \Bold{Z}_{3^{3}}
         """
         return self._repr_(do_latex = True)
 
