@@ -1,7 +1,7 @@
 r"""
 `p`-Adic Base Generic
 
-A superclass for implementations of `\mathbb{Z}_p` and `\mathbb{Q}_p`.
+A superclass for implementations of `\ZZ_p` and `\QQ_p`.
 
 AUTHORS:
 
@@ -84,43 +84,43 @@ class pAdicBaseGeneric(pAdicGeneric):
             sage: K = Zp(17); K #indirect doctest
             17-adic Ring with capped relative precision 20
             sage: latex(K)
-            \ZZ_{17}
+            \Bold{Z}_{17}
             sage: K = ZpCA(17); K #indirect doctest
             17-adic Ring with capped absolute precision 20
             sage: latex(K)
-            \ZZ_{17}
+            \Bold{Z}_{17}
             sage: K = ZpFP(17); K #indirect doctest
             17-adic Ring with floating precision 20
             sage: latex(K)
-            \ZZ_{17}
+            \Bold{Z}_{17}
             sage: K = ZpFM(7); K
             7-adic Ring of fixed modulus 7^20
             sage: latex(K) #indirect doctest
-            \ZZ_{7}
+            \Bold{Z}_{7}
             sage: K = ZpLF(2); K   # indirect doctest
             doctest:...: FutureWarning: This class/method/function is marked as experimental. It, its functionality or its interface might change without a formal deprecation.
             See http://trac.sagemath.org/23505 for details.
             2-adic Ring with lattice-float precision
             sage: latex(K)
-            \ZZ_{2}
+            \Bold{Z}_{2}
             sage: K = Qp(17); K #indirect doctest
             17-adic Field with capped relative precision 20
             sage: latex(K)
-            \QQ_{17}
+            \Bold{Q}_{17}
             sage: K = QpFP(17); K #indirect doctest
             17-adic Field with floating precision 20
             sage: latex(K)
-            \QQ_{17}
+            \Bold{Q}_{17}
             sage: K = QpLC(2); K   # indirect doctest
             2-adic Field with lattice-cap precision
             sage: latex(K)
-            \QQ_{2}
+            \Bold{Q}_{2}
         """
         if do_latex:
             if self.is_field():
-                s = r"\QQ_{%s}" % self.prime()
+                s = r"\Bold{Q}_{%s}" % self.prime()
             else:
-                s = r"\ZZ_{%s}" % self.prime()
+                s = r"\Bold{Z}_{%s}" % self.prime()
             if hasattr(self, '_label') and self._label:
                 s = r"\verb'%s' (\simeq %s)"%(self._label, s)
         else:
@@ -158,7 +158,7 @@ class pAdicBaseGeneric(pAdicGeneric):
 
     def is_isomorphic(self, ring):
         r"""
-        Returns whether ``self`` and ``ring`` are isomorphic, i.e. whether ``ring`` is an implementation of `\mathbb{Z}_p` for the same prime as ``self``.
+        Returns whether ``self`` and ``ring`` are isomorphic, i.e. whether ``ring`` is an implementation of `\ZZ_p` for the same prime as ``self``.
 
         INPUT:
 
@@ -168,7 +168,7 @@ class pAdicBaseGeneric(pAdicGeneric):
 
         OUTPUT:
 
-        - ``boolean`` -- whether ``ring`` is an implementation of \mathbb{Z}_p` for the same prime as ``self``.
+        - ``boolean`` -- whether ``ring`` is an implementation of \ZZ_p` for the same prime as ``self``.
 
         EXAMPLES::
 
@@ -307,7 +307,7 @@ class pAdicBaseGeneric(pAdicGeneric):
 
     def has_pth_root(self):
         r"""
-        Returns whether or not `\mathbb{Z}_p` has a primitive `p^{th}`
+        Returns whether or not `\ZZ_p` has a primitive `p^{th}`
         root of unity.
 
         EXAMPLES::
@@ -321,7 +321,7 @@ class pAdicBaseGeneric(pAdicGeneric):
 
     def has_root_of_unity(self, n):
         r"""
-        Returns whether or not `\mathbb{Z}_p` has a primitive `n^{th}`
+        Returns whether or not `\ZZ_p` has a primitive `n^{th}`
         root of unity.
 
         INPUT:
@@ -404,7 +404,7 @@ class pAdicBaseGeneric(pAdicGeneric):
         triangle.
 
         The resulting image attempts to capture the
-        algebraic and topological characteristics of `\mathbb{Z}_p`.
+        algebraic and topological characteristics of `\ZZ_p`.
 
         INPUT:
 
@@ -433,7 +433,7 @@ class pAdicBaseGeneric(pAdicGeneric):
             args['pointsize'] = 1
         from sage.misc.mrange import cartesian_product_iterator
         from sage.rings.real_double import RDF
-        from sage.plot.all import points, circle, Graphics
+        from sage.plot.all import points
         p = self.prime()
         phi = 2*RDF.pi()/p
         V = RDF**2
