@@ -16,15 +16,16 @@ AUTHORS:
 - Ben Hutz (2018-7) -- improvements to reduce and implement smallest coefficient model 
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2018 Benjamin Hutz <bn4941#gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
+from __future__ import division
 
 from sage.arith.misc import gcd
 from sage.calculus.functions import jacobian
@@ -515,10 +516,10 @@ def smallest_poly(F, prec=53, norm_type='norm', emb=None):
             else:
                 pts.append(item)
             return pts
-        else: #binary insertion
+        else:  # binary insertion
             left = 1
             right = N
-            mid = ((left + right)/2)# these are ints so this is .floor()
+            mid = (left + right) // 2  # these are ints so this is .floor()
             if item[index] > pts[mid][index]: # item goes into first half
                 return insert_item(pts[:mid], item, index) + pts[mid:N]
             else: # item goes into second half
