@@ -1,14 +1,13 @@
 r"""
 Groebner Fans
 
-Sage provides much of the functionality of gfan, which is a
+Sage provides much of the functionality of ``gfan``, which is a
 software package whose main function is to enumerate all reduced
 Groebner bases of a polynomial ideal. The reduced Groebner bases
 yield the maximal cones in the Groebner fan of the ideal. Several
 subcomputations can be issued and additional tools are included.
 Among these the highlights are:
 
-
 -  Commands for computing tropical varieties.
 
 -  Interactive walks in the Groebner fan of an ideal.
@@ -19,7 +18,7 @@ Among these the highlights are:
 
 AUTHORS:
 
-- Anders Nedergaard Jensen: Wrote the gfan C++ program, which
+- Anders Nedergaard Jensen: Wrote the ``gfan`` C++ program, which
   implements algorithms many of which were invented by Jensen, Komei
   Fukuda, and Rekha Thomas. All the underlying hard work of the
   Groebner fans functionality of Sage depends on this C++ program.
@@ -28,11 +27,11 @@ AUTHORS:
   for working with Groebner fans.
 
 - Tristram Bogart: the design of the Sage interface
-  to gfan is joint work with Tristram Bogart, who also supplied
+  to ``gfan`` is joint work with Tristram Bogart, who also supplied
   numerous examples.
 
 - Marshall Hampton (2008-03-25): Rewrote various functions to use
-  gfan-0.3. This is still a work in progress, comments are
+  ``gfan-0.3``. This is still a work in progress, comments are
   appreciated on sage-devel@googlegroups.com (or personally at
   hamptonio@gmail.com).
 
@@ -54,12 +53,10 @@ TESTS::
 
 REFERENCES:
 
-- Anders N. Jensen; Gfan, a software system for Groebner fans;
-  available at
-  http://www.math.tu-berlin.de/~jensen/software/gfan/gfan.html
+- Anders N. Jensen; *Gfan, a software system for Groebner fans*;
+  http://home.math.au.dk/jensen/software/gfan/gfan.html
 """
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import print_function, absolute_import
 
 import string
 import pexpect
@@ -81,10 +78,12 @@ from sage.geometry.polyhedron.constructor import Polyhedron
 from sage.geometry.fan import Fan
 from sage.matrix.constructor import matrix
 from sage.misc.misc_c import prod
+from sage.cpython.string import str_to_bytes, bytes_to_str
+
 
 def prefix_check(str_list):
     """
-    Checks if any strings in a list are prefixes of another string in
+    Check if any strings in a list are prefixes of another string in
     the list.
 
     EXAMPLES::
@@ -95,18 +94,17 @@ def prefix_check(str_list):
         sage: prefix_check(['z1','zz1'])
         True
     """
-    for index1 in range(len(str_list)):
-        for index2 in range(len(str_list)):
-            string1 = str_list[index1]
-            string2 = str_list[index2]
-            if index1 != index2 and str_list[index1][0:len(string2)].find(string2) != -1:
-                return False
+    for index1, string1 in enumerate(str_list):
+        for index2, string2 in enumerate(str_list):
+            if index1 != index2:
+                if string1[:len(string2)] == string2:
+                    return False
     return True
 
 
 def max_degree(list_of_polys):
     """
-    Computes the maximum degree of a list of polynomials
+    Compute the maximum degree of a list of polynomials
 
     EXAMPLES::
 
@@ -116,7 +114,8 @@ def max_degree(list_of_polys):
         sage: max_degree(p_list)
         11.0
     """
-    return max([float(qf.degree()) for qf in list_of_polys])
+    return float(max(qf.degree() for qf in list_of_polys))
+
 
 def _cone_parse(fan_dict_cone):
     """
@@ -125,11 +124,9 @@ def _cone_parse(fan_dict_cone):
 
     INPUT:
 
-
     -  ``fan_dict_cone`` - the value of a fan_dict with
        key 'CONES'
 
-
     EXAMPLES::
 
         sage: R.<x,y,z,w> = PolynomialRing(QQ,4)
@@ -154,14 +151,17 @@ def _cone_parse(fan_dict_cone):
             if cur_dim > 0:
                 cone_dict[cur_dim] = [[Integer(q) for q in temp if q != '']]
         else:
-            if cur_dim > 0: cone_dict[cur_dim] += [[Integer(q) for q in temp if q != '']]
+            if cur_dim > 0:
+                cone_dict[cur_dim] += [[Integer(q) for q in temp if q != '']]
     return cone_dict
 
+
 class PolyhedralCone(SageObject):
 
-    def __init__(self, gfan_polyhedral_cone, ring = QQ):
+    def __init__(self, gfan_polyhedral_cone, ring=QQ):
         """
-        Converts polymake/gfan data on a polyhedral cone into a sage class.
+        Convert polymake/gfan data on a polyhedral cone into a sage class.
+
         Currently (18-03-2008) needs a lot of work.
 
         EXAMPLES::
@@ -175,10 +175,9 @@ class PolyhedralCone(SageObject):
         cone_keys = ['AMBIENT_DIM','DIM','IMPLIED_EQUATIONS', 'LINEALITY_DIM', 'LINEALITY_SPACE','FACETS', 'RELATIVE_INTERIOR_POINT']
         poly_lines = gfan_polyhedral_cone.split('\n')
         self.cone_dict = {}
-        key_ind = 0
         cur_key = None
         for ting in poly_lines:
-            if cone_keys.count(ting) > 0:
+            if cone_keys.count(ting):
                 cur_key = ting
                 self.cone_dict[cur_key] = []
             elif cur_key and ting != '':
@@ -197,7 +196,7 @@ class PolyhedralCone(SageObject):
 
     def _repr_(self):
         """
-        Returns a basic description of the polyhedral cone.
+        Return a basic description of the polyhedral cone.
 
         EXAMPLES::
 
@@ -207,11 +206,11 @@ class PolyhedralCone(SageObject):
             sage: a # indirect doctests
             Polyhedral cone in 3 dimensions of dimension 3
         """
-        return "Polyhedral cone in %s dimensions of dimension %s"%(str(self.ambient_dim()), str(self.dim()))
+        return "Polyhedral cone in {} dimensions of dimension {}".format(self.ambient_dim(), self.dim())
 
     def facets(self):
         """
-        Returns the inward facet normals of the Groebner cone.
+        Return the inward facet normals of the Groebner cone.
 
         EXAMPLES::
 
@@ -225,7 +224,7 @@ class PolyhedralCone(SageObject):
 
     def ambient_dim(self):
         """
-        Returns the ambient dimension of the Groebner cone.
+        Return the ambient dimension of the Groebner cone.
 
         EXAMPLES::
 
@@ -239,7 +238,7 @@ class PolyhedralCone(SageObject):
 
     def dim(self):
         """
-        Returns the dimension of the Groebner cone.
+        Return the dimension of the Groebner cone.
 
         EXAMPLES::
 
@@ -253,7 +252,7 @@ class PolyhedralCone(SageObject):
 
     def lineality_dim(self):
         """
-        Returns the lineality dimension of the Groebner cone. This is
+        Return the lineality dimension of the Groebner cone. This is
         just the difference between the ambient dimension and the dimension
         of the cone.
 
@@ -269,7 +268,7 @@ class PolyhedralCone(SageObject):
 
     def relative_interior_point(self):
         """
-        Returns a point in the relative interior of the Groebner cone.
+        Return a point in the relative interior of the Groebner cone.
 
         EXAMPLES::
 
@@ -281,10 +280,11 @@ class PolyhedralCone(SageObject):
         """
         return self._relative_interior_point
 
+
 class PolyhedralFan(SageObject):
     def __init__(self, gfan_polyhedral_fan, parameter_indices = []):
         """
-        Converts polymake/gfan data on a polyhedral fan into a sage class.
+        Convert polymake/gfan data on a polyhedral fan into a sage class.
 
         INPUT:
 
@@ -307,7 +307,6 @@ class PolyhedralFan(SageObject):
                     'CONES','MAXIMAL_CONES','PURE','SIMPLICIAL','MULTIPLICITIES']
         poly_lines = gfan_polyhedral_fan.split('\n')
         self.fan_dict = {}
-        key_ind = 0
         cur_key = None
         for ting in poly_lines:
             if fan_keys.count(ting) > 0:
@@ -333,7 +332,7 @@ class PolyhedralFan(SageObject):
 
     def _repr_(self):
         """
-        Returns a basic description of the polyhedral fan.
+        Return a basic description of the polyhedral fan.
 
         EXAMPLES::
 
@@ -343,13 +342,14 @@ class PolyhedralFan(SageObject):
             sage: pf # indirect doctest
             Polyhedral fan in 3 dimensions of dimension 3
         """
-        return "Polyhedral fan in %s dimensions of dimension %s"%(str(self.ambient_dim()), str(self.dim()))
+        return "Polyhedral fan in {} dimensions of dimension {}".format(self.ambient_dim(), self.dim())
 
     def _str_(self):
         r"""
-        Returns the raw output of gfan as a string. This should only be
-        needed internally as all relevant output is converted to sage
-        objects.
+        Return the raw output of gfan as a string.
+
+        This should only be needed internally as all relevant output
+        is converted to sage objects.
 
         EXAMPLES::
 
@@ -363,7 +363,7 @@ class PolyhedralFan(SageObject):
 
     def ambient_dim(self):
         """
-        Returns the ambient dimension of the Groebner fan.
+        Return the ambient dimension of the Groebner fan.
 
         EXAMPLES::
 
@@ -377,7 +377,7 @@ class PolyhedralFan(SageObject):
 
     def dim(self):
         """
-        Returns the dimension of the Groebner fan.
+        Return the dimension of the Groebner fan.
 
         EXAMPLES::
 
@@ -391,7 +391,7 @@ class PolyhedralFan(SageObject):
 
     def lineality_dim(self):
         """
-        Returns the lineality dimension of the fan. This is the
+        Return the lineality dimension of the fan. This is the
         dimension of the largest subspace contained in the fan.
 
         EXAMPLES::
@@ -531,15 +531,17 @@ class PolyhedralFan(SageObject):
             self._fan = fan
             return self._fan
 
+
 class InitialForm(SageObject):
     def __init__(self, cone, rays, initial_forms):
         """
         A system of initial forms from a polynomial system.
+
         To each form is associated a cone and a list of
         polynomials (the initial form system itself).
 
         This class is intended for internal use inside of the
-        TropicalPrevariety class.
+        :class:`TropicalPrevariety` class.
 
         EXAMPLES::
 
@@ -553,7 +555,6 @@ class InitialForm(SageObject):
         self._rays = rays
         self._initial_forms = initial_forms
 
-
     def cone(self):
         """
         The cone associated with the initial form system.
@@ -619,9 +620,10 @@ class InitialForm(SageObject):
         """
         return self._initial_forms
 
+
 def verts_for_normal(normal, poly):
     """
-    Returns the exponents of the vertices of a Newton polytope
+    Return the exponents of the vertices of a Newton polytope
     that make up the supporting hyperplane for the given outward
     normal.
 
@@ -636,7 +638,7 @@ def verts_for_normal(normal, poly):
     """
     exps = [tuple(x) for x in poly.exponents()]
     expmat = matrix(exps)
-    vals = expmat*vector(QQ,normal)
+    vals = expmat * vector(QQ, normal)
     maxval = max(vals)
     outverts = []
     for i in range(len(exps)):
@@ -644,6 +646,7 @@ def verts_for_normal(normal, poly):
             outverts.append(exps[i])
     return outverts
 
+
 class TropicalPrevariety(PolyhedralFan):
 
     def __init__(self, gfan_polyhedral_fan, polynomial_system, poly_ring, parameters = []):
@@ -653,8 +656,7 @@ class TropicalPrevariety(PolyhedralFan):
 
         INPUT:
 
-
-        -  ``gfan_polyhedral_fan`` - output from gfan of a
+        -  ``gfan_polyhedral_fan`` - output from ``gfan`` of a
            polyhedral fan.
         -  ``polynomial_system`` - a list of polynomials
         -  ``poly_ring`` - the polynomial ring of the list of polynomials
@@ -679,7 +681,7 @@ class TropicalPrevariety(PolyhedralFan):
 
     def initial_form_systems(self):
         """
-        Returns a list of systems of initial forms for each cone
+        Return a list of systems of initial forms for each cone
         in the tropical prevariety.
 
         EXAMPLES::
@@ -718,6 +720,7 @@ class TropicalPrevariety(PolyhedralFan):
             self._initial_form_systems = initial_form_systems
             return self._initial_form_systems
 
+
 def ring_to_gfan_format(input_ring):
     """
     Converts a ring to gfan's format.
@@ -732,13 +735,14 @@ def ring_to_gfan_format(input_ring):
         sage: ring_to_gfan_format(R2)
         'Z/2Z[x, y]'
     """
-    if input_ring.base_ring() == QQ:
-        ring_str = 'Q' + str(input_ring.gens()).replace('(','[').replace(')',']')
-    elif input_ring.base_ring() == ZZ:
-        ring_str = 'Z' + str(input_ring.gens()).replace('(','[').replace(')',']')
+    gens = str(input_ring.gens()).replace('(', '[').replace(')', ']')
+    if input_ring.base_ring() is QQ:
+        return 'Q' + gens
+    elif input_ring.base_ring() is ZZ:
+        return 'Z' + gens
     else:
-        ring_str = 'Z/' + str(input_ring.characteristic()) + 'Z'+ str(input_ring.gens()).replace('(','[').replace(')',']')
-    return ring_str
+        return 'Z/{}Z'.format(input_ring.characteristic()) + gens
+
 
 def ideal_to_gfan_format(input_ring, polys):
     """
@@ -766,17 +770,18 @@ def ideal_to_gfan_format(input_ring, polys):
     output = ring_str + ideal_gen_str
     return output
 
+
 class GroebnerFan(SageObject):
 
     def __init__(self, I, is_groebner_basis=False, symmetry=None, verbose=False):
         """
-        This class is used to access capabilities of the program Gfan.  In
-        addition to computing Groebner fans, Gfan can compute other things in
-        tropical geometry such as tropical prevarieties.
+        This class is used to access capabilities of the program ``Gfan``.
+
+        In addition to computing Groebner fans, ``Gfan`` can compute
+        other things in tropical geometry such as tropical prevarieties.
 
         INPUT:
 
-
         -  ``I`` - ideal in a multivariate polynomial ring
 
         -  ``is_groebner_basis`` - bool (default False). if
@@ -848,7 +853,7 @@ class GroebnerFan(SageObject):
             Groebner fan of the ideal:
             Ideal (q - u, u^2 - 1) of Multivariate Polynomial Ring in q, u over Rational Field
         """
-        return "Groebner fan of the ideal:\n%s"%self.__ideal
+        return "Groebner fan of the ideal:\n{}".format(self.__ideal)
 
     def __eq__(self,right):
         """
@@ -883,10 +888,9 @@ class GroebnerFan(SageObject):
 
         OUTPUT:
 
-        - map from Sage ring to gfan ring
-
-        - map from gfan ring to Sage ring
+        - map from Sage ring to ``gfan`` ring
 
+        - map from ``gfan`` ring to Sage ring
 
         EXAMPLES::
 
@@ -929,7 +933,7 @@ class GroebnerFan(SageObject):
 
     def _gfan_ring(self):
         """
-        Return the ring in gfan's notation
+        Return the ring in ``gfan`` notation.
 
         EXAMPLES::
 
@@ -942,7 +946,7 @@ class GroebnerFan(SageObject):
 
     def _gfan_ideal(self):
         """
-        Return the ideal in gfan's notation.
+        Return the ideal in ``gfan`` notation.
 
         EXAMPLES::
 
@@ -959,7 +963,7 @@ class GroebnerFan(SageObject):
 
     def weight_vectors(self):
         """
-        Returns the weight vectors corresponding to the reduced Groebner
+        Return the weight vectors corresponding to the reduced Groebner
         bases.
 
         EXAMPLES::
@@ -974,10 +978,10 @@ class GroebnerFan(SageObject):
             23
         """
         gfan_processes = Popen(['gfan','_weightvector','-m'], stdin = PIPE, stdout=PIPE, stderr=PIPE)
-        ans, err = gfan_processes.communicate(input = self.gfan())
+        ans, err = gfan_processes.communicate(input=str_to_bytes(self.gfan()))
+        ans = bytes_to_str(ans)
         ans = sage_eval(ans.replace('{','').replace('}','').replace('\n',''))
-        ans = [vector(QQ,x) for x in ans]
-        return ans
+        return [vector(QQ, x) for x in ans]
 
     def ring(self):
         """
@@ -995,7 +999,7 @@ class GroebnerFan(SageObject):
     def _gfan_reduced_groebner_bases(self):
         """
         A string of the reduced Groebner bases of the ideal as output by
-        gfan.
+        ``gfan``.
 
         EXAMPLES::
 
@@ -1067,9 +1071,9 @@ class GroebnerFan(SageObject):
 
     def _gfan_mod(self):
         """
-        Return the extra options to the gfan command that are used by this
-        object to account for working modulo a prime or in the presence of
-        extra symmetries.
+        Return the extra options to the ``gfan`` command that are used
+        by this object to account for working modulo a prime or in the
+        presence of extra symmetries.
 
         EXAMPLES::
 
@@ -1082,11 +1086,11 @@ class GroebnerFan(SageObject):
             return self.__gfan_mod
         except AttributeError:
             mod = ''
-            #p = self.characteristic()
-            #if p != 0:
-            #    mod += ' --mod %s'%p
-            #else:
-            #    mod += ''
+            # p = self.characteristic()
+            # if p:
+            #     mod += ' --mod %s' % p
+            # else:
+            #     mod += ''
 
             if self.__is_groebner_basis:
                 mod += ' -g'
@@ -1099,8 +1103,10 @@ class GroebnerFan(SageObject):
 
     def gfan(self, cmd='bases', I=None, format=True):
         r"""
-        Returns the gfan output as a string given an input cmd; the default
-        is to produce the list of reduced Groebner bases in gfan format.
+        Return the ``gfan`` output as a string given an input ``cmd``.
+
+        The default is to produce the list of reduced Groebner bases
+        in ``gfan`` format.
 
         EXAMPLES::
 
@@ -1115,12 +1121,12 @@ class GroebnerFan(SageObject):
         cmd += self._gfan_mod()
         s = gfan(I, cmd, verbose=self.__verbose, format=format)
         if s.strip() == '{':
-            raise RuntimeError("Error running gfan command %s on %s"%(cmd, self))
+            raise RuntimeError("Error running gfan command %s on %s" % (cmd, self))
         return s
 
     def __iter__(self):
         """
-        Returns an iterator for the reduced Groebner bases.
+        Return an iterator for the reduced Groebner bases.
 
         EXAMPLES::
 
@@ -1135,11 +1141,9 @@ class GroebnerFan(SageObject):
 
     def __getitem__(self, i):
         """
-        Gets a reduced groebner basis
+        Get a reduced groebner basis
 
-        EXAMPLES;
-
-        ::
+        EXAMPLES::
 
             sage: R4.<w1,w2,w3,w4> = PolynomialRing(QQ,4)
             sage: gf = R4.ideal([w1^2-w2,w2^3-1,2*w3-w4^2,w4^2-w1]).groebner_fan()
@@ -1150,8 +1154,7 @@ class GroebnerFan(SageObject):
 
     def buchberger(self):
         """
-        Computes and returns a lexicographic reduced Groebner basis for the
-        ideal.
+        Return a lexicographic reduced Groebner basis for the ideal.
 
         EXAMPLES::
 
@@ -1174,7 +1177,7 @@ class GroebnerFan(SageObject):
 
     def polyhedralfan(self):
         """
-        Returns a polyhedral fan object corresponding to the reduced
+        Return a polyhedral fan object corresponding to the reduced
         Groebner bases.
 
         EXAMPLES::
@@ -1222,7 +1225,6 @@ class GroebnerFan(SageObject):
 
         INPUT:
 
-
         -  ``file`` - a filename if you prefer the output
            saved to a file. This will be in xfig format.
 
@@ -1278,12 +1280,12 @@ class GroebnerFan(SageObject):
             raise NotImplementedError
         cmd = 'render'
         if shift:
-            cmd += ' --shiftVariables %s'%shift
+            cmd += ' --shiftVariables %s' % shift
         if larger:
             cmd += ' -L'
         s = self.gfan(cmd, I=self._gfan_reduced_groebner_bases().replace(' ',','), format=False)
         if file is not None:
-            open(file,'w').write(s)
+            open(file, 'w').write(s)
         sp = s.split('\n')
         sp2 = []
         for x in sp[9:]:
@@ -1356,10 +1358,8 @@ class GroebnerFan(SageObject):
 
         INPUT:
 
-
         -  ``fpoint`` - a list of four numbers
 
-
         EXAMPLES::
 
             sage: R.<x> = PolynomialRing(QQ,1) # dummy stuff to get a gfan object
@@ -1370,10 +1370,10 @@ class GroebnerFan(SageObject):
         v1 = [1,1,-1,-1]
         v2 = [1,-1,1,-1]
         v3 = [-1,1,1,-1]
-        x1 = sum([fpoint[ind]*v1[ind] for ind in range(4)])
-        x2 = sum([fpoint[ind]*v2[ind] for ind in range(4)])
-        x3 = sum([fpoint[ind]*v3[ind] for ind in range(4)])
-        return [x1,x2,x3]
+        x1 = sum([fpoint[ind] * v1[ind] for ind in range(4)])
+        x2 = sum([fpoint[ind] * v2[ind] for ind in range(4)])
+        x3 = sum([fpoint[ind] * v3[ind] for ind in range(4)])
+        return [x1, x2, x3]
 
     def _4d_to_3d(self, polyhedral_data):
         """
@@ -1414,16 +1414,15 @@ class GroebnerFan(SageObject):
             i = vertex.index()
             for adjacent_vertex in vertex.adjacent():
                 j = adjacent_vertex.index()
-                if j>i:
+                if j > i:
                     try:
-                        edges.append([tpoints[i],tpoints[j]])
+                        edges.append([tpoints[i], tpoints[j]])
                     except Exception:
-                        print(adj)
                         print('tpoints: ' + str(tpoints))
                         print('fpoints: ' + str(fpoints))
                         print(adjacent_vertex)
                         print(polyhedral_data.ieqs())
-                        raise RuntimeError(adj)
+                        raise RuntimeError
         return edges
 
     def render3d(self, verbose = False):
@@ -1462,7 +1461,7 @@ class GroebnerFan(SageObject):
         g_cones_ieqs = [self._cone_to_ieq(q) for q in g_cones_facets]
         # Now the cones are intersected with a plane:
         cone_info = [Polyhedron(ieqs = q, eqns = [[1,-1,-1,-1,-1]]) for q in g_cones_ieqs]
-        #This is really just for debugging
+        # This is really just for debugging
         if verbose:
             for x in cone_info:
                 print(x.inequalities() + ([1,1,0,0,0],[1,0,1,0,0],[1,0,0,1,0],[1,0,0,0,1]))
@@ -1592,13 +1591,11 @@ class GroebnerFan(SageObject):
 
         INPUT:
 
-
         -  ``check`` - bool (default: True); if True raises a
            ValueError exception if this ideal does not define a tropical curve
            (i.e., the condition that R/I has dimension equal to 1 + the
            dimension of the homogeneity space is not satisfied).
 
-
         EXAMPLES::
 
             sage: R.<x,y,z> = PolynomialRing(QQ,3, order='lex')
@@ -1626,9 +1623,10 @@ class GroebnerFan(SageObject):
         if B.find(']') != -1:
                 B = B.split(']')[1]
         S = self.__ring
-        B = B.replace('\n','')
-        B = B.replace('{','').replace('}','').split(',')
-        if verbose: print(S, B)
+        B = B.replace('\n', '')
+        B = B.replace('{', '').replace('}', '').split(',')
+        if verbose:
+            print(S, B)
         X = [S(f) for f in B]
         self.__tropical_basis = X
         return X
@@ -1647,11 +1645,13 @@ class GroebnerFan(SageObject):
 
     def tropical_intersection(self, parameters = [], symmetry_generators = [], *args, **kwds):
         """
-        Returns information about the tropical intersection of the
-        polynomials defining the ideal.  This is the common refinement
-        of the outward-pointing normal fans of the Newton polytopes of
-        the generators of the ideal. Note that some people use the
-        inward-pointing normal fans.
+        Return information about the tropical intersection of the
+        polynomials defining the ideal.
+
+        This is the common refinement of the outward-pointing normal
+        fans of the Newton polytopes of the generators of the
+        ideal. Note that some people use the inward-pointing normal
+        fans.
 
         INPUT:
 
@@ -1697,12 +1697,13 @@ class GroebnerFan(SageObject):
             id_str = self._gfan_ideal()
             if parameters != []:
                 allvars = self.ring().gens()
-                truevars = [q for q in allvars if not q in parameters]
+                truevars = [q for q in allvars if q not in parameters]
                 base_ring = self.ring().base_ring()
-                new_ring = PolynomialRing(base_ring, len(truevars), ",".join(str(q) for q in truevars))
+                new_ring = PolynomialRing(base_ring, len(truevars),
+                                          ",".join(str(q) for q in truevars))
                 old_polys = self.ideal().gens()
                 new_polys = []
-                sub = dict([[v,1] for v in parameters])
+                sub = dict([[v, 1] for v in parameters])
                 for apoly in old_polys:
                     mons = apoly.monomials()
                     mons = [m.subs(sub) for m in mons]
@@ -1712,17 +1713,21 @@ class GroebnerFan(SageObject):
                 cmd = cmd + ' --symmetryExploit'
                 id_str = id_str + '{' + symmetry_generators + '}'
             f = self.gfan(cmd=cmd, I = id_str)
-            pf = TropicalPrevariety(f,self.ideal().gens(), self.ring(), parameters = parameters)
+            pf = TropicalPrevariety(f, self.ideal().gens(), self.ring(),
+                                    parameters=parameters)
             pf._gfan_output = f
             self.__tropical_intersection = pf
             return pf
 
-
     def mixed_volume(self):
         """
-        Returns the mixed volume of the generators of this ideal (i.e. this is
-        not really an ideal property, it can depend on the generators used).
-        The generators must give a square system (as many polynomials as variables).
+        Return the mixed volume of the generators of this ideal.
+
+        This is not really an ideal property, it can depend on the
+        generators used.
+
+        The generators must give a square system (as many polynomials
+        as variables).
 
         EXAMPLES::
 
@@ -1741,18 +1746,18 @@ class GroebnerFan(SageObject):
             15
         """
         if len(self.ring().variable_names()) != self.ideal().ngens():
-            raise UserWarning('not a square system')
+            raise ValueError('not a square system')
         return Integer(self.gfan(cmd='mixedvolume'))
 
+
 class ReducedGroebnerBasis(SageObject, list):
     def __init__(self, groebner_fan, gens, gfan_gens):
         """
         A class for representing reduced Groebner bases as produced by
-        gfan.
+        ``gfan``.
 
         INPUT:
 
-
         -  ``groebner_fan`` - a GroebnerFan object from an
            ideal
 
@@ -1776,7 +1781,7 @@ class ReducedGroebnerBasis(SageObject, list):
 
     def _repr_(self):
         """
-        Returns the reduced Groebner basis as a string.
+        Return the reduced Groebner basis as a string.
 
         EXAMPLES::
 
@@ -1790,7 +1795,7 @@ class ReducedGroebnerBasis(SageObject, list):
 
     def _gfan_gens(self):
         """
-        Returns the reduced Groebner basis as a string in gfan format.
+        Return the reduced Groebner basis as a string in ``gfan`` format.
 
         EXAMPLES::
 
@@ -1804,7 +1809,7 @@ class ReducedGroebnerBasis(SageObject, list):
 
     def _gfan(self):
         """
-        Returns a description of the Groebner fan this basis was derived
+        Return a description of the Groebner fan this basis was derived
         from.
 
         EXAMPLES::
@@ -1849,7 +1854,7 @@ class ReducedGroebnerBasis(SageObject, list):
         cmd += self.__groebner_fan._gfan_mod()
         E = pexpect.spawn(cmd)
         print("Initializing gfan interactive mode")
-        #E.sendline(self._gfan_ideal())
+        # E.sendline(self._gfan_ideal())
         E.sendline(self.__gfan_gens)
         print("*" * 45)
         print("*     Press control-C to return to Sage     *")
@@ -1866,12 +1871,10 @@ class ReducedGroebnerBasis(SageObject, list):
 
         INPUT:
 
-
         -  ``restrict`` - bool (default: False); if True, add
            an inequality for each coordinate, so that the cone is restricted
            to the positive orthant.
 
-
         OUTPUT: tuple of integer vectors
 
         EXAMPLES::
@@ -1899,7 +1902,6 @@ class ReducedGroebnerBasis(SageObject, list):
         c = gf.gfan(cmd=cmd, I=self.__ring + self.__gfan_gens)
         return PolyhedralCone(c)
 
-
     def ideal(self):
         """
         Return the ideal generated by this basis.
@@ -1912,6 +1914,3 @@ class ReducedGroebnerBasis(SageObject, list):
             Ideal (-13*z^3 + y^2, -z^3 + x) of Multivariate Polynomial Ring in x, y, z over Rational Field
         """
         return self.__groebner_fan.ring().ideal(self)
-
-
-
