@@ -70,7 +70,7 @@ from sage.rings.integer_ring import is_IntegerRing
 
 import sage.rings.polynomial.multi_polynomial_ideal as multi_polynomial_ideal
 
-from sage.rings.polynomial.multi_polynomial_ring_generic import MPolynomialRing_generic, is_MPolynomialRing
+from sage.rings.polynomial.multi_polynomial_ring_base import MPolynomialRing_base, is_MPolynomialRing
 from sage.rings.polynomial.polynomial_singular_interface import PolynomialRing_singular_repr
 from sage.rings.polynomial.polydict import PolyDict, ETuple
 from sage.rings.polynomial.term_order import TermOrder
@@ -120,7 +120,7 @@ class MPolynomialRing_macaulay2_repr:
         return self.base_ring().is_exact()
 
 
-class MPolynomialRing_polydict( MPolynomialRing_macaulay2_repr, PolynomialRing_singular_repr, MPolynomialRing_generic):
+class MPolynomialRing_polydict( MPolynomialRing_macaulay2_repr, PolynomialRing_singular_repr, MPolynomialRing_base):
     """
     Multivariable polynomial ring.
 
@@ -134,7 +134,7 @@ class MPolynomialRing_polydict( MPolynomialRing_macaulay2_repr, PolynomialRing_s
     def __init__(self, base_ring, n, names, order):
         from sage.rings.polynomial.polynomial_singular_interface import can_convert_to_singular
         order = TermOrder(order,n)
-        MPolynomialRing_generic.__init__(self, base_ring, n, names, order)
+        MPolynomialRing_base.__init__(self, base_ring, n, names, order)
         # Construct the generators
         v = [0] * n
         one = base_ring(1);
@@ -148,7 +148,7 @@ class MPolynomialRing_polydict( MPolynomialRing_macaulay2_repr, PolynomialRing_s
         self._zero_tuple = tuple(v)
         self._has_singular = can_convert_to_singular(self)
         # This polynomial ring should belong to Algebras(base_ring).
-        # Algebras(...).parent_class, which was called from MPolynomialRing_generic.__init__,
+        # Algebras(...).parent_class, which was called from MPolynomialRing_base.__init__,
         # tries to provide a conversion from the base ring, if it does not exist.
         # This is for algebras that only do the generic stuff in their initialisation.
         # But here, we want to use PolynomialBaseringInjection. Hence, we need to
@@ -194,6 +194,17 @@ class MPolynomialRing_polydict( MPolynomialRing_macaulay2_repr, PolynomialRing_s
         """
         return not (self == other)
 
+    def __hash__(self):
+        """
+        Compute the hash of self.
+
+        EXAMPLES::
+
+            sage: h = hash(PolynomialRing(Integers(8), 'x', 3))
+        """
+        return hash((self.base_ring(), self.ngens(),
+                     self.variable_names(), self.term_order()))
+
     def __call__(self, x, check=True):
         """
         Convert ``x`` to an element of this multivariate polynomial ring,
@@ -941,7 +952,7 @@ class MPolynomialRing_polydict_domain(IntegralDomain,
                 gens = gens[0]
         if not self._has_singular:
             # pass through
-            MPolynomialRing_generic.ideal(self,gens,**kwds)
+            MPolynomialRing_base.ideal(self,gens,**kwds)
         if is_SingularElement(gens):
             gens = list(gens)
             do_coerce = True
