@@ -13,7 +13,7 @@ TESTS::
 
     sage: R.<x> = PolynomialRing(ZZ)
     sage: I = R.ideal([4 + 3*x + x^2, 1 + x^2])
-    sage: S = R.quotient_ring(I);
+    sage: S = R.quotient_ring(I)
 
 .. todo::
 
