@@ -664,7 +664,7 @@ class NonFinalInductiveValuation(FiniteInductiveValuation, DiscreteValuation):
         from .augmented_valuation import AugmentedValuation
         return AugmentedValuation(self, phi, mu, check)
 
-    def mac_lane_step(self, G, principal_part_bound=None, assume_squarefree=False, assume_equivalence_irreducible=False, report_degree_bounds_and_caches=False, coefficients=None, valuations=None, check=True):
+    def mac_lane_step(self, G, principal_part_bound=None, assume_squarefree=False, assume_equivalence_irreducible=False, report_degree_bounds_and_caches=False, coefficients=None, valuations=None, check=True, allow_equivalent_key=True):
         r"""
         Perform an approximation step towards the squarefree monic non-constant
         integral polynomial ``G`` which is not an :meth:`equivalence unit <InductiveValuation.is_equivalence_unit>`.
@@ -698,6 +698,54 @@ class NonFinalInductiveValuation(FiniteInductiveValuation, DiscreteValuation):
           non-constant  integral polynomial and not an :meth:`equivalence unit <InductiveValuation.is_equivalence_unit>`
           (default: ``True``)
 
+        - ``allow_equivalent_key`` -- whether to return valuations which end in
+          essentially the same key polynomial as this valuation but have a
+          higher valuation assigned to that key polynomial (default: ``True``)
+
+        EXAMPLES:
+
+        We can use this method to perform the individual steps of
+        :meth:`~sage.rings.valuation.valuation.DiscreteValuation.mac_lane_approximants`::
+
+            sage: R.<x> = QQ[]
+            sage: v = QQ.valuation(2)
+            sage: f = x^36 + 1160/81*x^31 + 9920/27*x^30 + 1040/81*x^26 + 52480/81*x^25 + 220160/81*x^24 - 5120/81*x^21 - 143360/81*x^20 - 573440/81*x^19 + 12451840/81*x^18 - 266240/567*x^16 - 20316160/567*x^15 - 198737920/189*x^14 - 1129840640/81*x^13 - 1907359744/27*x^12 + 8192/81*x^11 + 655360/81*x^10 + 5242880/21*x^9 + 2118123520/567*x^8 + 15460204544/567*x^7 + 6509559808/81*x^6 - 16777216/567*x^2 - 268435456/567*x - 1073741824/567
+            sage: v.mac_lane_approximants(f)
+            [[ Gauss valuation induced by 2-adic valuation, v(x + 2056) = 23/2 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 11/9 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 2/5, v(x^5 + 4) = 7/2 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 3/5, v(x^10 + 8*x^5 + 64) = 7 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 3/5, v(x^5 + 8) = 5 ]]
+
+        Starting from the Gauss valuation, a MacLane step branches off with
+        some linear key polynomials in the above example::
+
+            sage: v0 = GaussValuation(R, v)
+            sage: V1 = v0.mac_lane_step(f); V1
+            [[ Gauss valuation induced by 2-adic valuation, v(x) = 3/5 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 2/5 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 3 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 11/9 ]]
+
+        The computation of MacLane approximants would now perform a MacLane
+        step on each of these branches, note however, that a direct call to
+        this method might produce some unexpected results::
+
+            sage: V1[0].mac_lane_step(f)
+            [[ Gauss valuation induced by 2-adic valuation, v(x) = 3/5, v(x^5 + 8) = 5 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 3/5, v(x^10 + 8*x^5 + 64) = 7 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 3 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 11/9 ]]
+
+        Note how this detected the two augmentations of ``V1[0]`` but also two
+        other valuations that we had seen in the previous step and that are
+        greater than ``V1[0]``. To ignore such trivial augmentations, we can
+        set ``allow_equivalent_key``::
+
+            sage: V1[0].mac_lane_step(f, allow_equivalent_key=False)
+            [[ Gauss valuation induced by 2-adic valuation, v(x) = 3/5, v(x^5 + 8) = 5 ],
+             [ Gauss valuation induced by 2-adic valuation, v(x) = 3/5, v(x^10 + 8*x^5 + 64) = 7 ]]
+
         TESTS::
 
             sage: K.<x> = FunctionField(QQ)
@@ -729,7 +777,7 @@ class NonFinalInductiveValuation(FiniteInductiveValuation, DiscreteValuation):
 
         from itertools import islice
         from sage.misc.misc import verbose
-        verbose("Augmenting %s towards %s"%(self, G), level=10)
+        verbose("Augmenting %s towards %s" % (self, G), level=10)
 
         if not G.is_monic():
             raise ValueError("G must be monic")
@@ -737,12 +785,14 @@ class NonFinalInductiveValuation(FiniteInductiveValuation, DiscreteValuation):
         if coefficients is None:
             coefficients = self.coefficients(G)
             if principal_part_bound:
-                coefficients = islice(coefficients, 0, principal_part_bound + 1, 1)
+                coefficients = islice(coefficients, 0,
+                                      int(principal_part_bound) + 1, 1)
             coefficients = list(coefficients)
         if valuations is None:
             valuations = self.valuations(G, coefficients=coefficients)
             if principal_part_bound:
-                valuations = islice(valuations, 0, principal_part_bound + 1, 1)
+                valuations = islice(valuations, 0,
+                                    int(principal_part_bound) + 1, 1)
             valuations = list(valuations)
 
         if check and min(valuations) < 0:
@@ -780,9 +830,28 @@ class NonFinalInductiveValuation(FiniteInductiveValuation, DiscreteValuation):
                     assert len(F) == 1
                     break
 
-                verbose("Determining the augmentation of %s for %s"%(self, phi), level=11)
+                if not allow_equivalent_key and self.phi().degree() == phi.degree():
+                    # We ignore augmentations that could have been detected in
+                    # the previous MacLane step, see [Rüt2014, Theorem 4.33],
+                    # i.e., we ignore key polynomials that are equivalent to
+                    # the current key in the sense of that theorem.
+                    if self.is_equivalent(self.phi(), phi):
+                        continue
+
+                verbose("Determining the augmentation of %s for %s" % (self, phi), level=11)
+
+                base = self
+                if phi.degree() == base.phi().degree():
+                    # very frequently, the degree of the key polynomials
+                    # stagnate for a bit while the valuation of the key
+                    # polynomial is slowly increased.
+                    # In this case, we can drop previous key polynomials
+                    # of the same degree. (They have no influence on the
+                    # phi-adic expansion.)
+                    if not base.is_gauss_valuation():
+                        base = base._base_valuation
                 old_mu = self(phi)
-                w = self.augmentation(phi, old_mu, check=False)
+                w = base.augmentation(phi, old_mu, check=False)
 
                 # we made some experiments here: instead of computing the
                 # coefficients again from scratch, update the coefficients when
@@ -794,12 +863,14 @@ class NonFinalInductiveValuation(FiniteInductiveValuation, DiscreteValuation):
 
                 w_coefficients = w.coefficients(G)
                 if principal_part_bound:
-                    w_coefficients = islice(w_coefficients, 0, principal_part_bound + 1, 1)
+                    w_coefficients = islice(w_coefficients, 0,
+                                            int(principal_part_bound) + 1, 1)
                 w_coefficients = list(w_coefficients)
 
                 w_valuations = w.valuations(G, coefficients=w_coefficients)
                 if principal_part_bound:
-                    w_valuations = islice(w_valuations, 0, principal_part_bound + 1, 1)
+                    w_valuations = islice(w_valuations, 0,
+                                          int(principal_part_bound) + 1, 1)
                 w_valuations = list(w_valuations)
 
                 from sage.geometry.newton_polygon import NewtonPolygon
@@ -818,23 +889,15 @@ class NonFinalInductiveValuation(FiniteInductiveValuation, DiscreteValuation):
                     new_mu = old_mu - slope
                     new_valuations = [val - (j*slope if slope is not -infinity else (0 if j == 0 else -infinity))
                                       for j,val in enumerate(w_valuations)]
-                    base = self
-                    if phi.degree() == base.phi().degree():
-                        # very frequently, the degrees of the key polynomials
-                        # stagnate for a bit while the valuation of the key
-                        # polynomial is slowly increased.
-                        # In this case, we can drop previous key polynomials
-                        # of the same degree. (They have no influence on the
-                        # phi-adic expansion.)
-                        assert new_mu > self(phi)
-                        if not base.is_gauss_valuation():
-                            base = base._base_valuation
+                    if phi.degree() == self.phi().degree():
+                        assert new_mu > self(phi), "the valuation of the key polynomial must increase when the degree stagnates"
                     # phi has already been simplified internally by the
                     # equivalence_decomposition method but we can now possibly
                     # simplify it further as we know exactly up to which
                     # precision it needs to be defined.
                     phi = base.simplify(phi, new_mu, force=True)
                     w = base.augmentation(phi, new_mu, check=False)
+                    verbose("Augmented %s to %s"%(self, w), level=13)
                     assert slope is -infinity or 0 in w.newton_polygon(G).slopes(repetition=False)
 
                     from sage.rings.all import ZZ
@@ -844,6 +907,10 @@ class NonFinalInductiveValuation(FiniteInductiveValuation, DiscreteValuation):
                     assert degree_bound >= phi.degree()
                     ret.append((w, degree_bound, multiplicities[slope], w_coefficients, new_valuations))
 
+        if len(ret) == 0:
+            assert not allow_equivalent_key, "a MacLane step produced no augmentation"
+            assert 0 not in self.newton_polygon(G).slopes(), "a MacLane step produced no augmentation but the valuation given to the key polynomial was correct, i.e., it appears to come out of a call to mac_lane_approximants"
+
         assert ret, "a MacLane step produced no augmentations"
         if not report_degree_bounds_and_caches:
             ret = [v for v,_,_,_,_ in ret]
