@@ -130,6 +130,92 @@ def solve(F, converter=None, solver=None, n=1, target_variables=None, **kwds):
         sage: solve_sat(F,n=infinity,target_variables=[a,b])              # optional - cryptominisat
         [{b: 0, a: 0}, {b: 1, a: 1}]
 
+    Here, we generate and solve the cubic equations of the AES SBox (see :trac:`26676`)::
+
+        sage: from sage.rings.polynomial.multi_polynomial_sequence import PolynomialSequence    # optional - cryptominisat, long time
+        sage: from sage.sat.boolean_polynomials import solve as solve_sat                       # optional - cryptominisat, long time
+        sage: sr = sage.crypto.mq.SR(1, 4, 4, 8, allow_zero_inversions = True)                  # optional - cryptominisat, long time
+        sage: sb = sr.sbox()                                                                    # optional - cryptominisat, long time
+        sage: eqs = sb.polynomials(degree = 3)                                                  # optional - cryptominisat, long time
+        sage: eqs = PolynomialSequence(eqs)                                                     # optional - cryptominisat, long time
+        sage: variables = map(str, eqs.variables())                                             # optional - cryptominisat, long time
+        sage: variables = ",".join(variables)                                                   # optional - cryptominisat, long time
+        sage: R = BooleanPolynomialRing(16, variables)                                          # optional - cryptominisat, long time
+        sage: eqs = map(R, eqs)                                                                 # optional - cryptominisat, long time
+        sage: sls_aes = solve_sat(eqs, n = infinity)                                            # optional - cryptominisat, long time
+        sage: len(sls_aes)                                                                      # optional - cryptominisat, long time
+        256
+
+    TESTS:
+
+    Test that :trac:`26676` is fixed::
+
+        sage: varl = ['k{0}'.format(p) for p in range(29)]
+        sage: B = BooleanPolynomialRing(names = varl)
+        sage: B.inject_variables(verbose=False)
+        sage: keqs = [
+        ....:     k0 + k6 + 1,
+        ....:     k3 + k9 + 1,
+        ....:     k5*k18 + k6*k18 + k7*k16 + k7*k10,
+        ....:     k9*k17 + k8*k24 + k11*k17,
+        ....:     k1*k13 + k1*k15 + k2*k12 + k3*k15 + k4*k14,
+        ....:     k5*k18 + k6*k16 + k7*k18,
+        ....:     k3 + k26,
+        ....:     k0 + k19,
+        ....:     k9 + k28,
+        ....:     k11 + k20]
+        sage: from sage.sat.boolean_polynomials import solve as solve_sat
+        sage: solve_sat(keqs, n=1, solver=SAT('cryptominisat'))     # optional - cryptominisat
+        [{k28: 1,
+          k26: 0,
+          k24: 0,
+          k20: 0,
+          k19: 1,
+          k18: 0,
+          k17: 0,
+          k16: 0,
+          k15: 0,
+          k14: 0,
+          k13: 0,
+          k12: 0,
+          k11: 0,
+          k10: 0,
+          k9: 1,
+          k8: 0,
+          k7: 0,
+          k6: 0,
+          k5: 0,
+          k4: 0,
+          k3: 0,
+          k2: 0,
+          k1: 0,
+          k0: 1}]
+        sage: solve_sat(keqs, n=1, solver=SAT('picosat'))           # optional - pycosat
+        [{k28: 0,
+          k26: 1,
+          k24: 0,
+          k20: 0,
+          k19: 0,
+          k18: 0,
+          k17: 0,
+          k16: 0,
+          k15: 0,
+          k14: 0,
+          k13: 1,
+          k12: 1,
+          k11: 0,
+          k10: 0,
+          k9: 0,
+          k8: 0,
+          k7: 0,
+          k6: 1,
+          k5: 0,
+          k4: 1,
+          k3: 1,
+          k2: 1,
+          k1: 1,
+          k0: 0}]
+
     .. NOTE::
 
        Although supported, passing converter and solver objects
