@@ -91,8 +91,8 @@ class CNFEncoder(ANF2CNFConverter):
             sage: _ = solver.write()
             sage: print(open(fn).read())
             p cnf 3 2
-            1 0
             -2 0
+            1 0
             sage: e.phi
             [None, a, b, c]
 
@@ -271,8 +271,8 @@ class CNFEncoder(ANF2CNFConverter):
             sage: _ = solver.write()
             sage: print(open(fn).read())
             p cnf 3 2
-            1 0
             -2 0
+            1 0
             sage: e.phi
             [None, a, b, c]
         """
@@ -280,17 +280,21 @@ class CNFEncoder(ANF2CNFConverter):
         # the block it is evaluated to 0 by f, iff it is not lying in
         # any zero block of f+1
 
-        blocks = self.zero_blocks(f+1)
-        C = [dict([(variable, 1-value) for (variable, value) in six.iteritems(b)]) for b in blocks ]
+        blocks = self.zero_blocks(f + 1)
+        C = [{variable: 1 - value for variable, value in six.iteritems(b)}
+             for b in blocks]
 
         def to_dimacs_index(v):
-            return v.index()+1
+            return v.index() + 1
 
         def clause(c):
-            return [to_dimacs_index(variable) if value == 1 else -to_dimacs_index(variable) for (variable, value) in six.iteritems(c)]
+            return [to_dimacs_index(variable)
+                    if value == 1 else -to_dimacs_index(variable)
+                    for variable, value in six.iteritems(c)]
 
-        for c in C:
-            self.solver.add_clause(clause(c))
+        data = (clause(c) for c in C)
+        for d in sorted(data):
+            self.solver.add_clause(d)
 
     ###################################################
     # Indirect conversion, may add new variables
@@ -505,8 +509,8 @@ class CNFEncoder(ANF2CNFConverter):
             sage: _ = solver.write()
             sage: print(open(fn).read())
             p cnf 3 2
-            1 0
             -2 0
+            1 0
             sage: e.phi
             [None, a, b, c]
 
@@ -560,8 +564,8 @@ class CNFEncoder(ANF2CNFConverter):
             sage: _ = solver.write()
             sage: print(open(fn).read())
             p cnf 4 9
-            1 0
             -2 0
+            1 0
             1 -4 0
             2 -4 0
             4 -1 -2 0
