@@ -53,14 +53,11 @@ from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.qqbar import (number_field_elements_from_algebraics,
                               QQbar)
 from sage.rings.rational_field import is_RationalField
-from sage.schemes.affine.affine_space import AffineSpace
 from sage.schemes.projective.projective_space import ProjectiveSpace, is_ProjectiveSpace
 
 from . import point
 
 from sage.schemes.projective.projective_subscheme import AlgebraicScheme_subscheme_projective
-from sage.schemes.projective.projective_space import (is_ProjectiveSpace,
-                                                      ProjectiveSpace)
 
 from .curve import Curve_generic
 
@@ -129,14 +126,14 @@ class ProjectiveCurve(Curve_generic, AlgebraicScheme_subscheme_projective):
             sage: C = Curve([y*z - x^2, w^2 - x*y], P)
             sage: C.affine_patch(0)
             Affine Curve over Complex Field with 53 bits of precision defined by
-            x0*x1 - 1.00000000000000, x2^2 - x0
+            y*z - 1.00000000000000, w^2 - y
 
         ::
 
             sage: P.<x,y,z> = ProjectiveSpace(QQ, 2)
             sage: C = Curve(x^3 - x^2*y + y^3 - x^2*z, P)
             sage: C.affine_patch(1)
-            Affine Plane Curve over Rational Field defined by x0^3 - x0^2*x1 - x0^2 + 1
+            Affine Plane Curve over Rational Field defined by x^3 - x^2*z - x^2 + 1
 
         ::
 
@@ -1612,7 +1609,7 @@ class ProjectivePlaneCurve(ProjectiveCurve):
             sage: R.<x,y,z>=QQ[]
             sage: C=Curve(x^3+3*y^3+5*z^3)
             sage: C.riemann_surface()
-            Riemann surface defined by polynomial f = x0^3 + 3*x1^3 + 5 = 0, with 53 bits of precision
+            Riemann surface defined by polynomial f = x^3 + 3*y^3 + 5 = 0, with 53 bits of precision
 
         """
         return self.affine_patch(2).riemann_surface(**kwargs)
@@ -1925,14 +1922,12 @@ class ProjectivePlaneCurve_prime_finite_field(ProjectivePlaneCurve_finite_field)
         v = singular('POINTS').sage_flattened_str_list()
         coords = [self(int(v[3*i]), int(v[3*i+1]), int(v[3*i+2])) for i in range(len(v)//3)]
         # build correct representation of D for singular
-        Dsupport = D.support()
         Dcoeffs = []
         for x in pnts:
             if x[0] == 1:
                 Dcoeffs.append(D.coefficient(coords[x[1]]))
             else:
                 Dcoeffs.append(0)
-        Dstr = str(tuple(Dcoeffs))
         G = singular(','.join([str(x) for x in Dcoeffs]), type='intvec')
         # call singular's brill noether routine and return
         T = X2[1][2]
