@@ -332,14 +332,12 @@ def prove_BSD(E, verbosity=0, two_desc='mwrank', proof=None, secs_hi=5,
         p = 2: True by 2-descent
         True for p not in {2, 3, 5} by Kolyvagin.
         Kolyvagin's bound for p = 3 applies by Lawson-Wuthrich
+        Kolyvagin's bound for p = 5 applies by Lawson-Wuthrich
         True for p = 3 by Kolyvagin bound
-        Remaining primes:
-        p = 5: reducible, not surjective, additive, divides a Tamagawa number
-            (no bounds found)
-            ord_p(#Sha_an) = 0
-        [5]
+        True for p = 5 by Kolyvagin bound
+        []
         sage: E.prove_BSD(two_desc='simon')
-        [5]
+        []
 
     A rank two curve::
 
@@ -395,11 +393,9 @@ def prove_BSD(E, verbosity=0, two_desc='mwrank', proof=None, secs_hi=5,
         sage: E.prove_BSD(verbosity=2)
         p = 2: True by 2-descent
         True for p not in {2, 5} by Kolyvagin.
-        Remaining primes:
-        p = 5: reducible, not surjective, good ordinary, divides a Tamagawa number
-            (no bounds found)
-            ord_p(#Sha_an) = 0
-        [5]
+        Kolyvagin's bound for p = 5 applies by Lawson-Wuthrich
+        True for p = 5 by Kolyvagin bound
+        []
 
     A curve for which 3 divides the order of the Tate-Shafarevich group::
 
@@ -537,7 +533,6 @@ def prove_BSD(E, verbosity=0, two_desc='mwrank', proof=None, secs_hi=5,
         raise RuntimeError("It seems that the rank conjecture does not hold for this curve (%s)! This may be a counterexample to BSD, but is more likely a bug."%(BSD.curve))
 
     # reduce set of remaining primes to a finite set
-    import signal
     kolyvagin_primes = []
     heegner_index = None
     if BSD.rank == 0:
@@ -667,7 +662,6 @@ def prove_BSD(E, verbosity=0, two_desc='mwrank', proof=None, secs_hi=5,
         for p in kolyvagin_primes:
             BSD.primes.remove(p)
     # apply other hypotheses which imply Kolyvagin's bound holds
-    bounded_primes = []
     D_K = rings.QuadraticField(D, 'a').disc()
 
     # Cha's hypothesis
@@ -708,7 +702,7 @@ def prove_BSD(E, verbosity=0, two_desc='mwrank', proof=None, secs_hi=5,
                 else:  # p == 5
                     Et = BSD.curve.quadratic_twist(5)
                     if Et.torsion_order() % p != 0 and C.torsion_order() % p != 0:
-                        crite_lw = True
+                        crit_lw = True
         if crit_lw:
             if verbosity > 0:
                 print('Kolyvagin\'s bound for p = %d applies by Lawson-Wuthrich' % p)
