@@ -15,7 +15,7 @@ Currently sage can decide whether the Galois module
 `E[p]` is reducible, i.e., if `E` admits an isogeny
 of degree `p`, and whether the image of
 the representation on `E[p]` is surjective onto
-`\text{Aut}(E[p]) = GL_2(\mathbb{F}_p)`.
+`\text{Aut}(E[p]) = GL_2(\GF{p})`.
 
 The following are the most useful functions for the class ``GaloisRepresentation``.
 
@@ -75,7 +75,7 @@ surjective if and only if it is irreducible::
     [5]
 
 For cm curves it is not true that there are only finitely many primes for which the
-Galois representation mod p is surjective onto `GL_2(\mathbb{F}_p)`::
+Galois representation mod p is surjective onto `GL_2(\GF{p})`::
 
     sage: E = EllipticCurve('27a1')
     sage: rho = E.galois_representation()
@@ -382,7 +382,7 @@ class GaloisRepresentation(SageObject):
     def is_surjective(self, p, A=1000):
         r"""
         Return True if the mod-p representation is
-        surjective onto `Aut(E[p]) = GL_2(\mathbb{F}_p)`.
+        surjective onto `Aut(E[p]) = GL_2(\GF{p})`.
 
         False if it is not, or None if we were unable to
         determine whether it is or not.
@@ -1116,14 +1116,14 @@ class GaloisRepresentation(SageObject):
         This function returns, given the representation `\rho`
         a list of `p` values that add up to 1, representing the
         frequency of the conjugacy classes of the projective image
-        of `\rho` in `PGL_2(\mathbb{F}_p)`.
+        of `\rho` in `PGL_2(\GF{p})`.
 
-        Let `M` be a matrix in `GL_2(\mathbb{F}_p)`, then define
+        Let `M` be a matrix in `GL_2(\GF{p})`, then define
         `u(M) = \text{tr}(M)^2/\det(M)`, which only depends on the
-        conjugacy class of `M` in `PGL_2(\mathbb{F}_p)`. Hence this defines
-        a map `u: PGL_2(\mathbb{F}_p) \to \mathbb{F}_p`, which is almost
+        conjugacy class of `M` in `PGL_2(\GF{p})`. Hence this defines
+        a map `u: PGL_2(\GF{p}) \to \GF{p}`, which is almost
         a bijection between conjugacy classes of the source
-        and `\mathbb{F}_p` (the elements of order `p` and the identity
+        and `\GF{p}` (the elements of order `p` and the identity
         map to `4` and both classes of elements of order 2 map to 0).
 
         This function returns the frequency with which the values of
@@ -1185,7 +1185,7 @@ class GaloisRepresentation(SageObject):
 
         REMARKS:
 
-        Conjugacy classes of subgroups of `PGL_2(\mathbb{F}_5)`
+        Conjugacy classes of subgroups of `PGL_2(\GF{5})`
 
         For the case `p=5`, the order of an element determines almost the value of `u`:
 
