@@ -28,6 +28,8 @@ from sage.rings.all import RealField, RationalField
 from math import sqrt, log, ceil
 import sage.functions.exp_integral as exp_integral
 from sage.misc.all import verbose
+from sage.misc.cachefunc import cached_method
+
 
 class Lseries_ell(SageObject):
     """
@@ -766,10 +768,12 @@ class Lseries_ell(SageObject):
         """
         return self.L_ratio() == 0
 
+    @cached_method
     def L_ratio(self):
         r"""
-        Returns the ratio `L(E,1)/\Omega` as an exact rational
-        number. The result is *provably* correct if the Manin
+        Return the ratio `L(E,1) / \Omega` as an exact rational number.
+
+        The result is *provably* correct if the Manin
         constant of the associated optimal quotient is `\leq 2`.  This
         hypothesis on the Manin constant is true for all semistable
         curves (i.e., squarefree conductor), by a theorem of Mazur
@@ -814,19 +818,12 @@ class Lseries_ell(SageObject):
 
         AUTHOR: William Stein, 2005-04-20.
         """
-        try:
-            return self.__lratio
-        except AttributeError:
-            pass
-
         if not self.__E.is_minimal():
-            self.__lratio = self.__E.minimal_model().lseries().L_ratio()
-            return self.__lratio
+            return self.__E.minimal_model().lseries().L_ratio()
 
         QQ = RationalField()
         if self.__E.root_number() == -1:
-            self.__lratio = QQ.zero()
-            return self.__lratio
+            return QQ.zero()
 
         # Even root number.  Decide if L(E,1) = 0.  If E is a modular
         # *OPTIMAL* quotient of J_0(N) elliptic curve, we know that T *
@@ -863,38 +860,38 @@ class Lseries_ell(SageObject):
         t = self.__E.torsion_subgroup().order()
         omega = self.__E.period_lattice().basis()[0]
         d = self.__E._multiple_of_degree_of_isogeny_to_optimal_curve()
-        C = 8*d*t
+        C = 8 * d * t
         eps = omega / C
 
-        sqrtN = 2*int(sqrt(self.__E.conductor()))
+        sqrtN = 2 * self.__E.conductor().isqrt()
         k = sqrtN + 10
         while True:
             L1, error_bound = self.at1(k)
             if error_bound < eps:
-                n = int(round(L1*C/omega))
-                quo = QQ((n,C))
-                self.__lratio = quo / self.__E.real_components()
-                return self.__lratio
+                n = (L1 * C / omega).round()
+                quo = QQ((n, C))
+                return quo / self.__E.real_components()
             k += sqrtN
             verbose("Increasing precision to %s terms." % k)
 
     def zero_sums(self, N=None):
         r"""
-        Return an LFunctionZeroSum class object for efficient computation
-        of sums over the zeros of self. This can be used to bound analytic
-        rank from above without having to compute with the $L$-series
-        directly.
+        Return an ``LFunctionZeroSum`` class object for efficient computation
+        of sums over the zeros of ``self``.
+
+        This can be used to bound analytic rank from above without
+        having to compute with the `L`-series directly.
 
         INPUT:
 
-        - ``N`` -- (default: None) If not None, the conductor of the
-          elliptic curve attached to self. This is passable so that zero
+        - ``N`` -- (default: ``None``) If not ``None``, the conductor of the
+          elliptic curve attached to ``self``. This is passable so that zero
           sum computations can be done on curves for which the conductor
           has been precomputed.
 
         OUTPUT:
 
-        A LFunctionZeroSum_EllipticCurve instance.
+        A ``LFunctionZeroSum_EllipticCurve`` instance.
 
         EXAMPLES::
 
