@@ -61,7 +61,7 @@ def __check_padic_hypotheses(self, p):
     """
     p = rings.Integer(p)
     if not p.is_prime():
-        raise ValueError("p = (%s) must be prime"%p)
+        raise ValueError("p = (%s) must be prime" % p)
     if p == 2:
         raise ValueError("p must be odd")
     if self.conductor() % p == 0 or self.ap(p) % p == 0:
@@ -69,27 +69,18 @@ def __check_padic_hypotheses(self, p):
     return p
 
 
-def _normalize_padic_lseries(self, p, normalize, use_eclib, implementation, precision):
+def _normalize_padic_lseries(self, p, normalize, implementation, precision):
     r"""
     Normalize parameters for :meth:`padic_lseries`.
 
     TESTS::
 
         sage: from sage.schemes.elliptic_curves.padics import _normalize_padic_lseries
-        sage: u = _normalize_padic_lseries(None, 5, None, None, 'sage', 10)
-        sage: v = _normalize_padic_lseries(None, 5, "L_ratio", None, 'sage', 10)
+        sage: u = _normalize_padic_lseries(None, 5, None, 'sage', 10)
+        sage: v = _normalize_padic_lseries(None, 5, "L_ratio", 'sage', 10)
         sage: u == v
         True
      """
-    if use_eclib is not None:
-        from sage.misc.superseded import deprecation
-        deprecation(812,"Use the option 'implementation' instead of 'use_eclib'")
-        if implementation == 'pollackstevens':
-            raise ValueError
-        if use_eclib:
-            implementation = 'eclib'
-        else:
-            implementation = 'sage'
     if implementation == 'eclib':
         if normalize is None:
             normalize = "L_ratio"
@@ -108,7 +99,7 @@ def _normalize_padic_lseries(self, p, normalize, use_eclib, implementation, prec
     return (p, normalize, implementation, precision)
 
 @cached_method(key=_normalize_padic_lseries)
-def padic_lseries(self, p, normalize = None, use_eclib = None, implementation = 'eclib', precision = None):
+def padic_lseries(self, p, normalize = None, implementation = 'eclib', precision = None):
     r"""
     Return the `p`-adic `L`-series of self at
     `p`, which is an object whose approx method computes
@@ -117,17 +108,14 @@ def padic_lseries(self, p, normalize = None, use_eclib = None, implementation =
 
     INPUT:
 
+    -  ``p`` -- prime
 
-    -  ``p`` - prime
-
-    -  ``normalize`` -  'L_ratio' (default), 'period' or 'none';
+    -  ``normalize`` -- 'L_ratio' (default), 'period' or 'none';
        this is describes the way the modular symbols
        are normalized. See modular_symbol for
        more details.
 
-    -  ``use_eclib`` - deprecated, use ``implementation`` instead
-
-    -  ``implementation`` - 'eclib' (default), 'sage', 'pollackstevens';
+    -  ``implementation`` -- 'eclib' (default), 'sage', 'pollackstevens';
        Whether to use John Cremona's eclib, the Sage implementation,
        or Pollack-Stevens' implementation of overconvergent
        modular symbols.
@@ -207,7 +195,7 @@ def padic_lseries(self, p, normalize = None, use_eclib = None, implementation =
         O(11^0)
     """
     p, normalize, implementation, precision = self._normalize_padic_lseries(p,\
-                             normalize, use_eclib, implementation, precision)
+                             normalize, implementation, precision)
 
     if implementation in ['sage', 'eclib']:
         if self.ap(p) % p != 0:
@@ -1500,7 +1488,8 @@ def padic_E2(self, p, prec=20, check=False, check_hypotheses=True, algorithm="au
             eq = self.tate_curve(p)
             return  eq.E2(prec=prec)
 
-    frob_p = self.matrix_of_frobenius(p, prec, check, check_hypotheses, algorithm).change_ring(Integers(p**prec))
+    X = self.minimal_model().short_weierstrass_model()
+    frob_p = X.matrix_of_frobenius(p, prec, check, check_hypotheses, algorithm).change_ring(Integers(p**prec))
 
     frob_p_n = frob_p**prec
 
@@ -1511,7 +1500,6 @@ def padic_E2(self, p, prec=20, check=False, check_hypotheses=True, algorithm="au
               + O(p**prec)
 
     # Take into account the coordinate change.
-    X = self.minimal_model().short_weierstrass_model()
     fudge_factor = (X.discriminant() / self.discriminant()).nth_root(6)
     # todo: here I should be able to write:
     #  return E2_of_X / fudge_factor
@@ -1523,9 +1511,11 @@ def padic_E2(self, p, prec=20, check=False, check_hypotheses=True, algorithm="au
     fudge_factor_inverse = Qp(p, prec=(E2_of_X.precision_absolute() + 1))(1 / fudge_factor)
     return output_ring(E2_of_X * fudge_factor_inverse)
 
+
 def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, algorithm="auto"):
     r"""
-    Returns the matrix of Frobenius on the Monsky Washnitzer cohomology of the elliptic curve.
+    Returns the matrix of Frobenius on the Monsky Washnitzer cohomology of
+    the short Weierstrass model of the minimal model of the elliptic curve.
 
     INPUT:
 
@@ -1580,10 +1570,15 @@ def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, al
         sage: E.matrix_of_frobenius(3,6)
         [                      2*3 + 3^5 + O(3^6)             2*3 + 2*3^2 + 2*3^3 + O(3^6)]
         [              2*3 + 3^2 + 2*3^5 + O(3^6) 2 + 2*3^2 + 2*3^3 + 2*3^4 + 3^5 + O(3^6)]
-
     """
-    # TODO change the basis back to the original equation.
-    # TODO, add lots of comments like the above
+    p = Integer(p)
+    prec = int(prec)
+
+    if p < 3:
+        raise NotImplementedError("p (=%s) must be at least 3" % p)
+    if prec < 1:
+        raise ValueError("prec (=%s) must be at least 1" % prec)
+
     if check_hypotheses:
         p = __check_padic_hypotheses(self, p)
 
@@ -1595,25 +1590,13 @@ def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, al
     if algorithm not in ["standard", "sqrtp"]:
         raise ValueError("unknown algorithm '%s'" % algorithm)
 
-    # todo: maybe it would be good if default prec was None, and then
-    # it selects an appropriate precision based on how large the prime
-    # is
-
     # for p = 3, we create the corresponding hyperelliptic curve
     # and call matrix of frobenius on it
-
     if p == 3:
         from sage.schemes.hyperelliptic_curves.constructor import HyperellipticCurve
         f,g = self.hyperelliptic_polynomials()
         return HyperellipticCurve(f + (g/2)**2).matrix_of_frobenius(p,prec)
 
-    if p < 3:
-        raise NotImplementedError("p (=%s) must be at least 3" % p)
-
-    prec = int(prec)
-    if prec < 1:
-        raise ValueError("prec (=%s) must be at least 1" % prec)
-
     # To run matrix_of_frobenius(), we need to have the equation in the
     # form y^2 = x^3 + ax + b, whose discriminant is invertible mod p.
     # When we change coordinates like this, we might scale the invariant
@@ -1628,6 +1611,7 @@ def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, al
 
     # todo: The following strategy won't work at all for p = 2, 3.
 
+    # TODO change the basis back to the original equation.
     X = self.minimal_model().short_weierstrass_model()
 
     assert X.discriminant().valuation(p) == 0, "Something's gone wrong. " \
