@@ -722,8 +722,7 @@ class ProjectiveConic_field(ProjectivePlaneCurve):
             sage: c.diagonalization()[0].is_diagonal()
             True
         """
-        return all([self.coefficients()[i] == 0 for i in [1,2,4]])
-
+        return all(self.coefficients()[i] == 0 for i in [1, 2, 4])
 
     def is_smooth(self):
         r"""
