@@ -22,17 +22,11 @@ from __future__ import absolute_import
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
-from sage.rings.all import (RDF, CDF, AA, RLF, QQbar, PolynomialRing)
-
-from sage.rings.complex_field import is_ComplexField
-
-from sage.rings.ring import is_Ring
+from sage.rings.all import (AA, RLF, PolynomialRing)
 from sage.rings.rational_field import is_RationalField
-from sage.rings.real_mpfi import is_RealIntervalField
-from sage.rings.complex_interval_field import is_ComplexIntervalField
-
 from .con_field import ProjectiveConic_field
 
+
 class ProjectiveConic_number_field(ProjectiveConic_field):
     r"""
     Create a projective plane conic curve over a number field.
