@@ -246,7 +246,8 @@ def differential_basis_baker(f):
     r"""
     Compute a differential bases for a curve that is nonsingular outside (1:0:0),(0:1:0),(0:0:1)
 
-    Baker's theorem tells us that if a curve has its singularities at the coordinate vertices,
+    Baker's theorem tells us that if a curve has its singularities at the coordinate vertices and meets
+    some further easily tested genericity criteria,
     then we can read off a basis for the regular differentials from the interior of the
     Newton polygon spanned by the monomials. While this theorem only applies to special plane curves
     it is worth implementing because the analysis is relatively cheap and it applies to a lot of
@@ -275,18 +276,38 @@ def differential_basis_baker(f):
         sage: differential_basis_baker(x^2+y^2-1)
         []
 
+    TESTS::
+
+        sage: from sage.schemes.riemann_surfaces.riemann_surface import differential_basis_baker
+        sage: R.<x,y>=QQ[]
+        sage: f = y^12 - x*(x - 1)^7
+        sage: differential_basis_baker(f) is None
+        True
+
     """
     k = f.base_ring()
     R = PolynomialRing(k,3,"x,y,z")
     x,y,z = R.gens()
     F = f(x/z,y/z).numerator()
     W = [F] + [F.derivative(v) for v in R.gens()]
+    #we check that the singularities lie at (1:0:0),(0:1:0),(0:0:1)
+    #by checking that the eliminations of x, y, z result in (principal) ideals
+    #generated by a monomial. This is a sufficient condition, but not completely necessary.
+    #It's cheap to check, though.
     for c in R.gens():
         B = GCD([W[i].resultant(W[j],c) for i in range(4) for j in range(i)])
         if len(B.monomials()) > 1:
             return None
     from sage.geometry.polyhedron.constructor import Polyhedron
-    P = Polyhedron(f.dict().keys())
+    D = { (k[0],k[1]): v for k,v in f.dict().items() }
+    P = Polyhedron(D)
+    kT = k['t']
+    #here we check the additional genericity conditions: that the polynomials
+    #along the edges of the newton polygon are square-free.
+    for e in P.bounded_edges():
+        h=kT([D.get(tuple(c),0) for c in Polyhedron(e).integral_points()])
+        if not h.is_squarefree():
+            return None
     x,y = f.parent().gens()
     return [x**(a[0]-1)*y**(a[1]-1) for a in P.integral_points() if P.interior_contains(a)]
 
@@ -659,7 +680,7 @@ class RiemannSurface(object):
             sage: R.<z,w> = QQ[]
             sage: f = z^3*w + w^3 + z
             sage: S = RiemannSurface(f)
-            sage: edge1 = S.edge_permutations().keys()[0]
+            sage: edge1 = sorted(S.edge_permutations())[0]
             sage: sigma = S.edge_permutations()[edge1]
             sage: continued_values = S.homotopy_continuation(edge1)
             sage: stored_values = S.w_values(S._vertices[edge1[1]])
