@@ -365,8 +365,8 @@ class Set_object(Set_generic):
             False
             sage: 5/3 in GF(7)
             False
-            sage: Set(GF(7)).union(Set(GF(5)))
-            {0, 1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 0}
+            sage: sorted(Set(GF(7)).union(Set(GF(5))), key=int)
+            [0, 0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 6]
             sage: Set(GF(7)).intersection(Set(GF(5)))
             {}
         """
@@ -424,8 +424,8 @@ class Set_object(Set_generic):
             True
             sage: GF(5)(2) in X
             False
-            sage: Set(GF(7)) + Set(GF(3))
-            {0, 1, 2, 3, 4, 5, 6, 1, 2, 0}
+            sage: sorted(Set(GF(7)) + Set(GF(3)), key=int)
+            [0, 0, 1, 1, 2, 2, 3, 4, 5, 6]
         """
         if isinstance(X, Set_generic):
             if self is X:
@@ -445,8 +445,8 @@ class Set_object(Set_generic):
             {0, 1, 2, 0, 1}
             sage: Set(GF(2)) + Set(GF(4,'a'))
             {0, 1, a, a + 1}
-            sage: Set(GF(8,'b')) + Set(GF(4,'a'))
-            {0, 1, b, b + 1, b^2, b^2 + 1, b^2 + b, b^2 + b + 1, a, a + 1, 1, 0}
+            sage: sorted(Set(GF(8,'b')) + Set(GF(4,'a')), key=str)
+            [0, 0, 1, 1, a, a + 1, b, b + 1, b^2, b^2 + 1, b^2 + b, b^2 + b + 1]
         """
         return self.union(X)
 
@@ -1002,10 +1002,10 @@ class Set_object_enumerated(Set_object):
             sage: Y = Set([GF(8,'c').0, 1, 2, 3])
             sage: X
             {0, 1, c, c + 1, c^2, c^2 + 1, c^2 + c, c^2 + c + 1}
-            sage: Y
-            {1, c, 3, 2}
-            sage: X.union(Y)
-            {0, 1, c, c + 1, c^2, c^2 + 1, c^2 + c, c^2 + c + 1, 2, 3}
+            sage: sorted(Y)
+            [1, 2, 3, c]
+            sage: sorted(X.union(Y), key=str)
+            [0, 1, 2, 3, c, c + 1, c^2, c^2 + 1, c^2 + c, c^2 + c + 1]
         """
         if not isinstance(other, Set_object_enumerated):
             return Set_object.union(self, other)
