@@ -127,7 +127,7 @@ def Sequence(x, universe=None, check=True, immutable=False, cr=False, cr_str=Non
 
         sage: v = Sequence(range(10))
         sage: v.universe()
-        <... 'int'>
+        <type 'int'>
         sage: v
         [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
 
@@ -311,7 +311,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
 
         sage: v = Sequence(range(10))
         sage: v.universe()
-        <... 'int'>
+        <type 'int'>
         sage: v
         [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
 
@@ -499,7 +499,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
             sage: v
             [1, 5, 3, 4]
             sage: type(v[2])
-            <... 'sage.rings.integer.Integer'>
+            <type 'sage.rings.integer.Integer'>
         """
         self._require_mutable()
         if isinstance(n, slice):
@@ -553,7 +553,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
             sage: v = Sequence([1/3,2,3,4])
             sage: v.append(4)
             sage: type(v[4])
-            <... 'sage.rings.rational.Rational'>
+            <type 'sage.rings.rational.Rational'>
         """
         self._require_mutable()
         y = self.__universe(x)
@@ -624,7 +624,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
         INPUT:
 
         - ``key`` - see Python ``list sort``
-        
+
         - ``reverse`` - see Python ``list sort``
 
         EXAMPLES::
@@ -791,7 +791,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
             True
             sage: a[0] = 100
             sage: type(a[0])
-            <... 'sage.rings.rational.Rational'>
+            <type 'sage.rings.rational.Rational'>
             sage: a.set_immutable()
             sage: a[0] = 50
             Traceback (most recent call last):
@@ -856,7 +856,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
             Traceback (most recent call last):
             ...
             AttributeError: 'Sequence_generic' object has no attribute '_Sequence_generic__hash'
-            sage: S._Sequence__hash = 34
+            sage: S._Sequence__hash = int(34)
             sage: hash(S)
             34
         """
