@@ -11,6 +11,8 @@ AUTHORS:
 - Eric Gourgoulhon, Michal Bejger (2014-2015): initial version
 - Travis Scrimshaw (2016): ABC Basis_abstract and list functionality for bases
   (:trac:`20770`)
+- Eric Gourgoulhon (2018): some refactoring and more functionalities in the
+  choice of symbols for basis elements (:trac:`24792`)
 
 REFERENCES:
 
@@ -19,7 +21,7 @@ REFERENCES:
 
 """
 #******************************************************************************
-#       Copyright (C) 2015 Eric Gourgoulhon <eric.gourgoulhon@obspm.fr>
+#       Copyright (C) 2015, 2018 Eric Gourgoulhon <eric.gourgoulhon@obspm.fr>
 #       Copyright (C) 2015 Michal Bejger <bejger@camk.edu.pl>
 #       Copyright (C) 2016 Travis Scrimshaw <tscrimsh@umn.edu>
 #
@@ -37,7 +39,7 @@ class Basis_abstract(UniqueRepresentation, SageObject):
     """
     Abstract base class for (dual) bases of free modules.
     """
-    def __init__(self, fmodule, symbol, latex_symbol, latex_name):
+    def __init__(self, fmodule, symbol, latex_symbol, indices, latex_indices):
         """
         Initialize ``self``.
 
@@ -48,10 +50,11 @@ class Basis_abstract(UniqueRepresentation, SageObject):
             sage: e._fmodule is M
             True
         """
+        self._fmodule = fmodule
         self._symbol = symbol
         self._latex_symbol = latex_symbol
-        self._latex_name = latex_name
-        self._fmodule = fmodule
+        self._indices = indices
+        self._latex_indices = latex_indices
 
     def __iter__(self):
         r"""
@@ -102,6 +105,63 @@ class Basis_abstract(UniqueRepresentation, SageObject):
         """
         return self._fmodule._rank
 
+    def __getitem__(self, index):
+        r"""
+        Return the basis element corresponding to a given index.
+
+        INPUT:
+
+        - ``index`` -- the index of the basis element
+
+        EXAMPLES::
+
+            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
+            sage: e = M.basis('e')
+            sage: e.__getitem__(0)
+            Element e_0 of the Rank-3 free module M over the Integer Ring
+            sage: e.__getitem__(1)
+            Element e_1 of the Rank-3 free module M over the Integer Ring
+            sage: e.__getitem__(2)
+            Element e_2 of the Rank-3 free module M over the Integer Ring
+            sage: e[1] is e.__getitem__(1)
+            True
+            sage: e[1].parent() is M
+            True
+            sage: e[:]
+            (Element e_0 of the Rank-3 free module M over the Integer Ring,
+             Element e_1 of the Rank-3 free module M over the Integer Ring,
+             Element e_2 of the Rank-3 free module M over the Integer Ring)
+            sage: f = e.dual_basis()
+            sage: f[0]
+            Linear form e^0 on the Rank-3 free module M over the Integer Ring
+
+        Examples with ``start_index=1``::
+
+            sage: M1 = FiniteRankFreeModule(ZZ, 3, name='M', start_index=1)
+            sage: e1 = M1.basis('e')
+            sage: e1.__getitem__(1)
+            Element e_1 of the Rank-3 free module M over the Integer Ring
+            sage: e1.__getitem__(2)
+            Element e_2 of the Rank-3 free module M over the Integer Ring
+            sage: e1.__getitem__(3)
+            Element e_3 of the Rank-3 free module M over the Integer Ring
+
+        """
+        si = self._fmodule._sindex
+        if isinstance(index, slice):
+            start, stop = index.start, index.stop
+            if start is not None:
+                start -= si
+            if stop is not None:
+                stop -= si
+            return self._vec[start:stop:index.step]
+        n = self._fmodule._rank
+        i = index - si
+        if i < 0 or i > n-1:
+            raise IndexError("out of range: {} not in [{},{}]".format(i+si, si,
+                                                                      n-1+si))
+        return self._vec[i]
+
     def _latex_(self):
         r"""
         Return a LaTeX representation of ``self``.
@@ -145,6 +205,219 @@ class Basis_abstract(UniqueRepresentation, SageObject):
         """
         return self._fmodule
 
+    def set_name(self, symbol, latex_symbol=None, indices=None,
+                 latex_indices=None, index_position='down'):
+        r"""
+        Set (or change) the text name and LaTeX name of ``self``.
+
+        INPUT:
+
+        - ``symbol`` -- either a string, to be used as a common base for the
+          symbols of the elements of ``self``, or a list of strings,
+          representing the individual symbols of the elements of ``self``
+        - ``latex_symbol`` -- (default: ``None``) either a string, to be used
+          as a common base for the LaTeX symbols of the elements of ``self``,
+          or a list of strings, representing the individual LaTeX symbols of
+          the elements of ``self``; if ``None``, ``symbol`` is used in place
+          of ``latex_symbol``
+        - ``indices`` -- (default: ``None``; used only if ``symbol`` is a
+          single string) tuple of strings representing the indices labelling
+          the elements of ``self``; if ``None``, the indices will be generated
+          as integers within the range declared on the free module on which
+          ``self`` is defined
+        - ``latex_indices`` -- (default: ``None``) list of strings representing
+          the indices for the LaTeX symbols of the elements of ``self``; if
+          ``None``, ``indices`` is used instead
+        - ``index_position`` -- (default: ``'down'``) determines the position
+          of the indices labelling the individual elements of ``self``; can be
+          either ``'down'`` or ``'up'``
+
+        EXAMPLES::
+
+            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
+            sage: e = M.basis('e'); e
+            Basis (e_0,e_1,e_2) on the Rank-3 free module M over the Integer Ring
+            sage: e.set_name('f'); e
+            Basis (f_0,f_1,f_2) on the Rank-3 free module M over the Integer Ring
+            sage: e.set_name(['a', 'b', 'c']); e
+            Basis (a,b,c) on the Rank-3 free module M over the Integer Ring
+            sage: e.set_name('e', indices=['x', 'y', 'z']); e
+            Basis (e_x,e_y,e_z) on the Rank-3 free module M over the Integer Ring
+            sage: e.set_name('e', index_position='up'); e
+            Basis (e^0,e^1,e^2) on the Rank-3 free module M over the Integer Ring
+            sage: latex(e)
+            \left(e^{0},e^{1},e^{2}\right)
+            sage: e.set_name('e', latex_symbol=r'\epsilon'); e
+            Basis (e_0,e_1,e_2) on the Rank-3 free module M over the Integer Ring
+            sage: latex(e)
+            \left(\epsilon_{0},\epsilon_{1},\epsilon_{2}\right)
+            sage: e.set_name('e', latex_symbol=[r'\alpha', r'\beta', r'\gamma'])
+            sage: latex(e)
+            \left(\alpha,\beta,\gamma\right)
+            sage: e.set_name('e', latex_symbol='E',
+            ....:            latex_indices=[r'\alpha', r'\beta', r'\gamma'])
+            sage: latex(e)
+            \left(E_{\alpha},E_{\beta},E_{\gamma}\right)
+            sage: e.set_name('e') # back to the default
+
+        """
+        n = self._fmodule._rank
+        if index_position == "down":
+            pos = "_"
+        else:
+            pos = "^"
+        if latex_symbol is None:
+            latex_symbol = symbol
+        self._symbol = symbol
+        self._latex_symbol = latex_symbol
+        self._indices = indices
+        self._latex_indices = latex_indices
+        # Text symbols:
+        if isinstance(symbol, (list, tuple)):
+            if len(symbol) != n:
+                raise ValueError("symbol must contain {} strings".format(n))
+            if len(set(symbol)) != n:
+                raise ValueError("the individual symbols must be different")
+        else:
+            if indices is None:
+                indices = [str(i) for i in self._fmodule.irange()]
+            elif len(indices) != n:
+                raise ValueError("indices must contain {} elements".format(n))
+            symbol0 = symbol + pos
+            symbol = [symbol0 + i for i in indices]
+        # LaTeX symbols:
+        if isinstance(latex_symbol, (list, tuple)):
+            if len(latex_symbol) != n:
+                raise ValueError(
+                              "latex_symbol must contain {} strings".format(n))
+            if len(set(latex_symbol)) != n:
+                raise ValueError("the individual symbols must be different")
+        else:
+            if latex_indices is None:
+                if indices is None:
+                    latex_indices = [str(i) for i in self._fmodule.irange()]
+                else:
+                    latex_indices = indices
+            elif len(latex_indices) != n:
+                raise ValueError(
+                            "latex_indices must contain {} elements".format(n))
+            symbol0 = latex_symbol + pos
+            latex_symbol = [symbol0 + "{" + i + "}" for i in latex_indices]
+        # Setting the names
+        self._name = "(" + ",".join(symbol) + ")"
+        self._latex_name = r"\left(" + ",".join(latex_symbol) + r"\right)"
+        for i in range(n):
+            self._vec[i].set_name(symbol[i], latex_name=latex_symbol[i])
+
+#******************************************************************************
+
+class FreeModuleCoBasis(Basis_abstract):
+    r"""
+    Dual basis of a free module over a commutative ring.
+
+    INPUT:
+
+    - ``basis`` -- basis of a free module `M` of which ``self`` is the dual
+      (must be an instance of :class:`FreeModuleBasis`)
+    - ``symbol`` -- either a string, to be used as a common base for the
+      symbols of the elements of the cobasis, or a tuple of strings,
+      representing the individual symbols of the elements of the cobasis
+    - ``latex_symbol`` -- (default: ``None``) either a string, to be used
+      as a common base for the LaTeX symbols of the elements of the cobasis,
+      or a tuple of strings, representing the individual LaTeX symbols of
+      the elements of the cobasis; if ``None``, ``symbol`` is used in place
+      of ``latex_symbol``
+    - ``indices`` -- (default: ``None``; used only if ``symbol`` is a single
+      string) tuple of strings representing the indices labelling
+      the elements of the cobasis; if ``None``, the indices will be generated
+      as integers within the range declared on the free module on which the
+      cobasis is defined
+    - ``latex_indices`` -- (default: ``None``) tuple of strings representing
+      the indices for the LaTeX symbols of the elements of the cobasis; if
+      ``None``, ``indices`` is used instead
+
+    EXAMPLES:
+
+    Dual basis on a rank-3 free module::
+
+        sage: M = FiniteRankFreeModule(ZZ, 3, name='M', start_index=1)
+        sage: e = M.basis('e') ; e
+        Basis (e_1,e_2,e_3) on the Rank-3 free module M over the Integer Ring
+        sage: from sage.tensor.modules.free_module_basis import FreeModuleCoBasis
+        sage: f = FreeModuleCoBasis(e, 'f') ; f
+        Dual basis (f^1,f^2,f^3) on the Rank-3 free module M over the Integer Ring
+
+    Instead of importing ``FreeModuleCoBasis`` in the global name space, it is
+    recommended to use the method
+    :meth:`~sage.tensor.modules.free_module_basis.FreeModuleBasis.dual_basis`
+    of the basis ``e``::
+
+        sage: f = e.dual_basis() ; f
+        Dual basis (e^1,e^2,e^3) on the Rank-3 free module M over the Integer Ring
+
+    Let us check that the elements of ``f`` are in the dual of ``M``::
+
+        sage: f[1]
+        Linear form e^1 on the Rank-3 free module M over the Integer Ring
+        sage: f[1] in M.dual()
+        True
+
+    and that ``f`` is indeed the dual of ``e``::
+
+        sage: f[1](e[1]), f[1](e[2]), f[1](e[3])
+        (1, 0, 0)
+        sage: f[2](e[1]), f[2](e[2]), f[2](e[3])
+        (0, 1, 0)
+        sage: f[3](e[1]), f[3](e[2]), f[3](e[3])
+        (0, 0, 1)
+
+    """
+    def __init__(self, basis, symbol, latex_symbol=None, indices=None,
+                 latex_indices=None):
+        r"""
+        TESTS::
+
+            sage: from sage.tensor.modules.free_module_basis import FreeModuleCoBasis
+            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
+            sage: e = M.basis('e')
+            sage: f = FreeModuleCoBasis(e, 'f')
+            sage: TestSuite(f).run()
+
+        """
+        self._basis = basis
+        Basis_abstract.__init__(self, basis._fmodule, symbol, latex_symbol,
+                                indices, latex_indices)
+        # The individual linear forms:
+        vl = list()
+        for i in self._fmodule.irange():
+            v = self._fmodule.linear_form()
+            for j in self._fmodule.irange():
+                v.set_comp(basis)[j] = 0
+            v.set_comp(basis)[i] = 1
+            vl.append(v)
+        self._vec = tuple(vl)
+        # The names:
+        self.set_name(symbol, latex_symbol=latex_symbol, indices=indices,
+                      latex_indices=latex_indices, index_position='up')
+
+
+    def _repr_(self):
+        r"""
+        Return a string representation of ``self``.
+
+        EXAMPLES::
+
+            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
+            sage: e = M.basis('e')
+            sage: f = e.dual_basis()
+            sage: f
+            Dual basis (e^0,e^1,e^2) on the
+             Rank-3 free module M over the Integer Ring
+
+        """
+        return "Dual basis {} on the {}".format(self._name, self._fmodule)
+
+#******************************************************************************
 
 class FreeModuleBasis(Basis_abstract):
     r"""
@@ -154,11 +427,26 @@ class FreeModuleBasis(Basis_abstract):
 
     - ``fmodule`` -- free module `M` (as an instance of
       :class:`FiniteRankFreeModule`)
-    - ``symbol`` -- string; a letter (of a few letters) to denote a generic
-      element of the basis
-    - ``latex_symbol`` -- (default: ``None``) string; symbol to denote a
-      generic element of the basis; if ``None``, the value of ``symbol``
-      is used
+    - ``symbol`` -- either a string, to be used as a common base for the
+      symbols of the elements of the basis, or a tuple of strings,
+      representing the individual symbols of the elements of the basis
+    - ``latex_symbol`` -- (default: ``None``) either a string, to be used
+      as a common base for the LaTeX symbols of the elements of the basis,
+      or a tuple of strings, representing the individual LaTeX symbols of
+      the elements of the basis; if ``None``, ``symbol`` is used in place
+      of ``latex_symbol``
+    - ``indices`` -- (default: ``None``; used only if ``symbol`` is a single
+      string) tuple of strings representing the indices labelling
+      the elements of the basis; if ``None``, the indices will be generated
+      as integers within the range declared on ``fmodule``
+    - ``latex_indices`` -- (default: ``None``) tuple of strings representing
+      the indices for the LaTeX symbols of the elements of the basis; if
+      ``None``, ``indices`` is used instead
+    - ``symbol_dual`` -- (default: ``None``) same as ``symbol`` but for the
+      dual basis; if ``None``, ``symbol`` must be a string and is used
+      for the common base of the symbols of the elements of the dual basis
+    - ``latex_symbol_dual`` -- (default: ``None``) same as ``latex_symbol``
+      but for the dual basis
 
     EXAMPLES:
 
@@ -169,7 +457,7 @@ class FreeModuleBasis(Basis_abstract):
         sage: e = FreeModuleBasis(M0, 'e') ; e
         Basis (e_0,e_1,e_2) on the Rank-3 free module M_0 over the Integer Ring
 
-    Instead of importing FreeModuleBasis in the global name space, it is
+    Instead of importing ``FreeModuleBasis`` in the global name space, it is
     recommended to use the module's method
     :meth:`~sage.tensor.modules.finite_rank_free_module.FiniteRankFreeModule.basis`::
 
@@ -185,12 +473,21 @@ class FreeModuleBasis(Basis_abstract):
         sage: e[0] in M
         True
 
-    The LaTeX symbol can be set explicitely, as the second argument of
-    :meth:`~sage.tensor.modules.finite_rank_free_module.FiniteRankFreeModule.basis`::
+    The slice operator ``:`` can be used to access to more than one element::
+
+        sage: e[0:2]
+        (Element e_0 of the Rank-3 free module M over the Integer Ring,
+         Element e_1 of the Rank-3 free module M over the Integer Ring)
+        sage: e[:]
+        (Element e_0 of the Rank-3 free module M over the Integer Ring,
+         Element e_1 of the Rank-3 free module M over the Integer Ring,
+         Element e_2 of the Rank-3 free module M over the Integer Ring)
+
+    The LaTeX symbol can be set explicitely::
 
         sage: latex(e)
         \left(e_{0},e_{1},e_{2}\right)
-        sage: eps = M.basis('eps', r'\epsilon') ; eps
+        sage: eps = M.basis('eps', latex_symbol=r'\epsilon') ; eps
         Basis (eps_0,eps_1,eps_2) on the Rank-3 free module M over the Integer
          Ring
         sage: latex(eps)
@@ -204,9 +501,34 @@ class FreeModuleBasis(Basis_abstract):
         Basis (e_1,e_2,e_3) on the Rank-3 free module M over the Integer Ring
         sage: e[1]
         Element e_1 of the Rank-3 free module M over the Integer Ring
+
+    It is also possible to fully customize the labels, via the argument
+    ``indices``::
+
+        sage: f = M.basis('f', indices=('x', 'y', 'z')); f
+        Basis (f_x,f_y,f_z) on the Rank-3 free module M over the Integer Ring
+        sage: f[1]
+        Element f_x of the Rank-3 free module M over the Integer Ring
+
+    The symbol of each element of the basis can also be freely chosen, by
+    providing a tuple of symbols as the first argument of ``basis``; it is then
+    mandatory to specify some symbols for the dual basis as well::
+
+        sage: g = M.basis(('a', 'b', 'c'), symbol_dual=('A', 'B', 'C')); g
+        Basis (a,b,c) on the Rank-3 free module M over the Integer Ring
+        sage: g[1]
+        Element a of the Rank-3 free module M over the Integer Ring
+        sage: g.dual_basis()[1]
+        Linear form A on the Rank-3 free module M over the Integer Ring
+
     """
+    # The following class attribute must be redefined by any derived class:
+    _cobasis_class = FreeModuleCoBasis
+
     @staticmethod
-    def __classcall_private__(cls, fmodule, symbol, latex_symbol=None):
+    def __classcall_private__(cls, fmodule, symbol, latex_symbol=None,
+                              indices=None, latex_indices=None,
+                              symbol_dual=None, latex_symbol_dual=None):
         """
         Normalize input to ensure a unique representation.
 
@@ -220,9 +542,29 @@ class FreeModuleBasis(Basis_abstract):
         """
         if latex_symbol is None:
             latex_symbol = symbol
-        return super(FreeModuleBasis, cls).__classcall__(cls, fmodule, symbol, latex_symbol)
+        # Only tuples are valid entries for the unique representation of
+        # FreeModuleBasis:
+        if isinstance(symbol, list):
+            symbol = tuple(symbol)
+        if isinstance(latex_symbol, list):
+            latex_symbol = tuple(latex_symbol)
+        if isinstance(indices, list):
+            indices = tuple(indices)
+        if isinstance(latex_indices, list):
+            latex_indices = tuple(latex_indices)
+        if isinstance(symbol_dual, list):
+            symbol_dual = tuple(symbol_dual)
+        if isinstance(latex_symbol_dual, list):
+            latex_symbol_dual = tuple(latex_symbol_dual)
+        return super(FreeModuleBasis, cls).__classcall__(cls, fmodule, symbol,
+                                           latex_symbol=latex_symbol,
+                                           indices=indices,
+                                           latex_indices=latex_indices,
+                                           symbol_dual=symbol_dual,
+                                           latex_symbol_dual=latex_symbol_dual)
 
-    def __init__(self, fmodule, symbol, latex_symbol=None):
+    def __init__(self, fmodule, symbol, latex_symbol=None, indices=None,
+                 latex_indices=None, symbol_dual=None, latex_symbol_dual=None):
         r"""
         Initialize ``self``.
 
@@ -235,31 +577,22 @@ class FreeModuleBasis(Basis_abstract):
             sage: TestSuite(e).run()
 
         """
-        if latex_symbol is None:
-            latex_symbol = symbol
-        self._name = "(" + \
-          ",".join([symbol + "_" + str(i) for i in fmodule.irange()]) +")"
-        latex_name = r"\left(" + ",".join([latex_symbol + "_{" + str(i) + "}"
-                                       for i in fmodule.irange()]) + r"\right)"
-
-        Basis_abstract.__init__(self, fmodule, symbol, latex_symbol, latex_name)
-
+        Basis_abstract.__init__(self, fmodule, symbol, latex_symbol, indices,
+                                latex_indices)
         # The basis is added to the module list of bases
-        for other in fmodule._known_bases:
-            if symbol == other._symbol:
-                raise ValueError("the {} already exist on the {}".format(other, fmodule))
         fmodule._known_bases.append(self)
         # The individual vectors:
         vl = list()
         for i in fmodule.irange():
-            v_name = symbol + "_" + str(i)
-            v_symb = latex_symbol + "_{" + str(i) + "}"
-            v = fmodule.element_class(fmodule, name=v_name, latex_name=v_symb)
+            v = fmodule.element_class(fmodule)
             for j in fmodule.irange():
                 v.set_comp(self)[j] = fmodule._ring.zero()
             v.set_comp(self)[i] = fmodule._ring.one()
             vl.append(v)
         self._vec = tuple(vl)
+        # The names:
+        self.set_name(symbol, latex_symbol=latex_symbol, indices=indices,
+                      latex_indices=latex_indices, index_position='down')
         # The first defined basis is considered as the default one:
         if fmodule._def_basis is None:
             fmodule._def_basis = self
@@ -278,8 +611,21 @@ class FreeModuleBasis(Basis_abstract):
         for t in fmodule._dual_exterior_powers.values():
             t._zero_element._components[self] = t._zero_element._new_comp(self)
         # The dual basis:
-        self._dual_basis = self._init_dual_basis()
-
+        self._symbol_dual = symbol_dual
+        self._latex_symbol_dual = latex_symbol_dual
+        if symbol_dual is None:
+            if isinstance(symbol, (list, tuple)):
+                raise ValueError("symbol_dual must be provided")
+            else:
+                symbol_dual = symbol
+        elif latex_symbol_dual is None:
+            latex_symbol_dual = symbol_dual
+        if latex_symbol_dual is None:
+            latex_symbol_dual = latex_symbol
+        self._dual_basis = type(self)._cobasis_class(self, symbol_dual,
+                                                latex_symbol=latex_symbol_dual,
+                                                indices=indices,
+                                                latex_indices=latex_indices)
 
     ###### Methods to be redefined by derived classes of FreeModuleBasis ######
 
@@ -301,38 +647,35 @@ class FreeModuleBasis(Basis_abstract):
         """
         return "Basis {} on the {}".format(self._name, self._fmodule)
 
-
-    def _init_dual_basis(self):
-        r"""
-        Construct the basis dual to ``self``.
-
-        OUTPUT:
-
-        - instance of :class:`FreeModuleCoBasis` representing the dual of
-          ``self``
-
-        EXAMPLES::
-
-            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
-            sage: e = M.basis('e')
-            sage: e._init_dual_basis()
-            Dual basis (e^0,e^1,e^2) on the Rank-3 free module M over the Integer Ring
-
-        """
-        return FreeModuleCoBasis(self, self._symbol,
-                                 latex_symbol=self._latex_symbol)
-
-    def _new_instance(self, symbol, latex_symbol=None):
+    def _new_instance(self, symbol, latex_symbol=None, indices=None,
+                      latex_indices=None, symbol_dual=None,
+                      latex_symbol_dual=None):
         r"""
         Construct a new basis on the same module as ``self``.
 
         INPUT:
 
-        - ``symbol`` -- string; a letter (of a few letters) to denote a
-          generic element of the basis
-        - ``latex_symbol`` -- (default: ``None``) string; symbol to denote a
-          generic element of the basis; if ``None``, the value of ``symbol``
-          is used
+        - ``symbol`` -- either a string, to be used as a common base for the
+          symbols of the elements of the basis, or a tuple of strings,
+          representing the individual symbols of the elements of the basis
+        - ``latex_symbol`` -- (default: ``None``) either a string, to be used
+          as a common base for the LaTeX symbols of the elements of the basis,
+          or a tuple of strings, representing the individual LaTeX symbols of
+          the elements of the basis; if ``None``, ``symbol`` is used in place
+          of ``latex_symbol``
+        - ``indices`` -- (default: ``None``; used only if ``symbol`` is a
+          single string) tuple of strings representing the indices labelling
+          the elements of the basis; if ``None``, the indices will be generated
+          as integers within the range declared on the free module on which the
+          ``self`` is defined
+        - ``latex_indices`` -- (default: ``None``) tuple of strings
+          representing the indices for the LaTeX symbols of the elements of the
+          basis; if ``None``, ``indices`` is used instead
+        - ``symbol_dual`` -- (default: ``None``) same as ``symbol`` but for the
+          dual basis; if ``None``, ``symbol`` must be a string and is used
+          for the common base of the symbols of the elements of the dual basis
+        - ``latex_symbol_dual`` -- (default: ``None``) same as ``latex_symbol``
+          but for the dual basis
 
         OUTPUT:
 
@@ -344,9 +687,20 @@ class FreeModuleBasis(Basis_abstract):
             sage: e = M.basis('e')
             sage: e._new_instance('f')
             Basis (f_0,f_1,f_2) on the Rank-3 free module M over the Integer Ring
+            sage: e._new_instance(('a', 'b', 'c'), symbol_dual=('A', 'B', 'C'))
+            Basis (a,b,c) on the Rank-3 free module M over the Integer Ring
+            sage: _.dual_basis()
+            Dual basis (A,B,C) on the Rank-3 free module M over the Integer Ring
+            sage: e._new_instance('E', indices=('x', 'y', 'z'))
+            Basis (E_x,E_y,E_z) on the Rank-3 free module M over the Integer Ring
+            sage: _.dual_basis()
+            Dual basis (E^x,E^y,E^z) on the Rank-3 free module M over the Integer Ring
 
         """
-        return FreeModuleBasis(self._fmodule, symbol, latex_symbol=latex_symbol)
+        return FreeModuleBasis(self._fmodule, symbol, latex_symbol=latex_symbol,
+                               indices=indices, latex_indices=latex_indices,
+                               symbol_dual=symbol_dual,
+                               latex_symbol_dual=latex_symbol_dual)
 
     ###### End of methods to be redefined by derived classes ######
 
@@ -410,48 +764,9 @@ class FreeModuleBasis(Basis_abstract):
         """
         return self._dual_basis
 
-    def __getitem__(self, index):
-        r"""
-        Return the basis element corresponding to the given index ``index``.
-
-        INPUT:
-
-        - ``index`` -- the index of the basis element
-
-        EXAMPLES::
-
-            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
-            sage: e = M.basis('e')
-            sage: e.__getitem__(0)
-            Element e_0 of the Rank-3 free module M over the Integer Ring
-            sage: e.__getitem__(1)
-            Element e_1 of the Rank-3 free module M over the Integer Ring
-            sage: e.__getitem__(2)
-            Element e_2 of the Rank-3 free module M over the Integer Ring
-            sage: e[1] is e.__getitem__(1)
-            True
-            sage: e[1].parent() is M
-            True
-            sage: M1 = FiniteRankFreeModule(ZZ, 3, name='M', start_index=1)
-            sage: e1 = M1.basis('e')
-            sage: e1.__getitem__(1)
-            Element e_1 of the Rank-3 free module M over the Integer Ring
-            sage: e1.__getitem__(2)
-            Element e_2 of the Rank-3 free module M over the Integer Ring
-            sage: e1.__getitem__(3)
-            Element e_3 of the Rank-3 free module M over the Integer Ring
-
-        """
-        n = self._fmodule._rank
-        si = self._fmodule._sindex
-        i = index - si
-        if i < 0 or i > n-1:
-            raise ValueError("Index out of range: " +
-                              str(i+si) + " not in [" + str(si) + "," +
-                              str(n-1+si) + "]")
-        return self._vec[i]
-
-    def new_basis(self, change_of_basis, symbol, latex_symbol=None):
+    def new_basis(self, change_of_basis, symbol, latex_symbol=None,
+                  indices=None, latex_indices=None, symbol_dual=None,
+                  latex_symbol_dual=None):
         r"""
         Define a new module basis from ``self``.
 
@@ -464,11 +779,27 @@ class FreeModuleBasis(Basis_abstract):
           describing the automorphism `P` that relates the current basis
           `(e_i)` (described by ``self``) to the new basis `(n_i)` according
           to `n_i = P(e_i)`
-        - ``symbol`` -- string; a letter (of a few letters) to denote a
-          generic element of the basis
-        - ``latex_symbol`` -- (default: ``None``) string; symbol to denote a
-          generic element of the basis; if ``None``, the value of ``symbol``
-          is used
+        - ``symbol`` -- either a string, to be used as a common base for the
+          symbols of the elements of the basis, or a tuple of strings,
+          representing the individual symbols of the elements of the basis
+        - ``latex_symbol`` -- (default: ``None``) either a string, to be used
+          as a common base for the LaTeX symbols of the elements of the basis,
+          or a tuple of strings, representing the individual LaTeX symbols of
+          the elements of the basis; if ``None``, ``symbol`` is used in place
+          of ``latex_symbol``
+        - ``indices`` -- (default: ``None``; used only if ``symbol`` is a
+          single string) tuple of strings representing the indices labelling
+          the elements of the basis; if ``None``, the indices will be generated
+          as integers within the range declared on the free module on which
+          ``self`` is defined
+        - ``latex_indices`` -- (default: ``None``) tuple of strings
+          representing the indices for the LaTeX symbols of the elements of the
+          basis; if ``None``, ``indices`` is used instead
+        - ``symbol_dual`` -- (default: ``None``) same as ``symbol`` but for the
+          dual basis; if ``None``, ``symbol`` must be a string and is used
+          for the common base of the symbols of the elements of the dual basis
+        - ``latex_symbol_dual`` -- (default: ``None``) same as ``latex_symbol``
+          but for the dual basis
 
         OUTPUT:
 
@@ -494,6 +825,17 @@ class FreeModuleBasis(Basis_abstract):
             sage: e[2].display(f)
             e_2 = -2/5 f_1 + 1/5 f_2
 
+        Use of some keyword arguments::
+
+            sage: b = e.new_basis(a, 'b', indices=('x', 'y'),
+            ....:                 symbol_dual=('A', 'B'))
+            sage: b
+            Basis (b_x,b_y) on the 2-dimensional vector space M over the
+             Rational Field
+            sage: b.dual_basis()
+            Dual basis (A,B) on the 2-dimensional vector space M over the
+             Rational Field
+
         """
         from .free_module_automorphism import FreeModuleAutomorphism
         if not isinstance(change_of_basis, FreeModuleAutomorphism):
@@ -502,7 +844,11 @@ class FreeModuleBasis(Basis_abstract):
         fmodule = self._fmodule
         # self._new_instance used instead of FreeModuleBasis for a correct
         # construction in case of derived classes:
-        the_new_basis = self._new_instance(symbol, latex_symbol=latex_symbol)
+        the_new_basis = self._new_instance(symbol, latex_symbol=latex_symbol,
+                                           indices=indices,
+                                           latex_indices=latex_indices,
+                                           symbol_dual=symbol_dual,
+                                           latex_symbol_dual=latex_symbol_dual)
         transf = change_of_basis.copy()
         inv_transf = change_of_basis.inverse().copy()
         si = fmodule._sindex
@@ -514,7 +860,7 @@ class FreeModuleBasis(Basis_abstract):
         # Components of the new dual-basis elements in the old dual basis:
         for i in fmodule.irange():
             for j in fmodule.irange():
-                the_new_basis._dual_basis._form[i-si].add_comp(self)[[j]] = \
+                the_new_basis._dual_basis._vec[i-si].add_comp(self)[[j]] = \
                                               inv_transf.comp(self)[[i,j]]
         # The components of the transformation and its inverse are the same in
         # the two bases:
@@ -531,7 +877,7 @@ class FreeModuleBasis(Basis_abstract):
         # Components of the old dual-basis elements in the new cobasis:
         for i in fmodule.irange():
             for j in fmodule.irange():
-                self._dual_basis._form[i-si].add_comp(the_new_basis)[[j]] = \
+                self._dual_basis._vec[i-si].add_comp(the_new_basis)[[j]] = \
                                                        transf.comp(self)[[i,j]]
         # The automorphism and its inverse are added to the module's dictionary
         # of changes of bases:
@@ -539,136 +885,3 @@ class FreeModuleBasis(Basis_abstract):
         fmodule._basis_changes[(the_new_basis, self)] = inv_transf
         #
         return the_new_basis
-
-#******************************************************************************
-
-class FreeModuleCoBasis(Basis_abstract):
-    r"""
-    Dual basis of a free module over a commutative ring.
-
-    INPUT:
-
-    - ``basis`` -- basis of a free module `M` of which ``self`` is the dual
-      (must be an instance of :class:`FreeModuleBasis`)
-    - ``symbol`` -- a letter (of a few letters) to denote a generic element of
-      the cobasis
-    - ``latex_symbol`` -- (default: ``None``) symbol to denote a generic
-      element of the cobasis; if ``None``, the value of ``symbol`` is used
-
-    EXAMPLES:
-
-    Dual basis on a rank-3 free module::
-
-        sage: M = FiniteRankFreeModule(ZZ, 3, name='M', start_index=1)
-        sage: e = M.basis('e') ; e
-        Basis (e_1,e_2,e_3) on the Rank-3 free module M over the Integer Ring
-        sage: from sage.tensor.modules.free_module_basis import FreeModuleCoBasis
-        sage: f = FreeModuleCoBasis(e, 'f') ; f
-        Dual basis (f^1,f^2,f^3) on the Rank-3 free module M over the Integer Ring
-
-    Let us check that the elements of ``f`` are in the dual of ``M``::
-
-        sage: f[1] in M.dual()
-        True
-        sage: f[1]
-        Linear form f^1 on the Rank-3 free module M over the Integer Ring
-
-    and that ``f`` is indeed the dual of ``e``::
-
-        sage: f[1](e[1]), f[1](e[2]), f[1](e[3])
-        (1, 0, 0)
-        sage: f[2](e[1]), f[2](e[2]), f[2](e[3])
-        (0, 1, 0)
-        sage: f[3](e[1]), f[3](e[2]), f[3](e[3])
-        (0, 0, 1)
-
-    """
-    def __init__(self, basis, symbol, latex_symbol=None):
-        r"""
-        TESTS::
-
-            sage: from sage.tensor.modules.free_module_basis import FreeModuleCoBasis
-            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
-            sage: e = M.basis('e')
-            sage: f = FreeModuleCoBasis(e, 'f')
-            sage: TestSuite(f).run()
-
-        """
-        self._basis = basis
-        self._name = "(" + \
-          ",".join([symbol + "^" + str(i) for i in basis._fmodule.irange()]) +")"
-        if latex_symbol is None:
-            latex_symbol = symbol
-        latex_name = r"\left(" + \
-          ",".join([latex_symbol + "^{" + str(i) + "}"
-                    for i in basis._fmodule.irange()]) + r"\right)"
-
-        Basis_abstract.__init__(self, basis._fmodule, symbol, latex_symbol, latex_name)
-
-        # The individual linear forms:
-        vl = list()
-        for i in self._fmodule.irange():
-            v_name = symbol + "^" + str(i)
-            v_symb = latex_symbol + "^{" + str(i) + "}"
-            v = self._fmodule.linear_form(name=v_name, latex_name=v_symb)
-            for j in self._fmodule.irange():
-                v.set_comp(basis)[j] = 0
-            v.set_comp(basis)[i] = 1
-            vl.append(v)
-        self._form = tuple(vl)
-
-    def _repr_(self):
-        r"""
-        Return a string representation of ``self``.
-
-        EXAMPLES::
-
-            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
-            sage: e = M.basis('e')
-            sage: f = e.dual_basis()
-            sage: f
-            Dual basis (e^0,e^1,e^2) on the
-             Rank-3 free module M over the Integer Ring
-
-        """
-        return "Dual basis {} on the {}".format(self._name, self._fmodule)
-
-    def __getitem__(self, index):
-        r"""
-        Return the basis linear form corresponding to a given index.
-
-        INPUT:
-
-        - ``index`` -- the index of the linear form
-
-        EXAMPLES::
-
-            sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
-            sage: e = M.basis('e')
-            sage: f = e.dual_basis()
-            sage: f[0]
-            Linear form e^0 on the Rank-3 free module M over the Integer Ring
-            sage: f[1]
-            Linear form e^1 on the Rank-3 free module M over the Integer Ring
-            sage: f[2]
-            Linear form e^2 on the Rank-3 free module M over the Integer Ring
-            sage: f[1] is f.__getitem__(1)
-            True
-            sage: M1 = FiniteRankFreeModule(ZZ, 3, name='M', start_index=1)
-            sage: f1 = M1.basis('e').dual_basis()
-            sage: f1[1]
-            Linear form e^1 on the Rank-3 free module M over the Integer Ring
-            sage: f1[2]
-            Linear form e^2 on the Rank-3 free module M over the Integer Ring
-            sage: f1[3]
-            Linear form e^3 on the Rank-3 free module M over the Integer Ring
-
-        """
-        n = self._fmodule._rank
-        si = self._fmodule._sindex
-        i = index - si
-        if i < 0 or i > n-1:
-            raise IndexError("out of range: {} not in [{},{}]".format(i+si,
-                                                                   si, n-1+si))
-        return self._form[i]
-
