@@ -52,6 +52,20 @@ class UnicodeArt(CharacterArt):
     """
     _string_type = text_type
 
+    def __unicode__(self):
+        r"""
+        Return a unicode representation of ``self``.
+
+        EXAMPLES::
+
+            sage: i = var('i')
+            sage: ua = unicode_art(sum(pi^i/factorial(i)*x^i, i, 0, oo))
+            sage: unicode(ua)  # py2
+            u' \u03c0\u22c5x\n\u212f   '
+            sage: str(ua)  # py3
+            ' \u03c0\u22c5x\n\u212f   '
+        """
+        return repr(self).decode("utf-8")
 
 _unicode_art_factory = CharacterArtFactory(
     UnicodeArt, text_type, '_unicode_art_',
@@ -74,11 +88,15 @@ def unicode_art(*obj, **kwds):
     - ``*obj`` -- any number of positional arguments, of arbitrary
       type. The objects whose ascii art representation we want.
 
-    - ``sep`` -- optional ``'sep=...'`` keyword argument. Anything
-      that can be converted to unicode art (default: empty unicode
+    - ``sep`` -- optional ``'sep=...'`` keyword argument (or ``'separator'``).
+      Anything that can be converted to unicode art (default: empty unicode
       art). The separator in-between a list of objects. Only used if
       more than one object given.
 
+    - ``baseline`` -- (default: 0) the baseline for the object
+
+    - ``sep_baseline`` -- (default: 0) the baseline for the separator
+
     OUTPUT:
 
     :class:`UnicodeArt` instance.
@@ -98,6 +116,18 @@ def unicode_art(*obj, **kwds):
               ⎛1 0⎞   ⎜0 1 0⎟
         (1) : ⎝0 1⎠ : ⎝0 0 1⎠
 
+    If specified, the ``sep_baseline`` overrides the baseline of
+    an unicode art separator::
+
+        sage: sep_line = unicode_art('\n'.join(u' ⎟ ' for _ in range(5)), baseline=5)
+        sage: unicode_art(*AlternatingSignMatrices(3),
+        ....:             separator=sep_line, sep_baseline=1)
+                ⎟         ⎟         ⎟            ⎟         ⎟         ⎟ 
+        ⎛1 0 0⎞ ⎟ ⎛0 1 0⎞ ⎟ ⎛1 0 0⎞ ⎟ ⎛ 0  1  0⎞ ⎟ ⎛0 0 1⎞ ⎟ ⎛0 1 0⎞ ⎟ ⎛0 0 1⎞
+        ⎜0 1 0⎟ ⎟ ⎜1 0 0⎟ ⎟ ⎜0 0 1⎟ ⎟ ⎜ 1 -1  1⎟ ⎟ ⎜1 0 0⎟ ⎟ ⎜0 0 1⎟ ⎟ ⎜0 1 0⎟
+        ⎝0 0 1⎠ ⎟ ⎝0 0 1⎠ ⎟ ⎝0 1 0⎠ ⎟ ⎝ 0  1  0⎠ ⎟ ⎝0 1 0⎠ ⎟ ⎝1 0 0⎠ ⎟ ⎝1 0 0⎠
+                ⎟         ⎟         ⎟            ⎟         ⎟         ⎟ 
+
     TESTS::
 
         sage: n = var('n')
@@ -114,12 +144,18 @@ def unicode_art(*obj, **kwds):
         sage: unicode_art(1)
         1
     """
-    separator = kwds.pop('sep', empty_unicode_art)
+    separator, baseline, sep_baseline = _unicode_art_factory.parse_keywords(kwds)
     if kwds:
         raise ValueError('unknown keyword arguments: {0}'.format(list(kwds)))
     if len(obj) == 1:
-        return _unicode_art_factory.build(obj[0])
+        return _unicode_art_factory.build(obj[0], baseline=baseline)
     if not isinstance(separator, UnicodeArt):
-        separator = _unicode_art_factory.build(separator)
+        separator = _unicode_art_factory.build(separator, baseline=sep_baseline)
+    elif sep_baseline is not None:
+        from copy import copy
+        separator = copy(separator)
+        separator._baseline = sep_baseline
     obj = map(_unicode_art_factory.build, obj)
-    return _unicode_art_factory.concatenate(obj, separator, empty_unicode_art)
+    return _unicode_art_factory.concatenate(obj, separator, empty_unicode_art,
+                                            baseline=baseline)
+
