@@ -88,8 +88,7 @@ def _find_stale_files(site_packages, python_packages, python_modules, ext_module
         sage: python_packages, python_modules = find_python_sources(
         ....:     SAGE_SRC, ['sage', 'sage_setup'])
         sage: extra_files = list(find_extra_files(SAGE_SRC,
-        ....:     ['sage', 'sage_setup'], cythonized_dir,
-        ....:     ["ntlwrap.cpp"]).items())
+        ....:     ['sage', 'sage_setup'], cythonized_dir, []).items())
         sage: from sage_setup.clean import _find_stale_files
 
     TODO: move ``module_list.py`` into ``sage_setup`` and also check
