@@ -265,35 +265,29 @@ class DocBuilder(object):
     # import the customized builder for object.inv files
     inventory = builder_helper('inventory')
 
-if NUM_THREADS > 1:
-    def build_many(target, args):
-        from multiprocessing import Pool
-        pool = Pool(NUM_THREADS, maxtasksperchild=1)
-        # map_async handles KeyboardInterrupt correctly. Plain map and
-        # apply_async does not, so don't use it.
-        x = pool.map_async(target, args, 1)
-        try:
-            ret = x.get(99999)
-            pool.close()
-            pool.join()
-        except Exception:
-            pool.terminate()
-            if ABORT_ON_ERROR:
-                raise
-        return ret
-else:
-    def build_many(target, args):
-        results = []
-
-        for arg in args:
-            try:
-                results.append(target(arg))
-            except Exception:
-                if ABORT_ON_ERROR:
-                    raise
-
-        return results
-
+def build_many(target, args):
+    # Pool() uses an actual fork() to run each new instance. This is important
+    # for performance reasons, i.e., don't use a forkserver when it becomes
+    # available with Python 3: Here, sage is already initialized which is quite
+    # costly, with a forkserver we would have to reinitialize it for every
+    # document we build. At the same time, don't serialize this by taking the
+    # pool (and thus the call to fork()) out completely: The call to Sphinx
+    # leaks memory, so we need to build each document in its own process to
+    # control the RAM usage.
+    from multiprocessing import Pool
+    pool = Pool(NUM_THREADS, maxtasksperchild=1)
+    # map_async handles KeyboardInterrupt correctly. Plain map and
+    # apply_async does not, so don't use it.
+    x = pool.map_async(target, args, 1)
+    try:
+        ret = x.get(99999)
+        pool.close()
+        pool.join()
+    except Exception:
+        pool.terminate()
+        if ABORT_ON_ERROR:
+            raise
+    return ret
 
 ##########################################
 #      Parallel Building Ref Manual      #
@@ -599,7 +593,7 @@ class ReferenceBuilder(AllBuilder):
                 #
                 #   <a href="module/module.pdf">blah <img src="_static/pdf.png" /></a>
                 #
-                rst = re.sub('`([^`]*)`__\.\n\n__ (.*)',
+                rst = re.sub(r'`([^`]*)`__\.\n\n__ (.*)',
                                   r'<a href="\2">\1</a>.', rst)
                 rst = re.sub(r':doc:`([^<]*?)\s+<(.*)/index>`',
                              r'<a href="\2/\2.pdf">\1 <img src="_static/pdf.png" /></a>',
@@ -940,7 +934,12 @@ class ReferenceSubBuilder(DocBuilder):
             except ImportError as err:
                 logger.error("Warning: Could not import %s %s", module_name, err)
                 raise
-            newtime = os.path.getmtime(sys.modules[module_name].__file__)
+
+            module_filename = sys.modules[module_name].__file__
+            if (module_filename.endswith('.pyc') or module_filename.endswith('.pyo')):
+                source_filename = module_filename[:-1]
+                if (os.path.exists(source_filename)): module_filename = source_filename
+            newtime = os.path.getmtime(module_filename)
 
             if newtime > mtime:
                 updated_modules.append(module_name)
@@ -978,7 +977,7 @@ class ReferenceSubBuilder(DocBuilder):
         all of the autogenerated reST files that it includes.
         """
         #Create the regular expression used to detect an autogenerated file
-        auto_re = re.compile('^\s*(..\/)*(sage(nb)?\/[\w\/]*)\s*$')
+        auto_re = re.compile(r'^\s*(..\/)*(sage(nb)?\/[\w\/]*)\s*$')
 
         #Read the lines
         f = open(filename)
@@ -1124,6 +1123,7 @@ class ReferenceSubBuilder(DocBuilder):
         for module_name in self.get_all_included_modules():
             print(module_name)
 
+
 class SingleFileBuilder(DocBuilder):
     """
     This is the class used to build the documentation for a single
@@ -1413,6 +1413,7 @@ def help_message_long(option, opt_str, value, parser):
         print(f())
     sys.exit(0)
 
+
 def help_message_short(option=None, opt_str=None, value=None, parser=None,
                        error=False):
     """
@@ -1423,13 +1424,14 @@ def help_message_short(option=None, opt_str=None, value=None, parser=None,
     requested a list (e.g., documents, formats, commands).
     """
     if not hasattr(parser.values, 'printed_help'):
-        if error == True:
+        if error is True:
             if not hasattr(parser.values, 'printed_list'):
                 parser.print_help()
         else:
             parser.print_help()
         setattr(parser.values, 'printed_help', 1)
 
+
 def help_wrapper(option, opt_str, value, parser):
     """
     A helper wrapper for command-line options to the Sage
